(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1138730,      30376]
NotebookOptionsPosition[   1055870,      29082]
NotebookOutlinePosition[   1056242,      29098]
CellTagsIndexPosition[   1056199,      29095]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.79515500425712*^9, 3.7951550386803713`*^9}, 
   3.795165870221341*^9},ExpressionUUID->"14421c1c-57e8-4218-bb57-\
d9d540f4628a"],

Cell[BoxData[
 RowBox[{"<<", "TripleK`"}]], "Input",
 CellChangeTimes->{{3.781711824066417*^9, 3.7817118319345713`*^9}, 
   3.7951870553132625`*^9},ExpressionUUID->"c2e79324-f909-450e-95ba-\
52618b29cd11"],

Cell[BoxData[
 RowBox[{"<<", "Konformal`"}]], "Input",
 CellChangeTimes->{{3.795187050218255*^9, 
  3.7951870587932673`*^9}},ExpressionUUID->"ab2417f3-5435-41ee-8f05-\
92faa1c3bcfa"],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.796742039262443*^9, 
  3.796742042078156*^9}},ExpressionUUID->"1f3612d0-22e2-42e8-a7f0-\
0c2d8e802e7a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"$Assumptions", "===", "True"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Mu]", ">", "0"}], "}"}], ",", 
     RowBox[{"Union", "[", 
      RowBox[{"$Assumptions", ",", 
       RowBox[{"{", 
        RowBox[{"\[Mu]", ">", "0"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.796977394703092*^9, 
  3.796977426815689*^9}},ExpressionUUID->"5bdee2b6-13eb-4650-a506-\
536006e7f2f7"],

Cell["Symmetric polynomials in momenta magnitudes.", "Text",
 CellChangeTimes->{{3.798507635099196*^9, 
  3.798507644155242*^9}},ExpressionUUID->"6dca54c3-3032-454a-810d-\
d42f45540f24"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PolExpand", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"a123", "\[Rule]", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "+", 
       RowBox[{"p", "[", "2", "]"}], "+", 
       RowBox[{"p", "[", "3", "]"}]}]}], ",", 
     RowBox[{"a12", "\[Rule]", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "+", 
       RowBox[{"p", "[", "2", "]"}]}]}], ",", 
     RowBox[{"a13", "\[Rule]", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "+", 
       RowBox[{"p", "[", "3", "]"}]}]}], ",", 
     RowBox[{"a23", "\[Rule]", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "+", 
       RowBox[{"p", "[", "3", "]"}]}]}], ",", 
     RowBox[{"b12", "\[Rule]", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], 
       RowBox[{"p", "[", "2", "]"}]}]}], ",", 
     RowBox[{"b13", "\[Rule]", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], 
       RowBox[{"p", "[", "3", "]"}]}]}], ",", 
     RowBox[{"b23", "\[Rule]", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], 
       RowBox[{"p", "[", "3", "]"}]}]}], ",", 
     RowBox[{"b123", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], 
        RowBox[{"p", "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], 
        RowBox[{"p", "[", "3", "]"}]}], "+", 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], 
        RowBox[{"p", "[", "3", "]"}]}]}]}], ",", 
     RowBox[{"c123", "\[Rule]", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], 
       RowBox[{"p", "[", "2", "]"}], 
       RowBox[{"p", "[", "3", "]"}]}]}]}], " ", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.696663735390913*^9, 
  3.69666378530612*^9}},ExpressionUUID->"6006c93b-3e30-4949-9d0b-\
da04d735224d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"logsu", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"x_", "*", "y_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"Log", "[", "x", "]"}], "+", 
       RowBox[{"Log", "[", "y", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"x_", "/", "y_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"Log", "[", "x", "]"}], "/", 
       RowBox[{"Log", "[", "y", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"x_", "^", "n_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"n", " ", 
       RowBox[{"Log", "[", "x", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"1", "/", "x_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"-", 
       RowBox[{"Log", "[", "x", "]"}]}]}]}], " ", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.796744281113373*^9, 
  3.796744299192423*^9}},ExpressionUUID->"d17054ad-5e10-45f6-89ca-\
f13acf7f4529"],

Cell["Applies CWIs to expressions and various simplifications.", "Text",
 CellChangeTimes->{{3.798507601467115*^9, 
  3.7985076194430027`*^9}},ExpressionUUID->"40eab396-6e6e-458c-a67f-\
fbf069198059"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Scaling", "[", 
    RowBox[{"Dims_", ",", "N_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "+", 
     RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "+", 
     RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "-", 
     RowBox[{"2", "d"}], "-", "N"}], "/.", "Dims"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7967435052213373`*^9, 
  3.796743514747582*^9}},ExpressionUUID->"ba584ccf-c8a4-4895-9cee-\
20f5588dddc7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ApplyDmu", "[", "As_", "]"}], ":=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", "n", "]"}], "/.", "As"}], ",", "\[Mu]"}], "]"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"Length", "[", "As", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",\
ExpressionUUID->"1f593d72-d52e-4e44-aa99-9a72a1a34e8b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"suAsFun", "[", "As_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "j", "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"A", "[", "j", "]"}], "[", 
         RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", "j", "]"}], "/.", "As"}], "/.", "PolExpand"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "\[Rule]", "p1"}], ",", 
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "\[Rule]", "p2"}], ",", 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "\[Rule]", "p3"}]}], "}"}]}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", 
         RowBox[{"Length", "[", "As", "]"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.796742755793078*^9, 3.796742819751321*^9}, {
  3.796742860496418*^9, 3.796742882627726*^9}, {3.7967429486418533`*^9, 
  3.796742975734942*^9}},ExpressionUUID->"9089bb95-f89b-4d16-8f65-\
0446df494a62"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{"X_", ",", "As_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"ReleaseHold", "[", 
     RowBox[{
      RowBox[{"X", "/.", 
       RowBox[{"suExpandAs", "[", "A", "]"}]}], "/.", 
      RowBox[{"suAsFun", "[", "As", "]"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"KExpand", "[", 
      RowBox[{"#", ",", " ", 
       RowBox[{"Level", "\[Rule]", "D"}]}], "]"}], "&"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{"X_", ",", "As_", ",", "Dims_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"ApplyCWIs", "[", 
     RowBox[{"X", ",", "As"}], "]"}], "/.", "Dims"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7967428244023037`*^9, 3.796742837118331*^9}, {
   3.796742896335079*^9, 3.796742912051106*^9}, {3.796742997865231*^9, 
   3.7967431012795486`*^9}, {3.796743163145136*^9, 3.796743164175955*^9}, {
   3.7967435859631033`*^9, 3.796743602287644*^9}, {3.796978069559971*^9, 
   3.796978071384794*^9}, {3.796978200468626*^9, 3.796978201448758*^9}, {
   3.796980084115602*^9, 3.796980086778021*^9}, {3.7975332544956083`*^9, 
   3.7975332590466146`*^9}, {3.7975392280466366`*^9, 
   3.7975392331478453`*^9}, {3.798418741714695*^9, 3.798418744633218*^9}, 
   3.798420269541051*^9},ExpressionUUID->"49e7340b-1e0b-4fff-882b-\
debf6a116e38"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ApplyTWIs", "[", 
    RowBox[{"X_", ",", "Dims_", ",", " ", 
     RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"ReleaseHold", "[", 
     RowBox[{
      RowBox[{"SecondaryCWIsRhs", "[", "X", "]"}], "/.", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"TransverseWIs", "[", 
         RowBox[{"X", ",", " ", "opts"}], "]"}], "/.", "Dims"}], ")"}]}], 
     "]"}], "/.", "Dims"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.796977859883155*^9, 3.79697789336036*^9}, {
  3.796977934571431*^9, 3.796977936088313*^9}, {3.796978608316558*^9, 
  3.7969786160170517`*^9}, {3.7969824298438272`*^9, 3.796982442619697*^9}, {
  3.796982506052862*^9, 
  3.796982508119629*^9}},ExpressionUUID->"31c6f2d4-bfd3-454a-9886-\
fee78dec48ab"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ByParts", "[", "Exp_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "tmp", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tmp", "=", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"KExpand", "[", 
          RowBox[{"Exp", ",", " ", 
           RowBox[{"Level", "\[Rule]", "\[Lambda]"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"NL", "[", "x___", "]"}], "\[RuleDelayed]", 
           RowBox[{"NL", "[", 
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], ",", 
             RowBox[{"p", "[", "2", "]"}], ",", 
             RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"NL", "[", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], ",", 
          RowBox[{"p", "[", "2", "]"}], ",", 
          RowBox[{"p", "[", "3", "]"}]}], "]"}], "*", 
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"tmp", ",", 
            RowBox[{"NL", "[", 
             RowBox[{
              RowBox[{"p", "[", "1", "]"}], ",", 
              RowBox[{"p", "[", "2", "]"}], ",", 
              RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "]"}], "//.", 
          "logsu"}], "]"}]}], "+", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tmp", "/.", 
           RowBox[{
            RowBox[{"NL", "[", 
             RowBox[{
              RowBox[{"p", "[", "1", "]"}], ",", 
              RowBox[{"p", "[", "2", "]"}], ",", 
              RowBox[{"p", "[", "3", "]"}]}], "]"}], "\[Rule]", "0"}]}], 
          ")"}], "//.", "logsu"}], "]"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SimplifyCWIs", "[", "Exp_", "]"}], ":=", 
   RowBox[{"ByParts", "/@", "Exp"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.796744225497851*^9, 3.796744250497725*^9}, 
   3.796744584467062*^9, {3.79674462361668*^9, 3.7967446244692087`*^9}, {
   3.796745492185807*^9, 3.796745498649394*^9}, {3.79697705201928*^9, 
   3.7969770537451687`*^9}, {3.797533247054598*^9, 3.797533251185604*^9}, {
   3.797539182362756*^9, 3.79753918479636*^9}, {3.798418750267*^9, 
   3.798418752579344*^9}},ExpressionUUID->"911f0882-1d84-4160-a8bd-\
a609ff159545"],

Cell[TextData[{
 "Expressions used in writing down closed form expressions for 3-point \
function in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "=", "4"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "08550ce1-d7e1-4ade-98df-9f1add7c480e"],
 "."
}], "Text",
 CellChangeTimes->{{3.798507564386462*^9, 
  3.798507592012169*^9}},ExpressionUUID->"da75c4c0-d852-45cc-a530-\
322cf0e6ebb8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MRed", "[", 
     RowBox[{"j_", ",", "\[Beta]_"}], "]"}], "[", "F_", "]"}], ":=", 
   RowBox[{
    RowBox[{"2", " ", "\[Beta]", " ", "F"}], "-", 
    RowBox[{
     RowBox[{"p", "[", "j", "]"}], " ", 
     RowBox[{"D", "[", 
      RowBox[{"F", ",", 
       RowBox[{"p", "[", "j", "]"}]}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.79697747917605*^9, 
  3.796977479672076*^9}},ExpressionUUID->"9b1c9588-da9e-47d1-974c-\
d98069d8c061"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"J2", "=", 
   RowBox[{
    RowBox[{"-", "\[Lambda]"}], "//", "KFullExpand"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i1000", "=", 
   RowBox[{
    RowBox[{"KEvaluate", "[", 
     RowBox[{"i", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], "]"}], "//", 
    "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i2111fin", "=", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
     RowBox[{
      RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "J2"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"3", "/", "2"}], ")"}]}]}], " ", 
     RowBox[{"NL", "[", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], ",", 
       RowBox[{"p", "[", "2", "]"}], ",", 
       RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"6", "J2"}], ")"}]}], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "-", 
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "4"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "]"}]}], 
       "+", 
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "-", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "4"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "]"}]}], 
       "+", 
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "4"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}]}], "]"}]}]}], 
      " ", ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i3222fin", "=", 
   RowBox[{
    RowBox[{"MRed", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "[", 
    RowBox[{
     RowBox[{"MRed", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", 
     RowBox[{
      RowBox[{"MRed", "[", 
       RowBox[{"3", ",", "1"}], "]"}], "[", 
      RowBox[{
       RowBox[{"1", "/", "4"}], " ", "J2", " ", "i1000"}], "]"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.796977480659025*^9, 3.796977501943885*^9}, {
  3.7969777736800222`*^9, 3.796977777947143*^9}, {3.7969793338271837`*^9, 
  3.7969793341074*^9}, {3.796980695540702*^9, 3.7969806963677197`*^9}, {
  3.7984187976182337`*^9, 
  3.7984187980892277`*^9}},ExpressionUUID->"a7bd4255-d2cb-4964-8ee6-\
ded60df42a88"],

Cell["Numerics:", "Text",
 CellChangeTimes->{{3.798507554931274*^9, 
  3.798507556292201*^9}},ExpressionUUID->"80d99238-d9ab-4c7a-a4b7-\
8f609f87487e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Aaa", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "\[Rule]", "4.5"}], ",", 
     RowBox[{
      RowBox[{"p", "[", "2", "]"}], "\[Rule]", "6.7"}], ",", 
     RowBox[{
      RowBox[{"p", "[", "3", "]"}], "\[Rule]", "3.3"}], ",", " ", 
     RowBox[{"\[Mu]", "\[Rule]", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KillZero", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x_", "\[RuleDelayed]", 
      RowBox[{"0", "/;", 
       RowBox[{
        RowBox[{"Abs", "[", "x", "]"}], "<", 
        RowBox[{"N", "[", 
         RowBox[{"10", "^", 
          RowBox[{"(", 
           RowBox[{"-", "7"}], ")"}]}], "]"}]}]}]}], ",", 
     RowBox[{"x_", "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"Re", "[", "x", "]"}], "/;", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"Im", "[", "x", "]"}], "]"}], "<", 
        RowBox[{"N", "[", 
         RowBox[{"10", "^", 
          RowBox[{"(", 
           RowBox[{"-", "7"}], ")"}]}], "]"}]}]}]}], ",", 
     RowBox[{"x_", "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"I", " ", 
        RowBox[{"Im", "[", "x", "]"}]}], "/;", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"Re", "[", "x", "]"}], "]"}], "<", 
        RowBox[{"N", "[", 
         RowBox[{"10", "^", 
          RowBox[{"(", 
           RowBox[{"-", "7"}], ")"}]}], "]"}]}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.79698001862877*^9, 
  3.796980019674284*^9}},ExpressionUUID->"a2370107-3466-4ff3-92f6-\
ca119716a189"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NumEval", "[", "Exp_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "/.", "Aaa"}], "//.", "logsu"}], "/.", "KillZero"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "cO", ",", "cJ", ",", "cT", ",", 
        RowBox[{"cO", "[", "0", "]"}], ",", 
        RowBox[{"cJ", "[", "0", "]"}], ",", 
        RowBox[{"cT", "[", "0", "]"}], ",", "\[Gamma]", ",", "\[Gamma]1", ",",
         "\[Gamma]2"}], "}"}], ",", "Simplify"}], "]"}], "/.", "KillZero"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.7969798068178167`*^9, 3.7969798108895206`*^9}, {
   3.7969808020289383`*^9, 3.796980822659031*^9}, {3.796980859306253*^9, 
   3.796980968100224*^9}, {3.7975332747966366`*^9, 3.7975332881596556`*^9}, 
   3.7975333908408003`*^9, {3.7975392483648725`*^9, 3.7975392652939024`*^9}, {
   3.7975394111105614`*^9, 3.7975394116409616`*^9}, {3.798418815610712*^9, 
   3.7984188568196*^9}, {3.7984207622979527`*^9, 
   3.79842078460505*^9}},ExpressionUUID->"fe395b7a-9395-4566-bf7c-\
3f7570fec166"]
}, Closed]],

Cell[CellGroupData[{

Cell["<JOO>", "Section",
 CellChangeTimes->{{3.696662757712263*^9, 3.696662759359742*^9}, {
  3.6973649446053753`*^9, 
  3.6973649458531427`*^9}},ExpressionUUID->"42c7f3cc-eb5c-4c6f-b45d-\
7230e8f23871"],

Cell[CellGroupData[{

Cell["d=3, \[CapitalDelta]=1", "Subsection",
 CellChangeTimes->{{3.696663690437581*^9, 3.6966636937738028`*^9}, {
  3.696683327400281*^9, 
  3.6966833280002623`*^9}},ExpressionUUID->"606c999d-b12b-4657-94e8-\
277503ba5552"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "g", " ", "TR", " ", 
      RowBox[{"cO", "/", 
       RowBox[{"(", 
        RowBox[{"b23", " ", "a123"}], ")"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "1"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 
  3.696676380531411*^9}},ExpressionUUID->"792d4662-4ff2-4a2e-8677-\
27a2f5f18fe0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677607964088*^9, 
  3.6966776258540688`*^9}},ExpressionUUID->"4d67d8de-a3b1-454a-808c-\
2364bac5891a"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{
  3.696677627230453*^9, 3.6966776623071833`*^9, 3.696678324117044*^9, 
   3.696679200338336*^9, 3.696683200850745*^9, {3.696683295750228*^9, 
   3.696683329467083*^9}, 3.6966834708348494`*^9, 3.696759731832218*^9, 
   3.7448152305530834`*^9, 3.744815887046633*^9, 3.7448162555497103`*^9, 
   3.744816506147043*^9, 3.74481692272087*^9, 3.7967423073062773`*^9, 
   3.796743863271967*^9, 3.7969708550549173`*^9, 3.796971135197287*^9, 
   3.7969712223106337`*^9, 3.7969766357522507`*^9, 3.796976779890353*^9, 
   3.7969768870723257`*^9, 3.796977956348523*^9, 3.797533230022574*^9, 
   3.797533406273822*^9, 3.7975339249576063`*^9, 3.7984187188302526`*^9, 
   3.798418932513916*^9, 3.7984190296456623`*^9, 3.798419495154031*^9, 
   3.79868592612698*^9, 
   3.799037737934291*^9},ExpressionUUID->"8ede1066-d241-4900-9379-\
e3a8509831eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JOO", "]"}], ",", "As"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", "Dims"}]}], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796742325054669*^9, 3.796742325302929*^9}, {3.7967431716996403`*^9, 
  3.7967431955835533`*^9}, {3.7969708598475657`*^9, 
  3.796970900287465*^9}},ExpressionUUID->"826861a2-89e6-48d3-a464-\
8f337301f850"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", "cO", " ", "g", " ", "TR", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["p", "3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "d", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "1", "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["p", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["p", "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["p", "3"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "d", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "3", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "d", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "3", "]"}]}]}], ")"}]}]}], 
        ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["p", "1"], " ", 
       SubscriptBox["p", "2"], " ", 
       SubsuperscriptBox["p", "3", "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["p", "1"], "+", 
          SubscriptBox["p", "2"], "+", 
          SubscriptBox["p", "3"]}], ")"}], "2"]}], ")"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SubsuperscriptBox["p", "2", "3"], " ", 
        SubsuperscriptBox["p", "3", "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["p", "1"], "+", 
           SubscriptBox["p", "2"], "+", 
           SubscriptBox["p", "3"]}], ")"}], "2"]}]], 
      RowBox[{"2", " ", "cO", " ", "g", " ", "TR", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["p", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "d", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "2", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["p", "3", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "d", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "2", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["p", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubsuperscriptBox["p", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", "d", "+", 
               RowBox[{"2", " ", 
                RowBox[{"\[CapitalDelta]", "[", "2", "]"}]}]}], ")"}]}], "+", 
            
            RowBox[{
             SubsuperscriptBox["p", "2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "d", "-", 
               RowBox[{"2", " ", 
                RowBox[{"\[CapitalDelta]", "[", "3", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["p", "2", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "d", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "3", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["p", "2", "2"], " ", 
          SubscriptBox["p", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "d", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "3", "]"}]}]}], ")"}]}]}], 
        ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", "cO", " ", "g", " ", "TR", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "d", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "1", "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["p", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["p", "2"]}], "+", 
            SubscriptBox["p", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "d", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "2", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "d", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalDelta]", "[", "2", "]"}]}]}], ")"}]}]}], 
        ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["p", "1"], " ", 
       SubsuperscriptBox["p", "2", "3"], " ", 
       SubscriptBox["p", "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["p", "1"], "+", 
          SubscriptBox["p", "2"], "+", 
          SubscriptBox["p", "3"]}], ")"}], "2"]}], ")"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, 3.696683202562179*^9, {
   3.696683296700439*^9, 3.696683329837998*^9}, 3.696683471481494*^9, 
   3.696759740266357*^9, 3.744815231578142*^9, 3.7448158874306545`*^9, 
   3.744816255874728*^9, 3.7448165065130644`*^9, 3.7448169233019032`*^9, {
   3.796743179725998*^9, 3.796743195892536*^9}, 3.796743614505616*^9, 
   3.796743864001227*^9, {3.796970855426289*^9, 3.796970882463916*^9}, 
   3.796971103679496*^9, 3.796971141921343*^9, 3.796971223403983*^9, 
   3.7969712983360987`*^9, 3.796976640251264*^9, 3.796976780259726*^9, 
   3.796976888138268*^9, 3.796977957839643*^9, 3.797533230952575*^9, 
   3.7975334072638235`*^9, {3.7975339299476132`*^9, 3.7975339477596383`*^9}, 
   3.798418719263896*^9, 3.798418932890482*^9, 3.7984190299883423`*^9, 
   3.798419495406309*^9, 3.798685926356993*^9, 
   3.799037738239088*^9},ExpressionUUID->"c86664e2-9c0b-4f32-904d-\
9770a56be4fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, 3.696683202562179*^9, {
   3.696683296700439*^9, 3.696683329837998*^9}, 3.696683471481494*^9, 
   3.696759740266357*^9, 3.744815231578142*^9, 3.7448158874306545`*^9, 
   3.744816255874728*^9, 3.7448165065130644`*^9, 3.7448169233019032`*^9, {
   3.796743179725998*^9, 3.796743195892536*^9}, 3.796743614505616*^9, 
   3.796743864001227*^9, {3.796970855426289*^9, 3.796970882463916*^9}, 
   3.796971103679496*^9, 3.796971141921343*^9, 3.796971223403983*^9, 
   3.7969712983360987`*^9, 3.796976640251264*^9, 3.796976780259726*^9, 
   3.796976888138268*^9, 3.796977957839643*^9, 3.797533230952575*^9, 
   3.7975334072638235`*^9, {3.7975339299476132`*^9, 3.7975339477596383`*^9}, 
   3.798418719263896*^9, 3.798418932890482*^9, 3.7984190299883423`*^9, 
   3.798419495406309*^9, 3.798685926356993*^9, 
   3.7990377382421227`*^9},ExpressionUUID->"8474b5d3-fd5a-431c-9f4b-\
d29fa2db4360"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JOO", "]"}], ",", "As", ",", " ", 
    "Dims"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JOO", ",", "Dims"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", 
    RowBox[{"cO", " ", "g", " ", "TR"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", "%%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.796976660932061*^9, 3.796976693125423*^9}, 
   3.796976788212955*^9, {3.79697689625279*^9, 3.796976924611396*^9}, {
   3.7969779175572453`*^9, 
   3.796977951792377*^9}},ExpressionUUID->"5d294889-21ee-40df-bd27-\
3d1561e2e5aa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", " ", "cO", " ", "g", " ", "TR", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       SubscriptBox["p", "2"]]}], "+", 
     FractionBox["1", 
      SubscriptBox["p", "3"]]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.796976657550275*^9, 3.796976689498765*^9}, {
   3.796976780517549*^9, 3.796976788591937*^9}, {3.796976890288094*^9, 
   3.796976924892078*^9}, {3.796977953091016*^9, 3.796977958752858*^9}, 
   3.797533408573825*^9, 3.7975339490796404`*^9, 3.7984187193302507`*^9, 
   3.79841893293038*^9, 3.798419030046399*^9, 3.798419495450428*^9, 
   3.7986859263829947`*^9, 
   3.799037738276164*^9},ExpressionUUID->"af15fc94-3edb-4aa3-a3c8-\
8156a3dba386"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"cO", " ", "g", " ", "TR"}], 
       SubscriptBox["p", "2"]]}], "+", 
     FractionBox[
      RowBox[{"cO", " ", "g", " ", "TR"}], 
      SubscriptBox["p", "3"]]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.796976657550275*^9, 3.796976689498765*^9}, {
   3.796976780517549*^9, 3.796976788591937*^9}, {3.796976890288094*^9, 
   3.796976924892078*^9}, {3.796977953091016*^9, 3.796977958752858*^9}, 
   3.797533408573825*^9, 3.7975339490796404`*^9, 3.7984187193302507`*^9, 
   3.79841893293038*^9, 3.798419030046399*^9, 3.798419495450428*^9, 
   3.7986859263829947`*^9, 
   3.7990377382784443`*^9},ExpressionUUID->"bdff51da-0287-4e6a-b621-\
80b3b244eb1f"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.796976657550275*^9, 3.796976689498765*^9}, {
   3.796976780517549*^9, 3.796976788591937*^9}, {3.796976890288094*^9, 
   3.796976924892078*^9}, {3.796977953091016*^9, 3.796977958752858*^9}, 
   3.797533408573825*^9, 3.7975339490796404`*^9, 3.7984187193302507`*^9, 
   3.79841893293038*^9, 3.798419030046399*^9, 3.798419495450428*^9, 
   3.7986859263829947`*^9, 
   3.799037738280157*^9},ExpressionUUID->"dcf606d7-8fb5-4f10-b449-\
844570d942f0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"c11b6fdb-6d36-4485-bdd1-\
63c4b84f6ab4"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169096141205`*^9, 
  3.7448169134623404`*^9}},ExpressionUUID->"e28f5806-8724-49ca-912b-\
654b11955428"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "3"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "3"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "3"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
   3.744816914663409*^9, 3.744816917912595*^9}, {3.744817149728854*^9, 
   3.744817154641135*^9}, 
   3.7967435536881227`*^9},ExpressionUUID->"3c5a1c74-9fc0-4bd8-8855-\
42311963ec0c"],

Cell[BoxData[
 RowBox[{"-", "3"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.744816928384194*^9, 3.7448170956417603`*^9, {
   3.744817145725625*^9, 3.7448171550661592`*^9}, 3.796743440510624*^9, 
   3.796743555625091*^9, 3.796743617635991*^9, 3.79674386801355*^9, 
   3.7969769340308447`*^9, 3.796977961005286*^9, 3.7975334110038285`*^9, 
   3.798418719353023*^9, 3.798418932999309*^9, 3.7984190300648823`*^9, 
   3.798419495465534*^9, 3.798685926408996*^9, 
   3.7990377382926188`*^9},ExpressionUUID->"a5fdf699-6f85-4d47-8020-\
9a8ef77bf015"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"c", "[", "1", "]"}], 
     SubsuperscriptBox["p", "1", "3"]], "+", 
    FractionBox[
     RowBox[{"c", "[", "2", "]"}], 
     SubsuperscriptBox["p", "2", "3"]], "+", 
    FractionBox[
     RowBox[{"c", "[", "3", "]"}], 
     SubsuperscriptBox["p", "3", "3"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.744816928384194*^9, 3.7448170956417603`*^9, {
   3.744817145725625*^9, 3.7448171550661592`*^9}, 3.796743440510624*^9, 
   3.796743555625091*^9, 3.796743617635991*^9, 3.79674386801355*^9, 
   3.7969769340308447`*^9, 3.796977961005286*^9, 3.7975334110038285`*^9, 
   3.798418719353023*^9, 3.798418932999309*^9, 3.7984190300648823`*^9, 
   3.798419495465534*^9, 3.798685926408996*^9, 
   3.799037738294014*^9},ExpressionUUID->"feee296c-476e-4426-9c06-\
09f3c0945729"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 3.744816494969404*^9}, {
  3.7969779616479683`*^9, 
  3.7969779628323717`*^9}},ExpressionUUID->"128286c2-b4d3-4bfa-8baa-\
49512600a6ca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JOO", "]"}], ",", "SemiLocals", ",", 
    "Dims"}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744817179367549*^9, 
   3.7448171796145635`*^9}, {3.79674357785341*^9, 3.7967435793515987`*^9}, {
   3.796743648655032*^9, 3.796743654071897*^9}, 
   3.7969769376742477`*^9},ExpressionUUID->"496c7953-4cee-4ee9-b33e-\
2d1f72220e8c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"12", " ", 
       RowBox[{"c", "[", "1", "]"}]}], 
      SubsuperscriptBox["p", "1", "5"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "5"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubsuperscriptBox["p", "2", "5"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "5"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"12", " ", 
       RowBox[{"c", "[", "1", "]"}]}], 
      SubsuperscriptBox["p", "1", "5"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubsuperscriptBox["p", "2", "5"]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.7448171573382893`*^9, 3.796743654593342*^9, 3.796743868972917*^9, 
   3.796976938432477*^9, 3.7969779640332813`*^9, 3.79753341222383*^9, 
   3.798418719440023*^9, 3.798418933085002*^9, 3.798419030138185*^9, 
   3.798419495518008*^9, 3.798685926435998*^9, 
   3.7990377383352957`*^9},ExpressionUUID->"f2d1d6bb-0759-417c-9ec4-\
86db735a9fbf"]
}, Open  ]],

Cell["No solutions.", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 
  3.7448165728888607`*^9}},ExpressionUUID->"5e11ae5f-aee0-473b-b16d-\
97a802bf6a33"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=3, \[CapitalDelta]=3", "Subsection",
 CellChangeTimes->{{3.696677309328281*^9, 
  3.696677312480341*^9}},ExpressionUUID->"7d206a98-72d1-4f7e-bc8c-\
446d46414c05"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"2", " ", "g", " ", "TR", " ", "cO", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"p", "[", "1", "]"}]}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{"a123", "/", "\[Mu]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"p", "[", "2", "]"}], "+", 
               RowBox[{"p", "[", "3", "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], 
             RowBox[{"p", "[", "3", "]"}]}], "+", 
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], "/", 
          "a123"}]}], ")"}]}], "+", 
      RowBox[{"scdep", " ", 
       RowBox[{"p", "[", "1", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
  3.696677341394161*^9, 3.69667740301085*^9}, {3.696759799810039*^9, 
  3.6967598029554663`*^9}},ExpressionUUID->"d2e29670-b7d7-49d0-b76e-\
0175d7039cdd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"675662d1-dbd7-47e8-b47f-\
26cb3818991d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", " ", "cO", " ", "g", " ", "TR", " ", 
   SubscriptBox["p", "1"]}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696679209740868*^9, 
   3.696683335860691*^9, 3.6967598091398497`*^9, 3.7448154117864494`*^9, 
   3.744816099087761*^9, 3.7448163512291822`*^9, 3.7448165814193487`*^9, 
   3.7448169343005323`*^9, 3.7448172042709737`*^9, 3.796743881775009*^9, 
   3.7967439498270817`*^9, 3.7969769424970407`*^9, 3.796977966908319*^9, 
   3.7975334158448353`*^9, 3.798418719490761*^9, 3.798418933121805*^9, 
   3.798419030202018*^9, 3.798419495563817*^9, 3.7986859264850006`*^9, 
   3.7990377383844213`*^9},ExpressionUUID->"b98d6677-9833-47a2-91c9-\
a51772698ecd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JOO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
   3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
   3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, 
   3.796743951805834*^9, 
   3.796976944258456*^9},ExpressionUUID->"6c06e8e5-d756-4704-80cb-\
4dcdee7ed653"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, 
   3.6966792104989567`*^9, 3.696683336836191*^9, 3.696759847449091*^9, 
   3.744815412970517*^9, 3.7448160995337863`*^9, 3.7448163517952147`*^9, 
   3.7448165818763747`*^9, 3.744816934982571*^9, 3.7448172045989923`*^9, 
   3.796743952777937*^9, 3.796976945016449*^9, 3.7969779676142807`*^9, 
   3.797533416645837*^9, 3.798418719628504*^9, 3.798418933197609*^9, 
   3.798419030246719*^9, 3.79841949559933*^9, 3.798685926510002*^9, 
   3.799037738438388*^9},ExpressionUUID->"34cf5070-af51-448f-af66-\
4c3a790fccb3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JOO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JOO", ",", " ", "Dims"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", 
    RowBox[{"cO", " ", "g", " ", "TR"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%%", "-", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696683339561006*^9, 3.696683347265876*^9}, {
  3.696759850173026*^9, 3.696759851050761*^9}, {3.6967599603950872`*^9, 
  3.6967599611675787`*^9}, {3.796743956200047*^9, 3.796743970509171*^9}, {
  3.796976947497612*^9, 3.796976960079018*^9}, {3.796977978356571*^9, 
  3.7969780019344473`*^9}},ExpressionUUID->"e413af9d-2c47-488d-bd22-\
e3728cbe2f81"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2"}], " ", "cO", " ", "g", " ", "TR", " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "1", "3"], "+", 
     SubsuperscriptBox["p", "2", "3"], "-", 
     SubsuperscriptBox["p", "3", "3"]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, {3.6966833377977657`*^9, 3.6966833475161657`*^9}, 
   3.696759853562933*^9, 3.6967599615976887`*^9, 3.7448154143405952`*^9, 
   3.74481609994881*^9, 3.744816352448252*^9, 3.7448165829384356`*^9, 
   3.744816935647609*^9, 3.744817204893009*^9, 3.796743974554049*^9, {
   3.796976956676992*^9, 3.796976960960256*^9}, {3.796977968596353*^9, 
   3.796977990305537*^9}, 3.796978028562512*^9, 3.7975334172258377`*^9, 
   3.798418719687924*^9, 3.7984189332307663`*^9, 3.798419030304297*^9, 
   3.798419495649049*^9, 3.7986859265360036`*^9, 
   3.799037738469083*^9},ExpressionUUID->"dea9c500-3d2c-412a-8cfb-\
41517d188df5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "cO"}], " ", "g", " ", "TR", " ", 
      SubsuperscriptBox["p", "2", "3"]}], "+", 
     RowBox[{"cO", " ", "g", " ", "TR", " ", 
      SubsuperscriptBox["p", "3", "3"]}]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, {3.6966833377977657`*^9, 3.6966833475161657`*^9}, 
   3.696759853562933*^9, 3.6967599615976887`*^9, 3.7448154143405952`*^9, 
   3.74481609994881*^9, 3.744816352448252*^9, 3.7448165829384356`*^9, 
   3.744816935647609*^9, 3.744817204893009*^9, 3.796743974554049*^9, {
   3.796976956676992*^9, 3.796976960960256*^9}, {3.796977968596353*^9, 
   3.796977990305537*^9}, 3.796978028562512*^9, 3.7975334172258377`*^9, 
   3.798418719687924*^9, 3.7984189332307663`*^9, 3.798419030304297*^9, 
   3.798419495649049*^9, 3.7986859265360036`*^9, 
   3.799037738471005*^9},ExpressionUUID->"b0698444-a347-428f-9abc-\
b84a38303099"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2"}], " ", "cO", " ", "g", " ", "TR", " ", 
   SubsuperscriptBox["p", "1", "3"]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, {3.6966833377977657`*^9, 3.6966833475161657`*^9}, 
   3.696759853562933*^9, 3.6967599615976887`*^9, 3.7448154143405952`*^9, 
   3.74481609994881*^9, 3.744816352448252*^9, 3.7448165829384356`*^9, 
   3.744816935647609*^9, 3.744817204893009*^9, 3.796743974554049*^9, {
   3.796976956676992*^9, 3.796976960960256*^9}, {3.796977968596353*^9, 
   3.796977990305537*^9}, 3.796978028562512*^9, 3.7975334172258377`*^9, 
   3.798418719687924*^9, 3.7984189332307663`*^9, 3.798419030304297*^9, 
   3.798419495649049*^9, 3.7986859265360036`*^9, 
   3.7990377384727583`*^9},ExpressionUUID->"61c0527f-a71d-44e7-bde1-\
03dc81373e3d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"3684403e-4eea-433b-a861-\
c7caf2376d8d"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"3a39f067-7637-4b92-9973-\
e7b1009fd3a8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], 
      RowBox[{"p", "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], 
      RowBox[{"p", "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], 
      RowBox[{"p", "[", "3", "]"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.796744087960782*^9, 
  3.796744088752359*^9}},ExpressionUUID->"46500e9d-70a2-4cca-919d-\
68d5c147ddaa"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, 3.79674408897189*^9, 
   3.796976963454279*^9, 3.796977970741678*^9, 3.796978030673326*^9, 
   3.7975334193158407`*^9, 3.798418719715382*^9, 3.798418933263941*^9, 
   3.798419030325625*^9, 3.798419495665154*^9, 3.7986859265500045`*^9, 
   3.799037738490193*^9},ExpressionUUID->"6598bb5c-b829-433a-bd61-\
016757115ad2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], " ", 
     SubscriptBox["p", "1"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", "2", "]"}], " ", 
     SubscriptBox["p", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", "3", "]"}], " ", 
     SubscriptBox["p", "3"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, 3.79674408897189*^9, 
   3.796976963454279*^9, 3.796977970741678*^9, 3.796978030673326*^9, 
   3.7975334193158407`*^9, 3.798418719715382*^9, 3.798418933263941*^9, 
   3.798419030325625*^9, 3.798419495665154*^9, 3.7986859265500045`*^9, 
   3.7990377384925947`*^9},ExpressionUUID->"5af49365-9fe6-4dd4-b348-\
12b4a241ccf9"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"cc2b340e-92e4-4e38-b5dd-\
0722cdcf39c0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JOO", "]"}], ",", "SemiLocals", ",", 
    "Dims"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", "%"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], ",", 
      RowBox[{"c", "[", "2", "]"}], ",", 
      RowBox[{"c", "[", "3", "]"}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.796744095216404*^9, 
  3.796744097592416*^9}, {3.796976965672907*^9, 
  3.796976966144099*^9}},ExpressionUUID->"705d8fed-ec97-491c-8e78-\
db43f6a32f4e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"c", "[", "3", "]"}]}], 
     SubscriptBox["p", "3"]], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", "2", "]"}]}], 
       SubscriptBox["p", "2"]]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubscriptBox["p", "3"]]}], "}"}], ",", 
   RowBox[{"{", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"c", "[", "2", "]"}]}], 
     SubscriptBox["p", "2"]], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, 3.7967440990502*^9, 
   3.796976968361577*^9, 3.796977972176119*^9, 3.796978033488492*^9, 
   3.797533420995843*^9, 3.798418719783044*^9, 3.798418933342754*^9, 
   3.79841903038279*^9, 3.798419495710021*^9, 3.7986859265650053`*^9, 
   3.799037738537723*^9},ExpressionUUID->"6bc2b96b-6c34-4269-aa03-\
43b4c0240bc1"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   192,2,29347142503502531606,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.744816499078639*^9, 3.744816511460347*^9}, 
   3.744816601255483*^9, 3.744817214820577*^9, 3.796744099055716*^9, 
   3.79697696840843*^9, 3.7969779721815157`*^9, 3.7969780334939127`*^9, 
   3.797533420995843*^9, 3.798418719764573*^9, 3.798418933350321*^9, 
   3.798419030390231*^9, 3.7984194957174683`*^9, 3.798685926567005*^9, 
   3.799037738539734*^9},ExpressionUUID->"15ab2c3d-75d2-4be5-9d66-\
f716e3767c4d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}], "}"}]], "Output",\

 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, 3.7967440990502*^9, 
   3.796976968361577*^9, 3.796977972176119*^9, 3.796978033488492*^9, 
   3.797533420995843*^9, 3.798418719783044*^9, 3.798418933342754*^9, 
   3.79841903038279*^9, 3.798419495710021*^9, 3.7986859265650053`*^9, 
   3.79903773854111*^9},ExpressionUUID->"b441fb96-346d-4375-82fe-\
8f69d4730cbc"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"7fdb4544-e2dc-4e90-a4b4-\
a523326a0a49"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "JOO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SecondaryCWIsRhs", "[", "JOO", "]"}], "/.", 
     RowBox[{"TransverseWIs", "[", "JOO", "]"}]}], "/.", "Dims"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", 
     RowBox[{"cO", " ", "g", " ", "TR"}]}], "}"}]}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.796744120623673*^9, 3.7967441502790947`*^9}, {
   3.796976971162538*^9, 
   3.796976996432342*^9}},ExpressionUUID->"61f22a6f-c9c5-45d4-b7dd-\
fd130bbefcf1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "0", "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.796744152241062*^9, {
   3.7969769866232653`*^9, 3.796976997290668*^9}, 3.796978038848487*^9, 
   3.797533422575845*^9, 3.798418719835063*^9, 3.7984189334940557`*^9, 
   3.7984190305363007`*^9, 3.7984194958276653`*^9, 3.7986859265870066`*^9, 
   3.7990377385549*^9},ExpressionUUID->"4a93f370-1a28-4d28-9782-46dcafdf5815"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", " ", "cO", " ", "g", " ", "TR", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["p", "2", "3"]}], "+", 
     SubsuperscriptBox["p", "3", "3"]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.796744152241062*^9, {
   3.7969769866232653`*^9, 3.796976997290668*^9}, 3.796978038848487*^9, 
   3.797533422575845*^9, 3.798418719835063*^9, 3.7984189334940557`*^9, 
   3.7984190305363007`*^9, 3.7984194958276653`*^9, 3.7986859265870066`*^9, 
   3.799037738556889*^9},ExpressionUUID->"d82a4132-e0ac-4899-b881-\
4ba4139e7f35"]
}, Open  ]],

Cell["\<\
Hence A[1] = c[1] p[1] is a semilocal solution. But it is a scheme-dependent \
part of the original solution already.\
\>", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 
  3.7448166929677286`*^9}},ExpressionUUID->"600bac7f-f175-4e36-bec5-\
ed2000eff64f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4, \[CapitalDelta]=2", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 
  3.69667770458226*^9}},ExpressionUUID->"ca2d690f-ea1a-4918-8fe2-\
f13b48f3ac7d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "g", " ", "TR", " ", "cO", " ", 
      RowBox[{"p", "[", "1", "]"}], " ", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"i", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], "[", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], ",", 
          RowBox[{"p", "[", "2", "]"}], ",", 
          RowBox[{"p", "[", "3", "]"}]}], "]"}], ",", 
        RowBox[{"p", "[", "1", "]"}]}], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.796744167224597*^9, 
  3.79674418248903*^9}},ExpressionUUID->"e50c20c7-8eec-40c8-9c92-\
2f080a2aeaac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"0d075e8f-b8d1-4a2d-9d6c-\
4d09524ba62b"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, 3.6966833548432837`*^9, 3.6967599817744417`*^9, 
   3.7448166969609575`*^9, 3.7448172215719633`*^9, 3.7967441961452007`*^9, 
   3.796977000687386*^9, 3.796977062842724*^9, 3.7969780422173977`*^9, 
   3.796978221351729*^9, 3.7975334254458485`*^9, 3.7975339556506495`*^9, 
   3.7984187199295597`*^9, 3.798418933663972*^9, 3.79841903061455*^9, 
   3.798419495892542*^9, 3.7986859266150084`*^9, 
   3.799037738603744*^9},ExpressionUUID->"fff682ab-5715-4507-b466-\
4616260b66f6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rhs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "JOO", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "//", "KSimplify"}]}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.7969770667305603`*^9, 3.796977092655735*^9}, {
  3.796977125483094*^9, 3.796977142351468*^9}, {3.796978051107736*^9, 
  3.796978053544429*^9}, {3.796978215108614*^9, 
  3.7969782187283907`*^9}},ExpressionUUID->"1febc738-e0ed-43ba-bf3f-\
60023e02df4f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, 3.69668335774496*^9, 3.696759982662921*^9, 
   3.7448166980060167`*^9, 3.744817222123995*^9, {3.796977064142074*^9, 
   3.796977093052889*^9}, {3.796977126581888*^9, 3.796977142817974*^9}, 
   3.796978081320068*^9, 3.7969782218535967`*^9, 3.7975334260258493`*^9, 
   3.797533969522669*^9, 3.797534052633786*^9, 3.797534089837838*^9, {
   3.797534230579091*^9, 3.797534241890107*^9}, 3.7975342832351656`*^9, 
   3.797535378027815*^9, 3.79841872012186*^9, 3.798418933768169*^9, 
   3.7984190307441607`*^9, 3.798419495963696*^9, 3.7986859266750116`*^9, 
   3.799037738644856*^9},ExpressionUUID->"f90dfeeb-5109-433e-aa8f-\
e7446db00b45"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"KEvaluate", "[", 
   RowBox[{"Rhs", ",", " ", 
    RowBox[{"ExpansionLevel", "\[Rule]", "\[Lambda]"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.796977130538392*^9, 3.796977174831828*^9}, {
   3.7969772346336813`*^9, 3.796977235604146*^9}, 3.7969772802359467`*^9, {
   3.797534306417198*^9, 3.797534308938202*^9}, 3.7975352662776036`*^9, {
   3.797535387048828*^9, 3.7975354023018494`*^9}, {3.798418945636733*^9, 
   3.79841895101432*^9}},ExpressionUUID->"c7168f94-e8a8-4784-9898-\
1ae65d75e5c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7969771345937147`*^9, 3.796977176681159*^9}, 
   3.7969772369898357`*^9, 3.7969772810661573`*^9, 3.796978091238798*^9, 
   3.796978224314579*^9, 3.797534311468205*^9, 3.7975352378935633`*^9, 
   3.797535269948609*^9, {3.797535381898821*^9, 3.7975354030318503`*^9}, 
   3.798418722160877*^9, 3.7984189369419527`*^9, 3.798419034229759*^9, 
   3.798419499081685*^9, 3.7986859301432095`*^9, 
   3.799037738674419*^9},ExpressionUUID->"5d50fb03-ee4e-499a-adaf-\
56c37d7a8d8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rhs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "JOO", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "//", "KSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7969772916555777`*^9, 3.796977296087984*^9}, {
  3.796978094923592*^9, 3.796978096408167*^9}, {3.7969782254035807`*^9, 
  3.796978226936501*^9}},ExpressionUUID->"ebd4afc8-5345-43a7-9397-\
2a4a17758d19"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", " ", "cO", " ", "g", " ", "TR", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubscriptBox["i", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubscriptBox["i", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "0"}], "}"}]}]]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], "+", 
        SubsuperscriptBox["p", "2", "2"], "-", 
        SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
      SubscriptBox["i", 
       RowBox[{"3", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "0", ",", "0"}], "}"}]}]]}]}], ")"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.796977299488002*^9, 3.7969780970609283`*^9, 
  3.79697822737764*^9, 3.7975354115728626`*^9, 3.798418722480872*^9, 
  3.798418937242489*^9, 3.798419034521003*^9, 3.798419499355364*^9, 
  3.7986859303402214`*^9, 
  3.799037738893126*^9},ExpressionUUID->"b24e2998-9d35-4525-a20d-\
b511c6516039"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"KEvaluate", "[", 
   RowBox[{"Rhs", ",", " ", 
    RowBox[{"ExpansionLevel", "\[Rule]", "\[Lambda]"}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ApplyTWIs", "[", 
    RowBox[{"JOO", ",", "Dims"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", 
     RowBox[{"cO", " ", "g", " ", "TR"}]}], "}"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "-", "%%"}], "//.", "logsu"}], "]"}]}], "Input",
 CellChangeTimes->{{3.79697737115442*^9, 3.796977374639716*^9}, {
  3.796977441146302*^9, 3.7969774421597843`*^9}, {3.796978100284246*^9, 
  3.79697811012853*^9}, {3.797535422785879*^9, 3.797535434926896*^9}, {
  3.798418968373589*^9, 
  3.798418975602467*^9}},ExpressionUUID->"386d6399-5b1c-4668-b7a6-\
c2e307421274"],

Cell[BoxData[
 RowBox[{"{", 
  InterpretationBox[
   RowBox[{
    RowBox[{"8", " ", "cO", " ", "g", " ", "TR", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubscriptBox["p", "3"], 
       SubscriptBox["p", "2"]], "]"}]}], "+", 
    InterpretationBox[
     SuperscriptBox[
      RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
     SeriesData[TripleK`\[Epsilon], 0, {}, 0, 1, 1],
     Editable->False]}],
   SeriesData[
   TripleK`\[Epsilon], 0, {
    8 $CellContext`cO Konformal`g $CellContext`TR 
     Log[TripleK`p[2]^(-1) TripleK`p[3]]}, 0, 1, 1],
   Editable->False], "}"}]], "Output",
 CellChangeTimes->{
  3.796977306238352*^9, 3.796977375734733*^9, {3.7969774359728813`*^9, 
   3.796977442507769*^9}, 3.7969781106638727`*^9, 3.796978228389185*^9, {
   3.7975354252158823`*^9, 3.797535435796897*^9}, 3.7984187229224787`*^9, 
   3.798418937426352*^9, 3.798419034719746*^9, 3.798419499574*^9, 
   3.7986859305012302`*^9, 
   3.7990377391270437`*^9},ExpressionUUID->"7a635bf3-df7c-4b32-b982-\
5ac69183d467"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", " ", "cO", " ", "g", " ", "TR", " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     SubsuperscriptBox["p", "3", "2"], 
     SubsuperscriptBox["p", "2", "2"]], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.796977306238352*^9, 3.796977375734733*^9, {3.7969774359728813`*^9, 
   3.796977442507769*^9}, 3.7969781106638727`*^9, 3.796978228389185*^9, {
   3.7975354252158823`*^9, 3.797535435796897*^9}, 3.7984187229224787`*^9, 
   3.798418937426352*^9, 3.798419034719746*^9, 3.798419499574*^9, 
   3.7986859305012302`*^9, 
   3.799037739128824*^9},ExpressionUUID->"b322c25e-9297-4fc6-aa7f-\
ee6463d475fc"],

Cell[BoxData[
 RowBox[{"{", 
  InterpretationBox[
   SuperscriptBox[
    RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
   SeriesData[TripleK`\[Epsilon], 0, {}, 1, 1, 1],
   Editable->False], "}"}]], "Output",
 CellChangeTimes->{
  3.796977306238352*^9, 3.796977375734733*^9, {3.7969774359728813`*^9, 
   3.796977442507769*^9}, 3.7969781106638727`*^9, 3.796978228389185*^9, {
   3.7975354252158823`*^9, 3.797535435796897*^9}, 3.7984187229224787`*^9, 
   3.798418937426352*^9, 3.798419034719746*^9, 3.798419499574*^9, 
   3.7986859305012302`*^9, 
   3.799037739130788*^9},ExpressionUUID->"8b922651-9975-4a30-b0d8-\
b3f3a5f96328"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"9adfb789-f4e9-40be-a0d0-\
e002e1d0cb0a"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448172330596204`*^9, 
  3.7448172335006456`*^9}},ExpressionUUID->"8c28a688-fa76-4ab8-8301-\
6c6025b3225a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744817239236974*^9, 
  3.7448172572960067`*^9}, {3.796745750401662*^9, 
  3.796745751225576*^9}},ExpressionUUID->"a9de90da-21b1-4876-8109-\
50c2ef2362f9"],

Cell[BoxData[
 RowBox[{"-", "2"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448172443592663`*^9, 
   3.744817257849038*^9}, 3.79674575225887*^9, 3.796977449041754*^9, 
   3.796978135583293*^9, 3.79697823010732*^9, 3.7975391254928536`*^9, 
   3.798418723391266*^9, 3.798418937501577*^9, 3.798419034741775*^9, 
   3.798419499635521*^9, 3.7986859305252314`*^9, 
   3.799037739179583*^9},ExpressionUUID->"e2e193d8-fc23-4599-ac06-\
6f93fc0dbc0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"c", "[", "1", "]"}], 
     SubsuperscriptBox["p", "1", "2"]], "+", 
    FractionBox[
     RowBox[{"c", "[", "2", "]"}], 
     SubsuperscriptBox["p", "2", "2"]], "+", 
    FractionBox[
     RowBox[{"c", "[", "3", "]"}], 
     SubsuperscriptBox["p", "3", "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448172443592663`*^9, 
   3.744817257849038*^9}, 3.79674575225887*^9, 3.796977449041754*^9, 
   3.796978135583293*^9, 3.79697823010732*^9, 3.7975391254928536`*^9, 
   3.798418723391266*^9, 3.798418937501577*^9, 3.798419034741775*^9, 
   3.798419499635521*^9, 3.7986859305252314`*^9, 
   3.7990377391818247`*^9},ExpressionUUID->"913cd982-3aee-4857-946c-\
a9903171daf5"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"b76f5bec-ed73-406c-a21a-\
ff3eda84a0a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JOO", "]"}], ",", "SemiLocals", ",", 
    "Dims"}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.7448172646544275`*^9, 
  3.7448172676625996`*^9}, {3.7967457571694403`*^9, 3.7967457606898623`*^9}, {
  3.796977453131855*^9, 
  3.796977453447575*^9}},ExpressionUUID->"c1bcdd13-530d-4414-940e-\
4a2927c6b71d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"8", " ", 
       RowBox[{"c", "[", "1", "]"}]}], 
      SubsuperscriptBox["p", "1", "4"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "4"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubsuperscriptBox["p", "2", "4"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "4"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"8", " ", 
       RowBox[{"c", "[", "1", "]"}]}], 
      SubsuperscriptBox["p", "1", "4"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubsuperscriptBox["p", "2", "4"]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.744817268172629*^9, 3.796745761194212*^9, {3.7969774506057777`*^9, 
   3.796977453728606*^9}, 3.796978138777896*^9, 3.796978231194821*^9, 
   3.7975391270528564`*^9, 3.798418723494109*^9, 3.798418937589087*^9, 
   3.798419034840104*^9, 3.798419499708108*^9, 3.798685930548233*^9, 
   3.79903773923288*^9},ExpressionUUID->"14bcef6d-d4aa-4da7-99b8-\
13a5030c1398"]
}, Open  ]],

Cell["No solution.", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.744817274668*^9, 
  3.74481727729115*^9}},ExpressionUUID->"5dc1269a-33a8-4e67-aa33-\
06efd9024ead"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4, \[CapitalDelta]=4", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 3.69667770458226*^9}, {
  3.696679255482382*^9, 
  3.6966792557773647`*^9}},ExpressionUUID->"c22f1d71-6014-4622-957e-\
936d7c5bbb95"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NonLocalTerm", "=", 
   RowBox[{"4", "g", " ", "TR", " ", "cO", " ", 
    RowBox[{
     RowBox[{"MRed", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", 
     RowBox[{
      RowBox[{"MRed", "[", 
       RowBox[{"3", ",", "1"}], "]"}], "[", 
      RowBox[{
       RowBox[{"1", "/", "4"}], " ", "J2", " ", "i1000"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LogTerm", "=", 
   RowBox[{"g", " ", "TR", " ", "cO", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], " ", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "4"}]}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], " ", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "4"}]}]}], "]"}]}], "-", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], " ", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "4"}]}]}], "]"}]}]}], ")"}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}], 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}], 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}], 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remainder", "=", 
   RowBox[{
    RowBox[{"2", " ", "g", " ", "TR", " ", 
     RowBox[{"(", " ", 
      RowBox[{"cO", "+", "a", "-", 
       RowBox[{"cO", " ", 
        RowBox[{
         RowBox[{"cJ", "[", "0", "]"}], "/", "cJ"}]}]}], " ", ")"}], 
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "^", "2"}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
       RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
    RowBox[{"g", " ", "TR", " ", "cO", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         RowBox[{"cJ", "[", "0", "]"}], "/", "cJ"}]}], "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "+", 
    RowBox[{"scdep", "*", 
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "^", "2"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696681450569047*^9, 3.6966815254376087`*^9}, {
  3.696681609206441*^9, 3.696681680808737*^9}, {3.6967609490943813`*^9, 
  3.6967609494220057`*^9}},ExpressionUUID->"6c480c7c-c233-4274-84b2-\
128755fca3f0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"NonLocalTerm", "+", "LogTerm", "+", "Remainder"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.6966792683570137`*^9, 3.696679279573285*^9}, {3.696681304201663*^9, 
  3.696681316408358*^9}, {3.696681366492388*^9, 3.696681387231173*^9}, {
  3.696681685048072*^9, 
  3.696681697567984*^9}},ExpressionUUID->"d7765540-5e1a-482c-94f0-\
57e643ce3152"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"ApplyDmu", "[", "As", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p", "[", "1", "]"}], ",", 
     RowBox[{"p", "[", "2", "]"}], ",", 
     RowBox[{"p", "[", "3", "]"}]}], "}"}], ",", "Simplify"}], "]"}]], "Input",\

 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 3.6966776876239157`*^9}, {3.696681706876687*^9, 
  3.696681748595314*^9}},ExpressionUUID->"32f6bde3-6b80-46ee-b16f-\
56d2bae99a60"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"4", " ", "g", " ", "TR", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "cJ"}], "+", 
       RowBox[{"cO", " ", 
        RowBox[{"cJ", "[", "0", "]"}]}], "+", 
       RowBox[{"cJ", " ", "cO", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["p", "1", "2"], 
          SuperscriptBox["\[Mu]", "2"]], "]"}]}]}], ")"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "cJ"], "-", 
   RowBox[{"4", " ", "cO", " ", "g", " ", "TR", " ", 
    SubsuperscriptBox["p", "2", "2"]}], "-", 
   RowBox[{"4", " ", "cO", " ", "g", " ", "TR", " ", 
    SubsuperscriptBox["p", "3", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, {3.6966816993011007`*^9, 3.6966817491437187`*^9}, 
   3.6966833723150177`*^9, 3.6967602258816833`*^9, 3.6967609543138742`*^9, 
   3.744817292241005*^9, 3.7969775152029877`*^9, 3.7969775977492437`*^9, 
   3.7969776347740593`*^9, 3.796977746021264*^9, 3.7969777937415543`*^9, 
   3.796978143738387*^9, 3.796978235603715*^9, 3.797539131873265*^9, 
   3.797539478075281*^9, 3.798418723614588*^9, 3.798418937711648*^9, 
   3.798419034999887*^9, 3.798419499817637*^9, 3.798685930602236*^9, 
   3.799037739342146*^9},ExpressionUUID->"85c9bcd9-ea0e-4f0e-ac49-\
af630b957f33"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"KExpand", "[", 
       RowBox[{"ApplyCWIs", "[", 
        RowBox[{
         RowBox[{"PrimaryCWIs", "[", "JOO", "]"}], ",", "As", ",", "Dims"}], 
        "]"}], "]"}], "/.", "Aaa"}], "//.", "logsu"}], ",", 
    RowBox[{"{", 
     RowBox[{"cO", ",", 
      RowBox[{"cO", "[", "0", "]"}], ",", "cJ", ",", 
      RowBox[{"cJ", "[", "0", "]"}], ",", 
      RowBox[{"Log", "[", "\[Mu]", "]"}]}], "}"}], ",", "Simplify"}], "]"}], "/.",
   "KillZero"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.696681878348083*^9, 3.696682040385975*^9}, {
  3.7969775669361563`*^9, 
  3.796977576816625*^9}},ExpressionUUID->"786d0829-29a0-44fb-851c-\
c823e389b233"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"8", " ", "a", " ", "g", " ", "TR"}], "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", " ", "a", " ", "g", " ", "TR"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, {3.696681874922673*^9, 3.696681907467486*^9}, {
   3.696681963808894*^9, 3.696681975145215*^9}, 3.6966820106142597`*^9, 
   3.696682042625102*^9, 3.6966833784651012`*^9, 3.6967603314967813`*^9, 
   3.6967608923493023`*^9, 3.696760958217023*^9, 3.7448172956692014`*^9, {
   3.796977572378858*^9, 3.7969775996759*^9}, 3.7969776377327137`*^9, 
   3.7969777473803587`*^9, 3.796977797147296*^9, 3.796978190330027*^9, 
   3.79697823856063*^9, 3.797539140500882*^9, 3.7975394808988857`*^9, 
   3.798418725164156*^9, 3.798418946394146*^9, 3.798419043599557*^9, 
   3.798419507975683*^9, 3.798685936320562*^9, 
   3.79903774488907*^9},ExpressionUUID->"1ce99ebc-fbc8-4628-beb4-\
068866eeb5e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"SimplifyCWIs", "[", 
    RowBox[{"ApplyCWIs", "[", 
     RowBox[{
      RowBox[{"SecondaryCWIsLhs", "[", "JOO", "]"}], ",", "As", ",", "Dims"}],
      "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"p", "[", "1", "]"}], "]"}], ",", 
     RowBox[{"Log", "[", 
      RowBox[{"p", "[", "2", "]"}], "]"}], ",", 
     RowBox[{"Log", "[", 
      RowBox[{"p", "[", "3", "]"}], "]"}], ",", 
     RowBox[{"Log", "[", "\[Mu]", "]"}], ",", "cJ", ",", 
     RowBox[{"cJ", "[", "0", "]"}], ",", "cO", ",", 
     RowBox[{"cO", "[", "0", "]"}]}], "}"}], ",", "Simplify"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ApplyTWIs", "[", 
    RowBox[{"JOO", ",", "Dims"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cO", "[", "j_", "]"}], "[", "0", "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"cO", "[", "0", "]"}], " ", "g", " ", "TR"}]}], ",", 
     RowBox[{
      RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", 
      RowBox[{"cO", " ", "g", " ", "TR"}]}]}], "}"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "-", "%%"}], "//.", "logsu"}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696678106749449*^9, 3.6966781141980352`*^9}, {
  3.696678238255801*^9, 3.696678242655888*^9}, {3.696682094182363*^9, 
  3.696682103623598*^9}, {3.696761374437016*^9, 3.69676143733055*^9}, {
  3.696761468523992*^9, 3.696761511635839*^9}, {3.796977811696765*^9, 
  3.7969778167047567`*^9}, {3.79697824768853*^9, 3.796978286216639*^9}, {
  3.796978317765717*^9, 
  3.7969783557287703`*^9}},ExpressionUUID->"b40e61bf-240f-495b-b87c-\
58092c86f010"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "8"}], " ", "cO", " ", "g", " ", "TR", " ", 
    RowBox[{"Log", "[", 
     SubscriptBox["p", "1"], "]"}], " ", 
    SubsuperscriptBox["p", "1", "4"]}], "+", 
   RowBox[{"8", " ", "cO", " ", "g", " ", "TR", " ", 
    SubsuperscriptBox["p", "1", "2"], " ", 
    SubsuperscriptBox["p", "2", "2"]}], "-", 
   RowBox[{"8", " ", "cO", " ", "g", " ", "TR", " ", 
    RowBox[{"Log", "[", 
     SubscriptBox["p", "2"], "]"}], " ", 
    SubsuperscriptBox["p", "2", "4"]}], "+", 
   RowBox[{"8", " ", "cO", " ", "g", " ", "TR", " ", 
    RowBox[{"Log", "[", 
     SubscriptBox["p", "3"], "]"}], " ", 
    SubsuperscriptBox["p", "3", "4"]}], "+", 
   RowBox[{"4", " ", "a", " ", "g", " ", "TR", " ", 
    SubsuperscriptBox["p", "1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      SubsuperscriptBox["p", "2", "2"], "-", 
      SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
   FractionBox[
    RowBox[{"4", " ", "cO", " ", "g", " ", "TR", " ", 
     RowBox[{"cJ", "[", "0", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "4"], "+", 
       SubsuperscriptBox["p", "2", "4"], "-", 
       SubsuperscriptBox["p", "3", "4"]}], ")"}]}], "cJ"], "+", 
   RowBox[{"8", " ", "cO", " ", "g", " ", "TR", " ", 
    RowBox[{"Log", "[", "\[Mu]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "4"], "+", 
      SubsuperscriptBox["p", "2", "4"], "-", 
      SubsuperscriptBox["p", "3", "4"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696682105615172*^9, 3.696683381749872*^9, {3.696761381834491*^9, 
   3.696761470819603*^9}, 3.696761512754631*^9, 3.7448172967942657`*^9, 
   3.79697825282358*^9, 3.796978286917981*^9, {3.7969783190013037`*^9, 
   3.796978356457354*^9}, 3.7975391517807016`*^9, 3.7975392039093933`*^9, 
   3.7975394273293915`*^9, 3.79753948308389*^9, 3.798418727568994*^9, 
   3.7984189480434637`*^9, 3.798419045146008*^9, 3.798419509436125*^9, 
   3.798685937461627*^9, 
   3.7990377459847193`*^9},ExpressionUUID->"b1f8b30e-77e4-4724-8160-\
67e7003c0d5c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", " ", "g", " ", "TR", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cO", "[", "0", "]"}], "+", 
         RowBox[{"cO", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["p", "2", "2"], 
            SuperscriptBox["\[Mu]", "2"]], "]"}]}]}], ")"}]}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cO", "[", "0", "]"}], "+", 
        RowBox[{"cO", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["p", "3", "2"], 
           SuperscriptBox["\[Mu]", "2"]], "]"}]}]}], ")"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696682105615172*^9, 3.696683381749872*^9, {3.696761381834491*^9, 
   3.696761470819603*^9}, 3.696761512754631*^9, 3.7448172967942657`*^9, 
   3.79697825282358*^9, 3.796978286917981*^9, {3.7969783190013037`*^9, 
   3.796978356457354*^9}, 3.7975391517807016`*^9, 3.7975392039093933`*^9, 
   3.7975394273293915`*^9, 3.79753948308389*^9, 3.798418727568994*^9, 
   3.7984189480434637`*^9, 3.798419045146008*^9, 3.798419509436125*^9, 
   3.798685937461627*^9, 
   3.799037746000725*^9},ExpressionUUID->"e89c52b6-6d3c-40ac-bb16-\
0b6c539f8ffe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", "cJ"], 
    RowBox[{"4", " ", "g", " ", "TR", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "cJ", " ", 
        SubsuperscriptBox["p", "1", "4"]}], "-", 
       RowBox[{"cO", " ", 
        RowBox[{"cJ", "[", "0", "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], "+", 
       RowBox[{"2", " ", "cJ", " ", "cO", " ", 
        RowBox[{"Log", "[", "\[Mu]", "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], "-", 
       RowBox[{"2", " ", "cJ", " ", "cO", " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], "+", 
       RowBox[{"a", " ", "cJ", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "+", 
       RowBox[{"2", " ", "cJ", " ", "cO", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "-", 
       RowBox[{"cO", " ", 
        RowBox[{"cJ", "[", "0", "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], "+", 
       RowBox[{"cJ", " ", 
        RowBox[{"cO", "[", "0", "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], "-", 
       RowBox[{"a", " ", "cJ", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], "+", 
       RowBox[{"cO", " ", 
        RowBox[{"cJ", "[", "0", "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], "-", 
       RowBox[{"cJ", " ", 
        RowBox[{"cO", "[", "0", "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696682105615172*^9, 3.696683381749872*^9, {3.696761381834491*^9, 
   3.696761470819603*^9}, 3.696761512754631*^9, 3.7448172967942657`*^9, 
   3.79697825282358*^9, 3.796978286917981*^9, {3.7969783190013037`*^9, 
   3.796978356457354*^9}, 3.7975391517807016`*^9, 3.7975392039093933`*^9, 
   3.7975394273293915`*^9, 3.79753948308389*^9, 3.798418727568994*^9, 
   3.7984189480434637`*^9, 3.798419045146008*^9, 3.798419509436125*^9, 
   3.798685937461627*^9, 
   3.7990377460278187`*^9},ExpressionUUID->"bd28d4f5-b743-4998-a10a-\
1ca1912319ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"04a3925b-1f40-4015-aa45-\
607eca545a67"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"9ddfaecd-b66b-4773-9a6b-\
965daa323c69"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "+", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"i", ",", "j"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "2"}], " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"p", "[", "j", "]"}], "^", "2"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.744817305039737*^9, 3.744817346824127*^9}, {
  3.796978483270063*^9, 3.796978484057599*^9}, {3.797539706427555*^9, 
  3.7975397073085566`*^9}},ExpressionUUID->"60cf211e-960f-40ea-a55b-\
eb50c0b5f47d"],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, 3.7448173021355715`*^9, 
   3.7448173480791993`*^9, 3.7969783982351837`*^9, 3.796978484366342*^9, 
   3.7975397079385576`*^9, 3.798418728385391*^9, 3.7984189481980963`*^9, 
   3.798419045290762*^9, 3.7984195095583763`*^9, 3.798685937549632*^9, 
   3.79903774607064*^9},ExpressionUUID->"d3ee7e87-f091-4efc-8ad5-\
236f2ec06f8d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "1"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", "2", "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "2"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", "3", "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "1"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "2"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, 3.7448173021355715`*^9, 
   3.7448173480791993`*^9, 3.7969783982351837`*^9, 3.796978484366342*^9, 
   3.7975397079385576`*^9, 3.798418728385391*^9, 3.7984189481980963`*^9, 
   3.798419045290762*^9, 3.7984195095583763`*^9, 3.798685937549632*^9, 
   3.799037746073806*^9},ExpressionUUID->"07414189-1fc1-4c4a-8a04-\
a30fc1f3bb44"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"ba7bf28c-344b-4cfd-bcd5-\
a4525f599453"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JOO", "]"}], ",", "SemiLocals", ",", 
    "Dims"}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.7448173563596725`*^9, 
  3.7448173926447477`*^9}, {3.7969784050836697`*^9, 
  3.7969784060164557`*^9}},ExpressionUUID->"78bac6fc-5dbc-4f61-b58f-\
451db3754875"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "[", "3", "]"}], "+", 
       RowBox[{"c", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "1"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], 
        SubsuperscriptBox["p", "1", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], 
        SubsuperscriptBox["p", "3", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], 
        SubsuperscriptBox["p", "3", "2"]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], 
        SubsuperscriptBox["p", "1", "2"]]}], ")"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", "2", "]"}]}], "+", 
       RowBox[{"c", "[", "3", "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "1"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "1"}], "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "2"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2"}], "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], 
        SubsuperscriptBox["p", "2", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], 
        SubsuperscriptBox["p", "3", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], 
        SubsuperscriptBox["p", "3", "2"]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], 
        SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "[", "2", "]"}], "+", 
       RowBox[{"c", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "1"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], 
        SubsuperscriptBox["p", "2", "2"]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], 
        SubsuperscriptBox["p", "1", "2"]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], 
        SubsuperscriptBox["p", "1", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], 
        SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, {3.7448173673333006`*^9, 
   3.7448173932117805`*^9}, 3.7448174837599597`*^9, 3.744817598669532*^9, {
   3.796978401398521*^9, 3.796978406514042*^9}, 3.796978487391499*^9, 
   3.797539710418561*^9, 3.79841872870982*^9, 3.798418948530891*^9, 
   3.798419045586219*^9, 3.798419509835374*^9, 3.798685937889652*^9, 
   3.799037746461434*^9},ExpressionUUID->"ebf39a0e-8632-49b6-9bcf-\
be4e4521e3da"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], "}"}], "//", 
   "Flatten"}]}], "\[IndentingNewLine]", 
 RowBox[{"%%", "/.", "LocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.744817575291195*^9, 
  3.7448176047488794`*^9}},ExpressionUUID->"d1fa7ade-4dc6-4edf-838d-\
8d8a1d279ca1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448175940442677`*^9, 3.744817604961892*^9}, 
   3.796978408780919*^9, 3.796978504495162*^9, 3.7975397125735636`*^9, 
   3.798418728726185*^9, 3.798418948548986*^9, 3.798419045602427*^9, 
   3.7984195098515253`*^9, 3.7986859379046526`*^9, 
   3.7990377464729357`*^9},ExpressionUUID->"04ae3770-6327-4a1d-9989-\
ce92a18512e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448175940442677`*^9, 3.744817604961892*^9}, 
   3.796978408780919*^9, 3.796978504495162*^9, 3.7975397125735636`*^9, 
   3.798418728726185*^9, 3.798418948548986*^9, 3.798419045602427*^9, 
   3.7984195098515253`*^9, 3.7986859379046526`*^9, 
   3.799037746475337*^9},ExpressionUUID->"09683a58-f1d7-48b7-bcb8-\
c076c5216f50"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"27bf8fd6-2d90-48c1-be11-\
6d087cbe3669"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SemiLocals", "/.", 
  "LocalPrimarySolution"}], "\[IndentingNewLine]", 
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "JOO", "]"}], ",", "%", ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JOO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.7969784382726727`*^9, 
   3.7969784561284246`*^9}, {3.796978522849304*^9, 
   3.796978528878256*^9}},ExpressionUUID->"e740856c-60a3-40b8-bee4-\
4fdcda898da9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"c", "[", "1", "]"}], " ", 
    SubsuperscriptBox["p", "1", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.744817612501323*^9, 
   3.796978456823813*^9, {3.7969785237980547`*^9, 3.796978529602182*^9}, 
   3.797539714473566*^9, 3.798418728776004*^9, 3.7984189486173363`*^9, 
   3.798419045666296*^9, 3.798419509912517*^9, 3.7986859379186535`*^9, 
   3.799037746514625*^9},ExpressionUUID->"7c6cf647-63c7-42f9-85b9-\
99e0e1fdf32d"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.744817612501323*^9, 
   3.796978456823813*^9, {3.7969785237980547`*^9, 3.796978529602182*^9}, 
   3.797539714473566*^9, 3.798418728776004*^9, 3.7984189486173363`*^9, 
   3.798419045666296*^9, 3.798419509912517*^9, 3.7986859379186535`*^9, 
   3.799037746516576*^9},ExpressionUUID->"bfb130c9-21c0-4fee-b045-\
31e10a19d1ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SubsuperscriptBox["p", "2", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"cO", "[", "2", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["p", "2", "2"], 
         SuperscriptBox["\[Mu]", "2"]], "]"}]}], "+", 
      RowBox[{
       RowBox[{"cO", "[", "2", "]"}], "[", "0", "]"}]}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["p", "3", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"cO", "[", "3", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["p", "3", "2"], 
         SuperscriptBox["\[Mu]", "2"]], "]"}]}], "+", 
      RowBox[{
       RowBox[{"cO", "[", "3", "]"}], "[", "0", "]"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.744817612501323*^9, 
   3.796978456823813*^9, {3.7969785237980547`*^9, 3.796978529602182*^9}, 
   3.797539714473566*^9, 3.798418728776004*^9, 3.7984189486173363`*^9, 
   3.798419045666296*^9, 3.798419509912517*^9, 3.7986859379186535`*^9, 
   3.799037746531104*^9},ExpressionUUID->"59108bb3-d889-488d-90f7-\
8be94d15e39f"]
}, Open  ]],

Cell["\<\
Hence A[1] = c[1] p[1]^2 is a semilocal solution. But it is a \
scheme-dependent part of the original solution already.\
\>", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.744817620649789*^9, 
  3.7448176208488007`*^9}},ExpressionUUID->"1e23dac5-9335-439a-a0f3-\
b954f3e9bc80"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["<TOO>", "Section",
 CellChangeTimes->{{3.696682141646401*^9, 
  3.696682142725572*^9}},ExpressionUUID->"f9914962-1785-4a25-a80e-\
25ca5e7dca8c"],

Cell[CellGroupData[{

Cell["d=3, \[CapitalDelta]=1", "Subsection",
 CellChangeTimes->{{3.696663690437581*^9, 
  3.6966636937738028`*^9}},ExpressionUUID->"875469da-9d5e-46f7-a508-\
a1a1ebebcdb4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"2", " ", "cO", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], "+", "a123"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"b23", "*", 
         RowBox[{"a123", "^", "2"}]}], ")"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "1"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
   3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
   3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
   3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
   3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
   3.696682247936219*^9, 3.696682264048477*^9}, 
   3.696762115285437*^9},ExpressionUUID->"c7e0bb36-912d-4d78-a9eb-\
489c2fb1e84d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677607964088*^9, 
  3.6966776258540688`*^9}},ExpressionUUID->"74a6f5d0-85f2-4967-9903-\
994d452b37ff"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{
  3.696677627230453*^9, 3.6966776623071833`*^9, 3.696678324117044*^9, 
   3.696679200338336*^9, 3.696682266910235*^9, {3.6966834009318457`*^9, 
   3.696683419241766*^9}, {3.696683492208569*^9, 3.696683524052888*^9}, 
   3.696761976505034*^9, 3.69676211708768*^9, 3.696762353364505*^9, 
   3.7448177544964447`*^9, 3.744817899801756*^9, 3.796978571270756*^9, 
   3.798418728871153*^9, 3.79841894874483*^9, 3.798419045761112*^9, 
   3.7984195100142593`*^9, 3.7986859379846573`*^9, 
   3.799037746575389*^9},ExpressionUUID->"e94fae19-5e90-4198-8317-\
4d6360212a5e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TOO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796978573824884*^9, 
  3.796978574976838*^9}},ExpressionUUID->"0c867bd8-904a-4138-9ed9-\
e0d6f89f0ff3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, 3.696682268533676*^9, {
   3.696683401902625*^9, 3.696683419970924*^9}, {3.696683492884836*^9, 
   3.696683524511423*^9}, 3.6967619779398193`*^9, 3.6967621176332817`*^9, 
   3.696762353850575*^9, 3.7448177555925074`*^9, 3.74481790145485*^9, 
   3.796978577015893*^9, 3.798418728919559*^9, 3.798418948822484*^9, 
   3.7984190458110247`*^9, 3.798419510082259*^9, 3.798685938019659*^9, 
   3.799037746608077*^9},ExpressionUUID->"e16d68cf-bdf6-429c-a7e0-\
05ec1ea1db05"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TOO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ApplyTWIs", "[", 
    RowBox[{"TOO", ",", "Dims"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", "cO"}], "}"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%%", "-", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.6966834562110043`*^9, 3.696683461179345*^9}, {
  3.696683497134564*^9, 3.696683500236513*^9}, {3.696761987824627*^9, 
  3.696761992717802*^9}, {3.796978579608388*^9, 3.796978594264585*^9}, {
  3.79697862526798*^9, 
  3.796978629545253*^9}},ExpressionUUID->"d0e64291-2600-4092-94fd-\
c93e66a3fbdb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", " ", "cO", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", 
      SubscriptBox["p", "2"]], "-", 
     FractionBox["1", 
      SubscriptBox["p", "3"]]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, 3.696682271537431*^9, {
   3.6966823751175957`*^9, 3.696682400181346*^9}, 3.696683420868623*^9, 
   3.6966834573609123`*^9, {3.6966834949522343`*^9, 3.6966835258679743`*^9}, {
   3.6967619810417557`*^9, 3.6967619930404*^9}, 3.696762118237331*^9, 
   3.696762354407765*^9, 3.7448177567225723`*^9, 3.744817910115346*^9, {
   3.7969785949800377`*^9, 3.796978629985491*^9}, 3.7984187289772253`*^9, 
   3.798418948848528*^9, 3.7984190458828707`*^9, 3.79841951013286*^9, 
   3.7986859380536613`*^9, 
   3.799037746636567*^9},ExpressionUUID->"40754541-f2da-4fe5-afc1-\
8ccd66151765"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", " ", "cO", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", 
      SubscriptBox["p", "2"]], "-", 
     FractionBox["1", 
      SubscriptBox["p", "3"]]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, 3.696682271537431*^9, {
   3.6966823751175957`*^9, 3.696682400181346*^9}, 3.696683420868623*^9, 
   3.6966834573609123`*^9, {3.6966834949522343`*^9, 3.6966835258679743`*^9}, {
   3.6967619810417557`*^9, 3.6967619930404*^9}, 3.696762118237331*^9, 
   3.696762354407765*^9, 3.7448177567225723`*^9, 3.744817910115346*^9, {
   3.7969785949800377`*^9, 3.796978629985491*^9}, 3.7984187289772253`*^9, 
   3.798418948848528*^9, 3.7984190458828707`*^9, 3.79841951013286*^9, 
   3.7986859380536613`*^9, 
   3.799037746638657*^9},ExpressionUUID->"4abf486c-e056-446b-9d27-\
4001d59aa036"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, 3.696682271537431*^9, {
   3.6966823751175957`*^9, 3.696682400181346*^9}, 3.696683420868623*^9, 
   3.6966834573609123`*^9, {3.6966834949522343`*^9, 3.6966835258679743`*^9}, {
   3.6967619810417557`*^9, 3.6967619930404*^9}, 3.696762118237331*^9, 
   3.696762354407765*^9, 3.7448177567225723`*^9, 3.744817910115346*^9, {
   3.7969785949800377`*^9, 3.796978629985491*^9}, 3.7984187289772253`*^9, 
   3.798418948848528*^9, 3.7984190458828707`*^9, 3.79841951013286*^9, 
   3.7986859380536613`*^9, 
   3.799037746641037*^9},ExpressionUUID->"685859ee-e175-4ede-8cfc-\
5988840c11b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"4aeedcb1-e4ca-4392-9551-\
e7323c292148"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"ae74c350-f102-4bb3-b71c-\
6eb4d1f9c761"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "3"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "3"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "3"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.744817795132769*^9, 3.744817803204231*^9}, {
  3.744817895395504*^9, 3.744817918811843*^9}, {3.796978636724716*^9, 
  3.7969786376894207`*^9}},ExpressionUUID->"e30706ac-b13f-4402-ab79-\
d577e726b536"],

Cell[BoxData[
 RowBox[{"-", "3"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.744817788526391*^9, 
   3.744817803564251*^9}, {3.744817912625489*^9, 3.7448179192838697`*^9}, {
   3.796978633000736*^9, 3.7969786381574907`*^9}, 3.798418729003233*^9, 
   3.798418948872655*^9, 3.798419045908374*^9, 3.798419510153861*^9, 
   3.7986859380676622`*^9, 
   3.799037746655321*^9},ExpressionUUID->"91e03bb2-5038-4c6c-b5df-\
e19542e4e959"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"c", "[", "1", "]"}], 
     SubsuperscriptBox["p", "1", "3"]], "+", 
    FractionBox[
     RowBox[{"c", "[", "2", "]"}], 
     SubsuperscriptBox["p", "2", "3"]], "+", 
    FractionBox[
     RowBox[{"c", "[", "3", "]"}], 
     SubsuperscriptBox["p", "3", "3"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.744817788526391*^9, 
   3.744817803564251*^9}, {3.744817912625489*^9, 3.7448179192838697`*^9}, {
   3.796978633000736*^9, 3.7969786381574907`*^9}, 3.798418729003233*^9, 
   3.798418948872655*^9, 3.798419045908374*^9, 3.798419510153861*^9, 
   3.7986859380676622`*^9, 
   3.799037746657836*^9},ExpressionUUID->"4b3407b3-c509-4a5d-a110-\
811a92923ef6"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"314cac44-5eeb-4c4b-9d87-\
f27a1caa0b0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TOO", "]"}], ",", "SemiLocals", ",", 
    "Dims"}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.7448178103706408`*^9, 
  3.744817810617655*^9}, {3.796978642768812*^9, 
  3.796978644064913*^9}},ExpressionUUID->"734f4c0e-18c8-4d3b-ba1d-\
b0d0f95a9053"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"18", " ", 
       RowBox[{"c", "[", "1", "]"}]}], 
      SubsuperscriptBox["p", "1", "5"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "5"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubsuperscriptBox["p", "2", "5"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "5"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"18", " ", 
       RowBox[{"c", "[", "1", "]"}]}], 
      SubsuperscriptBox["p", "1", "5"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubsuperscriptBox["p", "2", "5"]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, {3.7448178054863615`*^9, 
   3.74481781210874*^9}, 3.744817923374104*^9, 3.796978644371039*^9, 
   3.7984187291057463`*^9, 3.798418948954846*^9, 3.798419045992877*^9, 
   3.798419510226268*^9, 3.798685938100664*^9, 
   3.799037746711589*^9},ExpressionUUID->"342ce93a-9e69-4d9a-b694-\
cd4f83039047"]
}, Open  ]],

Cell["No solution.", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.7448178196721725`*^9, 
  3.7448178212792645`*^9}},ExpressionUUID->"3c329dfb-753a-4c7f-b1c6-\
427b828ac738"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=3, \[CapitalDelta]=3", "Subsection",
 CellChangeTimes->{{3.696677309328281*^9, 
  3.696677312480341*^9}},ExpressionUUID->"6868da7f-edc0-4a98-881b-\
3086c3b354ac"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "cO", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a123", "^", "3"}], "-", 
         RowBox[{"a123", " ", "b123"}], "-", "c123"}], ")"}], "/", 
       RowBox[{"a123", "^", "2"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
   3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
   3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
   3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
   3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
   3.696677341394161*^9, 3.69667740301085*^9}, {3.696682420743903*^9, 
   3.696682437276704*^9}, 
   3.6967623852418327`*^9},ExpressionUUID->"dd03bc85-6b26-46f8-8d24-\
43c30e76c77d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"c1a4ac8b-2dc6-4802-bda9-\
7ff617e8e799"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696679209740868*^9, 
   3.6966824393663816`*^9, 3.696683534397949*^9, {3.696762361949028*^9, 
   3.696762386164074*^9}, 3.744817828505678*^9, 3.7448178873150415`*^9, 
   3.744817930433508*^9, 3.796978648016913*^9, 3.798418729177622*^9, 
   3.7984189489900084`*^9, 3.7984190460617867`*^9, 3.7984195102925663`*^9, 
   3.7986859381246653`*^9, 
   3.799037746754889*^9},ExpressionUUID->"5a550cc4-d76d-494c-9d23-\
56a4f5870934"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TOO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796978650912898*^9, 
  3.796978652024879*^9}},ExpressionUUID->"5fb44c01-1d51-4205-b520-\
84d4ccb7704f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, 
   3.6966792104989567`*^9, 3.696682440955246*^9, 3.696683535087051*^9, {
   3.696762362834331*^9, 3.69676238671019*^9}, 3.744817829022708*^9, 
   3.744817887779068*^9, 3.7448179313055573`*^9, 3.796978652416889*^9, 
   3.798418729273285*^9, 3.7984189490450687`*^9, 3.798419046184759*^9, 
   3.798419510341587*^9, 3.798685938190669*^9, 
   3.799037746801746*^9},ExpressionUUID->"2a0a76de-86cb-4e08-8fd0-\
429246ceb5af"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TOO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ApplyTWIs", "[", 
    RowBox[{"TOO", ",", " ", "Dims"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", "cO"}], "}"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%%", "-", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.69668353889565*^9, 3.6966835422998953`*^9}, {
  3.696762367325982*^9, 3.696762377641526*^9}, {3.796978655937128*^9, 
  3.796978676264803*^9}},ExpressionUUID->"b43260e6-ee48-4c13-b274-\
96edcb53c49b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", " ", "cO", " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "2", "3"], "-", 
     SubsuperscriptBox["p", "3", "3"]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696682442684783*^9, {3.6966835361304092`*^9, 
   3.69668354267528*^9}, {3.6967623639048777`*^9, 3.6967623872712317`*^9}, 
   3.7448178294607325`*^9, 3.7448178882580957`*^9, 3.7448179317595835`*^9, {
   3.796978666763774*^9, 3.796978676839794*^9}, 3.798418729312729*^9, 
   3.798418949073414*^9, 3.798419046250065*^9, 3.7984195103873672`*^9, 
   3.7986859382296715`*^9, 
   3.7990377468299294`*^9},ExpressionUUID->"58977d64-3b08-48e8-bd88-\
51cfdc8ca1fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", " ", "cO", " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "2", "3"], "-", 
     SubsuperscriptBox["p", "3", "3"]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696682442684783*^9, {3.6966835361304092`*^9, 
   3.69668354267528*^9}, {3.6967623639048777`*^9, 3.6967623872712317`*^9}, 
   3.7448178294607325`*^9, 3.7448178882580957`*^9, 3.7448179317595835`*^9, {
   3.796978666763774*^9, 3.796978676839794*^9}, 3.798418729312729*^9, 
   3.798418949073414*^9, 3.798419046250065*^9, 3.7984195103873672`*^9, 
   3.7986859382296715`*^9, 
   3.799037746832076*^9},ExpressionUUID->"0f1cfb5a-0513-40f0-9a7b-\
a0beb6145610"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696682442684783*^9, {3.6966835361304092`*^9, 
   3.69668354267528*^9}, {3.6967623639048777`*^9, 3.6967623872712317`*^9}, 
   3.7448178294607325`*^9, 3.7448178882580957`*^9, 3.7448179317595835`*^9, {
   3.796978666763774*^9, 3.796978676839794*^9}, 3.798418729312729*^9, 
   3.798418949073414*^9, 3.798419046250065*^9, 3.7984195103873672`*^9, 
   3.7986859382296715`*^9, 
   3.799037746833726*^9},ExpressionUUID->"56afde4d-7033-46a1-ad83-\
ffd16417a873"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"6622eb63-21b3-4a77-b36a-\
5977f5252d2f"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"aa5cf9d5-2931-4ee6-b539-\
63282ba8a3ae"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], 
      RowBox[{"p", "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], 
      RowBox[{"p", "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], 
      RowBox[{"p", "[", "3", "]"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448178467317204`*^9, 3.7448178503079247`*^9}, {
  3.744817934475739*^9, 3.7448179387149816`*^9}, {3.796978679041541*^9, 
  3.796978681248973*^9}},ExpressionUUID->"f82bcfd6-e5c5-43f1-96c0-\
cda8bad436a9"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.744817835100055*^9, 
   3.744817854786181*^9}, 3.7448178923013268`*^9, {3.7448179347457542`*^9, 
   3.744817939234011*^9}, 3.796978681592547*^9, 3.798418729332033*^9, 
   3.798418949092374*^9, 3.798419046325108*^9, 3.798419510410357*^9, 
   3.798685938244672*^9, 
   3.79903774687013*^9},ExpressionUUID->"eae0482b-e568-4dcf-9523-\
579c20c21e0b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], " ", 
     SubscriptBox["p", "1"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", "2", "]"}], " ", 
     SubscriptBox["p", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", "3", "]"}], " ", 
     SubscriptBox["p", "3"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.744817835100055*^9, 
   3.744817854786181*^9}, 3.7448178923013268`*^9, {3.7448179347457542`*^9, 
   3.744817939234011*^9}, 3.796978681592547*^9, 3.798418729332033*^9, 
   3.798418949092374*^9, 3.798419046325108*^9, 3.798419510410357*^9, 
   3.798685938244672*^9, 
   3.7990377468726587`*^9},ExpressionUUID->"18af0a82-4d9c-4b71-87fb-\
69fdfabc6ba7"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"76b6b086-4ae0-4c1f-90d6-\
8d3f324890d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TOO", "]"}], ",", "SemiLocals", ",", 
    "Dims"}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744817945697381*^9, 
  3.7448179459283943`*^9}, {3.796978685611744*^9, 
  3.796978689936853*^9}},ExpressionUUID->"f2d3948f-712e-4c4b-8661-\
a28791f2f0f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", "1", "]"}]}], 
       SubscriptBox["p", "1"]]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubscriptBox["p", "3"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", "2", "]"}]}], 
       SubscriptBox["p", "2"]]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubscriptBox["p", "3"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", "1", "]"}]}], 
       SubscriptBox["p", "1"]]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubscriptBox["p", "2"]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, 3.7448178567922955`*^9, {
   3.744817940555087*^9, 3.7448179462474127`*^9}, 3.7969786903642483`*^9, 
   3.7984187294345827`*^9, 3.7984189491738997`*^9, 3.7984190464073153`*^9, 
   3.798419510478598*^9, 3.7986859382836742`*^9, 
   3.799037746935903*^9},ExpressionUUID->"63a71e92-b7ff-4177-99fe-\
580f105afa22"]
}, Open  ]],

Cell["No solution.", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.74481795267978*^9, 
  3.7448179540148563`*^9}},ExpressionUUID->"ff29c2b2-02a1-44e0-8b40-\
8bd94c1fe820"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4, \[CapitalDelta]=2", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 
  3.69667770458226*^9}},ExpressionUUID->"0d683512-f14a-4128-8b8d-\
08d05fc1a5c9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "cO", " ", 
      RowBox[{"p", "[", "1", "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"i1000", ",", 
           RowBox[{"p", "[", "1", "]"}], ",", 
           RowBox[{"p", "[", "1", "]"}]}], "]"}]}], "-", 
        RowBox[{"D", "[", 
         RowBox[{"i1000", ",", 
          RowBox[{"p", "[", "1", "]"}]}], "]"}]}], ")"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.6966824509163837`*^9, 
  3.696682484078072*^9}},ExpressionUUID->"df1882dd-f2df-4f33-98cf-\
0767cf1e9a46"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"4ad46ba8-9b21-4c45-acb9-\
e2ce891a55c9"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, 3.696682485856641*^9, 3.696683724500843*^9, 
   3.6967624572551813`*^9, 3.744817957410051*^9, 3.796978697563178*^9, 
   3.79841872951519*^9, 3.798418949232692*^9, 3.798419046484166*^9, 
   3.798419510543807*^9, 3.798685938308676*^9, 
   3.799037747034625*^9},ExpressionUUID->"cba9c727-a6b2-48b4-8da1-\
c8e28c141b12"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TOO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.7969787012048798`*^9, 
  3.796978703352779*^9}},ExpressionUUID->"a9e481b2-0a61-4f61-9e89-\
c7a27ba89173"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, 3.69668249632176*^9, 3.6966837298622293`*^9, 
   3.696762459013934*^9, 3.744817958247099*^9, 3.79697870446809*^9, 
   3.798418730498549*^9, 3.798418950579337*^9, 3.7984190478089542`*^9, 
   3.798419511839573*^9, 3.798685939268731*^9, 
   3.7990377478709307`*^9},ExpressionUUID->"18261ead-1248-4682-9e47-\
683d81739cfe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TOO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ApplyTWIs", "[", 
    RowBox[{"TOO", ",", "Dims"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", "cO"}], "}"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "-", "%%"}], "//.", "logsu"}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696678106749449*^9, 3.6966781141980352`*^9}, {
  3.696678238255801*^9, 3.696678242655888*^9}, {3.696683728854982*^9, 
  3.696683733177348*^9}, {3.6967624643630867`*^9, 3.696762476980503*^9}, {
  3.796978708313141*^9, 
  3.796978735328187*^9}},ExpressionUUID->"037d7f27-407e-4775-9f79-\
c14d43feaef4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"16", " ", "cO", " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     SubscriptBox["p", "2"], 
     SubscriptBox["p", "3"]], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.6966825003925247`*^9, 3.696683736001176*^9, {3.69676246123805*^9, 
   3.69676248187317*^9}, 3.7448179587381268`*^9, {3.796978724476932*^9, 
   3.796978736122759*^9}, 3.798418950864637*^9, 3.7984190481262827`*^9, 
   3.798419512136745*^9, 3.798685939513745*^9, 
   3.799037748084093*^9},ExpressionUUID->"103df170-194d-41b0-8a39-\
a936d1796454"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", " ", "cO", " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     SubsuperscriptBox["p", "2", "2"], 
     SubsuperscriptBox["p", "3", "2"]], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.6966825003925247`*^9, 3.696683736001176*^9, {3.69676246123805*^9, 
   3.69676248187317*^9}, 3.7448179587381268`*^9, {3.796978724476932*^9, 
   3.796978736122759*^9}, 3.798418950864637*^9, 3.7984190481262827`*^9, 
   3.798419512136745*^9, 3.798685939513745*^9, 
   3.799037748091563*^9},ExpressionUUID->"3f37e6c0-0bcb-477f-bbcd-\
9f799aedb794"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.6966825003925247`*^9, 3.696683736001176*^9, {3.69676246123805*^9, 
   3.69676248187317*^9}, 3.7448179587381268`*^9, {3.796978724476932*^9, 
   3.796978736122759*^9}, 3.798418950864637*^9, 3.7984190481262827`*^9, 
   3.798419512136745*^9, 3.798685939513745*^9, 
   3.79903774809363*^9},ExpressionUUID->"b297c6d5-9791-41c5-845e-\
3d0005690ea3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"61e19532-ad30-4744-b022-\
ddbdbe0bedce"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"cbc0da49-0176-48d0-9085-\
1b25eff772f8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448179635154*^9, 3.744817980595377*^9}, {
  3.796978740057392*^9, 
  3.796978742304978*^9}},ExpressionUUID->"3c6848df-e579-44f9-b26b-\
2f0b40a33a63"],

Cell[BoxData[
 RowBox[{"-", "2"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448179638254175`*^9, 
   3.7448179809003944`*^9}, 3.796978742578774*^9, 3.7984189509364033`*^9, 
   3.7984190481501303`*^9, 3.7984195121601887`*^9, 3.7986859395287457`*^9, 
   3.799037748129525*^9},ExpressionUUID->"bb8fe89b-8161-4741-85c2-\
a263001f57b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{"c", "[", "1", "]"}], 
     SubsuperscriptBox["p", "1", "2"]], "+", 
    FractionBox[
     RowBox[{"c", "[", "2", "]"}], 
     SubsuperscriptBox["p", "2", "2"]], "+", 
    FractionBox[
     RowBox[{"c", "[", "3", "]"}], 
     SubsuperscriptBox["p", "3", "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448179638254175`*^9, 
   3.7448179809003944`*^9}, 3.796978742578774*^9, 3.7984189509364033`*^9, 
   3.7984190481501303`*^9, 3.7984195121601887`*^9, 3.7986859395287457`*^9, 
   3.799037748133648*^9},ExpressionUUID->"fc339e2c-c652-4cb3-8ae1-\
3db04dc988d1"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"bc7724b5-6894-45b0-bc1f-\
c1658b8d02e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TOO", "]"}], ",", "SemiLocals", ",", 
    "Dims"}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744817985417653*^9, 
  3.744817985616664*^9}, {3.7969787462730017`*^9, 
  3.796978747102173*^9}},ExpressionUUID->"353a4222-d282-497a-b319-\
a146fa93c25e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"12", " ", 
       RowBox[{"c", "[", "1", "]"}]}], 
      SubsuperscriptBox["p", "1", "4"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "4"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubsuperscriptBox["p", "2", "4"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "4"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"12", " ", 
       RowBox[{"c", "[", "1", "]"}]}], 
      SubsuperscriptBox["p", "1", "4"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", "2", "]"}]}], 
      SubsuperscriptBox["p", "2", "4"]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, {3.7448179823254757`*^9, 
   3.74481798589368*^9}, 3.796978747423924*^9, 3.798418951000524*^9, 
   3.798419048238505*^9, 3.798419512234041*^9, 3.7986859395637474`*^9, 
   3.7990377481889353`*^9},ExpressionUUID->"bf9f72fb-182a-47c7-80b8-\
18bc82f8882d"]
}, Open  ]],

Cell["No solution.", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.744817991190983*^9, 
  3.744817993550118*^9}},ExpressionUUID->"9673afec-14da-4cb6-a9f9-\
7599cd8791a7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4, \[CapitalDelta]=4", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 3.69667770458226*^9}, {
  3.696679255482382*^9, 
  3.6966792557773647`*^9}},ExpressionUUID->"3f17a921-3727-4e64-9d93-\
0726bce13c38"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NonLocalTerm", "=", 
   RowBox[{
    RowBox[{"-", "2"}], "cO", " ", 
    RowBox[{
     RowBox[{"MRed", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "[", 
     RowBox[{
      RowBox[{"MRed", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "[", 
      RowBox[{
       RowBox[{"MRed", "[", 
        RowBox[{"3", ",", "1"}], "]"}], "[", 
       RowBox[{
        RowBox[{"1", "/", "4"}], " ", "J2", " ", "i1000"}], "]"}], "]"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LogTerm", "=", 
   RowBox[{
    RowBox[{"-", "cO"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
         RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
         RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
         RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remainder", "=", 
   RowBox[{"2", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"cO", "-", 
      RowBox[{"cO", "[", "0", "]"}]}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696681450569047*^9, 3.6966815254376087`*^9}, {
  3.696681609206441*^9, 3.696681680808737*^9}, {3.696682516812977*^9, 
  3.6966825994856987`*^9}, {3.69668263269106*^9, 3.696682633847459*^9}, {
  3.6966827911489363`*^9, 
  3.6966827968972883`*^9}},ExpressionUUID->"e405dd56-0424-44d0-adc8-\
e1893e1fed23"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"NonLocalTerm", "+", "LogTerm", "+", "Remainder"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.6966792683570137`*^9, 3.696679279573285*^9}, {3.696681304201663*^9, 
  3.696681316408358*^9}, {3.696681366492388*^9, 3.696681387231173*^9}, {
  3.696681685048072*^9, 3.696681697567984*^9}, {3.6966826044730577`*^9, 
  3.69668260480976*^9}},ExpressionUUID->"4b1ce7f9-6a50-4aa5-a292-\
2a4b6602d7b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"ApplyDmu", "[", "As", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p", "[", "1", "]"}], ",", 
     RowBox[{"p", "[", "2", "]"}], ",", 
     RowBox[{"p", "[", "3", "]"}]}], "}"}], ",", "Simplify"}], "]"}]], "Input",\

 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 3.6966776876239157`*^9}, {3.696681706876687*^9, 
  3.696681748595314*^9}},ExpressionUUID->"5f30dd93-1e3b-4d48-9a57-\
40a6be01f95d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "cO", " ", 
    SubsuperscriptBox["p", "1", "2"]}], "+", 
   RowBox[{"4", " ", "cO", " ", 
    SubsuperscriptBox["p", "2", "2"]}], "+", 
   RowBox[{"4", " ", "cO", " ", 
    SubsuperscriptBox["p", "3", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, {3.6966816993011007`*^9, 3.6966817491437187`*^9}, {
   3.696682606799593*^9, 3.6966826356365347`*^9}, 3.6966827983750353`*^9, 
   3.696683749517281*^9, 3.696762565411064*^9, 3.744818004158725*^9, 
   3.744829642943425*^9, 3.796978757220364*^9, 3.798418951109911*^9, 
   3.798419048372589*^9, 3.798419512337831*^9, 3.7986859396147504`*^9, 
   3.799037748292295*^9},ExpressionUUID->"7e35761b-aed2-49cb-acea-\
6b9aa217288a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"KExpand", "[", 
       RowBox[{"ApplyCWIs", "[", 
        RowBox[{
         RowBox[{"PrimaryCWIs", "[", "TOO", "]"}], ",", "As", ",", "Dims"}], 
        "]"}], "]"}], "/.", "Aaa"}], "//.", "logsu"}], ",", 
    RowBox[{"{", 
     RowBox[{"cO", ",", 
      RowBox[{"cO", "[", "0", "]"}], ",", "cJ", ",", 
      RowBox[{"cJ", "[", "0", "]"}], ",", 
      RowBox[{"Log", "[", "\[Mu]", "]"}]}], "}"}], ",", "Simplify"}], "]"}], "/.",
   "KillZero"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.696681878348083*^9, 3.696682040385975*^9}, {
  3.796978760697229*^9, 
  3.7969787723082542`*^9}},ExpressionUUID->"b1657f2e-4fac-406f-a8ec-\
182cc0cfd2f3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, {3.696681874922673*^9, 3.696681907467486*^9}, {
   3.696681963808894*^9, 3.696681975145215*^9}, 3.6966820106142597`*^9, 
   3.696682042625102*^9, 3.696682649443241*^9, 3.6966828081328487`*^9, 
   3.696683763562585*^9, 3.6967625856888742`*^9, 3.744818016443427*^9, 
   3.7448296555891485`*^9, 3.796978780850053*^9, 3.79841895731971*^9, 
   3.7984190782977333`*^9, 3.798419541515637*^9, 3.798685959117861*^9, 
   3.799037766220477*^9},ExpressionUUID->"df18c0ab-c928-4f8d-b8da-\
64c1b4e3e04c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"lhs", "=", 
  RowBox[{"SimplifyCWIs", "[", 
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TOO", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"rhs", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ApplyTWIs", "[", 
     RowBox[{"TOO", ",", " ", "Dims"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"cO", "[", "j_", "]"}], "\[RuleDelayed]", "cO"}], "}"}]}], "//",
    "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.69676261575229*^9, 3.696762643662058*^9}, {
  3.796978786457143*^9, 
  3.7969788140410852`*^9}},ExpressionUUID->"6057404f-7323-4ca4-8170-\
e1f0696d6a4b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cO", " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{"2", " ", "cO", " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"cO", "[", "0", "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "-", 
     RowBox[{"4", " ", "cO", " ", 
      RowBox[{"Log", "[", 
       SubscriptBox["p", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"cO", "[", "0", "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{"4", " ", "cO", " ", 
      RowBox[{"Log", "[", 
       SubscriptBox["p", "3"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{"4", " ", "cO", " ", 
      RowBox[{"Log", "[", "\[Mu]", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "2", "4"], "-", 
        SubsuperscriptBox["p", "3", "4"]}], ")"}]}]}], ")"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.696762632538765*^9, 3.696762647786045*^9}, 
   3.7448180215917215`*^9, 3.744829660635437*^9, {3.796978798501525*^9, 
   3.796978819335655*^9}, 3.798419083077428*^9, 3.798419546012725*^9, 
   3.798685962497054*^9, 
   3.79903776930157*^9},ExpressionUUID->"68835e3e-3a95-429c-9ab6-\
6f874843c776"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cO", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SubsuperscriptBox["p", "2", "2"], 
        SuperscriptBox["\[Mu]", "2"]], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "-", 
     RowBox[{"cO", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SubsuperscriptBox["p", "3", "2"], 
        SuperscriptBox["\[Mu]", "2"]], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{
      RowBox[{"cO", "[", "0", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "2", "4"], "-", 
        SubsuperscriptBox["p", "3", "4"]}], ")"}]}]}], ")"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.696762632538765*^9, 3.696762647786045*^9}, 
   3.7448180215917215`*^9, 3.744829660635437*^9, {3.796978798501525*^9, 
   3.796978819335655*^9}, 3.798419083077428*^9, 3.798419546012725*^9, 
   3.798685962497054*^9, 
   3.7990377693106833`*^9},ExpressionUUID->"b7796e91-ba66-40ca-9218-\
6e052bc6e60f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"lhs", "-", "rhs"}], "//.", "logsu"}], "]"}]], "Input",
 CellChangeTimes->{{3.696762645530176*^9, 3.69676265231802*^9}, {
  3.796978823833239*^9, 
  3.7969788272972507`*^9}},ExpressionUUID->"63eaedf7-5439-4298-93fb-\
41365efbcd20"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "4"}], " ", "cO", " ", 
   SubsuperscriptBox["p", "1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "1", "2"], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{3.696762652719969*^9, 3.7448180216577253`*^9, 
  3.7448296606764393`*^9, 3.7969788292825537`*^9, 3.7984190833007812`*^9, 
  3.798419546173998*^9, 3.798685962563058*^9, 
  3.799037769351438*^9},ExpressionUUID->"46b150bd-276a-44b1-8a7d-\
fabb3a4635ab"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"fc63dda8-8f57-43dd-9ee0-\
33d48827b7e7"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"443d70d2-1059-47f5-a443-\
bd1d80a9e549"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "+", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"i", ",", "j"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"p", "[", "j", "]"}], "^", "2"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.796978835026205*^9, 
  3.7969788373138447`*^9}},ExpressionUUID->"6142b1cf-f134-4e68-8484-\
3212b35c0cb8"],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, 3.744829717909713*^9, 3.796978838021875*^9, 
   3.798419083381213*^9, 3.7984195462279654`*^9, 3.7986859625780587`*^9, 
   3.799037769366214*^9},ExpressionUUID->"8adf52c0-f15f-46ef-91a2-\
6f8cef26142b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "1"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", "2", "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "2"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", "3", "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "1"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "2"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, 3.744829717909713*^9, 3.796978838021875*^9, 
   3.798419083381213*^9, 3.7984195462279654`*^9, 3.7986859625780587`*^9, 
   3.799037769369193*^9},ExpressionUUID->"4d43aede-0741-4731-bc2e-\
b3059bbc1e8f"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"394a3604-d39e-4ef9-be52-\
a6d01b5944a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TOO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
  3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
  3.796978842161059*^9, 
  3.7969788434892063`*^9}},ExpressionUUID->"8322fc61-be5a-4c10-af1f-\
b32d248dec3e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", "1", "]"}]}], "+", 
       RowBox[{"c", "[", "3", "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "1"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "1"}], "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "2"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2"}], "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], 
        SubsuperscriptBox["p", "1", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], 
        SubsuperscriptBox["p", "3", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], 
        SubsuperscriptBox["p", "3", "2"]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], 
        SubsuperscriptBox["p", "1", "2"]]}], ")"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", "2", "]"}]}], "+", 
       RowBox[{"c", "[", "3", "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "1"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "1"}], "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "2"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2"}], "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], 
        SubsuperscriptBox["p", "2", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], 
        SubsuperscriptBox["p", "3", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], 
        SubsuperscriptBox["p", "3", "2"]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], 
        SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", "1", "]"}]}], "+", 
       RowBox[{"c", "[", "2", "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "1"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "1"}], "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "2"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "2"}], "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], 
        SubsuperscriptBox["p", "2", "2"]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], 
        SubsuperscriptBox["p", "1", "2"]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], 
        SubsuperscriptBox["p", "1", "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], 
        SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, 3.7448180635631227`*^9, 
   3.7448181397164783`*^9, 3.7448297231820145`*^9, 3.796978844286907*^9, 
   3.798419083782865*^9, 3.7984195465524187`*^9, 3.7986859630750875`*^9, 
   3.7990377699648046`*^9},ExpressionUUID->"4a524816-c477-414b-a1df-\
190800ca2b03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cwis", "/.", "LocalPrimarySolution1"}], "//", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{"#", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Log", "[", 
        SuperscriptBox[
         RowBox[{"p", "[", "1", "]"}], "2"], "]"}], ",", 
       RowBox[{"Log", "[", 
        SuperscriptBox[
         RowBox[{"p", "[", "2", "]"}], "2"], "]"}], ",", 
       RowBox[{"Log", "[", 
        SuperscriptBox[
         RowBox[{"p", "[", "3", "]"}], "2"], "]"}]}], "}"}], ",", 
     "Simplify"}], "]"}], "&"}]}]}], "Input",
 CellChangeTimes->{{3.7448180899116297`*^9, 
  3.744818167140047*^9}},ExpressionUUID->"99e1d7ea-5e86-4d5a-ae1c-\
2e8a4d8b4a7e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448181357192497`*^9, 3.7448181673810606`*^9}, 
   3.7448297296643853`*^9, 3.79697884745673*^9, 3.798419083827701*^9, 
   3.798419546608549*^9, 3.7986859630960884`*^9, 
   3.799037769993222*^9},ExpressionUUID->"30b78035-dc86-41eb-b5bb-\
99f75b14d132"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", "1", "]"}]}], "+", 
       RowBox[{"c", "[", "3", "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", "2", "]"}]}], "+", 
       RowBox[{"c", "[", "3", "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", "1", "]"}]}], "+", 
       RowBox[{"c", "[", "2", "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}]}]}], ")"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.7448181357192497`*^9, 3.7448181673810606`*^9}, 
   3.7448297296643853`*^9, 3.79697884745673*^9, 3.798419083827701*^9, 
   3.798419546608549*^9, 3.7986859630960884`*^9, 
   3.7990377699961777`*^9},ExpressionUUID->"d3444d30-0f49-4a06-ae8f-\
1f9a1e2e8341"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution1", ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", "2", "]"}], "\[Rule]", 
        RowBox[{"c", "[", "1", "]"}]}], ",", 
       RowBox[{
        RowBox[{"c", "[", "3", "]"}], "\[Rule]", 
        RowBox[{"c", "[", "1", "]"}]}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"i", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "}"}], "//", 
     "Flatten"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7448181805508137`*^9, 
  3.7448182125856457`*^9}},ExpressionUUID->"f0c2b35b-a661-4d1f-a6fe-\
4990604f4c08"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"c", "[", "1", "]"}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], "\[Rule]", 
    RowBox[{"c", "[", "1", "]"}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448182129146647`*^9, 3.7448297463963423`*^9, 
  3.7969788502235394`*^9, 3.798419083881637*^9, 3.7984195466692257`*^9, 
  3.7986859631130896`*^9, 
  3.799037770006802*^9},ExpressionUUID->"9d11c9c1-5a71-4741-af3e-\
af29b2053c20"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"6b04955d-de0e-4878-aa98-\
bcc5516051cb"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TOO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TOO", ",", " ", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.7969788541609383`*^9, 
   3.796978868265339*^9}},ExpressionUUID->"d7b7379b-41b6-4da5-aa87-\
753a0feebb8c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", " ", 
   RowBox[{"c", "[", "1", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     SubsuperscriptBox["p", "3", "4"]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744829748468461*^9, {3.7969788628929777`*^9, 3.796978868799387*^9}, 
   3.7984190839392653`*^9, 3.798419546717038*^9, 3.7986859631250896`*^9, 
   3.799037770047633*^9},ExpressionUUID->"a6cf0e5d-0228-46fa-aa96-\
925670dfd2fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"cO", "[", "2", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SubsuperscriptBox["p", "2", "2"], 
        SuperscriptBox["\[Mu]", "2"]], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "-", 
     RowBox[{
      RowBox[{"cO", "[", "3", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SubsuperscriptBox["p", "3", "2"], 
        SuperscriptBox["\[Mu]", "2"]], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{
      SubsuperscriptBox["p", "2", "4"], " ", 
      RowBox[{
       RowBox[{"cO", "[", "2", "]"}], "[", "0", "]"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "3", "4"], " ", 
      RowBox[{
       RowBox[{"cO", "[", "3", "]"}], "[", "0", "]"}]}]}], ")"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744829748468461*^9, {3.7969788628929777`*^9, 3.796978868799387*^9}, 
   3.7984190839392653`*^9, 3.798419546717038*^9, 3.7986859631250896`*^9, 
   3.799037770058622*^9},ExpressionUUID->"53c1f94d-635f-4752-8f0c-\
213720dcb890"]
}, Open  ]],

Cell["\<\
The only possible solution could be A[1] = c[1] p[1]^2, but the constant, \
c[1], must be fixed in order to match the secondary Ward identity. The \
original solution already satisfies the secondary Ward identity and hence \
c[1] = 0. No solutions.\
\>", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.744818270940984*^9, 
  3.7448183241080246`*^9}},ExpressionUUID->"ba1d5fbf-b705-4456-bf6d-\
8abb3abcc7e0"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["<JJO>", "Section",
 CellChangeTimes->{{3.696662757712263*^9, 3.696662759359742*^9}, {
  3.696682859217309*^9, 
  3.696682859569441*^9}},ExpressionUUID->"6744bcd3-37b3-47c7-8f7c-\
f5c3122efc2f"],

Cell[CellGroupData[{

Cell["d=3, \[CapitalDelta]=1", "Subsection",
 CellChangeTimes->{{3.696663690437581*^9, 
  3.6966636937738028`*^9}},ExpressionUUID->"c643a012-8ffb-444d-a8b6-\
e3f7b6f24319"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"a", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], " ", 
         RowBox[{"a123", "^", "2"}]}], ")"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[Gamma]", " ", 
        RowBox[{"cO", "/", 
         RowBox[{"p", "[", "3", "]"}]}]}], "+", 
       RowBox[{"a", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "a123"}], "-", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"2", 
             RowBox[{"p", "[", "3", "]"}]}], ")"}]}]}], ")"}]}]}]}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "1"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
  3.696684013724811*^9, 3.696684064967544*^9}, {3.6967638548046913`*^9, 
  3.696763860401299*^9}, {3.744818712020212*^9, 3.7448187246249332`*^9}, {
  3.796979074360241*^9, 
  3.796979075065031*^9}},ExpressionUUID->"744db7f6-1452-42f7-92f4-\
3713fbcbcaaf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677607964088*^9, 
  3.6966776258540688`*^9}},ExpressionUUID->"363c7206-e291-44d0-abd5-\
031354ea89e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.696677627230453*^9, 3.6966776623071833`*^9, 3.696678324117044*^9, 
   3.696679200338336*^9, {3.696684066743404*^9, 3.6966840824275312`*^9}, 
   3.696763885886136*^9, 3.696764004765786*^9, 3.7448183443171806`*^9, 
   3.7448184874043646`*^9, 3.744818725708995*^9, 3.796979076479918*^9, 
   3.798419084034028*^9, 3.7984195467919693`*^9, 3.7986859631650925`*^9, 
   3.799037770104391*^9},ExpressionUUID->"b6744c62-7a5b-48b1-a45f-\
82ca3709770a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796979079536892*^9, 
  3.796979103592308*^9}},ExpressionUUID->"35a7ab3c-579b-4973-8afd-\
e0fed968ab71"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, {3.696684068482006*^9, 
   3.696684082890736*^9}, 3.696763890389574*^9, 3.696764005322192*^9, 
   3.7448183448562117`*^9, 3.744818487828389*^9, 3.744818726007012*^9, {
   3.796979080867148*^9, 3.796979104010571*^9}, 3.798419084054186*^9, 
   3.7984195468417397`*^9, 3.798685963191094*^9, 
   3.799037770136425*^9},ExpressionUUID->"ed9129e3-661a-4411-9442-\
525922e8ac0e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", "%%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696684086068306*^9, 3.6966840888764772`*^9}, {
  3.696763895787451*^9, 3.69676389611366*^9}, {3.696763997688212*^9, 
  3.6967639980998697`*^9}, {3.796979084848978*^9, 
  3.796979109344739*^9}},ExpressionUUID->"0d5b349f-a13d-4096-8f79-\
38c7b1b66587"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "cO", " ", "\[Gamma]"}], 
    SubscriptBox["p", "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, {3.6967638926190243`*^9, 3.69676389638797*^9}, {
   3.69676399865977*^9, 3.6967640059589043`*^9}, 3.744818345415243*^9, 
   3.744818488337418*^9, 3.744818726270027*^9, 3.796979109783041*^9, 
   3.798419084112747*^9, 3.798419546896538*^9, 3.7986859632060947`*^9, 
   3.799037770169742*^9},ExpressionUUID->"b474b869-6d11-44b4-ae85-\
536a67d54b84"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, {3.6967638926190243`*^9, 3.69676389638797*^9}, {
   3.69676399865977*^9, 3.6967640059589043`*^9}, 3.744818345415243*^9, 
   3.744818488337418*^9, 3.744818726270027*^9, 3.796979109783041*^9, 
   3.798419084112747*^9, 3.798419546896538*^9, 3.7986859632060947`*^9, 
   3.799037770172565*^9},ExpressionUUID->"90818340-7142-4d48-b7c4-\
5ed4ff7954a2"],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"2", " ", "cO", " ", "\[Gamma]"}], 
   SubscriptBox["p", "3"]], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, {3.6967638926190243`*^9, 3.69676389638797*^9}, {
   3.69676399865977*^9, 3.6967640059589043`*^9}, 3.744818345415243*^9, 
   3.744818488337418*^9, 3.744818726270027*^9, 3.796979109783041*^9, 
   3.798419084112747*^9, 3.798419546896538*^9, 3.7986859632060947`*^9, 
   3.7990377701749773`*^9},ExpressionUUID->"de0fdff1-0d5e-41e4-8a9f-\
deb45efecaf8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"08d27be6-1e95-458c-b97d-\
494a76ba096d"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"16c27a4a-e5a9-45a6-8b8d-\
c06a8070f312"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "2"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "dimA1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c2", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"dimA1", "+", "2"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.79697911640167*^9, 
  3.79697911903288*^9}},ExpressionUUID->"34dd996e-0acc-4b40-90e3-\
65ef4f710ede"],

Cell[BoxData[
 RowBox[{"-", "3"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.796979122072006*^9, 3.798419084129513*^9, 3.7984195469574127`*^9, 
   3.798685963226096*^9, 
   3.799037770190979*^9},ExpressionUUID->"7b4508a4-1b2c-44c6-92e0-\
e68e114a1e0b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c1", "[", "1", "]"}], 
      SubsuperscriptBox["p", "1", "3"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "2", "]"}], 
      SubsuperscriptBox["p", "2", "3"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "3", "]"}], 
      SubsuperscriptBox["p", "3", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], 
      SubscriptBox["p", "1"]], "+", 
     FractionBox[
      RowBox[{"c2", "[", "2", "]"}], 
      SubscriptBox["p", "2"]], "+", 
     FractionBox[
      RowBox[{"c2", "[", "3", "]"}], 
      SubscriptBox["p", "3"]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.796979122072006*^9, 3.798419084129513*^9, 3.7984195469574127`*^9, 
   3.798685963226096*^9, 
   3.799037770194495*^9},ExpressionUUID->"f39414f5-b276-44d8-96ac-\
1eecd6babee5"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"00b536af-a67b-4fd3-a689-\
93b316c71b15"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
  3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
  3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
  3.7448185876761*^9}, {3.796979131816085*^9, 
  3.796979132728368*^9}},ExpressionUUID->"9aaf704e-52de-4402-b4cb-\
c9fe91a9f9bd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"6", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]], "-", 
      FractionBox[
       RowBox[{"6", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, 3.7448180635631227`*^9, 
   3.7448181397164783`*^9, 3.7448183948390703`*^9, 3.744818533107979*^9, 
   3.744818588355139*^9, 3.744818729484211*^9, 3.7969791334074183`*^9, 
   3.7984190842785063`*^9, 3.798419547052197*^9, 3.7986859633071003`*^9, 
   3.799037770311326*^9},ExpressionUUID->"bf0c8601-7f38-44fd-bd28-\
f0681125db2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis", "/.", "LocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.7448185917453327`*^9, 
  3.744818615404686*^9}},ExpressionUUID->"492827f5-815b-4c11-9ab1-\
eefce9a58a6e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448186156917024`*^9, 3.7448187309882965`*^9, 
  3.796979135412498*^9, 3.7984190843525667`*^9, 3.798419547105536*^9, 
  3.7986859633201013`*^9, 
  3.7990377703217688`*^9},ExpressionUUID->"3ecea387-f6ba-4915-9669-\
b71f73a66b6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448186156917024`*^9, 3.7448187309882965`*^9, 
  3.796979135412498*^9, 3.7984190843525667`*^9, 3.798419547105536*^9, 
  3.7986859633201013`*^9, 
  3.799037770329801*^9},ExpressionUUID->"7dff2000-db15-42e7-818d-\
6470754bdfb8"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"7c05c533-11c8-45b3-a602-\
7b27dc160ea9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.796979139216971*^9, 
   3.796979152664946*^9}},ExpressionUUID->"7203198c-a5b9-441f-b2d8-\
30866a283f6d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"c2", "[", "3", "]"}]}], 
    SubscriptBox["p", "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.796979153074953*^9, 
   3.7984190844113827`*^9, 3.798419547182914*^9, 3.7986859633371024`*^9, 
   3.7990377703930397`*^9},ExpressionUUID->"82056588-9cd4-47eb-8dcb-\
d97137c7d36d"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.796979153074953*^9, 
   3.7984190844113827`*^9, 3.798419547182914*^9, 3.7986859633371024`*^9, 
   3.799037770396246*^9},ExpressionUUID->"86710cde-d0f8-410a-ae83-\
650b7bfa7931"]
}, Open  ]],

Cell["\<\
The only possible solution could be A[1] = 0, A[2] = c2[3]/p[3]. This is the \
semilocal solution of the functional derivative type. However, the constant, \
c2[3], must be fixed in order to match the secondary Ward identity. The \
original solution already satisfies the secondary Ward identity and hence \
c2[3] = 0. No solutions.\
\>", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.744818270940984*^9, 
  3.7448183241080246`*^9}, {3.744818645090384*^9, 
  3.744818706001868*^9}},ExpressionUUID->"3e3dd3fa-9410-4308-a708-\
310fd36e9070"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=3, \[CapitalDelta]=3", "Subsection",
 CellChangeTimes->{{3.696677309328281*^9, 
  3.696677312480341*^9}},ExpressionUUID->"a8e2ba60-e678-4130-8271-\
2e62d29b1f4b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"a", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a123", "+", 
          RowBox[{"p", "[", "3", "]"}]}], ")"}], "/", 
        RowBox[{"a123", "^", "2"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "a"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a12", "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "a12"}], "-", 
          RowBox[{"2", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "a123"}], ")"}]}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
  3.696677341394161*^9, 3.69667740301085*^9}, {3.696684094936317*^9, 
  3.6966841405674343`*^9}, {3.696763932597541*^9, 3.6967639340787487`*^9}, {
  3.796979159139708*^9, 
  3.796979159432972*^9}},ExpressionUUID->"d15a3e0a-eaaf-4191-ab15-\
8f92e395f908"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"d316aa4f-393a-408f-b147-\
6cc235b2af99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696679209740868*^9, 
   3.6966841440153103`*^9, 3.696763961406042*^9, 3.6967640179225607`*^9, 
   3.7448184198535013`*^9, 3.744818745940152*^9, 3.744818838762461*^9, 
   3.7969791606102858`*^9, 3.798419084482777*^9, 3.798419547261196*^9, 
   3.798685963367104*^9, 
   3.799037770441782*^9},ExpressionUUID->"3ccbcae1-b942-48c5-916c-\
ae3431477633"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.7969791631125393`*^9, 
  3.796979164145198*^9}},ExpressionUUID->"268602f1-e9c1-4ddf-8e7a-\
26e29f048951"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, 
   3.6966792104989567`*^9, 3.696684144938717*^9, 3.696763961885736*^9, 
   3.6967640185320387`*^9, 3.7448184208055553`*^9, 3.7448187467832003`*^9, 
   3.7448188393454943`*^9, 3.796979164638144*^9, 3.798419084561551*^9, 
   3.7984195473055143`*^9, 3.798685963401106*^9, 
   3.7990377704826117`*^9},ExpressionUUID->"bf04aadf-75dc-4eac-9b0c-\
42d29250fc77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.69676396534678*^9, 3.69676396565079*^9}, {
  3.6967640212686577`*^9, 3.6967640219558268`*^9}, {3.796979167488768*^9, 
  3.796979176152762*^9}},ExpressionUUID->"6243f0a3-3eef-485d-8f26-\
820a126bc0e5"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696684147312687*^9, {3.696763962999544*^9, 
   3.696763965923875*^9}, 3.696764022260346*^9, 3.7448184214355917`*^9, 
   3.7448187485052986`*^9, 3.744818840034534*^9, 3.796979176641925*^9, 
   3.798419084615741*^9, 3.798419547353025*^9, 3.798685963415107*^9, 
   3.799037770519947*^9},ExpressionUUID->"2bf66dd5-3819-4eef-a455-\
492d6ab1c198"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696684147312687*^9, {3.696763962999544*^9, 
   3.696763965923875*^9}, 3.696764022260346*^9, 3.7448184214355917`*^9, 
   3.7448187485052986`*^9, 3.744818840034534*^9, 3.796979176641925*^9, 
   3.798419084615741*^9, 3.798419547353025*^9, 3.798685963415107*^9, 
   3.7990377705227337`*^9},ExpressionUUID->"98af7799-7883-47d3-818c-\
bc6a5a4f4af7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"eb5b7b56-6e28-4079-9def-\
325cddcbb60e"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"aeb1d4ba-6d0b-440c-9205-\
e791824c83fb"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "2"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "dimA1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c2", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"dimA1", "+", "2"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7969791804413633`*^9, 
  3.796979182905184*^9}},ExpressionUUID->"df523ff1-615c-4d80-b7c2-\
6d19a6dc0f27"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, 3.7969791833964443`*^9, 
   3.79841908462963*^9, 3.7984195474142933`*^9, 3.798685963432108*^9, 
   3.799037770540759*^9},ExpressionUUID->"40d5401e-1c81-44e1-8ce9-\
db85d67c842b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c1", "[", "1", "]"}], 
      SubscriptBox["p", "1"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "2", "]"}], 
      SubscriptBox["p", "2"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "3", "]"}], 
      SubscriptBox["p", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c2", "[", "1", "]"}], " ", 
      SubscriptBox["p", "1"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      SubscriptBox["p", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubscriptBox["p", "3"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, 3.7969791833964443`*^9, 
   3.79841908462963*^9, 3.7984195474142933`*^9, 3.798685963432108*^9, 
   3.7990377705448713`*^9},ExpressionUUID->"0f576dc6-71b8-4160-8bf9-\
0afb6b9b3bd9"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"0917fc43-dff4-483c-8ae7-\
4b50ae29895c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
  3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
  3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
  3.7448185876761*^9}, {3.796979198008648*^9, 
  3.7969791982974043`*^9}},ExpressionUUID->"834d29e2-c190-4dd4-a76f-\
c0ed1e72673f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubscriptBox["p", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", "[", "3", "]"}], "-", 
          RowBox[{"c2", "[", "3", "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubscriptBox["p", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", "[", "3", "]"}], "-", 
          RowBox[{"c2", "[", "3", "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, 3.7448180635631227`*^9, 
   3.7448181397164783`*^9, 3.7448183948390703`*^9, 3.744818533107979*^9, 
   3.744818588355139*^9, 3.744818729484211*^9, 3.744818779734085*^9, 
   3.744818845451844*^9, 3.796979199616589*^9, 3.79841908473563*^9, 
   3.798419547475451*^9, 3.7986859634811106`*^9, 
   3.799037770625243*^9},ExpressionUUID->"e2c9d85c-269b-4ba8-a1e8-\
a4088827f6e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis", "/.", "LocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.7448185917453327`*^9, 3.744818615404686*^9}, {
  3.7448187928928375`*^9, 
  3.7448187961940265`*^9}},ExpressionUUID->"8cc697ac-4971-4e51-b167-\
723f538ddf76"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448186156917024`*^9, 3.7448187309882965`*^9, 
  3.744818796555047*^9, 3.7448188464899035`*^9, 3.7969792069050922`*^9, 
  3.798419084749221*^9, 3.798419547526567*^9, 3.798685963493111*^9, 
  3.799037770639344*^9},ExpressionUUID->"af17d518-352c-41ea-ba16-\
05ce36676535"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448186156917024`*^9, 3.7448187309882965`*^9, 
  3.744818796555047*^9, 3.7448188464899035`*^9, 3.7969792069050922`*^9, 
  3.798419084749221*^9, 3.798419547526567*^9, 3.798685963493111*^9, 
  3.7990377706417227`*^9},ExpressionUUID->"783856c2-8e15-41c9-9e2b-\
3e31b07d1c4f"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"08ce6bb4-bada-4218-975a-\
bb0a96fc74f1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", " ", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.796979211553328*^9, 
   3.796979224074223*^9}},ExpressionUUID->"25f38d64-0bd1-4d8f-bbee-\
3a9e97268189"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{"c2", "[", "2", "]"}], " ", 
   SubscriptBox["p", "2"]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7969792272283087`*^9, 3.798419084815819*^9, 
   3.798419547588678*^9, 3.798685963508112*^9, 
   3.799037770677802*^9},ExpressionUUID->"c8bcce63-12a3-422b-a9e0-\
50511ca2c2b3"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7969792272283087`*^9, 3.798419084815819*^9, 
   3.798419547588678*^9, 3.798685963508112*^9, 
   3.799037770680785*^9},ExpressionUUID->"5089e78d-b192-46cb-aa14-\
f01b08ff0edd"]
}, Open  ]],

Cell["\<\
We have a solution: A[1] = 0, A[2] = c2[1] p[1]. Let\[CloseCurlyQuote]s test \
it:\
\>", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.744818270940984*^9, 
  3.7448183241080246`*^9}, {3.744818645090384*^9, 3.744818706001868*^9}, {
  3.7448188600646796`*^9, 
  3.744818913495736*^9}},ExpressionUUID->"d7988999-b95a-43f5-b077-\
9b1d92d84e63"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"a", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a123", "+", 
          RowBox[{"p", "[", "3", "]"}]}], ")"}], "/", 
        RowBox[{"a123", "^", "2"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a12", "^", "2"}], "+", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "a12"}], "-", 
           RowBox[{"2", 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "a123"}], ")"}]}]}], " ", "+", " ", 
       RowBox[{"c", " ", 
        RowBox[{"p", "[", "1", "]"}]}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
  3.696677341394161*^9, 3.69667740301085*^9}, {3.696684094936317*^9, 
  3.6966841405674343`*^9}, {3.696763932597541*^9, 3.6967639340787487`*^9}, {
  3.744818917398959*^9, 3.744818923765323*^9}, {3.7969795968518257`*^9, 
  3.7969795971054707`*^9}},ExpressionUUID->"d15a3e0a-eaaf-4191-ab15-\
8f92e395f908"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"d316aa4f-393a-408f-b147-\
6cc235b2af99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696679209740868*^9, 
   3.6966841440153103`*^9, 3.696763961406042*^9, 3.6967640179225607`*^9, 
   3.7448184198535013`*^9, 3.744818745940152*^9, 3.744818838762461*^9, 
   3.744818925962449*^9, 3.796979236505496*^9, 3.798419084882476*^9, 
   3.7984195476776123`*^9, 3.798685963534114*^9, 
   3.79903777073344*^9},ExpressionUUID->"b2aa1e7a-a850-43ab-a296-\
4ee79a16d0b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796979238929296*^9, 
  3.7969792399530897`*^9}},ExpressionUUID->"268602f1-e9c1-4ddf-8e7a-\
26e29f048951"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, 
   3.6966792104989567`*^9, 3.696684144938717*^9, 3.696763961885736*^9, 
   3.6967640185320387`*^9, 3.7448184208055553`*^9, 3.7448187467832003`*^9, 
   3.7448188393454943`*^9, 3.7448189266094856`*^9, 3.796979240402169*^9, 
   3.798419084959958*^9, 3.798419547721756*^9, 3.798685963596117*^9, 
   3.799037770769845*^9},ExpressionUUID->"4af0e45d-ac1a-401f-bdce-\
e7fd9c164fac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.69676396534678*^9, 3.69676396565079*^9}, {
  3.6967640212686577`*^9, 3.6967640219558268`*^9}, {3.796979242776091*^9, 
  3.7969792499449987`*^9}},ExpressionUUID->"6243f0a3-3eef-485d-8f26-\
820a126bc0e5"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696684147312687*^9, {3.696763962999544*^9, 
   3.696763965923875*^9}, 3.696764022260346*^9, 3.7448184214355917`*^9, 
   3.7448187485052986`*^9, 3.744818840034534*^9, 3.7448189273195267`*^9, 
   3.796979250388721*^9, 3.7984190850143623`*^9, 3.798419547768152*^9, 
   3.798685963620118*^9, 
   3.799037770807721*^9},ExpressionUUID->"7727a7e8-65d0-4cab-a8c2-\
7354465ea88b"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696684147312687*^9, {3.696763962999544*^9, 
   3.696763965923875*^9}, 3.696764022260346*^9, 3.7448184214355917`*^9, 
   3.7448187485052986`*^9, 3.744818840034534*^9, 3.7448189273195267`*^9, 
   3.796979250388721*^9, 3.7984190850143623`*^9, 3.798419547768152*^9, 
   3.798685963620118*^9, 
   3.7990377708111353`*^9},ExpressionUUID->"013c02ce-bd48-4e28-b1ae-\
ced3df18f4cc"]
}, Open  ]],

Cell["Ok.", "Text",
 CellChangeTimes->{{3.7448189507118645`*^9, 
  3.744818951071885*^9}},ExpressionUUID->"0325f17b-a1c3-4f58-8150-\
e851b1635ad8"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4, \[CapitalDelta]=2", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 
  3.69667770458226*^9}},ExpressionUUID->"1eea18bc-2e64-4c1c-9879-\
57d352a4c4d4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{"p", "[", "1", "]"}], 
       RowBox[{"p", "[", "2", "]"}], " ", 
       RowBox[{"D", "[", 
        RowBox[{"i1000", ",", 
         RowBox[{"p", "[", "1", "]"}], ",", 
         RowBox[{"p", "[", "2", "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"a", 
        RowBox[{"(", 
         RowBox[{"i2111fin", "+", 
          RowBox[{
           RowBox[{"1", "/", "6"}], " ", 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "3", "]"}], "^", "4"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
               RowBox[{
                RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}]}], "]"}]}], 
          "+", 
          RowBox[{"1", "/", "2"}]}], ")"}]}], "+", "c1", "+", 
       RowBox[{"c0", " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.696684161089705*^9, 3.696684198078211*^9}, {3.696684252001034*^9, 
  3.696684254088887*^9}, {3.696764038615696*^9, 3.696764040947901*^9}, {
  3.697364969313258*^9, 3.697364970801893*^9}, {3.69736504087598*^9, 
  3.697365056095274*^9}, {3.796979256160548*^9, 
  3.796979256392898*^9}},ExpressionUUID->"b0d5ec4c-18ea-4e8a-89de-\
63e42c05154e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"97cde6f5-4cea-4bfc-91f6-\
cb3609dbab46"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "c0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, 3.696684203185841*^9, 3.696764160300931*^9, 
   3.697364976318466*^9, 3.697365057851697*^9, 3.7448189551541185`*^9, 
   3.7969792590163727`*^9, 3.796979358367811*^9, 3.798419085087502*^9, 
   3.798419547842593*^9, 3.7986859636681213`*^9, 
   3.7990377708632917`*^9},ExpressionUUID->"6ab775d8-20b0-47bd-aceb-\
3c4e0371cc7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.796979262784828*^9, 3.796979263289085*^9}, {
  3.7969792968738737`*^9, 3.796979299241074*^9}, {3.796979362875404*^9, 
  3.7969793637125893`*^9}},ExpressionUUID->"8fc5f08f-de5f-404e-abdb-\
4f2434140771"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, 3.696684208811737*^9, {3.696684242701248*^9, 
   3.6966842567745113`*^9}, 3.696764161448435*^9, 3.697364977511446*^9, 
   3.697365059130555*^9, 3.7448189569742227`*^9, 3.7969792684258833`*^9, 
   3.796979306895811*^9, {3.796979361495085*^9, 3.7969793654177027`*^9}, 
   3.79841908745179*^9, 3.7984195500599833`*^9, 3.7986859655702286`*^9, 
   3.7990377727058783`*^9},ExpressionUUID->"1be72725-ed48-416b-8fc4-\
2bdbec8e6d82"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696678106749449*^9, 3.6966781141980352`*^9}, {
  3.696678238255801*^9, 3.696678242655888*^9}, {3.796979369048992*^9, 
  3.796979377576736*^9}},ExpressionUUID->"d2f86c00-89f3-41d3-9986-\
7a24d68d147e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"(", 
    RowBox[{"c1", "-", 
     RowBox[{"2", " ", "c0", " ", 
      RowBox[{"Log", "[", "\[Mu]", "]"}]}], "+", 
     RowBox[{"2", " ", "c0", " ", 
      RowBox[{"Log", "[", 
       SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696684262444735*^9, 3.696764162321403*^9, 3.69736497848522*^9, 
   3.697365026019041*^9, 3.6973650602735167`*^9, 3.7448189574022474`*^9, 
   3.7969793783767443`*^9, 3.798419087966037*^9, 3.798419550446848*^9, 
   3.7986859658882465`*^9, 
   3.799037773016308*^9},ExpressionUUID->"8e811283-f610-46b0-8d1f-\
ddf4f27f7fec"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696684262444735*^9, 3.696764162321403*^9, 3.69736497848522*^9, 
   3.697365026019041*^9, 3.6973650602735167`*^9, 3.7448189574022474`*^9, 
   3.7969793783767443`*^9, 3.798419087966037*^9, 3.798419550446848*^9, 
   3.7986859658882465`*^9, 
   3.799037773020073*^9},ExpressionUUID->"e86b47d8-2ef3-410e-9358-\
28296829fbc8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"b903009a-22ab-4bf6-9f88-\
8d91b9b97eed"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"63dea736-4bb6-4535-8ce2-\
a36fef88fa49"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "2"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "dimA1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"c", "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", "i", "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.796979382225462*^9, 
  3.79697938623274*^9}},ExpressionUUID->"13c0ddd6-1d7b-40e6-b9f8-\
f0febd3b1ff1"],

Cell[BoxData[
 RowBox[{"-", "2"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.79697938667715*^9, 3.798419087984264*^9, 
   3.798419550501218*^9, 3.7986859659022474`*^9, 
   3.799037773036592*^9},ExpressionUUID->"7258615b-33f4-4609-b6dd-\
76286a06aaaf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c1", "[", "1", "]"}], 
      SubsuperscriptBox["p", "1", "2"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "2", "]"}], 
      SubsuperscriptBox["p", "2", "2"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "3", "]"}], 
      SubsuperscriptBox["p", "3", "2"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"c", "+", 
     RowBox[{
      RowBox[{"c2", "[", "1", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.79697938667715*^9, 3.798419087984264*^9, 
   3.798419550501218*^9, 3.7986859659022474`*^9, 
   3.7990377730392513`*^9},ExpressionUUID->"3379321b-8a0d-44d6-b114-\
c7b25ac7e046"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"0a4a4b6b-94fb-45de-a427-\
437f13cdfab1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
  3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
  3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
  3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
  3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
  3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
  3.7448185876761*^9}, {3.796979390680998*^9, 
  3.796979391681423*^9}},ExpressionUUID->"c6a51a1e-56bf-40ae-bae4-\
123929a9dd0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c2", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, 3.7448180635631227`*^9, 
   3.7448181397164783`*^9, 3.7448183948390703`*^9, 3.744818533107979*^9, 
   3.744818588355139*^9, 3.744818729484211*^9, 3.744818779734085*^9, 
   3.744818845451844*^9, 3.7448190497795305`*^9, 3.796979392349176*^9, 
   3.798419088114694*^9, 3.798419550594047*^9, 3.798685965979252*^9, 
   3.799037773157405*^9},ExpressionUUID->"c0199a6a-2bd2-4442-96c0-\
179ea69cce92"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis", "/.", "LocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.7448185917453327`*^9, 3.744818615404686*^9}, {
  3.7448187928928375`*^9, 3.7448187961940265`*^9}, {3.744819059923111*^9, 
  3.744819077658125*^9}},ExpressionUUID->"3c0521dc-9ce3-4f44-87c7-\
04a2846790b7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448186156917024`*^9, 3.7448187309882965`*^9, 
  3.744818796555047*^9, 3.7448188464899035`*^9, 3.7448190783291636`*^9, 
  3.7969793942110033`*^9, 3.798419088126891*^9, 3.798419550651536*^9, 
  3.7986859659942527`*^9, 
  3.799037773167988*^9},ExpressionUUID->"14d164e4-7d65-4ce9-a805-\
6de161f2f8d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448186156917024`*^9, 3.7448187309882965`*^9, 
  3.744818796555047*^9, 3.7448188464899035`*^9, 3.7448190783291636`*^9, 
  3.7969793942110033`*^9, 3.798419088126891*^9, 3.798419550651536*^9, 
  3.7986859659942527`*^9, 
  3.79903777317065*^9},ExpressionUUID->"bcd35cee-253f-424e-bf9e-513544c109fe"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"d1bf059a-6d86-4155-b6d7-\
8f4749732328"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.796979398120832*^9, 
   3.7969794110320387`*^9}},ExpressionUUID->"d25b184e-dbb6-4588-b43f-\
dae6546001d7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"(", 
    RowBox[{"c", "+", 
     RowBox[{"2", " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.796979411802734*^9, 
   3.798419088187554*^9, 3.7984195506997957`*^9, 3.798685966010254*^9, 
   3.799037773244528*^9},ExpressionUUID->"37e03318-f35b-4750-99bb-\
10ee53a19d67"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.796979411802734*^9, 
   3.798419088187554*^9, 3.7984195506997957`*^9, 3.798685966010254*^9, 
   3.799037773247121*^9},ExpressionUUID->"c10ba27a-6acb-43c4-ac72-\
dabb6d5bb32a"]
}, Open  ]],

Cell["No solutions.", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
  3.744816642839862*^9, 3.7448166929677286`*^9}, {3.744818270940984*^9, 
  3.7448183241080246`*^9}, {3.744818645090384*^9, 3.744818706001868*^9}, {
  3.7448188600646796`*^9, 3.744818913495736*^9}, {3.7448191115910664`*^9, 
  3.744819115382283*^9}},ExpressionUUID->"e25bb784-b685-4114-af4b-\
939b18ce46f3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4, \[CapitalDelta]=4", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 3.69667770458226*^9}, {
  3.696679255482382*^9, 
  3.6966792557773647`*^9}},ExpressionUUID->"c8720ac8-845f-477d-861a-\
e49219549136"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{
         RowBox[{"MRed", "[", 
          RowBox[{"3", ",", "1"}], "]"}], "[", "i2111fin", "]"}]}], "-", 
       RowBox[{
        RowBox[{"1", "/", "3"}], " ", "a", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], ")"}]}], "+", "scdep"}]}],
      ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", "i2111fin"}], "+", 
       RowBox[{
        RowBox[{"1", "/", "6"}], " ", "a", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", 
              RowBox[{
               RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "-", 
             RowBox[{
              RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
             RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", 
              RowBox[{
               RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], "-", 
             RowBox[{
              RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
             RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
             RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
          RowBox[{"3", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "6"}], " ", "a"}], "-", 
          RowBox[{
           RowBox[{"1", "/", "2"}], " ", "scdep"}]}], ")"}]}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.6966792683570137`*^9, 3.696679279573285*^9}, {3.696681304201663*^9, 
  3.696681316408358*^9}, {3.696681366492388*^9, 3.696681387231173*^9}, {
  3.696681685048072*^9, 3.696681697567984*^9}, {3.69668428384752*^9, 
  3.6966844247304697`*^9}, {3.696684771280221*^9, 3.696684771471381*^9}, {
  3.7969794186893387`*^9, 
  3.796979418921505*^9}},ExpressionUUID->"9cc5556e-d5e7-4b39-aa7f-\
e39a276d1d2a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyDmu", "[", "As", "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 3.6966776876239157`*^9}, {3.696681706876687*^9, 
  3.696681748595314*^9}, {3.696684438331925*^9, 
  3.696684444394032*^9}},ExpressionUUID->"e3313f07-ff52-401a-9c9f-\
5fb01158cd15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", "a"}], ",", 
   RowBox[{
    RowBox[{"-", "a"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      SubsuperscriptBox["p", "2", "2"], "-", 
      SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, {3.6966816993011007`*^9, 3.6966817491437187`*^9}, {
   3.6966844040786943`*^9, 3.696684444634461*^9}, 3.6967642776847067`*^9, 
   3.7448191319322295`*^9, 3.744830678420651*^9, 3.796979422493526*^9, 
   3.798419088255522*^9, 3.798419550790036*^9, 3.798685966052256*^9, 
   3.799037773308961*^9},ExpressionUUID->"6432e5f1-c34d-4977-aac3-\
a84997773e4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.696681878348083*^9, 3.696682040385975*^9}, {
  3.696764293312912*^9, 3.696764305178122*^9}, {3.796979433913432*^9, 
  3.796979435100136*^9}},ExpressionUUID->"f8ee9291-44e9-4ec2-a1a5-\
2cef1b1b84c3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", "a"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", "a"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, {3.696681874922673*^9, 3.696681907467486*^9}, {
   3.696681963808894*^9, 3.696681975145215*^9}, 3.6966820106142597`*^9, 
   3.696682042625102*^9, 3.696684451424481*^9, 3.696684629058628*^9, 
   3.696684754647168*^9, 3.696764306328925*^9, 3.7448191346093826`*^9, 
   3.744830682227869*^9, 3.7969794382254457`*^9, 3.798419092134823*^9, 
   3.798419554126376*^9, 3.79868596962446*^9, 
   3.799037776762936*^9},ExpressionUUID->"3c6565d7-e5dd-47e5-a70a-\
400863934d44"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
   3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
   3.6966772912178926`*^9}, {3.696678106749449*^9, 3.6966781141980352`*^9}, {
   3.696678238255801*^9, 3.696678242655888*^9}, {3.696682094182363*^9, 
   3.696682103623598*^9}, 3.696684803970422*^9, {3.796979445064457*^9, 
   3.796979452721095*^9}},ExpressionUUID->"5d35bb63-d5c6-4768-9d64-\
64e3e25608a2"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696682105615172*^9, 3.696684774774837*^9, 3.6966848058389807`*^9, 
   3.696764313711619*^9, 3.744819135246419*^9, 3.7969794540221567`*^9, 
   3.798419092688923*^9, 3.798419554717535*^9, 3.798685970189492*^9, 
   3.799037777296327*^9},ExpressionUUID->"92993499-f331-401e-9185-\
1277b3976cd5"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696682105615172*^9, 3.696684774774837*^9, 3.6966848058389807`*^9, 
   3.696764313711619*^9, 3.744819135246419*^9, 3.7969794540221567`*^9, 
   3.798419092688923*^9, 3.798419554717535*^9, 3.798685970189492*^9, 
   3.799037777299082*^9},ExpressionUUID->"aeb2e227-55c9-482a-8719-\
81b65144a7cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"9a1f3a53-97a5-4112-ace8-\
e153ab23bf5c"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"b33b8c8e-1f65-4e27-9780-\
1ee8a8284514"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"c1", "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c1", "[", "i", "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", " ", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", "i", "]"}], " ", 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", 
          RowBox[{"i", ",", "j"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "j", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.7448191688423405`*^9, 3.7448192158060265`*^9}, {3.796979456730165*^9, 
  3.796979459033543*^9}},ExpressionUUID->"079287f4-5c92-43b3-a405-\
ca5378991d5a"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448306625037403`*^9, 3.744830687308159*^9}, 
   3.796979459616296*^9, 3.798419092703596*^9, 3.7984195548933*^9, 
   3.7986859702084937`*^9, 
   3.799037777313425*^9},ExpressionUUID->"1237ed3c-95c4-498c-a7de-\
9d2ad6c8139e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"c1", "+", 
     RowBox[{
      RowBox[{"c1", "[", "1", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c1", "[", "2", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c1", "[", "3", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c2", "[", "1", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448306625037403`*^9, 3.744830687308159*^9}, 
   3.796979459616296*^9, 3.798419092703596*^9, 3.7984195548933*^9, 
   3.7986859702084937`*^9, 
   3.799037777317009*^9},ExpressionUUID->"84e087ce-52cc-4ba3-8e94-\
b145f5368a28"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"1d96bcb4-899c-4420-9d65-\
9d4c21a21574"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis1", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.796979463264311*^9, 
   3.796979464176876*^9}},ExpressionUUID->"eb36f0c8-6121-45d5-b672-\
f6b4cb34912e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c1"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "1"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c1", "[", "1", "]"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c1", "[", "2", "]"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c1", "[", "3", "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c1", "[", "2", "]"}]}], 
        SubsuperscriptBox["p", "2", "2"]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c1"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"2", ",", "2"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c1", "[", "1", "]"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c1", "[", "2", "]"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c1", "[", "3", "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "-", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "2"}], "]"}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "2"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "4"]}], "-", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "1"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "4"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"c2", "[", 
               RowBox[{"3", ",", "2"}], "]"}], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "-", 
             RowBox[{
              RowBox[{"c2", "[", 
               RowBox[{"3", ",", "1"}], "]"}], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "2", "2"]}]]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7448164990766387`*^9, 3.744816511456347*^9}, 
   3.744816601251483*^9, 3.744817214817577*^9, 3.7448180635631227`*^9, 
   3.7448181397164783`*^9, 3.7448183948390703`*^9, 3.744818533107979*^9, 
   3.744818588355139*^9, 3.744818729484211*^9, 3.744818779734085*^9, 
   3.744818845451844*^9, 3.7448190497795305`*^9, 3.7448192345000963`*^9, 
   3.744819265739883*^9, 3.7448196522329893`*^9, {3.7448306640978317`*^9, 
   3.7448306916384068`*^9}, 3.796979464956132*^9, 3.798419093092003*^9, 
   3.798419555274522*^9, 3.7986859705775146`*^9, 
   3.799037777748015*^9},ExpressionUUID->"060ba0df-4f1b-455c-a3eb-\
6b8f30960614"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448185917453327`*^9, 3.744818615404686*^9}, {
  3.7448187928928375`*^9, 3.7448187961940265`*^9}, {3.744819059923111*^9, 
  3.744819077658125*^9}, {3.744819250809029*^9, 
  3.744819270990183*^9}},ExpressionUUID->"91633264-ea76-48af-8544-\
174f98d38a92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448306930434875`*^9, 
   3.796979468406336*^9, 3.7984190931035633`*^9, 3.79841955534166*^9, 
   3.798685970594516*^9, 
   3.799037777764777*^9},ExpressionUUID->"1cc0d4a6-e790-4378-b933-\
99aab5357696"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c1"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "1"}], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c1"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"2", ",", "2"}], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", 
         RowBox[{"3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "-", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "2"}], "]"}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "2"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "4"]}], "-", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "1"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "4"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"c2", "[", 
               RowBox[{"3", ",", "2"}], "]"}], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "-", 
             RowBox[{
              RowBox[{"c2", "[", 
               RowBox[{"3", ",", "1"}], "]"}], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "2", "2"]}]]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448306930434875`*^9, 
   3.796979468406336*^9, 3.7984190931035633`*^9, 3.79841955534166*^9, 
   3.798685970594516*^9, 
   3.7990377778595457`*^9},ExpressionUUID->"86d9925c-a33a-46bc-9794-\
7262fb8b8643"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution2", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c2", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", 
      RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{"cwis2", "/.", "LocalPrimarySolution2"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448192902262836`*^9, 
  3.744819355498017*^9}},ExpressionUUID->"d5bc76e7-cdc0-4b83-af86-\
1f92de73a900"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744819313141594*^9, 3.7448193559330416`*^9}, 
   3.7448196582313323`*^9, 3.744830694537573*^9, 3.796979469969296*^9, 
   3.798419093242435*^9, 3.798419555459934*^9, 3.798685970704522*^9, 
   3.7990377779036503`*^9},ExpressionUUID->"1a8795c1-2665-48fa-9922-\
43d2ce50fb9b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c1"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c2", "[", "3", "]"}], "+", 
         RowBox[{"c2", "[", 
          RowBox[{"1", ",", "1"}], "]"}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c1"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c2", "[", "3", "]"}], "+", 
         RowBox[{"c2", "[", 
          RowBox[{"2", ",", "2"}], "]"}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "-", 
        RowBox[{"c2", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744819313141594*^9, 3.7448193559330416`*^9}, 
   3.7448196582313323`*^9, 3.744830694537573*^9, 3.796979469969296*^9, 
   3.798419093242435*^9, 3.798419555459934*^9, 3.798685970704522*^9, 
   3.799037777906233*^9},ExpressionUUID->"710fe454-5f19-454e-9029-\
1348b0c72585"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution3", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", "cwis3"}], ",", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"c2", "[", 
        RowBox[{"2", ",", "2"}], "]"}], ",", "c1"}], " ", "}"}]}], "]"}], 
   "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"LocalPrimarySolution4", "=", 
  RowBox[{"Union", "[", 
   RowBox[{
   "LocalPrimarySolution1", ",", "LocalPrimarySolution2", ",", 
    "LocalPrimarySolution3"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cwis1", "/.", "LocalPrimarySolution4"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7448193676707134`*^9, 3.7448194467742376`*^9}, {
  3.744819670383027*^9, 
  3.744819747380431*^9}},ExpressionUUID->"a81da4d7-8c86-4dea-9b34-\
dff855fc4b62"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "1"}], "]"}]}], ",", 
   RowBox[{"c1", "\[Rule]", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c2", "[", "3", "]"}], "+", 
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "1"}], "]"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448194172065463`*^9, 3.7448194470302525`*^9}, {
   3.744819704927003*^9, 3.744819747900461*^9}, 3.7448306957956448`*^9, 
   3.79697947319597*^9, 3.798419093261941*^9, 3.798419555478574*^9, 
   3.7986859707215233`*^9, 
   3.799037777942384*^9},ExpressionUUID->"3fec4c98-1d1b-4c62-9187-\
00e9cff0231c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c1", "\[Rule]", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c2", "[", "3", "]"}], "+", 
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "1"}], "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "1"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448194172065463`*^9, 3.7448194470302525`*^9}, {
   3.744819704927003*^9, 3.744819747900461*^9}, 3.7448306957956448`*^9, 
   3.79697947319597*^9, 3.798419093261941*^9, 3.798419555478574*^9, 
   3.7986859707215233`*^9, 
   3.799037777945321*^9},ExpressionUUID->"5928a0f3-1aa6-465d-b63e-\
c6f9b91c0cc2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7448194172065463`*^9, 3.7448194470302525`*^9}, {
   3.744819704927003*^9, 3.744819747900461*^9}, 3.7448306957956448`*^9, 
   3.79697947319597*^9, 3.798419093261941*^9, 3.798419555478574*^9, 
   3.7986859707215233`*^9, 
   3.7990377779486217`*^9},ExpressionUUID->"9b4497d4-45ec-4f6d-8bfc-\
b7fee13a4d3e"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"447ea9f3-b035-455b-9aae-\
36e787638e74"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.796979477032201*^9, 
   3.796979490945394*^9}},ExpressionUUID->"6c466464-a524-4d02-b5c8-\
6c9fd4202d2c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{"c1", " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubscriptBox["p", "3"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{"c1", " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubscriptBox["p", "3"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"Log", "[", 
       SubscriptBox["p", "1"], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        RowBox[{
         RowBox[{"c2", "[", 
          RowBox[{"3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"Log", "[", 
       SubscriptBox["p", "2"], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", 
          RowBox[{"2", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        RowBox[{
         RowBox[{"c2", "[", 
          RowBox[{"3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.7448306970907187`*^9, 3.7969794917007093`*^9, 
   3.7984190933489733`*^9, 3.798419555580514*^9, 3.7986859707675257`*^9, 
   3.799037778030682*^9},ExpressionUUID->"4bb73de9-435a-4ca3-ae18-\
6f42a5985cd2"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.7448306970907187`*^9, 3.7969794917007093`*^9, 
   3.7984190933489733`*^9, 3.798419555580514*^9, 3.7986859707675257`*^9, 
   3.799037778033566*^9},ExpressionUUID->"b57e3df2-a9d1-479e-ae46-\
e87ba9ec533c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FinalLocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{
    RowBox[{"LocalPrimarySolution4", "/.", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"c2", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"c2", "[", "3", "]"}], "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"c2", "[", "2", "]"}]}]}]}], " ", "}"}]}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"c2", "[", "3", "]"}], "\[Rule]", 
       RowBox[{"-", 
        RowBox[{"c2", "[", "2", "]"}]}]}]}], " ", "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LocalSecs", "/.", "FinalLocalPrimarySolution"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.74481948300531*^9, 3.744819514150091*^9}, {
  3.7448197516386747`*^9, 
  3.744819770420749*^9}},ExpressionUUID->"dad1e519-158d-4918-b1e6-\
3c45bc00136a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c1", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"c2", "[", "2", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"c2", "[", "2", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448195144311075`*^9, {3.744819754398833*^9, 3.7448197718658314`*^9}, 
   3.744830698293788*^9, 3.7969794946135263`*^9, 3.79841909336651*^9, 
   3.798419555596343*^9, 3.7986859707865267`*^9, 
   3.799037778047003*^9},ExpressionUUID->"f531a147-080f-47ad-8dfe-\
f5ea175c9dd5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", " ", 
   RowBox[{"c2", "[", "2", "]"}], " ", 
   SubsuperscriptBox["p", "2", "2"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448195144311075`*^9, {3.744819754398833*^9, 3.7448197718658314`*^9}, 
   3.744830698293788*^9, 3.7969794946135263`*^9, 3.79841909336651*^9, 
   3.798419555596343*^9, 3.7986859707865267`*^9, 
   3.7990377780500402`*^9},ExpressionUUID->"6b8c824f-4d06-4c6a-9397-\
bd2731ea4f69"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SemiLocals", "/.", "FinalLocalPrimarySolution"}]], "Input",
 CellChangeTimes->{{3.744819521357504*^9, 
  3.7448195236526346`*^9}},ExpressionUUID->"8d11acec-2691-46a1-b159-\
9498fa5b5974"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"c2", "[", "2", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c2", "[", "1", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448195254677386`*^9, 3.7448197757570543`*^9, 
  3.7448306998288755`*^9, 3.796979496685912*^9, 3.798419093426915*^9, 
  3.798419555654319*^9, 3.7986859708015275`*^9, 
  3.7990377780866127`*^9},ExpressionUUID->"818a11ca-c999-4780-9da8-\
411377381c2c"]
}, Open  ]],

Cell["\<\
This is the most general solution. What multiplies c2[2] is the \
scheme-dependence of the original solution. A new solution, A[1] = 0, A[2] = \
c2[1] p[1]^2 seems ok. Let\[CloseCurlyQuote]s check.\
\>", "Text",
 CellChangeTimes->{{3.7448165699846945`*^9, 3.7448165728888607`*^9}, {
   3.744816642839862*^9, 3.7448166929677286`*^9}, {3.744818270940984*^9, 
   3.7448183241080246`*^9}, {3.744818645090384*^9, 3.744818706001868*^9}, {
   3.7448188600646796`*^9, 3.744818913495736*^9}, {3.7448191115910664`*^9, 
   3.744819115382283*^9}, {3.744819561179781*^9, 3.7448195685392017`*^9}, {
   3.7448198939378138`*^9, 3.744819954328268*^9}, 
   3.74482005752217*^9},ExpressionUUID->"bfdc3488-68d3-4e1c-bf6a-\
39e9c7fca7f7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"SemiLocals", "/.", "FinalLocalPrimarySolution"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
   3.6966792683570137`*^9, 3.696679279573285*^9}, {3.696681304201663*^9, 
   3.696681316408358*^9}, {3.696681366492388*^9, 3.696681387231173*^9}, {
   3.696681685048072*^9, 3.696681697567984*^9}, {3.69668428384752*^9, 
   3.6966844247304697`*^9}, {3.696684771280221*^9, 3.696684771471381*^9}, {
   3.7448195899084244`*^9, 3.744819608048462*^9}, {3.744819843572933*^9, 
   3.7448198619479837`*^9}, 3.7448306563953915`*^9, {3.796979501472538*^9, 
   3.7969795017841673`*^9}},ExpressionUUID->"9cc5556e-d5e7-4b39-aa7f-\
e39a276d1d2a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyDmu", "[", "As", "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 3.6966776876239157`*^9}, {3.696681706876687*^9, 
  3.696681748595314*^9}, {3.696684438331925*^9, 
  3.696684444394032*^9}},ExpressionUUID->"e3313f07-ff52-401a-9c9f-\
5fb01158cd15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, {3.6966816993011007`*^9, 3.6966817491437187`*^9}, {
   3.6966844040786943`*^9, 3.696684444634461*^9}, 3.6967642776847067`*^9, 
   3.7448191319322295`*^9, {3.744819598140895*^9, 3.744819609201528*^9}, {
   3.7448198455180445`*^9, 3.744819866562248*^9}, 3.744830704545145*^9, 
   3.796979503043394*^9, 3.798419093496051*^9, 3.798419555743555*^9, 
   3.7986859708385296`*^9, 
   3.7990377781346684`*^9},ExpressionUUID->"61e072da-6060-4912-be2a-\
8f6b85b6e3a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.696681878348083*^9, 3.696682040385975*^9}, {
  3.696764293312912*^9, 3.696764305178122*^9}, {3.796979505881023*^9, 
  3.796979506801077*^9}},ExpressionUUID->"f8ee9291-44e9-4ec2-a1a5-\
2cef1b1b84c3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, {3.696681874922673*^9, 3.696681907467486*^9}, {
   3.696681963808894*^9, 3.696681975145215*^9}, 3.6966820106142597`*^9, 
   3.696682042625102*^9, 3.696684451424481*^9, 3.696684629058628*^9, 
   3.696684754647168*^9, 3.696764306328925*^9, 3.7448191346093826`*^9, 
   3.7448196132427588`*^9, 3.7448198689993877`*^9, 3.7448307094924283`*^9, 
   3.79697950732592*^9, 3.798419093548026*^9, 3.798419555791168*^9, 
   3.7986859708505306`*^9, 
   3.799037778163721*^9},ExpressionUUID->"f804caf7-fa4d-4b88-b89f-\
4d3aa5e64b20"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JJO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
   3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
   3.6966772912178926`*^9}, {3.696678106749449*^9, 3.6966781141980352`*^9}, {
   3.696678238255801*^9, 3.696678242655888*^9}, {3.696682094182363*^9, 
   3.696682103623598*^9}, 3.696684803970422*^9, {3.796979510032765*^9, 
   3.796979517321372*^9}},ExpressionUUID->"5d35bb63-d5c6-4768-9d64-\
64e3e25608a2"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696682105615172*^9, 3.696684774774837*^9, 3.6966848058389807`*^9, 
   3.696764313711619*^9, 3.744819135246419*^9, 3.744819871527532*^9, 
   3.7448307141286936`*^9, 3.796979518333612*^9, 3.7984190935964327`*^9, 
   3.798419555849101*^9, 3.7986859708615313`*^9, 
   3.7990377781993427`*^9},ExpressionUUID->"74ac94ea-93b4-49c3-bdfe-\
1cf574796fef"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696682105615172*^9, 3.696684774774837*^9, 3.6966848058389807`*^9, 
   3.696764313711619*^9, 3.744819135246419*^9, 3.744819871527532*^9, 
   3.7448307141286936`*^9, 3.796979518333612*^9, 3.7984190935964327`*^9, 
   3.798419555849101*^9, 3.7986859708615313`*^9, 
   3.7990377782038593`*^9},ExpressionUUID->"e241bc30-73b7-48e3-8245-\
af9e18c459df"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["<TTO>", "Section",
 CellChangeTimes->{{3.696662757712263*^9, 3.696662759359742*^9}, {
  3.696682859217309*^9, 3.696682859569441*^9}, {3.69668482149916*^9, 
  3.6966848220265007`*^9}},ExpressionUUID->"a977d338-a959-4424-918f-\
2e887bba4fe0"],

Cell[CellGroupData[{

Cell["d=3, \[CapitalDelta]=1", "Subsection",
 CellChangeTimes->{{3.696663690437581*^9, 
  3.6966636937738028`*^9}},ExpressionUUID->"6174f6c4-6463-412c-8104-\
38e2a7b41c3b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"C1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"a12", "^", "2"}]}], "+", 
          RowBox[{"6", "b12"}], "+", 
          RowBox[{"4", "a12", " ", 
           RowBox[{"p", "[", "3", "]"}]}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a123", "^", "4"}], " ", 
          RowBox[{"p", "[", "3", "]"}]}], ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{"C1", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], 
           RowBox[{"a12", "^", "3"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", "b12"}], "-", 
             RowBox[{"a12", "^", "2"}]}], ")"}], 
           RowBox[{"p", "[", "3", "]"}]}], "+", 
          RowBox[{"3", "a12", " ", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a123", "^", "3"}], " ", 
          RowBox[{"p", "[", "3", "]"}]}], ")"}]}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
      RowBox[{"C1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a12", "-", 
          RowBox[{"p", "[", "3", "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"4", 
          RowBox[{"a123", "^", "2"}], " ", 
          RowBox[{"p", "[", "3", "]"}]}], ")"}]}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", "a12", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a12", "^", "2"}], "-", 
            RowBox[{"2", "b12"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a12", "^", "2"}], "-", 
            RowBox[{"10", "b12"}]}], ")"}], 
          RowBox[{"p", "[", "3", "]"}]}], "-", 
         RowBox[{"3", "a12", " ", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], ")"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "1"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
  3.696684013724811*^9, 3.696684064967544*^9}, {3.696684911473774*^9, 
  3.696685070660282*^9}, {3.696685199934741*^9, 3.6966852000062723`*^9}, {
  3.7299403945995073`*^9, 3.729940547204808*^9}, {3.7299423751414137`*^9, 
  3.7299424165492697`*^9}, {3.796979533956088*^9, 
  3.796979534145464*^9}},ExpressionUUID->"f063aedf-d3ae-43a6-a8e6-\
8262773db74f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.729942728995207*^9, 3.729942729235404*^9}, {
  3.796979537568921*^9, 
  3.796979538632326*^9}},ExpressionUUID->"b0170095-b8f9-401b-9c95-\
9a746cd9736a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.729942729591786*^9, {3.729942808700036*^9, 3.729942841748987*^9}, 
   3.744820125635066*^9, 3.7448307807445035`*^9, 3.7969795389896593`*^9, 
   3.796979641207981*^9, 3.798419093793235*^9, 3.798419164917549*^9, 
   3.7984195560486937`*^9, 3.798421208023478*^9, 3.7986859710165396`*^9, 
   3.799037778382555*^9},ExpressionUUID->"82aac1a5-661f-442d-8801-\
dbf288c1770f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTO", ",", "Dims"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", "%%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696684086068306*^9, 3.6966840888764772`*^9}, {
  3.7969795415041113`*^9, 
  3.7969795489961443`*^9}},ExpressionUUID->"df2cd2f8-4afc-4ce1-9777-\
cda464f21bd9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, {3.6966851770233717`*^9, 3.6966852027309217`*^9}, 
   3.69676569820014*^9, 3.7299403819481487`*^9, 3.7299427793058453`*^9, 
   3.744820132637467*^9, 3.796979549812735*^9, 3.7969796417261753`*^9, 
   3.798419093848111*^9, 3.798419165115643*^9, 3.798419556093829*^9, 
   3.7986859710625424`*^9, 
   3.799037778426179*^9},ExpressionUUID->"54aabff7-a449-43c0-b635-\
e3a76c497bdc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, {3.6966851770233717`*^9, 3.6966852027309217`*^9}, 
   3.69676569820014*^9, 3.7299403819481487`*^9, 3.7299427793058453`*^9, 
   3.744820132637467*^9, 3.796979549812735*^9, 3.7969796417261753`*^9, 
   3.798419093848111*^9, 3.798419165115643*^9, 3.798419556093829*^9, 
   3.7986859710625424`*^9, 
   3.7990377784295273`*^9},ExpressionUUID->"dfdc7af2-911e-4b2c-8191-\
3e90600f64b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, {3.6966851770233717`*^9, 3.6966852027309217`*^9}, 
   3.69676569820014*^9, 3.7299403819481487`*^9, 3.7299427793058453`*^9, 
   3.744820132637467*^9, 3.796979549812735*^9, 3.7969796417261753`*^9, 
   3.798419093848111*^9, 3.798419165115643*^9, 3.798419556093829*^9, 
   3.7986859710625424`*^9, 
   3.7990377784326677`*^9},ExpressionUUID->"9ddd3e2f-eb92-4ecc-8611-\
d1abc1b825cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"1e18cf65-5fd7-4120-a56b-\
705f81e7dbca"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"4ca147fd-455e-47d0-a64a-\
e8a8605f2660"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "4"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "dimA1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c2", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"dimA1", "+", "2"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c3", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"dimA1", "+", "4"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.7448191688423405`*^9, 3.7448192158060265`*^9}, {3.744820155447771*^9, 
  3.7448202194684334`*^9}, {3.7448202787108216`*^9, 3.744820278797827*^9}, {
  3.7969795544735518`*^9, 
  3.796979556889511*^9}},ExpressionUUID->"b5ac24a1-5beb-462b-8a4f-\
253418b396c0"],

Cell[BoxData[
 RowBox[{"-", "3"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744830782380597*^9, 
   3.796979557508153*^9, 3.796979643186411*^9, 3.7984190938810787`*^9, 
   3.798419166439019*^9, 3.79841955611707*^9, 3.7986859710805435`*^9, 
   3.799037778447815*^9},ExpressionUUID->"e4274623-db4a-4896-8f47-\
66a469bf90cf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c1", "[", "1", "]"}], 
      SubsuperscriptBox["p", "1", "3"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "2", "]"}], 
      SubsuperscriptBox["p", "2", "3"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "3", "]"}], 
      SubsuperscriptBox["p", "3", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], 
      SubscriptBox["p", "1"]], "+", 
     FractionBox[
      RowBox[{"c2", "[", "2", "]"}], 
      SubscriptBox["p", "2"]], "+", 
     FractionBox[
      RowBox[{"c2", "[", "3", "]"}], 
      SubscriptBox["p", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c3", "[", "1", "]"}], " ", 
      SubscriptBox["p", "1"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", "2", "]"}], " ", 
      SubscriptBox["p", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", "3", "]"}], " ", 
      SubscriptBox["p", "3"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744830782380597*^9, 
   3.796979557508153*^9, 3.796979643186411*^9, 3.7984190938810787`*^9, 
   3.798419166439019*^9, 3.79841955611707*^9, 3.7986859710805435`*^9, 
   3.799037778451316*^9},ExpressionUUID->"a05764a2-5224-4d76-9778-\
faee4e471608"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"f753994a-18e3-46ce-a3ef-\
a194c23c9213"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis1", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.796979561064828*^9, 
   3.796979562152679*^9}},ExpressionUUID->"96f8c343-b9ee-4509-832c-\
2860be69ef68"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"6", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", "1", "]"}], "+", 
           RowBox[{"c3", "[", "1", "]"}]}], ")"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubscriptBox["p", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "3", "]"}]}], 
       SubscriptBox["p", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c3", "[", "3", "]"}]}], 
       SubscriptBox["p", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]], "-", 
      FractionBox[
       RowBox[{"6", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", "1", "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"c2", "[", "3", "]"}], " ", 
           SubscriptBox["p", "2"]}], "+", 
          RowBox[{
           RowBox[{"c3", "[", "3", "]"}], " ", 
           SubscriptBox["p", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"c2", "[", "2", "]"}], "+", 
             RowBox[{"c3", "[", "2", "]"}]}], ")"}], " ", 
           SubscriptBox["p", "3"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["p", "2"], " ", 
        SubscriptBox["p", "3"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", "1", "]"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c3", "[", "2", "]"}]}], 
       SubscriptBox["p", "2"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.7448307840486927`*^9, 3.796979562657538*^9, 
   3.796979644446004*^9, 3.798419094075145*^9, 3.7984191672740707`*^9, 
   3.798419556309855*^9, 3.7986859712345524`*^9, 
   3.799037778641706*^9},ExpressionUUID->"0e918b22-1748-4d93-b878-\
d8a969f41100"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c3", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c3", "[", "2", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448185917453327`*^9, 3.744818615404686*^9}, {
  3.7448187928928375`*^9, 3.7448187961940265`*^9}, {3.744819059923111*^9, 
  3.744819077658125*^9}, {3.744819250809029*^9, 3.744819270990183*^9}, {
  3.744820242266737*^9, 
  3.744820254043411*^9}},ExpressionUUID->"f50e1cf4-294e-4fe4-bce8-\
e45bb9b1eedd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448202549504623`*^9, 
   3.7448203016981363`*^9, 3.7448307852537613`*^9, 3.796979564253385*^9, 
   3.796979645797244*^9, 3.798419094092927*^9, 3.798419167407998*^9, 
   3.7984195563786507`*^9, 3.7986859712485533`*^9, 
   3.799037778654578*^9},ExpressionUUID->"fcdf939a-939b-4adf-a4c5-\
4267c3d035d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c2", "[", "3", "]"}], "+", 
          RowBox[{"c3", "[", "3", "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c2", "[", "3", "]"}], "+", 
          RowBox[{"c3", "[", "3", "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448202549504623`*^9, 
   3.7448203016981363`*^9, 3.7448307852537613`*^9, 3.796979564253385*^9, 
   3.796979645797244*^9, 3.798419094092927*^9, 3.798419167407998*^9, 
   3.7984195563786507`*^9, 3.7986859712485533`*^9, 
   3.7990377786577377`*^9},ExpressionUUID->"5d124133-6a4d-4213-a516-\
30c80dd25cc2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution1", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c3", "[", "3", "]"}], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{"c2", "[", "3", "]"}]}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{"cwis2", "/.", "LocalPrimarySolution"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448192902262836`*^9, 3.744819355498017*^9}, {
  3.7448203073794613`*^9, 
  3.744820342865491*^9}},ExpressionUUID->"39131c66-2839-4a20-adc9-\
56f28b3adf8e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", "3", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"c2", "[", "3", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.74482034336852*^9, 3.744830786403827*^9, 
  3.7969795653919487`*^9, 3.79697964728336*^9, 3.7984190941608877`*^9, 
  3.798419167636902*^9, 3.798419556400427*^9, 3.798685971264554*^9, 
  3.7990377786931667`*^9},ExpressionUUID->"aa225c9b-61b6-4cb2-bdf7-\
8c18c59a7897"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.74482034336852*^9, 3.744830786403827*^9, 
  3.7969795653919487`*^9, 3.79697964728336*^9, 3.7984190941608877`*^9, 
  3.798419167636902*^9, 3.798419556400427*^9, 3.798685971264554*^9, 
  3.799037778696797*^9},ExpressionUUID->"8ba3e42f-d9cc-42db-bdc9-\
392b938f8099"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"c0680935-94ae-4025-a029-\
aecef9375f28"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}]], "Input",ExpressionUUID->"d6d0f10c-6529-4139-b126-3d0ce6bd6e6a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"c2", "[", "3", "]"}], 
     SubscriptBox["p", "3"]]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"c2", "[", "3", "]"}]}], " ", 
     SubscriptBox["p", "3"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.744830794966317*^9, 3.796979568381494*^9, 
  3.796979648587029*^9, 3.798419094226322*^9, 3.798419168384425*^9, 
  3.798419556457341*^9, 3.798685971280555*^9, 
  3.799037778737452*^9},ExpressionUUID->"046f0555-6201-4235-8dae-\
4d0ced64451d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.796979572457391*^9, 
   3.796979581472618*^9}},ExpressionUUID->"2054a5fe-17b3-4e37-be88-\
f59ffe254d35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"c2", "[", "3", "]"}]}], 
     SubscriptBox["p", "3"]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["p", "2", "2"], "-", 
           RowBox[{"5", " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}], 
     SubscriptBox["p", "3"]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.744820353267086*^9, 3.796979582159396*^9, 
   3.796979649415634*^9, 3.7984190943099003`*^9, 3.798419168614851*^9, 
   3.798419556517455*^9, 3.7986859712945557`*^9, 
   3.799037778781983*^9},ExpressionUUID->"9bcc8288-871f-47fa-8445-\
012290a929c2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.744820353267086*^9, 3.796979582159396*^9, 
   3.796979649415634*^9, 3.7984190943099003`*^9, 3.798419168614851*^9, 
   3.798419556517455*^9, 3.7986859712945557`*^9, 
   3.799037778784911*^9},ExpressionUUID->"b7d6ad58-2cd1-4f55-976f-\
024f882648f1"]
}, Open  ]],

Cell["\<\
This is the functional derivative type of the solution. Hence, no new \
solutions.\
\>", "Text",
 CellChangeTimes->{{3.7448203761903973`*^9, 
  3.74482042204502*^9}},ExpressionUUID->"ff92fe21-1723-4704-a5df-\
cce339a4645a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=3, \[CapitalDelta]=3", "Subsection",
 CellChangeTimes->{{3.696677309328281*^9, 
  3.696677312480341*^9}},ExpressionUUID->"28952264-c3d3-4418-8407-\
ea6486283726"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a123", "^", "3"}], "+", 
          RowBox[{"a123", " ", "b123"}], "+", 
          RowBox[{"3", "c123"}]}], ")"}], "/", 
        RowBox[{"a123", "^", "4"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{"a", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a12", "^", "4"}]}], "+", 
          RowBox[{
           RowBox[{"a12", "^", "2"}], "b12"}], "+", 
          RowBox[{"3", "a12", " ", 
           RowBox[{"p", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{"b12", "-", 
             RowBox[{"a12", "^", "2"}]}], ")"}]}], "+", 
          RowBox[{"6", "b12", " ", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "+", 
          RowBox[{"3", " ", "a12", " ", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], ")"}], "/", 
        RowBox[{"a123", "^", "3"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], "\[Gamma]", " ", "cO", " ", 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], "+", 
       RowBox[{"a", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "+", 
           RowBox[{"p", "[", "2", "]"}], "-", 
           RowBox[{"p", "[", "3", "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", 
           RowBox[{"a123", "^", "2"}]}], ")"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a12", "^", "4"}], "-", 
          RowBox[{"3", 
           RowBox[{"a12", "^", "2"}], "b12"}], "+", 
          RowBox[{"3", "a12", " ", 
           RowBox[{"p", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a12", "^", "2"}], "-", 
             RowBox[{"3", "b12"}]}], ")"}]}], "-", 
          RowBox[{"8", "b12", " ", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
          RowBox[{"3", "a12", " ", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], "-", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], ")"}]}]}]}]}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
  3.696677341394161*^9, 3.69667740301085*^9}, {3.696684094936317*^9, 
  3.6966841405674343`*^9}, {3.696685218585596*^9, 3.6966852688967237`*^9}, {
  3.6966853100241537`*^9, 3.6966854039054747`*^9}, {3.796979588964713*^9, 
  3.7969795893953533`*^9}},ExpressionUUID->"a505a2a4-b5b3-49a5-aa7e-\
f50f1e0507c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"659a1993-fe92-4afb-a8b1-\
bac38641a458"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696679209740868*^9, 
   3.6966841440153103`*^9, {3.69668537942127*^9, 3.696685404861095*^9}, 
   3.69676600734892*^9, 3.729943087689664*^9, 3.744820431016533*^9, 
   3.796979652605315*^9, 3.798419094391603*^9, 3.798419170072989*^9, 
   3.7984195565980883`*^9, 3.7986859713365583`*^9, 
   3.799037778837966*^9},ExpressionUUID->"5eee65f3-17c8-435f-be01-\
ba819bac00a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796979655008059*^9, 
  3.796979656025433*^9}},ExpressionUUID->"9b52ee7c-7549-4740-ba22-\
ffac3ae9b929"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, 
   3.6966792104989567`*^9, 3.696684144938717*^9, {3.696685380735346*^9, 
   3.696685405273488*^9}, 3.696766008059181*^9, 3.729943089424983*^9, 
   3.7448204317205734`*^9, 3.796979656370514*^9, 3.798419094565405*^9, 
   3.798419170529406*^9, 3.7984195567653427`*^9, 3.798685971501568*^9, 
   3.799037779024688*^9},ExpressionUUID->"c69cd856-a068-4ba7-a65b-\
becc7ce3b896"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.796979658889648*^9, 
  3.7969796680575523`*^9}},ExpressionUUID->"9be87307-5c02-4540-95c3-\
ecf2581863fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"36", " ", "cO", " ", "\[Gamma]", " ", 
    SubsuperscriptBox["p", "3", "3"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696684147312687*^9, {3.6966853823866367`*^9, 
   3.696685405722066*^9}, 3.696766008716885*^9, 3.729943095174458*^9, 
   3.7448204323476095`*^9, 3.796979668920808*^9, 3.798419094615073*^9, 
   3.798419170658337*^9, 3.798419556821343*^9, 3.79868597154957*^9, 
   3.799037779112959*^9},ExpressionUUID->"9b560262-9e91-4cbc-ba9c-\
ececfdf5512d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696684147312687*^9, {3.6966853823866367`*^9, 
   3.696685405722066*^9}, 3.696766008716885*^9, 3.729943095174458*^9, 
   3.7448204323476095`*^9, 3.796979668920808*^9, 3.798419094615073*^9, 
   3.798419170658337*^9, 3.798419556821343*^9, 3.79868597154957*^9, 
   3.7990377791159067`*^9},ExpressionUUID->"e478b8d1-c2a1-406b-acdb-\
57aeb9d7584a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"As", "/.", 
   RowBox[{"\[Gamma]", "\[Rule]", "0"}]}], "/.", 
  RowBox[{"a", "\[Rule]", "C1"}]}]], "Input",
 CellChangeTimes->{{3.729943104638286*^9, 
  3.729943117027*^9}},ExpressionUUID->"43817390-5de5-4063-88f2-d9e17105d7ae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"C1", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a123", "3"], "+", 
        RowBox[{"a123", " ", "b123"}], "+", 
        RowBox[{"3", " ", "c123"}]}], ")"}]}], 
     SuperscriptBox["a123", "4"]]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"C1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a12", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a12", "2"], " ", "b12"}], "+", 
        RowBox[{"3", " ", "a12", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a12", "2"]}], "+", "b12"}], ")"}], " ", 
         SubscriptBox["p", "3"]}], "+", 
        RowBox[{"6", " ", "b12", " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"3", " ", "a12", " ", 
         SubsuperscriptBox["p", "3", "3"]}], "+", 
        SubsuperscriptBox["p", "3", "4"]}], ")"}]}], 
     SuperscriptBox["a123", "3"]]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", 
       SuperscriptBox["a123", "2"]}]], 
     RowBox[{"C1", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "1"], "+", 
        SubscriptBox["p", "2"], "-", 
        SubscriptBox["p", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a12", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a12", "2"], " ", "b12"}], "+", 
        RowBox[{"3", " ", "a12", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a12", "2"], "-", 
           RowBox[{"3", " ", "b12"}]}], ")"}], " ", 
         SubscriptBox["p", "3"]}], "-", 
        RowBox[{"8", " ", "b12", " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"3", " ", "a12", " ", 
         SubsuperscriptBox["p", "3", "3"]}], "-", 
        SubsuperscriptBox["p", "3", "4"]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729943106990315*^9, 3.7299431172498198`*^9}, 
   3.7448204338966975`*^9, 3.796979672153808*^9, 3.798419094633119*^9, 
   3.798419170908642*^9, 3.798419556841489*^9, 3.7986859715695715`*^9, 
   3.799037779128392*^9},ExpressionUUID->"eabe4ebd-dd51-4696-9e98-\
114330a81f89"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2", "=", 
   RowBox[{
    RowBox[{"C1", "/", 
     RowBox[{"a123", "^", "3"}]}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a12", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{"b12", "-", 
         RowBox[{"a12", "^", "2"}]}], ")"}]}], "+", 
      RowBox[{"3", "a12", 
       RowBox[{"(", 
        RowBox[{"b12", "-", 
         RowBox[{"a12", "^", "2"}]}], ")"}], 
       RowBox[{"p", "[", "3", "]"}]}], "+", 
      RowBox[{"6", "b12", " ", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "+", 
      RowBox[{"3", "a12", " ", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], "+", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3", "=", 
   RowBox[{"C1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a12", "-", 
       RowBox[{"p", "[", "3", "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", 
       RowBox[{"a123", "^", "2"}]}], ")"}]}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a12", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a12", "^", "2"}], "-", 
         RowBox[{"3", "b12"}]}], ")"}]}], "+", 
      RowBox[{"3", "a12", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a12", "^", "2"}], "-", 
         RowBox[{"3", "b12"}]}], ")"}], 
       RowBox[{"p", "[", "3", "]"}]}], "-", 
      RowBox[{"8", "b12", " ", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
      RowBox[{"3", "a12", " ", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], "-", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], ")"}]}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.7299431305574617`*^9, 3.729943205939641*^9}, {
  3.72994326335502*^9, 
  3.729943263763536*^9}},ExpressionUUID->"ee86a0ba-8ac4-4c71-965e-\
80a353aa3180"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "-", "a2"}], "/.", "As"}], "/.", 
    "PolExpand"}], "/.", 
   RowBox[{"a", "\[Rule]", "C1"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", "3", "]"}], "-", "a3"}], "/.", "As"}], "/.", 
     "PolExpand"}], "/.", 
    RowBox[{"a", "\[Rule]", "C1"}]}], "/.", 
   RowBox[{"\[Gamma]", "\[Rule]", "0"}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.729943209353108*^9, 
  3.729943241539247*^9}},ExpressionUUID->"6e518317-918f-48c2-8de9-\
a52d3121fdb3"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7299432214472237`*^9, 3.72994326514425*^9}, 
   3.744820446122397*^9, 3.796979677918095*^9, 3.798419094705118*^9, 
   3.798419171493414*^9, 3.79841955691713*^9, 3.7986859715955725`*^9, 
   3.799037779172735*^9},ExpressionUUID->"cf514c1b-0795-4baa-8287-\
79121a17ec60"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7299432214472237`*^9, 3.72994326514425*^9}, 
   3.744820446122397*^9, 3.796979677918095*^9, 3.798419094705118*^9, 
   3.798419171493414*^9, 3.79841955691713*^9, 3.7986859715955725`*^9, 
   3.7990377791762457`*^9},ExpressionUUID->"152161fe-1b15-4ef9-b913-\
d2a75c295dc2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"f2604ca9-be2e-4d46-8c90-\
4dec0a84bba7"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"208d28c5-054c-46a6-8388-\
63bb35ee07aa"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "4"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "dimA1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c2", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"dimA1", "+", "2"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c3", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"dimA1", "+", "4"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.7448191688423405`*^9, 3.7448192158060265`*^9}, {3.744820155447771*^9, 
  3.7448202194684334`*^9}, {3.7448202787108216`*^9, 3.744820278797827*^9}, {
  3.796979681363093*^9, 
  3.796979685313429*^9}},ExpressionUUID->"281df248-7e6b-44c4-8275-\
c66427b855ce"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.744830842115014*^9, 3.796979685710391*^9, 3.7984190947709303`*^9, 
   3.79841917290841*^9, 3.798419556977972*^9, 3.798685971612574*^9, 
   3.799037779216929*^9},ExpressionUUID->"1853b96d-9d21-4b0d-b4c6-\
abb9ee0eb58c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c1", "[", "1", "]"}], 
      SubscriptBox["p", "1"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "2", "]"}], 
      SubscriptBox["p", "2"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "3", "]"}], 
      SubscriptBox["p", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c2", "[", "1", "]"}], " ", 
      SubscriptBox["p", "1"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      SubscriptBox["p", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubscriptBox["p", "3"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c3", "[", "1", "]"}], " ", 
      SubsuperscriptBox["p", "1", "3"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", "2", "]"}], " ", 
      SubsuperscriptBox["p", "2", "3"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "3", "3"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.744830842115014*^9, 3.796979685710391*^9, 3.7984190947709303`*^9, 
   3.79841917290841*^9, 3.798419556977972*^9, 3.798685971612574*^9, 
   3.799037779219912*^9},ExpressionUUID->"45b078b1-880a-45dc-81d2-\
ba867fce2020"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"15750ecf-c96d-416b-b651-\
f53b9d156b95"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis1", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.796979690185251*^9, 
   3.796979691185268*^9}},ExpressionUUID->"b09db85d-8494-4a2a-a6fe-\
893dcbb329a5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "1", "]"}]}], 
       SubscriptBox["p", "1"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubscriptBox["p", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubscriptBox["p", "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "3", "]"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", "1", "]"}], " ", 
         SubscriptBox["p", "1"]}], "+", 
        RowBox[{
         RowBox[{"c2", "[", "2", "]"}], " ", 
         SubscriptBox["p", "2"]}], "+", 
        RowBox[{
         RowBox[{"c2", "[", "3", "]"}], " ", 
         SubscriptBox["p", "3"]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           RowBox[{"c1", "[", "2", "]"}]}], "+", 
          RowBox[{"c2", "[", "2", "]"}]}], ")"}]}], 
       SubscriptBox["p", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubscriptBox["p", "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "3", "]"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", "1", "]"}], " ", 
         SubscriptBox["p", "1"]}], "+", 
        RowBox[{
         RowBox[{"c2", "[", "2", "]"}], " ", 
         SubscriptBox["p", "2"]}], "+", 
        RowBox[{
         RowBox[{"c2", "[", "3", "]"}], " ", 
         SubscriptBox["p", "3"]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", "1", "]"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubscriptBox["p", "2"]]}], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448308432580795`*^9, 
   3.7969796916394663`*^9, 3.7984190949880466`*^9, 3.798419173786942*^9, 
   3.798419557138404*^9, 3.79868597172558*^9, 
   3.799037779370098*^9},ExpressionUUID->"c83a874f-decd-454d-bdce-\
2f033309113d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448185917453327`*^9, 3.744818615404686*^9}, {
  3.7448187928928375`*^9, 3.7448187961940265`*^9}, {3.744819059923111*^9, 
  3.744819077658125*^9}, {3.744819250809029*^9, 3.744819270990183*^9}, {
  3.744820242266737*^9, 3.744820254043411*^9}, {3.744820495495221*^9, 
  3.7448204958812428`*^9}},ExpressionUUID->"e9887645-686e-46e4-b465-\
43b4acc74e27"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448202549504623`*^9, 
   3.7448203016981363`*^9, 3.7448204967112904`*^9, 3.7448308447891665`*^9, 
   3.7969796936697063`*^9, 3.7984190950014753`*^9, 3.798419173947695*^9, 
   3.798419557156581*^9, 3.7986859717605824`*^9, 
   3.799037779385028*^9},ExpressionUUID->"1890ec5b-8abb-4679-ab6c-\
9ffeea1a7076"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], 
      SubscriptBox["p", "3"]], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubscriptBox["p", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], 
      SubscriptBox["p", "3"]], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubscriptBox["p", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448202549504623`*^9, 
   3.7448203016981363`*^9, 3.7448204967112904`*^9, 3.7448308447891665`*^9, 
   3.7969796936697063`*^9, 3.7984190950014753`*^9, 3.798419173947695*^9, 
   3.798419557156581*^9, 3.7986859717605824`*^9, 
   3.799037779388151*^9},ExpressionUUID->"cccc1d2f-d5c1-4f30-a3f8-\
49ae370e982a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution1", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{"cwis2", "/.", "LocalPrimarySolution"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448192902262836`*^9, 3.744819355498017*^9}, {
  3.7448203073794613`*^9, 3.744820342865491*^9}, {3.7448205174644775`*^9, 
  3.744820520935676*^9}},ExpressionUUID->"d7c15d7d-783b-43f4-838f-\
1f7b004e3f09"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.74482034336852*^9, 3.7448205217677236`*^9, 
  3.7448308459122305`*^9, 3.7969796952586937`*^9, 3.798419095051074*^9, 
  3.798419174228408*^9, 3.798419557212961*^9, 3.798685971779584*^9, 
  3.7990377794225817`*^9},ExpressionUUID->"60b42e48-2e3f-4a49-aea6-\
67e32646823c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.74482034336852*^9, 3.7448205217677236`*^9, 
  3.7448308459122305`*^9, 3.7969796952586937`*^9, 3.798419095051074*^9, 
  3.798419174228408*^9, 3.798419557212961*^9, 3.798685971779584*^9, 
  3.799037779425993*^9},ExpressionUUID->"569b5a67-0b04-4fa1-939b-\
ab5a2bb6a1eb"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"e15d9433-5c83-4283-8699-\
3fa42109bb47"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.79697969900091*^9, 
   3.796979708129278*^9}},ExpressionUUID->"f749e283-303b-4c78-a22e-\
0be9d2a538fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "12"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"c3", "[", "2", "]"}], " ", 
       SubsuperscriptBox["p", "2", "3"]}], "+", 
      RowBox[{
       RowBox[{"c3", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "3", "3"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.744820353267086*^9, 3.7448205246838903`*^9, 
   3.7448308502184772`*^9, 3.7969797087573223`*^9, 3.798419095143708*^9, 
   3.798419175046404*^9, 3.798419557277297*^9, 3.7986859717955847`*^9, 
   3.7990377794663677`*^9},ExpressionUUID->"20c40747-5087-4a61-a441-\
febecff73370"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.744820353267086*^9, 3.7448205246838903`*^9, 
   3.7448308502184772`*^9, 3.7969797087573223`*^9, 3.798419095143708*^9, 
   3.798419175046404*^9, 3.798419557277297*^9, 3.7986859717955847`*^9, 
   3.799037779468975*^9},ExpressionUUID->"0919fdd1-70ef-49b5-bd4f-\
45d6d5503dbc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FinalLocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{
    RowBox[{"LocalPrimarySolution", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"c3", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"c3", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"c3", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"c3", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "/.", "FinalLocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.744820545784097*^9, 
  3.7448205980090847`*^9}},ExpressionUUID->"2bb2e9a6-8467-4e54-a79b-\
fbb4cc94b539"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448205614909954`*^9, 3.7448205985671167`*^9, 
  3.7448308522335925`*^9, 3.79697971739565*^9, 3.7984190952355967`*^9, 
  3.79841917528364*^9, 3.7984195572958*^9, 3.7986859718125854`*^9, 
  3.799037779482326*^9},ExpressionUUID->"d376bf0a-ef3f-4e2c-af47-\
003f0f7dbfcc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c3", "[", "1", "]"}], " ", 
     SubsuperscriptBox["p", "1", "3"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448205614909954`*^9, 3.7448205985671167`*^9, 
  3.7448308522335925`*^9, 3.79697971739565*^9, 3.7984190952355967`*^9, 
  3.79841917528364*^9, 3.7984195572958*^9, 3.7986859718125854`*^9, 
  3.799037779485208*^9},ExpressionUUID->"ae4d8cba-7cf3-49c4-890a-\
66e1d61f71de"]
}, Open  ]],

Cell["\<\
We do have a new solution, A[1] = A[2] = 0, A[3] = c3[1] p[1]^3. Let\
\[CloseCurlyQuote]s check.\
\>", "Text",
 CellChangeTimes->{{3.7448203761903973`*^9, 3.74482042204502*^9}, {
  3.7448206070286007`*^9, 
  3.744820621507428*^9}},ExpressionUUID->"82ca8632-23e3-4924-8d01-\
4d13f69943e9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"SemiLocals", "/.", "FinalLocalPrimarySolution"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
  3.696677341394161*^9, 3.69667740301085*^9}, {3.696684094936317*^9, 
  3.6966841405674343`*^9}, {3.696685218585596*^9, 3.6966852688967237`*^9}, {
  3.6966853100241537`*^9, 3.6966854039054747`*^9}, {3.7448206480439463`*^9, 
  3.744820651899167*^9}, {3.744830866364401*^9, 3.74483086863253*^9}, {
  3.7969796035444317`*^9, 
  3.796979603762096*^9}},ExpressionUUID->"a505a2a4-b5b3-49a5-aa7e-\
f50f1e0507c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"659a1993-fe92-4afb-a8b1-\
bac38641a458"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696679209740868*^9, 
   3.6966841440153103`*^9, {3.69668537942127*^9, 3.696685404861095*^9}, 
   3.69676600734892*^9, 3.729943087689664*^9, 3.744820431016533*^9, 
   3.744820653959285*^9, 3.7448308699436054`*^9, 3.7969797218382998`*^9, 
   3.798419095347547*^9, 3.798419176245236*^9, 3.798419557582231*^9, 
   3.798685971841587*^9, 
   3.7990377795337563`*^9},ExpressionUUID->"02b0e89f-7c65-4d85-ba90-\
ff2482742395"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796979724225346*^9, 
  3.796979726000971*^9}},ExpressionUUID->"9b52ee7c-7549-4740-ba22-\
ffac3ae9b929"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, 
   3.6966792104989567`*^9, 3.696684144938717*^9, {3.696685380735346*^9, 
   3.696685405273488*^9}, 3.696766008059181*^9, 3.729943089424983*^9, 
   3.7448204317205734`*^9, 3.7448206547563305`*^9, 3.744830875564927*^9, 
   3.796979726364588*^9, 3.798419095391281*^9, 3.798419176501734*^9, 
   3.798419557636907*^9, 3.798685971856588*^9, 
   3.799037779550057*^9},ExpressionUUID->"a8b6d475-3652-49b1-846a-\
472242aa9d2e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.7969797290721817`*^9, 
  3.7969797355933332`*^9}},ExpressionUUID->"9be87307-5c02-4540-95c3-\
ecf2581863fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696684147312687*^9, {3.6966853823866367`*^9, 
   3.696685405722066*^9}, 3.696766008716885*^9, 3.729943095174458*^9, 
   3.7448204323476095`*^9, 3.7448206556013784`*^9, 3.7448308765799847`*^9, 
   3.796979736262635*^9, 3.798419095402293*^9, 3.798419176741157*^9, 
   3.7984195576492987`*^9, 3.798685971869589*^9, 
   3.799037779585264*^9},ExpressionUUID->"998453a0-4f6f-4601-9a81-\
480c27978d95"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696679212393332*^9, 3.696684147312687*^9, {3.6966853823866367`*^9, 
   3.696685405722066*^9}, 3.696766008716885*^9, 3.729943095174458*^9, 
   3.7448204323476095`*^9, 3.7448206556013784`*^9, 3.7448308765799847`*^9, 
   3.796979736262635*^9, 3.798419095402293*^9, 3.798419176741157*^9, 
   3.7984195576492987`*^9, 3.798685971869589*^9, 
   3.799037779588306*^9},ExpressionUUID->"a2c982b5-f088-4e9d-b9d7-\
845825a320be"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4, \[CapitalDelta]=2", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 
  3.69667770458226*^9}},ExpressionUUID->"edf8f951-96cf-45d2-b861-\
4f6bf920cf5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Q", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "1", "]"}], "^", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}], "-", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "4"}], "+", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "4"}], "+", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "4"}], "-", 
      RowBox[{"2", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "-", 
      RowBox[{"8", 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ")"}], 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.692956273487557*^9, 3.692956276913228*^9}, {
   3.6929563203777122`*^9, 3.692956548054249*^9}, {3.692956655384243*^9, 
   3.6929566748805723`*^9}, {3.6930392356050253`*^9, 3.693039237423312*^9}, {
   3.6965991238302526`*^9, 3.696599124253927*^9}, {3.69659935055628*^9, 
   3.696599350738061*^9}, {3.6966008340414667`*^9, 3.6966008346404676`*^9}, 
   3.69668555481313*^9},ExpressionUUID->"33faba58-1476-4957-b526-\
41ebf8477915"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{
        RowBox[{"MRed", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", 
        RowBox[{
         RowBox[{"MRed", "[", 
          RowBox[{"2", ",", "1"}], "]"}], "[", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], 
          RowBox[{"p", "[", "2", "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"i1000", ",", 
            RowBox[{"p", "[", "1", "]"}], ",", 
            RowBox[{"p", "[", "2", "]"}]}], "]"}]}], "]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"4", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"MRed", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "[", 
           RowBox[{
            RowBox[{"MRed", "[", 
             RowBox[{"2", ",", "1"}], "]"}], "[", "i2111fin", "]"}], "]"}], 
          "-", 
          RowBox[{
           RowBox[{"2", "/", "3"}], " ", 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
              RowBox[{
               RowBox[{"p", "[", "3", "]"}], "^", "4"}]}]}], "]"}]}], "+", 
          RowBox[{"7", "/", "3"}]}], ")"}]}], "-", 
       RowBox[{"4", " ", "d1"}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"96", "a", " ", 
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], "^", "4"}], 
        RowBox[{
         RowBox[{"p", "[", "2", "]"}], "^", "4"}], 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "^", "4"}], 
        RowBox[{"i1000", "/", 
         RowBox[{"J2", "^", "2"}]}]}], "+", 
       RowBox[{"2", 
        RowBox[{"a", "/", 
         RowBox[{"J2", "^", "2"}]}], 
        RowBox[{"(", 
         RowBox[{"Q", "+", 
          RowBox[{"Swap", "[", 
           RowBox[{"Q", ",", 
            RowBox[{"p", "[", "1", "]"}], ",", 
            RowBox[{"p", "[", "2", "]"}]}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"a", "/", "J2"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", 
           RowBox[{"a12", "^", "6"}]}], "-", 
          RowBox[{
           RowBox[{"a12", "^", "4"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"18", "b12"}], "+", 
             RowBox[{"7", 
              RowBox[{
               RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"a12", "^", "2"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"24", 
              RowBox[{"b12", "^", "2"}]}], "+", 
             RowBox[{"28", "b12", " ", 
              RowBox[{
               RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "+", 
             RowBox[{"5", 
              RowBox[{
               RowBox[{"p", "[", "3", "]"}], "^", "4"}]}]}], ")"}]}], "-", 
          RowBox[{"28", 
           RowBox[{"b12", "^", "2"}], 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
          RowBox[{"10", "b12", " ", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], "-", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "6"}]}], ")"}]}], "+", 
       RowBox[{"d1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "+", 
       RowBox[{"d2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}]}]}]}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
   3.696684161089705*^9, 3.696684198078211*^9}, {3.696684252001034*^9, 
   3.696684254088887*^9}, {3.69668544503052*^9, 3.696685604293304*^9}, {
   3.697366480769733*^9, 3.697366514786227*^9}, 3.729943517316944*^9, {
   3.79697960596859*^9, 3.796979606185886*^9}, 
   3.79841915165138*^9},ExpressionUUID->"719f5baa-1bd9-4c44-92b2-\
99c6d7fd5e39"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"508c3e96-90df-4256-af05-\
581bb9679cda"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, 3.696684203185841*^9, 3.696685606446148*^9, 
   3.6967669589895782`*^9, 3.697366464953898*^9, 3.697366518822071*^9, 
   3.729943524732403*^9, 3.7448207116895866`*^9, 3.796979789212511*^9, 
   3.7969798370195293`*^9, 3.79698005438236*^9, 3.798419095522546*^9, 
   3.798419178072084*^9, 3.798419557839048*^9, 3.798421219333007*^9, 
   3.798685971950593*^9, 
   3.799037779695724*^9},ExpressionUUID->"5715a33e-e8f8-4e42-853d-\
b53620db7f5b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumEval", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.696685624589093*^9, 3.696685625004813*^9}, {
  3.6966856618613453`*^9, 3.696685675845212*^9}, {3.6966857426828213`*^9, 
  3.696685747175213*^9}, {3.7969798422733393`*^9, 
  3.796979843264803*^9}},ExpressionUUID->"6018e081-a1eb-4374-bde6-\
94344d04e490"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, 3.696684208811737*^9, {3.696684242701248*^9, 
   3.6966842567745113`*^9}, 3.696685619683587*^9, {3.696685668189961*^9, 
   3.696685681594283*^9}, 3.696685752950491*^9, 3.6967669650995607`*^9, 
   3.697366471758523*^9, 3.697366524914908*^9, 3.729943540404763*^9, 
   3.7448207185719805`*^9, 3.796979854752492*^9, 3.79698006677277*^9, 
   3.798419110388908*^9, 3.798419198068987*^9, 3.7984195777897263`*^9, 
   3.7984212317198057`*^9, 3.7986859826011953`*^9, 
   3.799037789966653*^9},ExpressionUUID->"700c992e-88bf-4611-82ba-\
3f57b63182bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"lhs", "=", 
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
   3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
   3.6966772912178926`*^9}, {3.696678106749449*^9, 3.6966781141980352`*^9}, {
   3.696678238255801*^9, 3.696678242655888*^9}, {3.6973665818718567`*^9, 
   3.697366582661743*^9}, {3.729943639989152*^9, 3.729943671698748*^9}, {
   3.729943744101709*^9, 3.729943746403071*^9}, 3.729943777700529*^9, {
   3.7969798675853167`*^9, 
   3.796979881985394*^9}},ExpressionUUID->"1effed3f-c0a0-4afc-b6c4-\
63517f67ddb4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696684262444735*^9, 3.696685768314904*^9, 3.696766967601866*^9, 
   3.697366475995571*^9, 3.6973665282558317`*^9, 3.697366585237156*^9, 
   3.729943551721242*^9, {3.7299436419014883`*^9, 3.729943666524374*^9}, {
   3.729943719225932*^9, 3.729943748169105*^9}, 3.729943780134572*^9, 
   3.7448207210271206`*^9, 3.796979882921516*^9, 3.7969800998745403`*^9, 
   3.798419111284656*^9, 3.798419199821477*^9, 3.79841957956245*^9, 
   3.7986859843082914`*^9, 
   3.7990377915763474`*^9},ExpressionUUID->"d8385fbb-4320-4939-bc70-\
c55f6e48c1c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"lhs", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"d1", "\[Rule]", "0"}], ",", 
      RowBox[{"d2", "\[Rule]", "0"}]}], "}"}]}], "/.", 
   RowBox[{
    RowBox[{"NL", "[", "x___", "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
  "Aaa"}]], "Input",
 CellChangeTimes->{{3.7986861174058*^9, 
  3.798686117966832*^9}},ExpressionUUID->"f387cc7e-274e-44c4-b5a3-\
7ecf98e6e49b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.673470251262188`*^-10", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", "a"}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1.7462298274040222`*^-9"}], "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", "a"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.79868611845086*^9, 
  3.799037791771099*^9},ExpressionUUID->"bf1d17b8-5ee4-4087-92fd-\
9d239a9cbf65"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"2ac2a2a9-e350-410f-845f-\
3632190e0d6e"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"9de44be7-9c6b-4bd2-97bd-\
539c5763b9a3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "4"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "dimA1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"c2", "[", "0", "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", "i", "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c3", "[", "i", "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"i", ",", "j"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "j", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.7448191688423405`*^9, 3.7448192158060265`*^9}, {3.744820155447771*^9, 
  3.7448202194684334`*^9}, {3.7448202787108216`*^9, 3.744820278797827*^9}, {
  3.7448207748992023`*^9, 3.744820823908005*^9}, {3.7448218418222265`*^9, 
  3.7448218420292387`*^9}, {3.7969801244023027`*^9, 3.796980126565773*^9}, {
  3.7969802533171873`*^9, 
  3.796980254523204*^9}},ExpressionUUID->"a0cb4336-e7c1-40d6-9902-\
b07bb99f5b1e"],

Cell[BoxData[
 RowBox[{"-", "2"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.796980128422989*^9, 3.7969802552061243`*^9, 3.798419119952523*^9, 
   3.798419216772089*^9, 3.798419584544928*^9, 3.7986861297514973`*^9, 
   3.799037791787711*^9},ExpressionUUID->"9b9b37e2-8a4e-4acf-bbf0-\
9a8a0bc7b6d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c1", "[", "1", "]"}], 
      SubsuperscriptBox["p", "1", "2"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "2", "]"}], 
      SubsuperscriptBox["p", "2", "2"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "3", "]"}], 
      SubsuperscriptBox["p", "3", "2"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c2", "[", "0", "]"}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "1", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c3", "[", "1", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", "2", "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.796980128422989*^9, 3.7969802552061243`*^9, 3.798419119952523*^9, 
   3.798419216772089*^9, 3.798419584544928*^9, 3.7986861297514973`*^9, 
   3.799037791792603*^9},ExpressionUUID->"765ec9cc-c988-4366-b3d4-\
ed56af41e471"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"09a78886-b366-465f-a416-\
f64a37fa065e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.7969801323933077`*^9, 3.796980133704232*^9}, 
   3.796980270252911*^9},ExpressionUUID->"60f0bfb0-a4e9-4c69-b9ad-\
6ecc7ac4589e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c2", "[", "0", "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", "1", "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", "3", "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c2", "[", "1", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c3", "[", 
             RowBox[{"1", ",", "1"}], "]"}], "+", 
            RowBox[{"c3", "[", 
             RowBox[{"3", ",", "1"}], "]"}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c2", "[", "2", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c3", "[", 
             RowBox[{"1", ",", "2"}], "]"}], "+", 
            RowBox[{"c3", "[", 
             RowBox[{"3", ",", "2"}], "]"}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c2", "[", "0", "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", "2", "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", "3", "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c2", "[", "1", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c3", "[", 
             RowBox[{"2", ",", "1"}], "]"}], "+", 
            RowBox[{"c3", "[", 
             RowBox[{"3", ",", "1"}], "]"}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c2", "[", "2", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c3", "[", 
             RowBox[{"2", ",", "2"}], "]"}], "+", 
            RowBox[{"c3", "[", 
             RowBox[{"3", ",", "2"}], "]"}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c2", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c3", "[", "1", "]"}]}], "+", 
        RowBox[{"c3", "[", "2", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c3", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "-", 
           RowBox[{"c3", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c3", "[", 
            RowBox[{"1", ",", "2"}], "]"}], "-", 
           RowBox[{"c3", "[", 
            RowBox[{"2", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.796980134881978*^9, 3.796980270882926*^9, 
   3.7984191204863167`*^9, 3.798419218200935*^9, 3.7984195850750847`*^9, 
   3.798686131716608*^9, 
   3.7990377923483057`*^9},ExpressionUUID->"b5527223-cda3-401b-8fa6-\
392639dd10b6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448185917453327`*^9, 3.744818615404686*^9}, {
  3.7448187928928375`*^9, 3.7448187961940265`*^9}, {3.744819059923111*^9, 
  3.744819077658125*^9}, {3.744819250809029*^9, 3.744819270990183*^9}, {
  3.744820242266737*^9, 3.744820254043411*^9}, {3.744820495495221*^9, 
  3.7448204958812428`*^9}},ExpressionUUID->"5afe4fe7-fb53-4552-9a7c-\
1d67d5a37872"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448202549504623`*^9, 
   3.7448203016981363`*^9, 3.7448204967112904`*^9, 3.744820845374233*^9, 
   3.7448218498156834`*^9, 3.796980136048608*^9, {3.796980294367137*^9, 
   3.796980319184495*^9}, 3.7984191205074377`*^9, 3.798419219009659*^9, 
   3.798419585093933*^9, 3.7986861334177055`*^9, 
   3.799037792362083*^9},ExpressionUUID->"07283327-08cb-496a-9714-\
a1c6072c74d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], 
      SubscriptBox["p", "3"]], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubscriptBox["p", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], 
      SubscriptBox["p", "3"]], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubscriptBox["p", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448202549504623`*^9, 
   3.7448203016981363`*^9, 3.7448204967112904`*^9, 3.744820845374233*^9, 
   3.7448218498156834`*^9, 3.796980136048608*^9, {3.796980294367137*^9, 
   3.796980319184495*^9}, 3.7984191205074377`*^9, 3.798419219009659*^9, 
   3.798419585093933*^9, 3.7986861334177055`*^9, 
   3.7990377923651323`*^9},ExpressionUUID->"3b5ccbfe-646e-4fa2-b863-\
317ccb4ad71d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution2", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"k", ",", "3"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"p", "[", "1", "]"}], "]"}], ",", 
             RowBox[{"Log", "[", 
              RowBox[{"p", "[", "2", "]"}], "]"}], ",", 
             RowBox[{"Log", "[", 
              RowBox[{"p", "[", "3", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"c3", "[", 
         RowBox[{"i", ",", "j"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "//", "Flatten"}]}], "]"}], 
   "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
     RowBox[{
      RowBox[{"p", "[", "2", "]"}], "^", "2"}], "cwis2"}], "/.", 
    "LocalPrimarySolution2"}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448192902262836`*^9, 3.744819355498017*^9}, {
   3.7448203073794613`*^9, 3.744820342865491*^9}, {3.7448205174644775`*^9, 
   3.744820520935676*^9}, {3.7448208860535593`*^9, 3.744821000544108*^9}, {
   3.796980356821035*^9, 3.796980387065702*^9}, {3.7969804179167547`*^9, 
   3.7969804625782757`*^9}, 
   3.796980499984137*^9},ExpressionUUID->"c02f5433-831a-4551-b443-\
172593a6e663"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{
  3.74482034336852*^9, 3.7448205217677236`*^9, {3.744820916155281*^9, 
   3.7448210008001227`*^9}, 3.7448218540109234`*^9, 3.7969801381394367`*^9, {
   3.796980359097995*^9, 3.796980387622266*^9}, 3.7969804658965693`*^9, 
   3.796980501073976*^9, 3.7984191205795*^9, 3.7984192199920588`*^9, 
   3.798419585154104*^9, 3.7986861346777754`*^9, 
   3.7990377924006147`*^9},ExpressionUUID->"a01330e3-6340-427a-afc6-\
5ed36cf6735b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "2", "2"]}], 
      SubscriptBox["p", "3"]], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubscriptBox["p", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "2", "2"]}], 
      SubscriptBox["p", "3"]], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubscriptBox["p", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.74482034336852*^9, 3.7448205217677236`*^9, {3.744820916155281*^9, 
   3.7448210008001227`*^9}, 3.7448218540109234`*^9, 3.7969801381394367`*^9, {
   3.796980359097995*^9, 3.796980387622266*^9}, 3.7969804658965693`*^9, 
   3.796980501073976*^9, 3.7984191205795*^9, 3.7984192199920588`*^9, 
   3.798419585154104*^9, 3.7986861346777754`*^9, 
   3.799037792404078*^9},ExpressionUUID->"a5f13a68-2d98-4fe5-87a7-\
720a313ab292"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"cwis3", "\[LeftDoubleBracket]", 
             RowBox[{"k", ",", "3"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "1", "]"}], "^", "4"}], ",", 
              RowBox[{
               RowBox[{"p", "[", "2", "]"}], "^", "4"}], ",", 
              RowBox[{
               RowBox[{"p", "[", "3", "]"}], "^", "4"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
               RowBox[{
                RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
               RowBox[{
                RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
               RowBox[{
                RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], "}"}]}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"c2", "[", "i", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"c3", "[", "i", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"c3", "[", 
            RowBox[{"i", ",", "j"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], "}"}], "//", 
       "Flatten"}]}], "]"}], "\[LeftDoubleBracket]", "1", 
    "\[RightDoubleBracket]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis4", "=", 
  RowBox[{
   RowBox[{"cwis3", "/.", "LocalPrimarySolution4"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448211614493113`*^9, 3.7448213319060607`*^9}, {
  3.7969805082839127`*^9, 
  3.796980566015203*^9}},ExpressionUUID->"56a5df82-f768-4455-8b2d-\
cd2e9d6ad545"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   405,3,29347142503502531606,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.744821227969116*^9, 3.7448212727706785`*^9, {3.744821304298482*^9, 
   3.7448213322170787`*^9}, 3.744821863233451*^9, {3.7969805581769123`*^9, 
   3.79698056694057*^9}, 3.798419120648389*^9, 3.798419220934507*^9, 
   3.798419585234941*^9, 3.7986861357318344`*^9, 
   3.7990377924465847`*^9},ExpressionUUID->"b9dbb976-59df-4031-bf5a-\
cc6864dd1a40"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448212279951177`*^9, 3.744821272772679*^9, {3.744821304301482*^9, 
   3.7448213322220793`*^9}, 3.7448218632374516`*^9, {3.796980558190176*^9, 
   3.7969805669567347`*^9}, 3.7984191206587553`*^9, 3.798419220948329*^9, 
   3.79841958524902*^9, 3.798686135756836*^9, 
   3.799037792448621*^9},ExpressionUUID->"2c99dd9e-92df-4281-9a5a-\
8b8bfd8cde69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "2", "2"]}], 
      SubscriptBox["p", "3"]], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubscriptBox["p", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "2", "2"]}], 
      SubscriptBox["p", "3"]], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubscriptBox["p", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448212279951177`*^9, 3.744821272772679*^9, {3.744821304301482*^9, 
   3.7448213322220793`*^9}, 3.7448218632374516`*^9, {3.796980558190176*^9, 
   3.7969805669567347`*^9}, 3.7984191206587553`*^9, 3.798419220948329*^9, 
   3.79841958524902*^9, 3.798686135756836*^9, 
   3.799037792452127*^9},ExpressionUUID->"143a1a07-be38-4bd8-a3b5-\
0bdb115a573d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{
   RowBox[{"Union", "[", 
    RowBox[{
    "LocalPrimarySolution1", ",", "LocalPrimarySolution2", ",", 
     "LocalPrimarySolution3"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.744821339168476*^9, 3.744821362425806*^9}, {
  3.796980576568933*^9, 
  3.796980583353985*^9}},ExpressionUUID->"8fd02cba-a71c-49a8-a95f-\
d4b45f35ff48"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744821350842144*^9, 3.744821362715823*^9}, 
   3.7448218651055584`*^9, 3.796980583686351*^9, 3.798419120678133*^9, 
   3.798419222313987*^9, 3.798419585302747*^9, 3.79868613705291*^9, 
   3.799037792464189*^9},ExpressionUUID->"31630bb2-38fb-4c7b-a85a-\
bd663f7ee9b7"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 
  3.744816541465063*^9}},ExpressionUUID->"7cdbb024-47e9-4fa5-8dbb-\
b354029cf3c0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTO", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.79698058741774*^9, 
   3.796980599408601*^9}},ExpressionUUID->"1bba32e2-f4e0-4d20-8fc4-\
c63ff2790cd0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    RowBox[{"c2", "[", "0", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"c2", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"1", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", "2", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"16", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"16", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c3", "[", 
           RowBox[{"1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c3", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.744820353267086*^9, 3.7448205246838903`*^9, 
   3.744821391742483*^9, 3.7448218678357143`*^9, 3.7969806002893877`*^9, 
   3.798419120794299*^9, 3.798419223664504*^9, 3.798419585411344*^9, 
   3.7986861382799797`*^9, 
   3.7990377925612803`*^9},ExpressionUUID->"e19d4bb7-4a12-43bc-a209-\
ec667e7952f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.744820353267086*^9, 3.7448205246838903`*^9, 
   3.744821391742483*^9, 3.7448218678357143`*^9, 3.7969806002893877`*^9, 
   3.798419120794299*^9, 3.798419223664504*^9, 3.798419585411344*^9, 
   3.7986861382799797`*^9, 
   3.799037792564416*^9},ExpressionUUID->"7c2ca168-c8e2-4307-9ce6-\
8b5e6437e97e"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4, \[CapitalDelta]=4", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 3.69667770458226*^9}, {
  3.696679255482382*^9, 
  3.6966792557773647`*^9}},ExpressionUUID->"822bd6b9-ba7a-48d4-9435-\
59adb022172b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NonLocalTerma", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{
       RowBox[{"MRed", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "[", 
       RowBox[{
        RowBox[{"MRed", "[", 
         RowBox[{"2", ",", "1"}], "]"}], "[", 
        RowBox[{
         RowBox[{"MRed", "[", 
          RowBox[{"3", ",", "1"}], "]"}], "[", "i2111fin", "]"}], "]"}], 
       "]"}]}], ",", 
     RowBox[{"4", " ", "a", " ", 
      RowBox[{"(", 
       RowBox[{"i3222fin", "-", 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"i3222fin", ",", 
           RowBox[{"p", "[", "3", "]"}]}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", "a", " ", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", "i3222fin"}]}], " ", 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LogTerm", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], "/", "3"}], "a", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], ")"}]}], ",", 
     RowBox[{"2", "a", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], "-", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], " ", ")"}]}], ",", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "4"}], "+", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], ")"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "4"}], "+", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], ")"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "+", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
           RowBox[{"3", 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "4"}]}]}], ")"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], ")"}]}]}], " ", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LocalTerm", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", "a"}], "-", 
      RowBox[{"4", " ", "scdep"}]}], ",", 
     RowBox[{
      RowBox[{"4", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", "a"}], "+", 
      RowBox[{"4", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], "scdep"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], "a", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"p", "[", "1", "]"}], "4"], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"p", "[", "1", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"p", "[", "2", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"p", "[", "2", "]"}], "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"p", "[", "3", "]"}], "4"]}]}], ")"}]}], "+", 
      RowBox[{"scdep", 
       RowBox[{"(", 
        RowBox[{"J2", "-", 
         RowBox[{"2", " ", 
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{"a0", "+", 
         RowBox[{"u", " ", 
          RowBox[{"a", "/", 
           RowBox[{"(", 
            RowBox[{"u", "+", 
             RowBox[{"v", "[", "3", "]"}]}], ")"}]}]}]}], ")"}]}]}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6966859482679787`*^9, 3.696685986188987*^9}, {
   3.6966860457914248`*^9, 3.696686339429101*^9}, {3.6967702330953417`*^9, 
   3.6967702378120823`*^9}, {3.696770378689711*^9, 3.6967704542705507`*^9}, {
   3.696770891868947*^9, 3.696770893332798*^9}, {3.697369902974091*^9, 
   3.6973699153940287`*^9}, {3.697370448906966*^9, 3.697370458274673*^9}, {
   3.729944083781355*^9, 3.729944100741527*^9}, {3.7319345060792913`*^9, 
   3.73193453606216*^9}, 
   3.73193472691086*^9},ExpressionUUID->"fc4e3916-2c91-4435-8f25-\
f557d2b05b67"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "n", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
       "NonLocalTerma", "\[LeftDoubleBracket]", "n", 
        "\[RightDoubleBracket]"}], "+", 
       RowBox[{
       "LogTerm", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], "+", 
       RowBox[{
       "LocalTerm", "\[LeftDoubleBracket]", "n", 
        "\[RightDoubleBracket]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"Length", "[", "NonLocalTerma", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.6966792683570137`*^9, 3.696679279573285*^9}, {3.696681304201663*^9, 
  3.696681316408358*^9}, {3.696681366492388*^9, 3.696681387231173*^9}, {
  3.696681685048072*^9, 3.696681697567984*^9}, {3.69668428384752*^9, 
  3.6966844247304697`*^9}, {3.696684771280221*^9, 3.696684771471381*^9}, {
  3.696686342433242*^9, 3.6966863967371817`*^9}, {3.729944104466456*^9, 
  3.729944105810862*^9}, {3.796979610744446*^9, 
  3.7969796110001097`*^9}},ExpressionUUID->"1a802061-9805-4ce1-ad3f-\
ef7d30566b32"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prims", "=", 
  RowBox[{
   RowBox[{"ApplyDmu", "[", "As", "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 3.6966776876239157`*^9}, {3.696681706876687*^9, 
  3.696681748595314*^9}, {3.696684438331925*^9, 3.696684444394032*^9}, {
  3.696770921657111*^9, 
  3.696770923301057*^9}},ExpressionUUID->"f904990e-81bb-4c5e-9fd5-\
8ed8f2441592"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8", " ", "a"}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      SubsuperscriptBox["p", "2", "2"], "-", 
      SubsuperscriptBox["p", "3", "2"]}], ")"}]}], ",", 
   RowBox[{"2", " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "4"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, {3.6966816993011007`*^9, 3.6966817491437187`*^9}, {
   3.6966844040786943`*^9, 3.696684444634461*^9}, 3.6966864006993523`*^9, 
   3.6967704639259577`*^9, {3.696770908737446*^9, 3.696770923950945*^9}, 
   3.6973699210611753`*^9, 3.697370462994184*^9, 3.729944109424553*^9, 
   3.73193455677894*^9, 3.731934732759931*^9, 3.7448219955730205`*^9, 
   3.796980721820032*^9, 3.798419121066535*^9, 3.7984192267911177`*^9, 
   3.798419585670937*^9, 3.798421246563704*^9, 3.798686141400155*^9, 
   3.799037792805709*^9},ExpressionUUID->"498cb64d-6dbe-4bda-af9b-\
c777c1cede91"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"time", ",", "cwis"}], "}"}], "=", 
   RowBox[{
    RowBox[{"ApplyCWIs", "[", 
     RowBox[{
      RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], 
     "]"}], "//", "AbsoluteTiming"}]}], 
  ";"}], "\[IndentingNewLine]", "time"}], "Input",
 CellChangeTimes->{{3.796980992606636*^9, 3.796980994737653*^9}, {
  3.796981036574568*^9, 3.796981046338881*^9}, {3.798419231218896*^9, 
  3.798419239497941*^9}},ExpressionUUID->"1d0a3201-2413-43b7-95ab-\
000d2df75db0"],

Cell[BoxData["54.372346`"], "Output",
 CellChangeTimes->{3.798419149032631*^9, 3.798419229716778*^9, 
  3.7984193012872763`*^9, 3.7984196472010813`*^9, 3.798421316585022*^9, 
  3.798686207298885*^9, 
  3.7990378472051888`*^9},ExpressionUUID->"3730aa24-f59f-4a86-847c-\
4624175d842a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"NumEval", "[", "cwis", "]"}], "//", "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{{3.6967710983675203`*^9, 3.696771101783538*^9}, {
   3.6967711465791607`*^9, 3.69677114875325*^9}, {3.7969807426501093`*^9, 
   3.7969807500363894`*^9}, 3.796980991797806*^9, {3.796981037381274*^9, 
   3.796981042954094*^9}, {3.7984193638466253`*^9, 
   3.798419375609495*^9}},ExpressionUUID->"82c7bcb1-bfb8-43c9-abac-\
d4d3b6ffef40"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"9.621688`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"32.00000005029142`", " ", "a"}], ",", 
       RowBox[{
        RowBox[{"718.24`", " ", "a0"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "868.000000001106`"}], "+", 
           FractionBox[
            RowBox[{"718.24`", " ", "u"}], 
            RowBox[{"u", "+", 
             RowBox[{"v", "[", "3", "]"}]}]]}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"31.999999969964847`", " ", "a"}], ",", 
       RowBox[{
        RowBox[{"324.`", " ", "a0"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "867.9999999885331`"}], "+", 
           FractionBox[
            RowBox[{"324.`", " ", "u"}], 
            RowBox[{"u", "+", 
             RowBox[{"v", "[", "3", "]"}]}]]}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"394.24`", " ", "a0"}], "+", 
        FractionBox[
         RowBox[{"394.24`", " ", "a", " ", "u"}], 
         RowBox[{"u", "+", 
          RowBox[{"v", "[", "3", "]"}]}]]}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.696771299137005*^9, 3.697370082084155*^9, 
  3.697370620228602*^9, 3.72994415987877*^9, 3.731934712749793*^9, 
  3.7319348760145683`*^9, 3.744822034460245*^9, 3.796980781450778*^9, 
  3.796981058073451*^9, 3.798419362455793*^9, 3.798419726417182*^9, 
  3.79842132685893*^9, 3.798686220041607*^9, 
  3.799037856946958*^9},ExpressionUUID->"4ea374f6-b2f5-4e6d-9c22-\
d2975ea5ca83"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", "=", 
  RowBox[{"SimplifyCWIs", "[", 
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696686597433378*^9, 3.696686600383979*^9}, {
  3.69668665227813*^9, 3.6966866528691883`*^9}, {3.796981079962366*^9, 
  3.7969810828821087`*^9}},ExpressionUUID->"b3032765-6ac2-469a-ae2a-\
9a56a1087308"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{"32", " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "u"}], "+", 
       RowBox[{"a0", " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", 
          RowBox[{"v", "[", "3", "]"}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"u", "+", 
     RowBox[{"v", "[", "3", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.6966865958954363`*^9, 3.69668664563006*^9, 
  3.696686711806786*^9, 3.696771338907934*^9, 3.697370106769093*^9, 
  3.697370645052367*^9, 3.731934908086825*^9, 3.7969810983049173`*^9, 
  3.798419750806465*^9, 3.798686244516*^9, 
  3.799037873720607*^9},ExpressionUUID->"b9bd2ef4-7200-4704-be90-\
9e10f34d11d9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a0su", "=", 
  RowBox[{"{", 
   RowBox[{"a0", "\[Rule]", 
    RowBox[{"\[CapitalDelta]C", "-", 
     RowBox[{"a", " ", 
      RowBox[{"u", "/", 
       RowBox[{"(", 
        RowBox[{"u", "+", 
         RowBox[{"v", "[", "3", "]"}]}], ")"}]}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LocalTerm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
   "/.", "a0su"}]}], "Input",
 CellChangeTimes->{{3.7319349647105017`*^9, 
  3.7319349797722607`*^9}},ExpressionUUID->"1743c08d-5100-4aee-b4cb-\
8b51cffeccf9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a0", "\[Rule]", 
   RowBox[{"\[CapitalDelta]C", "-", 
    FractionBox[
     RowBox[{"a", " ", "u"}], 
     RowBox[{"u", "+", 
      RowBox[{"v", "[", "3", "]"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.731934980335926*^9, 3.796981099828188*^9, 
  3.798419750887236*^9, 3.7986862445550017`*^9, 
  3.799037873763509*^9},ExpressionUUID->"0dea6558-aa0d-4557-b829-\
3b572ecbec8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", "\[CapitalDelta]C", " ", 
   SubsuperscriptBox["p", "1", "2"], " ", 
   SubsuperscriptBox["p", "2", "2"]}], "+", 
  RowBox[{"scdep", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["p", "1", "4"]}], "-", 
     SubsuperscriptBox["p", "2", "4"], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "-", 
     SubsuperscriptBox["p", "3", "4"]}], ")"}]}], "-", 
  RowBox[{"2", " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "1", "4"], "-", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     SubsuperscriptBox["p", "2", "4"], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "3", "4"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.731934980335926*^9, 3.796981099828188*^9, 
  3.798419750887236*^9, 3.7986862445550017`*^9, 
  3.799037873766395*^9},ExpressionUUID->"74283e6e-0240-4a38-a60a-\
62824b543717"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"prims", "/.", "a0su"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lhs", "/.", "a0su"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7319349141175423`*^9, 3.7319349517402983`*^9}, {
  3.73193499086008*^9, 
  3.731935004428129*^9}},ExpressionUUID->"0b9e4f78-7736-43c0-80d9-\
1e5908588ddf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8", " ", "a"}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      SubsuperscriptBox["p", "2", "2"], "-", 
      SubsuperscriptBox["p", "3", "2"]}], ")"}]}], ",", 
   RowBox[{"2", " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "4"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.731934991663628*^9, 3.731935004671232*^9}, 
   3.796981101877598*^9, 3.798419750981628*^9, 3.798686244604005*^9, 
   3.79903787379585*^9},ExpressionUUID->"e5301b5c-592c-4b5a-be32-\
1c2579a5b02e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"32", " ", "\[CapitalDelta]C", " ", 
    SubsuperscriptBox["p", "1", "2"], " ", 
    SubsuperscriptBox["p", "2", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.731934991663628*^9, 3.731935004671232*^9}, 
   3.796981101877598*^9, 3.798419750981628*^9, 3.798686244604005*^9, 
   3.799037873800488*^9},ExpressionUUID->"30bab3f6-686a-4686-8bb6-\
e9e33278f915"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"0de42ee0-5d1e-4746-bacf-\
78b90c4c6b78"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"9f5cb12f-93a7-412d-ba04-\
48417e7e0b82"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Scaling", "[", 
  RowBox[{"Dims", ",", "4"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"c1", "[", "0", "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c1", "[", "i", "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", "i", "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", 
          RowBox[{"i", ",", "j"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "j", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"i", ",", "j"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], " ", 
         RowBox[{
          RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"i", ",", "j", ",", "k"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
         RowBox[{
          RowBox[{"p", "[", "j", "]"}], "^", "2"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "k", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "i"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.7448191688423405`*^9, 3.7448192158060265`*^9}, {3.744820155447771*^9, 
  3.7448202194684334`*^9}, {3.7448202787108216`*^9, 3.744820278797827*^9}, {
  3.7448207748992023`*^9, 3.744820823908005*^9}, {3.7448218418222265`*^9, 
  3.7448218420292387`*^9}, {3.7448220484410443`*^9, 3.744822108835499*^9}, {
  3.796981121291853*^9, 
  3.7969811221955338`*^9}},ExpressionUUID->"9c48edee-8b6e-49f2-a960-\
ea4850eb30b5"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7969811231148148`*^9, 3.798419751057184*^9, 3.798686247934195*^9, 
   3.799037873822957*^9},ExpressionUUID->"c7b9f239-2e50-4cde-b97d-\
3e39e1031484"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c1", "[", "0", "]"}], "+", 
     RowBox[{
      RowBox[{"c1", "[", "1", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c1", "[", "2", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c1", "[", "3", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c2", "[", "1", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7969811231148148`*^9, 3.798419751057184*^9, 3.798686247934195*^9, 
   3.7990378738286047`*^9},ExpressionUUID->"52a0c260-184d-4249-902b-\
2821919ff503"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"2d202777-9e50-4935-b75c-\
d6750adadba3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis1", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.796981128474167*^9, 
   3.7969811295621223`*^9}},ExpressionUUID->"b4c4c86b-2e00-481c-8889-\
113414158fb5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"c1", "[", "0", "]"}]}], "-", 
        RowBox[{"c2", "[", "1", "]"}], "+", 
        RowBox[{"c2", "[", "3", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"c1", "[", "1", "]"}]}], "+", 
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"3", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"c1", "[", "2", "]"}]}], "+", 
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "2"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"3", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"c1", "[", "3", "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "2", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "1"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "2", "]"}]}], 
        SubsuperscriptBox["p", "2", "2"]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"c1", "[", "0", "]"}]}], "-", 
        RowBox[{"c2", "[", "2", "]"}], "+", 
        RowBox[{"c2", "[", "3", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"c1", "[", "1", "]"}]}], "+", 
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "1"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"3", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"c1", "[", "2", "]"}]}], "+", 
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "2"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"3", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"c1", "[", "3", "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "2", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c2", "[", "1", "]"}]}], "+", 
        RowBox[{"c2", "[", "2", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "2"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"1", ",", "1", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"1", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "4"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "4"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "4"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "4"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"c3", "[", 
             RowBox[{"2", ",", "1", ",", "1"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["p", "1", "2"], "-", 
              SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"c3", "[", 
                RowBox[{"3", ",", "1", ",", "1"}], "]"}]}], "+", 
              RowBox[{"c3", "[", 
               RowBox[{"3", ",", "2", ",", "1"}], "]"}]}], ")"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"c3", "[", 
             RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["p", "1", "2"], "-", 
              SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"c3", "[", 
                RowBox[{"3", ",", "1", ",", "2"}], "]"}]}], "+", 
              RowBox[{"c3", "[", 
               RowBox[{"3", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.796981131757675*^9, 3.7984197529264708`*^9, 3.798686251887421*^9, 
   3.7990378761954813`*^9},ExpressionUUID->"521e123a-7de4-4d2b-9928-\
725fad772c6a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448185917453327`*^9, 3.744818615404686*^9}, {
  3.7448187928928375`*^9, 3.7448187961940265`*^9}, {3.744819059923111*^9, 
  3.744819077658125*^9}, {3.744819250809029*^9, 3.744819270990183*^9}, {
  3.744820242266737*^9, 3.744820254043411*^9}, {3.744820495495221*^9, 
  3.7448204958812428`*^9}, {3.7448234158842573`*^9, 3.7448234177313633`*^9}, {
  3.79698113981806*^9, 
  3.7969811664291973`*^9}},ExpressionUUID->"169a9726-9180-42a9-ad13-\
6a0395c1f8f3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448202549504623`*^9, 
   3.7448203016981363`*^9, 3.7448204967112904`*^9, 3.744820845374233*^9, 
   3.7448218498156834`*^9, 3.7448221309517636`*^9, 3.744823173303383*^9, 
   3.7448234193324547`*^9, {3.796981140094865*^9, 3.796981166841548*^9}, 
   3.798419753019034*^9, 3.798686251938424*^9, 
   3.7990378762492332`*^9},ExpressionUUID->"0736e891-a87e-42f8-ac0e-\
794661f31086"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"c1", "[", "0", "]"}]}], "-", 
        RowBox[{"c2", "[", "1", "]"}], "+", 
        RowBox[{"c2", "[", "3", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"3", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "2"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"3", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "2", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "1"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"c1", "[", "0", "]"}]}], "-", 
        RowBox[{"c2", "[", "2", "]"}], "+", 
        RowBox[{"c2", "[", "3", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "1"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"3", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "2"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"3", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "2", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "3", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c2", "[", "1", "]"}]}], "+", 
        RowBox[{"c2", "[", "2", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c2", "[", 
            RowBox[{"1", ",", "2"}], "]"}], "-", 
           RowBox[{"c2", "[", 
            RowBox[{"2", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c2", "[", 
          RowBox[{"2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c2", "[", 
           RowBox[{"3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"1", ",", "1", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"1", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "4"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"2", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "4"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{
         RowBox[{"c3", "[", 
          RowBox[{"3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c3", "[", 
          RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "4"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "4"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"c3", "[", 
             RowBox[{"2", ",", "1", ",", "1"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["p", "1", "2"], "-", 
              SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"c3", "[", 
                RowBox[{"3", ",", "1", ",", "1"}], "]"}]}], "+", 
              RowBox[{"c3", "[", 
               RowBox[{"3", ",", "2", ",", "1"}], "]"}]}], ")"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"c3", "[", 
             RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["p", "1", "2"], "-", 
              SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"c3", "[", 
                RowBox[{"3", ",", "1", ",", "2"}], "]"}]}], "+", 
              RowBox[{"c3", "[", 
               RowBox[{"3", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448186156917024`*^9, 3.7448187309882965`*^9, 3.744818796555047*^9, 
   3.7448188464899035`*^9, 3.7448190783291636`*^9, {3.7448192605355854`*^9, 
   3.7448192712761993`*^9}, 3.7448196533060503`*^9, 3.7448202549504623`*^9, 
   3.7448203016981363`*^9, 3.7448204967112904`*^9, 3.744820845374233*^9, 
   3.7448218498156834`*^9, 3.7448221309517636`*^9, 3.744823173303383*^9, 
   3.7448234193324547`*^9, {3.796981140094865*^9, 3.796981166841548*^9}, 
   3.798419753019034*^9, 3.798686251938424*^9, 
   3.799037877480377*^9},ExpressionUUID->"fb0df2b4-4a38-4b08-823e-\
00b70f39800b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AllEquations", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
          RowBox[{"cwis2", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], "//", 
         "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}], " ", 
            RowBox[{"Log", "[", 
             RowBox[{"p", "[", "k", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], "/.", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"p", "[", "j_", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "//",
          "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
          RowBox[{"cwis2", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "//", 
         "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}], " ", 
            RowBox[{"Log", "[", 
             RowBox[{"p", "[", "k", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "/.", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"p", "[", "j_", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "//",
          "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
          RowBox[{"cwis2", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], "//", 
         "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "m", "]"}], "^", "2"}], " ", 
            RowBox[{"Log", "[", 
             RowBox[{"p", "[", "k", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", "j"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], "/.", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"p", "[", "j_", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "//",
          "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "m", "]"}], "^", "2"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", "j"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
          RowBox[{"cwis2", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "//", 
         "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "m", "]"}], "^", "2"}], " ", 
            RowBox[{"Log", "[", 
             RowBox[{"p", "[", "k", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", "j"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "/.", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"p", "[", "j_", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "//",
          "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "m", "]"}], "^", "2"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", "j"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}]}], " ", "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.744822365741193*^9, 3.7448226594179907`*^9}, {
  3.796981225351347*^9, 3.796981230015273*^9}, {3.796981543978479*^9, 
  3.796981630825733*^9}},ExpressionUUID->"2f2d4353-8745-4395-a6cb-\
d7f45ffc0b80"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "2"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "3"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "3"}], "]"}]}]}], "\[Equal]", "0"}], ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"c2", "[", 
      RowBox[{"1", ",", "2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", "1", "]"}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"c2", "[", "2", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"c2", "[", 
      RowBox[{"2", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"c2", "[", 
      RowBox[{"3", ",", "2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"c2", "[", 
      RowBox[{"3", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "2"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "3"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}]}], "\[Equal]", "0"}], ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"c2", "[", 
      RowBox[{"1", ",", "3"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"c2", "[", 
      RowBox[{"2", ",", "3"}], "]"}]}], "\[Equal]", "0"}], ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"c1", "[", "0", "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{"c2", "[", "1", "]"}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"c2", "[", "3", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"c2", "[", 
      RowBox[{"2", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"c2", "[", 
      RowBox[{"3", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "2"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "2"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"1", ",", "3"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "3"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1", ",", "1"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1", ",", "2"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2", ",", "2"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"2", ",", "3"}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1", ",", "3"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2", ",", "3"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   "True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "2"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c2", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1", ",", "3"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"c3", "[", 
      RowBox[{"1", ",", "1", ",", "3"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "1", ",", "3"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "2", ",", "3"}], "]"}]}], "\[Equal]", "0"}], ",", 
   "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "1", "]"}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "1", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "2", "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "2", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c2", "[", "3", "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "3", ",", "3"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"3", ",", "2", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"3", ",", "3", ",", "1"}], "]"}]}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.744822544655426*^9, 3.7448226007316337`*^9, {3.744822633663517*^9, 
   3.744822660848072*^9}, 3.7448231798907595`*^9, 3.744823423880715*^9, 
   3.7969816339143353`*^9, 3.7984197536121197`*^9, 3.7986862530984907`*^9, 
   3.799037877635849*^9},ExpressionUUID->"48158703-77f2-4612-99ef-\
02c9362fca2e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution2", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"AllEquations", ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c1", "[", "0", "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c2", "[", "i", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c3", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c3", "[", 
           RowBox[{"i", ",", "j", ",", "k"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{"cwis2", "/.", "LocalPrimarySolution2"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448192902262836`*^9, 3.744819355498017*^9}, {
  3.7448203073794613`*^9, 3.744820342865491*^9}, {3.7448205174644775`*^9, 
  3.744820520935676*^9}, {3.7448208860535593`*^9, 3.744821000544108*^9}, {
  3.74482214487256*^9, 3.7448221526640053`*^9}, {3.7448226719127045`*^9, 
  3.74482278074893*^9}, {3.7448228256935005`*^9, 3.7448228280846376`*^9}, {
  3.7448228811966753`*^9, 
  3.7448228857809377`*^9}},ExpressionUUID->"fdbd3323-0756-471e-98b2-\
e6a08ceabfbc"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   430,4,29347142503502531606,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.744822781496973*^9, 3.744822828282649*^9, 
  3.744822885953947*^9, 3.744823183555969*^9, 3.7448234256208143`*^9, 
  3.796981640038327*^9, 3.798419753793499*^9, 3.7986862532064967`*^9, 
  3.7990378777691298`*^9},ExpressionUUID->"2718438d-2cfb-4333-90db-\
427b416a5bdc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"c2", "[", "1", "]"}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"c1", "[", "0", "]"}]}], "+", 
     RowBox[{"c2", "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], "2"], "+", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "1"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"1", ",", "1", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], "4"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"1", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "2"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"c1", "[", "0", "]"}], "2"]}], "-", 
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], "4"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.74482034336852*^9, 3.7448205217677236`*^9, {3.744820916155281*^9, 
   3.7448210008001227`*^9}, 3.7448218540109234`*^9, {3.7448221357070355`*^9, 
   3.7448221529600224`*^9}, {3.744822738652522*^9, 3.744822781499973*^9}, 
   3.7448228282866488`*^9, 3.7448228859569473`*^9, 3.7448231835609694`*^9, 
   3.744823425624815*^9, 3.7969816400633307`*^9, 3.798419753813211*^9, 
   3.7986862532304983`*^9, 
   3.799037877776267*^9},ExpressionUUID->"503d739f-d8ba-4da1-9df3-\
e29b5b6ffd92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c2", "[", "1", "]"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1"}], "]"}]}]}], ")"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"1", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c2", "[", "1", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1"}], "]"}]}]}], ")"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c3", "[", 
         RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.74482034336852*^9, 3.7448205217677236`*^9, {3.744820916155281*^9, 
   3.7448210008001227`*^9}, 3.7448218540109234`*^9, {3.7448221357070355`*^9, 
   3.7448221529600224`*^9}, {3.744822738652522*^9, 3.744822781499973*^9}, 
   3.7448228282866488`*^9, 3.7448228859569473`*^9, 3.7448231835609694`*^9, 
   3.744823425624815*^9, 3.7969816400633307`*^9, 3.798419753813211*^9, 
   3.7986862532304983`*^9, 
   3.799037877999031*^9},ExpressionUUID->"2105620c-69b8-44c1-a83b-\
3dba5b3f2925"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution1", ",", "LocalPrimarySolution2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.744821339168476*^9, 3.744821362425806*^9}, {
  3.7448227939126825`*^9, 
  3.7448227988549657`*^9}},ExpressionUUID->"37245f5b-de3f-40a9-ab42-\
e3699a9ec001"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"c2", "[", "1", "]"}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"c1", "[", "0", "]"}]}], "+", 
     RowBox[{"c2", "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], "2"], "+", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "1"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"1", ",", "1", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], "4"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"1", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "2"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"c1", "[", "0", "]"}], "2"]}], "-", 
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], "4"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744821350842144*^9, 3.744821362715823*^9}, 
   3.7448218651055584`*^9, {3.744822799748017*^9, 3.744822829224703*^9}, 
   3.7448231853440714`*^9, 3.7448234288429985`*^9, 3.796981642382207*^9, 
   3.7984197540731277`*^9, 3.7986862537445273`*^9, 
   3.799037878017025*^9},ExpressionUUID->"6dfc46fb-503f-4b8f-ba71-\
255042694856"]
}, Open  ]],

Cell["\<\
Substitute to secondary CWIs and compare with what the right hand side should \
be:\
\>", "Text",
 CellChangeTimes->{{3.7448165250491247`*^9, 3.744816541465063*^9}, {
   3.7984192600730762`*^9, 3.798419260728879*^9}, 
   3.7984193429424763`*^9},ExpressionUUID->"445ec3d9-749d-4ba4-938e-\
c94ae18c568f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTO", ",", " ", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.744815924271762*^9, 3.7448159298470807`*^9}, {
   3.7448159895034933`*^9, 3.744815992406659*^9}, {3.744816022703392*^9, 
   3.744816070897148*^9}, 3.7448163404065638`*^9, {3.7448165637103357`*^9, 
   3.7448165668035126`*^9}, {3.79698164602639*^9, 
   3.796981658122244*^9}},ExpressionUUID->"a470febf-6429-4e54-8924-\
8f2e6bfefac5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c1", "[", "0", "]"}], "+", 
      RowBox[{"c2", "[", "1", "]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"c2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "1", "4"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "4"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "2", "4"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "4"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c1", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c1", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c1", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "3", "4"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "3", "4"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "4"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"c1", "[", "0", "]"}]}], "+", 
         RowBox[{"c2", "[", "1", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "4"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "+", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"c3", "[", 
              RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
             SubsuperscriptBox["p", "2", "4"]}], "+", 
            RowBox[{
             RowBox[{"c3", "[", 
              RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
             SubsuperscriptBox["p", "3", "4"]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.744820353267086*^9, 3.7448205246838903`*^9, 
   3.744821391742483*^9, 3.7448218678357143`*^9, {3.7448228156179247`*^9, 
   3.74482283074879*^9}, 3.7448231881222305`*^9, 3.7448234306020994`*^9, 
   3.796981658907153*^9, 3.798419754163155*^9, 3.7986862560226574`*^9, 
   3.799037878137857*^9},ExpressionUUID->"74dc7dec-7716-4ad5-bdb9-\
d104abc1ed09"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.744816543927204*^9, 3.744816567663562*^9}, 
   3.744816604223653*^9, 3.7448172171207085`*^9, 3.7448182177659426`*^9, 
   3.744818634476777*^9, 3.7448187325593867`*^9, 3.7448187993272057`*^9, 
   3.7448188496860857`*^9, 3.7448190815583487`*^9, 3.74481945119049*^9, 
   3.744819722969035*^9, 3.744820353267086*^9, 3.7448205246838903`*^9, 
   3.744821391742483*^9, 3.7448218678357143`*^9, {3.7448228156179247`*^9, 
   3.74482283074879*^9}, 3.7448231881222305`*^9, 3.7448234306020994`*^9, 
   3.796981658907153*^9, 3.798419754163155*^9, 3.7986862560226574`*^9, 
   3.7990378781411324`*^9},ExpressionUUID->"567ec422-2162-47ae-b286-\
725c7ee71121"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution3", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"c1", "[", "0", "]"}]}]}], " ", "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis4", "=", 
  RowBox[{
   RowBox[{"LocalSecs", "/.", "LocalPrimarySolution3"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448214205091286`*^9, 3.7448215466313424`*^9}, {
   3.744821873685049*^9, 3.7448218740140676`*^9}, {3.7448228489108286`*^9, 
   3.744822908053211*^9}, 3.7448231991958637`*^9, {3.7448234343233123`*^9, 
   3.7448234393706007`*^9}},ExpressionUUID->"fe3d45ee-0ace-4318-85ee-\
f5bc0472d124"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c2", "[", "1", "]"}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{"c1", "[", "0", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744821471992073*^9, 3.744821499590652*^9}, {
   3.7448215404419885`*^9, 3.744821547046366*^9}, 3.7448218742550817`*^9, 
   3.744822908287225*^9, 3.7448231998999043`*^9, 3.744823439584613*^9, 
   3.796981662502266*^9, 3.798419754181076*^9, 3.7986862571797233`*^9, 
   3.799037878160118*^9},ExpressionUUID->"0e73c359-e7cf-460c-b8b1-\
8610a1b8c3d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c1", "[", "0", "]"}]}], " ", 
       SubsuperscriptBox["p", "1", "4"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "4"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c1", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "2", "4"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "4"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c1", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c1", "[", "0", "]"}], " ", 
       SubsuperscriptBox["p", "3", "4"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c3", "[", 
        RowBox[{"3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "4"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c1", "[", "0", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c3", "[", 
           RowBox[{"3", ",", "1"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "4"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c3", "[", 
           RowBox[{"2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "+", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"c3", "[", 
              RowBox[{"2", ",", "2", ",", "2"}], "]"}], " ", 
             SubsuperscriptBox["p", "2", "4"]}], "+", 
            RowBox[{
             RowBox[{"c3", "[", 
              RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
             SubsuperscriptBox["p", "3", "4"]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744821471992073*^9, 3.744821499590652*^9}, {
   3.7448215404419885`*^9, 3.744821547046366*^9}, 3.7448218742550817`*^9, 
   3.744822908287225*^9, 3.7448231998999043`*^9, 3.744823439584613*^9, 
   3.796981662502266*^9, 3.798419754181076*^9, 3.7986862571797233`*^9, 
   3.799037878181487*^9},ExpressionUUID->"fd64be53-c59a-437f-9188-\
e7834468e6b8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AllEquations", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"cwis4", "\[LeftDoubleBracket]", 
          RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], "//", "Expand"}], 
        ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}], " ", 
            RowBox[{"Log", "[", 
             RowBox[{"p", "[", "k", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"cwis4", "\[LeftDoubleBracket]", 
           RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], "/.", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"p", "[", "j_", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "//",
          "Expand"}], ",", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "//", "Flatten"}]}], 
       "]"}]}], " ", "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.744822927317313*^9, 3.74482297395098*^9}, {
  3.796981677164435*^9, 
  3.796981681539578*^9}},ExpressionUUID->"2b46e3ee-0d11-4883-9ed4-\
5f1e36b709a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "16"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "1", ",", "2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "32"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "2", ",", "2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "32"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "1", ",", "2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   "True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "32"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"3", ",", "3", ",", "2"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"8", " ", 
      RowBox[{"c1", "[", "0", "]"}]}], "+", 
     RowBox[{"16", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"c1", "[", "0", "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"c1", "[", "0", "]"}]}], "-", 
     RowBox[{"16", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"c1", "[", "0", "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "1"}], "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "16"}], " ", 
     RowBox[{"c3", "[", 
      RowBox[{"2", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"c1", "[", "0", "]"}]}], "-", 
     RowBox[{"16", " ", 
      RowBox[{"c3", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}]}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.744822974440008*^9, 3.744823201958022*^9, 
  3.7448234412477083`*^9, 3.796981682715789*^9, 3.79841975428372*^9, 
  3.7986862583347893`*^9, 
  3.799037878212791*^9},ExpressionUUID->"db5a7bd9-ed16-46cd-adfe-\
273c647faf7f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution4", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"AllEquations", ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c1", "[", "0", "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c2", "[", "i", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c2", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c3", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c3", "[", 
           RowBox[{"i", ",", "j", ",", "k"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis5", "=", 
  RowBox[{
   RowBox[{"cwis4", "/.", "LocalPrimarySolution4"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448216639700537`*^9, 3.7448217661738997`*^9}, {
  3.7448229889348373`*^9, 
  3.7448230134602404`*^9}},ExpressionUUID->"70a196ce-c40c-432e-b5c8-\
fe19fe2c2aa9"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   438,5,29347142503502531606,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.744821735154125*^9, 3.7448217672919636`*^9}, 
   3.744821875586158*^9, {3.744823004235713*^9, 3.74482301398127*^9}, 
   3.744823204497167*^9, 3.7448234424247756`*^9, 3.796981684746098*^9, 
   3.79841975436758*^9, 3.798686259478853*^9, 
   3.799037878251808*^9},ExpressionUUID->"6df21fd6-976f-4412-b7b6-\
1bd9c985f188"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"c1", "[", "0", "]"}], "4"]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"c1", "[", "0", "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"c1", "[", "0", "]"}], "4"]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744821735158126*^9, 3.744821767294964*^9}, 
   3.744821875589158*^9, {3.744823004240713*^9, 3.7448230139862704`*^9}, 
   3.744823204500167*^9, 3.744823442428776*^9, 3.796981684759132*^9, 
   3.798419754380762*^9, 3.7986862594988546`*^9, 
   3.7990378782531433`*^9},ExpressionUUID->"4d037507-a8fa-4320-a5b4-\
d57451f7b5d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.744821735158126*^9, 3.744821767294964*^9}, 
   3.744821875589158*^9, {3.744823004240713*^9, 3.7448230139862704`*^9}, 
   3.744823204500167*^9, 3.744823442428776*^9, 3.796981684759132*^9, 
   3.798419754380762*^9, 3.7986862594988546`*^9, 
   3.799037878255513*^9},ExpressionUUID->"9b0d305d-e3e6-49c4-ae1e-\
65bbe2c4d29d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FinalLocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{
    RowBox[{"LocalPrimarySolution", "/.", 
     RowBox[{"Union", "[", 
      RowBox[{
       RowBox[{"LocalPrimarySolution4", "/.", "LocalPrimarySolution3"}], ",", 
       "LocalPrimarySolution3"}], "]"}]}], ",", 
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{"LocalPrimarySolution4", "/.", "LocalPrimarySolution3"}], ",", 
      "LocalPrimarySolution3"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "/.", "FinalLocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.744820545784097*^9, 3.7448205980090847`*^9}, {
  3.7448217973746843`*^9, 3.7448218176078415`*^9}, {3.7448219695575323`*^9, 
  3.744821973495758*^9}, {3.7448230294011517`*^9, 
  3.7448230497363153`*^9}},ExpressionUUID->"1ed6af5c-161d-4539-99e4-\
4a629a643cb4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"c1", "[", "0", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"c1", "[", "0", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", 
    RowBox[{"c1", "[", "0", "]"}]}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"c1", "[", "0", "]"}], "4"]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"c1", "[", "0", "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"c1", "[", "0", "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"c1", "[", "0", "]"}], "4"]}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"1", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"1", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"2", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c3", "[", 
     RowBox[{"3", ",", "3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7448205614909954`*^9, 3.7448205985671167`*^9, 
  3.744821819928974*^9, 3.7448218770462413`*^9, 3.74482197388278*^9, 
  3.7448230509693856`*^9, 3.7448232069563074`*^9, 3.744823445417947*^9, 
  3.796981686707857*^9, 3.798419754401408*^9, 3.798686260888932*^9, 
  3.799037878273069*^9},ExpressionUUID->"d27ec821-ecbc-43ac-bea0-\
087b8385b62f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"c1", "[", "0", "]"}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"c1", "[", "0", "]"}]}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "-", 
     RowBox[{
      RowBox[{"c1", "[", "0", "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c1", "[", "0", "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c3", "[", 
       RowBox[{"1", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c1", "[", "0", "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c1", "[", "0", "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c1", "[", "0", "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c1", "[", "0", "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448205614909954`*^9, 3.7448205985671167`*^9, 
  3.744821819928974*^9, 3.7448218770462413`*^9, 3.74482197388278*^9, 
  3.7448230509693856`*^9, 3.7448232069563074`*^9, 3.744823445417947*^9, 
  3.796981686707857*^9, 3.798419754401408*^9, 3.798686260888932*^9, 
  3.799037878276539*^9},ExpressionUUID->"e3a48fd9-1a17-4a2e-bac2-\
53c6ef94badc"]
}, Open  ]],

Cell["\<\
The solution proportional to c1[0] is the scheme-dependence of the original \
solution. We have one new solution, though, A[1] = A[2] = 0, A[3] = c3[1,1] \
p[1]^4. Let\[CloseCurlyQuote]s check.\
\>", "Text",
 CellChangeTimes->{{3.7448203761903973`*^9, 3.74482042204502*^9}, {
  3.7448206070286007`*^9, 3.744820621507428*^9}, {3.7448219781790257`*^9, 
  3.7448219805861635`*^9}, {3.7448233626982155`*^9, 3.7448233777600775`*^9}, {
  3.7448234537524233`*^9, 
  3.7448234764077196`*^9}},ExpressionUUID->"6ec10eb1-7269-4267-9262-\
e9a6969dd920"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"As", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "scdep"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"4", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
        RowBox[{
         RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], "scdep"}]}], ",", 
    
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"scdep", 
       RowBox[{"(", 
        RowBox[{"J2", "-", 
         RowBox[{"2", " ", 
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}]}]}], ")"}]}], "+", 
      RowBox[{"c", " ", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "4"}]}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.6966792683570137`*^9, 3.696679279573285*^9}, {3.696681304201663*^9, 
  3.696681316408358*^9}, {3.696681366492388*^9, 3.696681387231173*^9}, {
  3.696681685048072*^9, 3.696681697567984*^9}, {3.69668428384752*^9, 
  3.6966844247304697`*^9}, {3.696684771280221*^9, 3.696684771471381*^9}, {
  3.696686342433242*^9, 3.6966863967371817`*^9}, {3.729944104466456*^9, 
  3.729944105810862*^9}, {3.744823273518115*^9, 3.7448233227529306`*^9}, {
  3.7969796176573057`*^9, 
  3.796979617872672*^9}},ExpressionUUID->"1a802061-9805-4ce1-ad3f-\
ef7d30566b32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "4"}], " ", "scdep"}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"4", " ", "scdep", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "2"], "+", 
       SubsuperscriptBox["p", "2", "2"], "-", 
       SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{"scdep", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["p", "1", "4"]}], "-", 
        SubsuperscriptBox["p", "2", "4"], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "2", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        SubsuperscriptBox["p", "3", "4"]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448233234809723`*^9, 3.796981688985681*^9, 
  3.798419754471574*^9, 3.798686262344015*^9, 
  3.7990378783120403`*^9},ExpressionUUID->"eb283612-69e6-47e0-9ca7-\
4f5d46726269"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prims", "=", 
  RowBox[{"SimplifyCWIs", "[", 
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6967710983675203`*^9, 3.696771101783538*^9}, {
  3.6967711465791607`*^9, 3.69677114875325*^9}, {3.796981761457999*^9, 
  3.7969817640347548`*^9}},ExpressionUUID->"82c7bcb1-bfb8-43c9-abac-\
d4d3b6ffef40"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.696771299137005*^9, 3.697370082084155*^9, 
  3.697370620228602*^9, 3.72994415987877*^9, 3.731934712749793*^9, 
  3.7319348760145683`*^9, 3.744822034460245*^9, 3.7448233358396797`*^9, 
  3.796981765106862*^9, 3.7984197545603933`*^9, 3.798686265688203*^9, 
  3.799037878343144*^9},ExpressionUUID->"2ff832e2-6365-4833-a7e9-\
4467049e03cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTO", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.696686597433378*^9, 3.696686600383979*^9}, {
  3.69668665227813*^9, 3.6966866528691883`*^9}, {3.744823345163213*^9, 
  3.744823353073665*^9}, {3.796981767130412*^9, 
  3.796981769898991*^9}},ExpressionUUID->"b3032765-6ac2-469a-ae2a-\
9a56a1087308"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966865958954363`*^9, 3.69668664563006*^9, 3.696686711806786*^9, 
   3.696771338907934*^9, 3.697370106769093*^9, 3.697370645052367*^9, 
   3.731934908086825*^9, {3.744823338740845*^9, 3.7448233533576813`*^9}, 
   3.796981770169705*^9, 3.7984197546146297`*^9, 3.7986862668622704`*^9, 
   3.799037878373683*^9},ExpressionUUID->"c1cc5b3b-2eba-48cb-a64d-\
d50b668ac2ec"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["<JJJ>", "Section",
 CellChangeTimes->{{3.696662757712263*^9, 3.696662759359742*^9}, {
  3.696682859217309*^9, 3.696682859569441*^9}, {3.696686788827385*^9, 
  3.696686789194077*^9}},ExpressionUUID->"8c789367-e10e-4c71-9577-\
593a70ec7fb7"],

Cell[CellGroupData[{

Cell["d=3", "Subsection",
 CellChangeTimes->{{3.696663690437581*^9, 3.6966636937738028`*^9}, 
   3.6966888362755013`*^9},ExpressionUUID->"911318c2-21fb-4fdf-b357-\
72d0cccaeeb4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"2", " ", 
       RowBox[{"a", "/", 
        RowBox[{"a123", "^", "3"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "/", 
         RowBox[{"a123", "^", "2"}]}]}], "-", 
       RowBox[{"2", " ", "g", " ", "f", " ", 
        RowBox[{"cJ", "/", "a123"}]}]}]}]}], " ", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
  3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
  3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
  3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
  3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
  3.696684013724811*^9, 3.696684064967544*^9}, {3.696688839660561*^9, 
  3.696688862140767*^9}, {3.696688902834281*^9, 3.696688922139936*^9}, {
  3.6966893311366453`*^9, 3.69668933408633*^9}, {3.696690238543086*^9, 
  3.696690238880156*^9}, {3.696690288573051*^9, 3.696690288741581*^9}, {
  3.69677352035641*^9, 3.696773521437907*^9}, {3.696863918491787*^9, 
  3.696863918642304*^9}},ExpressionUUID->"d220060c-ef4a-4465-b201-\
64048b2864fa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677607964088*^9, 
  3.6966776258540688`*^9}},ExpressionUUID->"200503d4-d856-47a5-979c-\
c2931968cb53"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.696677627230453*^9, 3.6966776623071833`*^9, 3.696678324117044*^9, 
   3.696679200338336*^9, {3.696684066743404*^9, 3.6966840824275312`*^9}, 
   3.69668892366024*^9, 3.696689334936253*^9, 3.696689963534178*^9, 
   3.696690289670549*^9, 3.696772116555436*^9, 3.696773524904941*^9, 
   3.696863908870982*^9, 3.696863968242531*^9, 3.696864030067958*^9, 
   3.7448255549216037`*^9, 3.744832159514632*^9, 3.796981781385178*^9, 
   3.798419754691255*^9, 3.7986862824141483`*^9, 
   3.799037878424223*^9},ExpressionUUID->"d1886d58-c726-4a9b-a399-\
97e848fba255"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JJJ", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796981783882277*^9, 
  3.7969817855195436`*^9}},ExpressionUUID->"62465093-aa44-4790-82fe-\
a3eba5a1bdc1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, {3.696684068482006*^9, 
   3.696684082890736*^9}, 3.696688925859529*^9, 3.696689335378479*^9, 
   3.696689964009571*^9, 3.69669029008694*^9, 3.696772117592514*^9, 
   3.6967735256636744`*^9, 3.696863969032928*^9, 3.6968640306161613`*^9, 
   3.6968647235855217`*^9, 3.7448255556706467`*^9, 3.7448321617187586`*^9, 
   3.796981785906139*^9, 3.798419754750502*^9, 3.7986862829821806`*^9, 
   3.7990378784578323`*^9},ExpressionUUID->"8d81c6ab-24c1-4de2-a53b-\
cf4bde58a8ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JJJ", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696684086068306*^9, 3.6966840888764772`*^9}, {
  3.6966902221590433`*^9, 3.696690304039969*^9}, {3.696863993915718*^9, 
  3.696864007828238*^9}, {3.7969817887628193`*^9, 
  3.796981791930798*^9}},ExpressionUUID->"42a586a8-810e-454d-9f5a-\
798a28c974bc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"2", " ", "cJ", " ", "f", " ", "g", " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["p", "2"], "-", 
      SubscriptBox["p", "3"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, 
   3.696772123060525*^9, {3.696863995348433*^9, 3.696864031291771*^9}, {
   3.696864154150429*^9, 3.696864188236549*^9}, 3.696864724684412*^9, 
   3.696864829214048*^9, 3.744825556289682*^9, 3.7448321630468345`*^9, 
   3.7969817922383127`*^9, 3.7984197548154297`*^9, 3.7986862835202117`*^9, 
   3.799037878489097*^9},ExpressionUUID->"00d01486-a7e4-4532-81be-\
51172f7caec1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"JJJ", ",", "Dims"}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696690300151896*^9, 3.696690308983574*^9}, {
  3.69686475289846*^9, 3.696864753655519*^9}, {3.796981798441615*^9, 
  3.796981798731098*^9}},ExpressionUUID->"2f438e05-e88c-46d3-8c5d-\
e956faa27eee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "cJ", " ", "g", " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["p", "2"], "-", 
      SubscriptBox["p", "3"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696690298893585*^9, 3.696690309209648*^9}, {
   3.69686474702724*^9, 3.69686475394339*^9}, 3.696864829966242*^9, 
   3.744825556889716*^9, 3.7448321828009644`*^9, 3.796981799461687*^9, 
   3.7984197548684998`*^9, 3.7986862839542365`*^9, 
   3.799037878536484*^9},ExpressionUUID->"06c55d6b-deba-465d-9533-\
6094ba628bb2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"7c2f35bb-a878-47df-bf30-\
a09e0e1347bd"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"ef418171-faac-47aa-97ee-\
b19ceec7cf69"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "3"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "dimA1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c2", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"dimA1", "+", "2"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], " ", "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.7448191688423405`*^9, 3.7448192158060265`*^9}, {3.744820155447771*^9, 
  3.7448202194684334`*^9}, {3.7448202787108216`*^9, 3.744820278797827*^9}, {
  3.7448207748992023`*^9, 3.744820823908005*^9}, {3.7448218418222265`*^9, 
  3.7448218420292387`*^9}, {3.7448220484410443`*^9, 3.744822108835499*^9}, {
  3.744825571416547*^9, 3.7448256146310186`*^9}, {3.796981819400228*^9, 
  3.796981820235384*^9}},ExpressionUUID->"6cc5ec64-9c7e-4db1-8daf-\
051d71a909ed"],

Cell[BoxData[
 RowBox[{"-", "3"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, 3.7448321844580593`*^9, {
   3.796981815873066*^9, 3.796981820581769*^9}, 3.798419754881579*^9, 
   3.798686285253307*^9, 
   3.799037878574751*^9},ExpressionUUID->"bb8ff287-8acc-4678-b4ab-\
dd4ff009756b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c1", "[", "1", "]"}], 
      SubsuperscriptBox["p", "1", "3"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "2", "]"}], 
      SubsuperscriptBox["p", "2", "3"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "3", "]"}], 
      SubsuperscriptBox["p", "3", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c2", "[", "1", "]"}], 
      SubscriptBox["p", "1"]], "+", 
     FractionBox[
      RowBox[{"c2", "[", "2", "]"}], 
      SubscriptBox["p", "2"]], "+", 
     FractionBox[
      RowBox[{"c2", "[", "3", "]"}], 
      SubscriptBox["p", "3"]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, 3.7448321844580593`*^9, {
   3.796981815873066*^9, 3.796981820581769*^9}, 3.798419754881579*^9, 
   3.798686285253307*^9, 
   3.799037878578396*^9},ExpressionUUID->"701ef3d9-b54f-4814-8adb-\
3f9ce9c4fb69"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"b690f5b3-5b1c-4201-b4ef-\
c5a3580aa578"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"cwis", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "JJJ", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cwis", "/.", "LocalPrimarySolution"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.744825621683422*^9, 3.744825667576047*^9}, {
   3.7448257092444305`*^9, 3.7448257097734604`*^9}, {3.796981824531294*^9, 
   3.796981825761264*^9}},ExpressionUUID->"ea3117d1-5d7d-46c0-9c18-\
002484de9177"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c1", "[", "1", "]"}], "-", 
           RowBox[{"c2", "[", "1", "]"}]}], ")"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", "[", "3", "]"}], "+", 
          RowBox[{"c2", "[", "3", "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c1", "[", "2", "]"}]}], "+", 
          RowBox[{"c2", "[", "2", "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", "[", "3", "]"}], "+", 
          RowBox[{"c2", "[", "3", "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.74483218605015*^9, 3.796981828121776*^9, 
   3.798419755631126*^9, 3.7986862875584383`*^9, 
   3.799037879384398*^9},ExpressionUUID->"6f22f543-feb9-4337-ab1d-\
261741b204e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.74483218605015*^9, 3.796981828121776*^9, 
   3.798419755631126*^9, 3.7986862875584383`*^9, 
   3.799037879388692*^9},ExpressionUUID->"56b16aeb-9706-49d2-a7e3-\
b21585b3c68d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c2", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.74483218605015*^9, 3.796981828121776*^9, 
   3.798419755631126*^9, 3.7986862875584383`*^9, 
   3.799037879392262*^9},ExpressionUUID->"c80438e9-c274-49af-a7a2-\
6b15c2fa15a1"]
}, Open  ]],

Cell["No solution.", "Text",
 CellChangeTimes->{{3.744825691873437*^9, 
  3.744825694136566*^9}},ExpressionUUID->"c336da3e-580b-4edf-86ac-\
d68935d8a894"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 3.69667770458226*^9}, 
   3.696690321058776*^9},ExpressionUUID->"a1057c38-5267-444a-bc57-\
6375bf3c51a3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "a"}], " ", 
       RowBox[{"p", "[", "1", "]"}], 
       RowBox[{"p", "[", "2", "]"}], 
       RowBox[{"p", "[", "3", "]"}], 
       RowBox[{"D", "[", 
        RowBox[{"i1000", ",", 
         RowBox[{"p", "[", "1", "]"}], ",", 
         RowBox[{"p", "[", "2", "]"}], ",", 
         RowBox[{"p", "[", "3", "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"p", "[", "1", "]"}], 
        RowBox[{"p", "[", "2", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", 
        RowBox[{"D", "[", 
         RowBox[{"i1000", ",", 
          RowBox[{"p", "[", "1", "]"}], ",", 
          RowBox[{"p", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{"4", " ", "g", " ", "f", " ", "cJ", " ", "i2111fin"}], "-", 
       RowBox[{
        RowBox[{"2", "/", "3"}], "g", " ", "f", " ", "cJ", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "g", " ", "f", " ", "DJ"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
  3.696684161089705*^9, 3.696684198078211*^9}, {3.696684252001034*^9, 
  3.696684254088887*^9}, {3.696690336520917*^9, 3.69669042548135*^9}, {
  3.696865091141136*^9, 
  3.696865121146154*^9}},ExpressionUUID->"b19efd89-be3c-4b52-9342-\
1ce0e5d0a880"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 
  3.6966776876239157`*^9}},ExpressionUUID->"52e0aaf5-e0fc-4e07-8b50-\
cd890673d58c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"4", " ", "cJ", " ", "f", " ", "g"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, 3.696684203185841*^9, 3.6966904272283993`*^9, 
   3.696865123630101*^9, 3.7448257265544205`*^9, 3.7969818345467567`*^9, 
   3.798419755807538*^9, 3.7986862899005713`*^9, 
   3.799037879461117*^9},ExpressionUUID->"94fc53d8-7aba-44eb-8595-\
ebd681698c8c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "JJJ", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
  3.696678231271586*^9}, {3.7969818376824493`*^9, 
  3.796981838562058*^9}},ExpressionUUID->"be9e60ab-5c10-4e03-aae5-\
ede835ee0f46"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, 3.696684208811737*^9, {3.696684242701248*^9, 
   3.6966842567745113`*^9}, 3.6966904367944202`*^9, 3.696865132223857*^9, 
   3.7448257294845877`*^9, 3.7448323114653234`*^9, 3.796981843878549*^9, 
   3.798419762225274*^9, 3.798686295323876*^9, 
   3.799037884028171*^9},ExpressionUUID->"17a3815e-07cb-4562-a964-\
7c27f33b53d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", "=", 
  RowBox[{"SimplifyCWIs", "[", 
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "JJJ", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696690683795772*^9, 3.696690714348679*^9}, {
  3.69669134894098*^9, 3.696691357279027*^9}, {3.696691427146387*^9, 
  3.6966914347660217`*^9}, {3.696691469535232*^9, 3.696691470942459*^9}, {
  3.6966916963138313`*^9, 3.6966917059815693`*^9}, {3.696865167909911*^9, 
  3.696865171293861*^9}, {3.796981842160861*^9, 
  3.796981845938045*^9}},ExpressionUUID->"0028dbd9-b579-4bcb-a591-\
233cf6bed596"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "f", " ", "g", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cJ", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"DJ", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"2", " ", "cJ", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"DJ", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"2", " ", "cJ", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"2", " ", "cJ", " ", 
       RowBox[{"Log", "[", "\[Mu]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.696691357976824*^9, 3.696691471786271*^9, 
  3.6966917068344917`*^9, 3.6968651721436234`*^9, 3.744825730100623*^9, 
  3.744832312039356*^9, 3.796981847328396*^9, 3.798419763729525*^9, 
  3.798686296535945*^9, 
  3.799037885171618*^9},ExpressionUUID->"8dd08307-c9e6-4603-b7f0-\
0287bcb2b379"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhs", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ApplyTWIs", "[", 
     RowBox[{"JJJ", ",", "Dims"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"cJ", "[", "0", "]"}], "\[Rule]", "DJ"}]}], "//", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"#", ",", "as"}], "]"}], "&"}]}]}]], "Input",
 CellChangeTimes->{{3.696691384841769*^9, 3.696691401942644*^9}, {
  3.696691650697281*^9, 3.696691679062705*^9}, {3.696865180494331*^9, 
  3.696865211590679*^9}, {3.796981850858708*^9, 
  3.796981853338784*^9}},ExpressionUUID->"1f0821ce-db03-49cb-9ae6-\
84279a9af7d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"4", " ", "\[ImaginaryI]", " ", "g", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cJ", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["p", "2", "2"], 
         SuperscriptBox["\[Mu]", "2"]], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"cJ", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["p", "3", "2"], 
         SuperscriptBox["\[Mu]", "2"]], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"DJ", " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.696691378241849*^9, 3.696691402348506*^9}, 
   3.6966915021830387`*^9, {3.6966916665556917`*^9, 3.696691679325433*^9}, 
   3.6966917096803427`*^9, {3.696865185282596*^9, 3.696865212131578*^9}, 
   3.744825730132625*^9, 3.7448323132194242`*^9, 3.7969818580099163`*^9, 
   3.798419763805007*^9, 3.798686296583948*^9, 
   3.7990378852437468`*^9},ExpressionUUID->"372de600-f72d-46a5-8060-\
82a6c6893095"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"lhs", "-", "rhs"}], "/.", 
     RowBox[{"f", "\[Rule]", "I"}]}], "//.", "logsu"}], ",", "as"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.69686518730838*^9, 3.696865201678485*^9}, {
  3.7969818673885107`*^9, 
  3.796981868483136*^9}},ExpressionUUID->"bdc4c98d-beff-4a9c-a37e-\
b84a86985410"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "cJ", " ", "g", " ", 
    SubsuperscriptBox["p", "1", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6968651949760847`*^9, 3.6968652131487417`*^9}, 
   3.7448257302956343`*^9, 3.744832315052529*^9, {3.7969818612489767`*^9, 
   3.796981869350727*^9}, 3.798419763855858*^9, 3.7986862966289506`*^9, 
   3.799037885256359*^9},ExpressionUUID->"469f9954-d6af-451c-897c-\
dfcfa02cc1c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"c3b70d19-df57-4a15-ac78-\
7ba6d556e32e"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"c8d56013-270d-441c-b40b-\
cc4ed2df4bad"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "3"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", "[", "i", "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "dimA1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"c2", "[", "0", "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c2", "[", "i", "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}]}], " ", 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.7448191688423405`*^9, 3.7448192158060265`*^9}, {3.744820155447771*^9, 
  3.7448202194684334`*^9}, {3.7448202787108216`*^9, 3.744820278797827*^9}, {
  3.7448207748992023`*^9, 3.744820823908005*^9}, {3.7448218418222265`*^9, 
  3.7448218420292387`*^9}, {3.7448220484410443`*^9, 3.744822108835499*^9}, {
  3.744825571416547*^9, 3.7448256146310186`*^9}, {3.744825749869754*^9, 
  3.7448257594623027`*^9}, {3.7969818763303633`*^9, 
  3.796981877179551*^9}},ExpressionUUID->"11bf8711-d93b-4ecc-b705-\
c9b5a846eeef"],

Cell[BoxData[
 RowBox[{"-", "2"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448323253851194`*^9, 3.7969818779340963`*^9, 
   3.798419763870919*^9, 3.798686299697126*^9, 
   3.799037885340186*^9},ExpressionUUID->"19b7ee3f-cd94-43f2-8ffc-\
2224f105a3e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c1", "[", "1", "]"}], 
      SubsuperscriptBox["p", "1", "2"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "2", "]"}], 
      SubsuperscriptBox["p", "2", "2"]], "+", 
     FractionBox[
      RowBox[{"c1", "[", "3", "]"}], 
      SubsuperscriptBox["p", "3", "2"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c2", "[", "0", "]"}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "1", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "2", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448323253851194`*^9, 3.7969818779340963`*^9, 
   3.798419763870919*^9, 3.798686299697126*^9, 
   3.799037885344777*^9},ExpressionUUID->"62f2d67c-5275-4741-98e7-\
c753705faaeb"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"e66a1656-85ca-4358-882f-\
538f7c9d964d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"cwis", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "JJJ", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cwis", "/.", "LocalPrimarySolution"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.744825621683422*^9, 3.744825667576047*^9}, {
   3.7448257092444305`*^9, 3.7448257097734604`*^9}, {3.79698188193857*^9, 
   3.796981882825766*^9}},ExpressionUUID->"d2d30573-555b-4c2a-b2be-\
d1bebc6914d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c1", "[", "1", "]"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c2", "[", "1", "]"}]}]}], ")"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", "[", "3", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"c2", "[", "3", "]"}]}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "3", "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c1", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", "[", "2", "]"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"c2", "[", "2", "]"}]}]}], ")"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", "[", "3", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"c2", "[", "3", "]"}]}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "1", "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c1", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c2", "[", "1", "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c2", "[", "2", "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.7448257679317875`*^9, 3.7448323274412374`*^9, 
   3.796981884440645*^9, 3.798419764530394*^9, 3.79868630151123*^9, 
   3.799037886135228*^9},ExpressionUUID->"f2210c2a-cabe-41e7-bc0a-\
3d8997d35ee7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.7448257679317875`*^9, 3.7448323274412374`*^9, 
   3.796981884440645*^9, 3.798419764530394*^9, 3.79868630151123*^9, 
   3.799037886140563*^9},ExpressionUUID->"b9988adb-90a6-4a2e-af36-\
d9a50229f682"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "2"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c2", "[", "3", "]"}]}], 
      SubsuperscriptBox["p", "3", "2"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.7448257679317875`*^9, 3.7448323274412374`*^9, 
   3.796981884440645*^9, 3.798419764530394*^9, 3.79868630151123*^9, 
   3.7990378861438503`*^9},ExpressionUUID->"22206749-f698-49c6-8126-\
b906d480c2fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"PrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "JJJ", "]"}], ",", 
    RowBox[{"SemiLocals", "/.", "PrimarySolution"}], ",", "Dims"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7448324258898687`*^9, 3.7448324637080317`*^9}, {
  3.796981893476802*^9, 
  3.7969818969067698`*^9}},ExpressionUUID->"60ff9ee6-67b0-499d-ab28-\
f6e1e9ab7cbd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c1", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c1", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c2", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448324644130716`*^9, {3.796981888722801*^9, 3.796981897263854*^9}, 
   3.798419764557679*^9, 3.7986863023942804`*^9, 
   3.799037886159852*^9},ExpressionUUID->"1af67588-1b92-4505-b553-\
027e4e676b58"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"2", " ", 
    RowBox[{"c2", "[", "0", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448324644130716`*^9, {3.796981888722801*^9, 3.796981897263854*^9}, 
   3.798419764557679*^9, 3.7986863023942804`*^9, 
   3.799037886163372*^9},ExpressionUUID->"3cd23989-ccb7-4673-9a6f-\
ce3e0424fded"]
}, Open  ]],

Cell["No solution.", "Text",
 CellChangeTimes->{{3.744825691873437*^9, 
  3.744825694136566*^9}},ExpressionUUID->"fba39d64-7589-4501-8c96-\
45113d407fa5"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["<TJJ>", "Section",
 CellChangeTimes->{{3.696662757712263*^9, 3.696662759359742*^9}, {
  3.696682859217309*^9, 3.696682859569441*^9}, {3.696686788827385*^9, 
  3.696686789194077*^9}, {3.696690487457403*^9, 
  3.696690487825531*^9}},ExpressionUUID->"8b59e486-e928-4a5e-85ab-\
8abcca2c3d7b"],

Cell[CellGroupData[{

Cell["d=3", "Subsection",
 CellChangeTimes->{{3.696663690437581*^9, 3.6966636937738028`*^9}, 
   3.6966888362755013`*^9},ExpressionUUID->"67895a5c-c9ed-4309-9dfa-\
b451d75c76c9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"2", " ", "a", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", 
           RowBox[{"p", "[", "1", "]"}]}], "+", "a23"}], ")"}], "/", 
        RowBox[{"a123", "^", "4"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"2", " ", "a", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
         RowBox[{"a123", "^", "3"}]}]}], "-", 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{"p", "[", "1", "]"}]}], "+", "a23"}], ")"}], "/", 
         RowBox[{"a123", "^", "2"}]}], " ", "cJ"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "/", 
         RowBox[{"a123", "^", "3"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], 
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "-", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "-", 
          RowBox[{"3", 
           RowBox[{"p", "[", "1", "]"}], 
           RowBox[{"p", "[", "2", "]"}]}], "+", 
          RowBox[{"3", 
           RowBox[{"p", "[", "1", "]"}], 
           RowBox[{"p", "[", "3", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{"p", "[", "1", "]"}]}], "+", "a23"}], ")"}], "/", 
         RowBox[{"a123", "^", "2"}]}], "cJ"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"a", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", 
           RowBox[{"p", "[", "1", "]"}]}], "+", "a23"}], ")"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], "-", 
           RowBox[{"a23", "^", "2"}], "+", 
           RowBox[{"4", "b23"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", 
           RowBox[{"a123", "^", "2"}]}], ")"}]}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", "a123"}]}], "-", 
          "a23"}], ")"}], "cJ"}], "+", 
       RowBox[{"2", " ", "a23", " ", "\[Gamma]", " ", "cJ"}]}]}]}], " ", 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
   3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
   3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
   3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
   3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
   3.696684013724811*^9, 3.696684064967544*^9}, {3.696688839660561*^9, 
   3.696688862140767*^9}, {3.696688902834281*^9, 3.696688922139936*^9}, {
   3.6966893311366453`*^9, 3.69668933408633*^9}, {3.696690238543086*^9, 
   3.696690238880156*^9}, {3.696690288573051*^9, 3.696690288741581*^9}, {
   3.6966924967498302`*^9, 3.6966925965674343`*^9}, 3.696692744549728*^9, {
   3.696692801152857*^9, 3.696692818171936*^9}, {3.696692875211596*^9, 
   3.696692875556382*^9}},ExpressionUUID->"858ed6e6-d5c5-4e6e-81c0-\
fa3ce8a787a8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677607964088*^9, 
  3.6966776258540688`*^9}},ExpressionUUID->"987e351d-36cd-4b0c-97ef-\
52cec0c42815"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.696677627230453*^9, 3.6966776623071833`*^9, 3.696678324117044*^9, 
   3.696679200338336*^9, {3.696684066743404*^9, 3.6966840824275312`*^9}, 
   3.69668892366024*^9, 3.696689334936253*^9, 3.696689963534178*^9, 
   3.696690289670549*^9, 3.696692600831484*^9, 3.696692746038089*^9, {
   3.696692802888487*^9, 3.696692819140151*^9}, 3.696692877323474*^9, 
   3.69684250442776*^9, 3.7448257982585216`*^9, 3.796981916036004*^9, 
   3.79698245553179*^9, 3.797539723394581*^9, 3.798419764635458*^9, 
   3.7986863116258016`*^9, 
   3.799037886249506*^9},ExpressionUUID->"1d73740f-8089-4283-9a6d-\
15cc3f09681d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TJJ", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796981918554596*^9, 
  3.796981920138742*^9}},ExpressionUUID->"0050ee0b-be3b-4026-b0d3-\
20392296fdff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, {3.696684068482006*^9, 
   3.696684082890736*^9}, 3.696688925859529*^9, 3.696689335378479*^9, 
   3.696689964009571*^9, 3.69669029008694*^9, 3.696692604822192*^9, {
   3.6966927468247137`*^9, 3.696692838124413*^9}, {3.696692877837805*^9, 
   3.69669288591216*^9}, 3.69684250675068*^9, 3.744825799136572*^9, 
   3.7969819205164022`*^9, 3.7969824570060062`*^9, 3.7975397266795855`*^9, 
   3.798419764734375*^9, 3.7986863121708326`*^9, 
   3.7990378863464127`*^9},ExpressionUUID->"0de50107-7c74-42fe-a36d-\
256133696a5f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TJJ", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TJJ", ",", "Dims", ",", " ", 
    RowBox[{"dTdADerivative", "\[Rule]", "\[Gamma]"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "-", "%%"}], "/.", 
   RowBox[{"c3", "\[Rule]", "\[Gamma]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696684086068306*^9, 3.6966840888764772`*^9}, {
  3.6966902221590433`*^9, 3.696690304039969*^9}, {3.6966928953364277`*^9, 
  3.696692914743807*^9}, {3.696692999505937*^9, 3.696693008918251*^9}, {
  3.79698192365091*^9, 3.796981979848012*^9}, {3.7969824620618258`*^9, 
  3.7969824737957783`*^9}},ExpressionUUID->"f275c6d5-d600-44c0-9f72-\
7382163a1b5f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"6", " ", "cJ", " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["p", "2"], "-", 
      SubscriptBox["p", "3"]}], ")"}]}], ",", 
   RowBox[{"12", " ", "cJ", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["p", "3"]}], "+", 
      RowBox[{"\[Gamma]", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["p", "2"], "+", 
         SubscriptBox["p", "3"]}], ")"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.6968425090635557`*^9, 3.7448258020007353`*^9, {
   3.7969819350804787`*^9, 3.796981980169066*^9}, {3.7969824745253153`*^9, 
   3.796982514936552*^9}, 3.797539741562607*^9, 3.798419764863011*^9, 
   3.798686312693863*^9, 
   3.7990378864279633`*^9},ExpressionUUID->"5fa22d36-b3c3-4a48-8316-\
cc32f3712d3e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"6", " ", "cJ", " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["p", "2"], "-", 
      SubscriptBox["p", "3"]}], ")"}]}], ",", 
   RowBox[{"12", " ", "cJ", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["p", "3"]}], "+", 
      RowBox[{"\[Gamma]", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["p", "2"], "+", 
         SubscriptBox["p", "3"]}], ")"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.6968425090635557`*^9, 3.7448258020007353`*^9, {
   3.7969819350804787`*^9, 3.796981980169066*^9}, {3.7969824745253153`*^9, 
   3.796982514936552*^9}, 3.797539741562607*^9, 3.798419764863011*^9, 
   3.798686312693863*^9, 
   3.799037886439897*^9},ExpressionUUID->"5df17830-e36d-4c63-a9b4-\
75d9b8681a2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.6968425090635557`*^9, 3.7448258020007353`*^9, {
   3.7969819350804787`*^9, 3.796981980169066*^9}, {3.7969824745253153`*^9, 
   3.796982514936552*^9}, 3.797539741562607*^9, 3.798419764863011*^9, 
   3.798686312693863*^9, 
   3.799037886443602*^9},ExpressionUUID->"d94c9584-955e-42fb-957c-\
eef7f525a8ed"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"12def57d-03cc-44bc-b901-\
a4d255bb10c1"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"08a54d79-eab4-48e3-99fe-\
b2d094353510"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "4"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"-", "3"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "i"}], "]"}], 
        RowBox[{"p", "[", "i", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7448164183170195`*^9, 3.7448164193210773`*^9}, {
  3.744816596324201*^9, 3.74481659944438*^9}, {3.744816937896738*^9, 
  3.74481693827376*^9}, {3.7448180178805094`*^9, 3.744818053452544*^9}, {
  3.744818359395043*^9, 3.7448183897207775`*^9}, {3.744818492863677*^9, 
  3.7448185236254363`*^9}, {3.7448190283813066`*^9, 3.7448190397009544`*^9}, {
  3.7448191688423405`*^9, 3.7448192158060265`*^9}, {3.744820155447771*^9, 
  3.7448202194684334`*^9}, {3.7448202787108216`*^9, 3.744820278797827*^9}, {
  3.7448207748992023`*^9, 3.744820823908005*^9}, {3.7448218418222265`*^9, 
  3.7448218420292387`*^9}, {3.7448220484410443`*^9, 3.744822108835499*^9}, {
  3.744825571416547*^9, 3.7448256146310186`*^9}, {3.744825749869754*^9, 
  3.7448257594623027`*^9}, {3.7448258212938395`*^9, 3.7448258214058456`*^9}, {
  3.744825889709752*^9, 3.744825931837162*^9}, {3.7969819878036118`*^9, 
  3.796981989997014*^9}},ExpressionUUID->"f3359186-b56c-4477-9357-\
509bcf8fb6cc"],

Cell[BoxData[
 RowBox[{"-", "3"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448258234009595`*^9, 3.7448259321781816`*^9, 
   3.744832591437337*^9, 3.796981990311879*^9, 3.797539749092617*^9, 
   3.798419764933783*^9, 3.798686314512967*^9, 
   3.7990378864612427`*^9},ExpressionUUID->"39efe00b-c821-49c5-8658-\
92d25a321aa1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "1"}], "]"}], 
      SubsuperscriptBox["p", "1", "3"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2"}], "]"}], 
      SubsuperscriptBox["p", "2", "3"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "3"}], "]"}], 
      SubsuperscriptBox["p", "3", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "1"}], "]"}], 
      SubscriptBox["p", "1"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "2"}], "]"}], 
      SubscriptBox["p", "2"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "3"}], "]"}], 
      SubscriptBox["p", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "1"}], "]"}], 
      SubscriptBox["p", "1"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "2"}], "]"}], 
      SubscriptBox["p", "2"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3"}], "]"}], 
      SubscriptBox["p", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      SubscriptBox["p", "1"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      SubscriptBox["p", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      SubscriptBox["p", "3"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448258234009595`*^9, 3.7448259321781816`*^9, 
   3.744832591437337*^9, 3.796981990311879*^9, 3.797539749092617*^9, 
   3.798419764933783*^9, 3.798686314512967*^9, 
   3.799037886465119*^9},ExpressionUUID->"263f6ccf-39a0-4a8d-a1c3-\
d589a6a23b19"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"b6a37aed-19a5-431f-ad88-\
e238758ddd4b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis1", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TJJ", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.744825621683422*^9, 3.744825667576047*^9}, {
   3.7448257092444305`*^9, 3.7448257097734604`*^9}, {3.744825937418481*^9, 
   3.744825937696497*^9}, 3.744826062704647*^9, {3.796981999044134*^9, 
   3.796982000130987*^9}},ExpressionUUID->"ccedcb83-30f9-49b5-8ef0-\
bfbecbb6b2f5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "1"}], "]"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}]}], 
         SubsuperscriptBox["p", "1", "3"]], "+", 
        FractionBox[
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "2"}], "]"}], 
         SubsuperscriptBox["p", "2", "3"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "3"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "3"}], "]"}]}], 
         SubsuperscriptBox["p", "3", "3"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "1"}], "]"}]}], ")"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"1", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "1"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1"}], "]"}]}], ")"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}]}], 
       SubscriptBox["p", "3"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "2"}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2"}], "]"}]}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"1", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["p", "2"], "-", 
          SubscriptBox["p", "3"]}], ")"}]}], 
       RowBox[{
        SubscriptBox["p", "2"], " ", 
        SubscriptBox["p", "3"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "1"}], "]"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}]}], 
         SubsuperscriptBox["p", "1", "3"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "2"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "2"}], "]"}]}], 
         SubsuperscriptBox["p", "2", "3"]], "+", 
        FractionBox[
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "3"}], "]"}], 
         SubsuperscriptBox["p", "3", "3"]]}], ")"}]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "1"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1"}], "]"}]}], ")"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}]}], 
       SubscriptBox["p", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "3"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.7448257679317875`*^9, 3.7448259390115724`*^9, 
   3.7448260629036584`*^9, 3.7448325929564238`*^9, 3.7969820026223383`*^9, 
   3.797539754120639*^9, 3.798419766586561*^9, 3.798686317650144*^9, 
   3.799037888331806*^9},ExpressionUUID->"0d87cb4b-7414-493a-9484-\
5d9f26979bf7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.744825945281931*^9, 3.7448259722504735`*^9}, {
  3.7448260565192933`*^9, 
  3.7448260657938237`*^9}},ExpressionUUID->"f4e38d51-48f8-4590-bab2-\
64feeaf0a10a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744826066441861*^9, 3.744832594145492*^9, 
  3.796982005023108*^9, 3.7975397561346445`*^9, 3.7984197666601*^9, 
  3.798686317702147*^9, 
  3.799037888393195*^9},ExpressionUUID->"b5870223-af2f-4e2f-85d0-\
2069d280cc55"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SubscriptBox["p", "2"]]}], "+", 
        FractionBox["1", 
         SubscriptBox["p", "3"]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "3"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744826066441861*^9, 3.744832594145492*^9, 
  3.796982005023108*^9, 3.7975397561346445`*^9, 3.7984197666601*^9, 
  3.798686317702147*^9, 
  3.799037888413781*^9},ExpressionUUID->"757bd004-00df-42b3-a9b3-\
afb677650683"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{"cwis2", "/.", "LocalPrimarySolution2"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448260767274494`*^9, 
  3.7448261038339996`*^9}},ExpressionUUID->"2a910d6c-8752-4910-b0b6-\
9be1174a6301"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744826104033011*^9, 3.7448325953305597`*^9, 
  3.79698200690132*^9, 3.7975397574296465`*^9, 3.798419766718128*^9, 
  3.7986863177611504`*^9, 
  3.799037888438528*^9},ExpressionUUID->"301b0a07-34b8-4e3b-818c-\
cca3d9a8d11d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744826104033011*^9, 3.7448325953305597`*^9, 
  3.79698200690132*^9, 3.7975397574296465`*^9, 3.798419766718128*^9, 
  3.7986863177611504`*^9, 
  3.7990378884424677`*^9},ExpressionUUID->"e0e22b0d-f425-46b4-bc71-\
fb0a022b272e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution1", ",", "LocalPrimarySolution2"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.7448261121344748`*^9, 
  3.744826126024269*^9}},ExpressionUUID->"04b2cdca-7328-4925-8662-\
b4478867883b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826115502667*^9, 3.74482612621728*^9}, 
   3.7448325967786427`*^9, 3.7969820086643267`*^9, 3.7975397588196483`*^9, 
   3.798419766788595*^9, 3.798686318171174*^9, 
   3.799037888488352*^9},ExpressionUUID->"467b2803-a056-4921-b2a7-\
9f36f97cec50"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      SubscriptBox["p", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      SubscriptBox["p", "3"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826115502667*^9, 3.74482612621728*^9}, 
   3.7448325967786427`*^9, 3.7969820086643267`*^9, 3.7975397588196483`*^9, 
   3.798419766788595*^9, 3.798686318171174*^9, 
   3.799037888492057*^9},ExpressionUUID->"7e7e0cf9-6e55-43a2-90ea-\
323bcf7ea0f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TJJ", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"12", " ", "cJ", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"p", "[", "3", "]"}]}], "+", 
    RowBox[{"\[Gamma]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "+", 
       RowBox[{"p", "[", "3", "]"}]}], ")"}]}]}], ")"}]}]}], "Input",
 CellChangeTimes->{
  3.7448327117392178`*^9, {3.7969820121550417`*^9, 
   3.7969820164428988`*^9}},ExpressionUUID->"8225ef7e-9dba-48b0-9390-\
f672d1dd7ae1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2"}], "]"}], " ", 
       SubscriptBox["p", "2"]}], "+", 
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubscriptBox["p", "3"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448327553667135`*^9, 3.796982019939518*^9, 
  3.79753976004965*^9, 3.798419766918993*^9, 3.798686318815211*^9, 
  3.7990378885435038`*^9},ExpressionUUID->"061a015d-c953-49c0-8f5e-\
8022b597692a"],

Cell[BoxData[
 RowBox[{"12", " ", "cJ", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["p", "3"]}], "+", 
    RowBox[{"\[Gamma]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["p", "2"], "+", 
       SubscriptBox["p", "3"]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.7448327553667135`*^9, 3.796982019939518*^9, 
  3.79753976004965*^9, 3.798419766918993*^9, 3.798686318815211*^9, 
  3.799037888547175*^9},ExpressionUUID->"d628ef0b-57ce-48f0-b5d8-\
7b1a75182e36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", "cJ", " ", "\[Gamma]"}], "==", 
      RowBox[{"6", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"12", " ", "cJ", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Gamma]"}], ")"}]}], "\[Equal]", 
      RowBox[{"6", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], ",", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "2"}], "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7448327201406984`*^9, 
  3.744832769247507*^9}},ExpressionUUID->"cb0c83ed-7338-446c-a9e6-\
2fcfa7ff8282"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "cJ", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", 
     RowBox[{"2", " ", "cJ", " ", "\[Gamma]"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7448327706345863`*^9, 3.7969820246684437`*^9, 
  3.7975397614296517`*^9, 3.7984197669843407`*^9, 3.798686319675258*^9, 
  3.799037888565465*^9},ExpressionUUID->"1fc87efa-94b9-4235-a374-\
44129affaca0"]
}, Open  ]],

Cell["No solution.", "Text",
 CellChangeTimes->{{3.744825691873437*^9, 
  3.744825694136566*^9}},ExpressionUUID->"9538f964-4632-40d4-a12f-\
aef1306bd22a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 3.69667770458226*^9}, 
   3.696690321058776*^9},ExpressionUUID->"d242f314-dc20-4c9c-b7a6-\
fb42dc122b6c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NonLocalTerm", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"p", "[", "1", "]"}], 
      RowBox[{"p", "[", "2", "]"}], 
      RowBox[{"p", "[", "3", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"i1000", ",", 
           RowBox[{"p", "[", "1", "]"}], ",", 
           RowBox[{"p", "[", "1", "]"}], ",", 
           RowBox[{"p", "[", "2", "]"}], ",", 
           RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "-", 
        RowBox[{"D", "[", 
         RowBox[{"i1000", ",", 
          RowBox[{"p", "[", "1", "]"}], ",", 
          RowBox[{"p", "[", "2", "]"}], ",", 
          RowBox[{"p", "[", "3", "]"}]}], "]"}]}], ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", " ", "cJ", " ", 
       RowBox[{
        RowBox[{"MRed", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "i2111fin", "]"}]}], "-", 
      RowBox[{"a", " ", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "3"}], " ", 
       RowBox[{"p", "[", "2", "]"}], " ", 
       RowBox[{"p", "[", "3", "]"}], " ", 
       RowBox[{"D", "[", 
        RowBox[{"i1000", ",", 
         RowBox[{"p", "[", "1", "]"}], ",", 
         RowBox[{"p", "[", "2", "]"}], ",", 
         RowBox[{"p", "[", "3", "]"}]}], "]"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", " ", "cJ", " ", 
       RowBox[{
        RowBox[{"MRed", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "i2111fin", "]"}]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       RowBox[{"p", "[", "1", "]"}], " ", 
       RowBox[{"p", "[", "2", "]"}], " ", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"i1000", ",", 
           RowBox[{"p", "[", "1", "]"}], ",", 
           RowBox[{"p", "[", "2", "]"}]}], "]"}], "-", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"i1000", ",", 
            RowBox[{"p", "[", "1", "]"}], ",", 
            RowBox[{"p", "[", "1", "]"}], ",", 
            RowBox[{"p", "[", "2", "]"}]}], "]"}]}]}], " ", ")"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "cJ", " ", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}], " ", "i2111fin"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "^", "2"}], " ", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", 
       RowBox[{"p", "[", "1", "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"i1000", ",", 
           RowBox[{"p", "[", "1", "]"}]}], "]"}], "-", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], " ", 
          RowBox[{"D", "[", 
           RowBox[{"i1000", ",", 
            RowBox[{"p", "[", "1", "]"}], ",", 
            RowBox[{"p", "[", "1", "]"}]}], "]"}]}]}], " ", ")"}]}]}]}], " ", 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LogTerm", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], "/", "3"}], " ", "cJ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], " ", ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], "/", "3"}], " ", "cJ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], " ", ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", "3"}], " ", "cJ", " ", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], " ", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "\[Gamma]"}], "-", "1"}], ")"}], " ", "cJ", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], ")"}]}]}]}], " ", 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remainder", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"2", "/", "3"}], " ", "cJ"}], "-", 
      RowBox[{"2", " ", "DJ"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"2", "/", "3"}], " ", "cJ"}], "-", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"a", "+", "DJ"}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "cJ"}], " ", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"a", "+", "DJ"}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", "DJ"}], "+", 
         RowBox[{"\[Gamma]1", " ", "cJ"}]}], ")"}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.6969323801649446`*^9, 
  3.696932458777873*^9}},ExpressionUUID->"a87b6f5c-a7a0-4528-9de5-\
c3024f655422"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "n", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
       "NonLocalTerm", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
        "+", 
       RowBox[{
       "LogTerm", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], "+", 
       RowBox[{
       "Remainder", "\[LeftDoubleBracket]", "n", 
        "\[RightDoubleBracket]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"Length", "[", "NonLocalTerm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
   3.696684161089705*^9, 3.696684198078211*^9}, {3.696684252001034*^9, 
   3.696684254088887*^9}, {3.696690336520917*^9, 3.69669042548135*^9}, 
   3.6966934033084173`*^9, {3.6966934363449297`*^9, 3.696693437524848*^9}, {
   3.696693775102064*^9, 3.6966938040822763`*^9}, {3.696849253262422*^9, 
   3.696849261989676*^9}, {3.696849419420697*^9, 3.696849438832179*^9}, {
   3.696858827955868*^9, 3.6968588291643972`*^9}, {3.696932563189107*^9, 
   3.69693256937142*^9}, 
   3.7448331402337265`*^9},ExpressionUUID->"250205a7-b0b6-4f32-9663-\
879dd96a968a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"ApplyDmu", "[", "As", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 3.6966776876239157`*^9}, {3.69669381153874*^9, 
  3.696693814491118*^9}, {3.796982039723115*^9, 
  3.7969820400024137`*^9}},ExpressionUUID->"2f8e3ed5-7529-4bc1-a81b-\
b542276647fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"4", " ", "cJ"}], ",", 
   RowBox[{"4", " ", "cJ"}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "cJ", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "\[Gamma]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, 3.696684203185841*^9, 3.6966904272283993`*^9, {
   3.6966938085734673`*^9, 3.696693832208404*^9}, 3.696697596580287*^9, 
   3.696843308489655*^9, 3.696844091274022*^9, 3.696844309074664*^9, 
   3.696845072780553*^9, 3.6968452508802977`*^9, 3.696845584354619*^9, 
   3.6968494402799683`*^9, 3.6968593877331963`*^9, 3.696861495636035*^9, 
   3.696861561855953*^9, {3.6969321991467533`*^9, 3.6969322368039627`*^9}, 
   3.69693246509295*^9, 3.69693257092946*^9, 3.7448261899739265`*^9, 
   3.7448330067680926`*^9, 3.744833141371792*^9, 3.7969820404192123`*^9, 
   3.7969825686017523`*^9, 3.7975397658596587`*^9, 3.798419767108221*^9, 
   3.79842028816107*^9, 3.7986863232214594`*^9, 
   3.799037888700831*^9},ExpressionUUID->"f992edd1-1651-45bd-afa8-\
ca288760cbdb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"time", ",", " ", "prims"}], "}"}], "=", 
  RowBox[{
   RowBox[{"SimplifyCWIs", "[", 
    RowBox[{"ApplyCWIs", "[", 
     RowBox[{
      RowBox[{"PrimaryCWIs", "[", "TJJ", "]"}], ",", "As", ",", "Dims"}], 
     "]"}], "]"}], "//", "AbsoluteTiming"}]}]], "Input",
 CellChangeTimes->{{3.696843420159877*^9, 3.696843426376923*^9}, {
  3.79698204458676*^9, 3.796982046386406*^9}, {3.79753981445979*^9, 
  3.797539821804801*^9}},ExpressionUUID->"2ff46d12-d677-4c15-9346-\
7d248ae98a6c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"20.895258`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "8"}], " ", "cJ", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "8"}], " ", "cJ", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}]}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.696843435030678*^9, 3.696844318767333*^9, 
  3.696845082676386*^9, 3.696845262415168*^9, 3.696845595257348*^9, 
  3.6968494506202383`*^9, 3.696859400701304*^9, 3.696861504260302*^9, 
  3.696861570473144*^9, 3.696932473446184*^9, 3.696932524942006*^9, 
  3.696932580407442*^9, 3.744826198393408*^9, 3.7448330213339252`*^9, 
  3.74483315323147*^9, 3.7969820726666727`*^9, 3.796982595208475*^9, 
  3.79753980686378*^9, 3.797539860863047*^9, 3.798419796380872*^9, 
  3.7984203118018713`*^9, 3.7986863460907555`*^9, 
  3.799037909615848*^9},ExpressionUUID->"dda4bceb-2e50-4f63-85ee-\
ed4c0f80bb14"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", "=", 
  RowBox[{"SimplifyCWIs", "[", 
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TJJ", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696678106749449*^9, 3.6966781141980352`*^9}, {
  3.696678238255801*^9, 3.696678242655888*^9}, {3.69669044482646*^9, 
  3.6966904717141743`*^9}, {3.696693883779908*^9, 3.6966939003157787`*^9}, {
  3.796982050353252*^9, 
  3.7969820580038233`*^9}},ExpressionUUID->"883c6ac5-c4fe-4408-a6e1-\
c926c7367f76"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cJ", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"2", " ", "DJ", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", "cJ", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", "DJ", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", "cJ", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", "cJ", " ", 
       RowBox[{"Log", "[", "\[Mu]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cJ", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"2", " ", "DJ", " ", "\[Gamma]", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"2", " ", "cJ", " ", "\[Gamma]1", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", "cJ", " ", "\[Gamma]", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", "DJ", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"2", " ", "DJ", " ", "\[Gamma]", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"2", " ", "cJ", " ", "\[Gamma]1", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", "cJ", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", "cJ", " ", "\[Gamma]", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", "cJ", " ", 
       RowBox[{"Log", "[", "\[Mu]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696684262444735*^9, 3.696690462856483*^9, {3.696693887586896*^9, 
   3.696693904208905*^9}, 3.696843530955571*^9, 3.696844097501534*^9, 
   3.696844327726385*^9, 3.696845093645646*^9, 3.6968452647298527`*^9, 
   3.6968455975840473`*^9, 3.696849458395878*^9, 3.696859406605722*^9, 
   3.696861473661708*^9, 3.6968615066415367`*^9, 3.696861572873027*^9, 
   3.696932539161889*^9, 3.696932582936802*^9, 3.7448330243821*^9, 
   3.7448331562146406`*^9, 3.796982087917815*^9, 3.796982600282509*^9, 
   3.7975400171449175`*^9, 3.7984198052353983`*^9, 3.7986863749333878`*^9, 
   3.799037915656638*^9},ExpressionUUID->"5700acde-c1d1-4624-a021-\
fb34a5c9e68c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhs", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"ApplyTWIs", "[", 
      RowBox[{"TJJ", ",", " ", "Dims", ",", " ", 
       RowBox[{"dTdADerivative", "\[Rule]", "\[Gamma]"}]}], "]"}], "/.", 
     RowBox[{
      RowBox[{"cJ", "[", "0", "]"}], "\[Rule]", "DJ"}]}], "]"}], "//.", 
   "logsu"}]}]], "Input",
 CellChangeTimes->{{3.6966939200124826`*^9, 3.6966939350685263`*^9}, {
  3.696859421460332*^9, 3.696859423388295*^9}, {3.796982088371085*^9, 
  3.796982100306878*^9}, {3.796982181507759*^9, 3.796982195447489*^9}, {
  3.796982561639352*^9, 
  3.796982561887525*^9}},ExpressionUUID->"ab4d1d3d-22fc-45cd-8be8-\
5d439f735322"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{"DJ", "+", 
       RowBox[{"cJ", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"Log", "[", "\[Mu]", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}]}]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "-", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{"DJ", "+", 
       RowBox[{"cJ", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"Log", "[", "\[Mu]", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}]}]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}]}], ",", 
   RowBox[{"16", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cJ", " ", "\[Gamma]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"Log", "[", "\[Mu]", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}]}]}], ")"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"DJ", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"cJ", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"Log", "[", "\[Mu]", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}]}]}], ")"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"DJ", " ", "\[Gamma]", " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.696693923908321*^9, 3.696693936204144*^9}, 
   3.696843837385605*^9, 3.6968441002743387`*^9, 3.696844328714201*^9, 
   3.696845096737369*^9, 3.696845264786026*^9, 3.69684559763097*^9, 
   3.696849461107463*^9, {3.696859414477421*^9, 3.69685942385639*^9}, 
   3.6968609270347233`*^9, 3.696861473839282*^9, 3.696861506703205*^9, 
   3.6968615729293337`*^9, 3.696863400302599*^9, 3.696932544127263*^9, 
   3.696932583067937*^9, 3.7448330410890555`*^9, 3.7969821027211323`*^9, {
   3.796982182847745*^9, 3.796982195654921*^9}, 3.796982563078196*^9, 
   3.796982600431302*^9, 3.797540019564921*^9, 3.79841980542213*^9, 
   3.798686375014393*^9, 
   3.79903791577169*^9},ExpressionUUID->"43b8c604-b46c-4b2f-bf2e-\
224b95c4a034"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"lhs", "-", "rhs"}], "/.", 
    RowBox[{"c3", "\[Rule]", "\[Gamma]"}]}], "//.", "logsu"}], "]"}]], "Input",\

 CellChangeTimes->{{3.696859438826866*^9, 3.6968594585259*^9}, {
  3.796982107611528*^9, 3.796982162066684*^9}, {3.796982227365308*^9, 
  3.796982227579122*^9}, {3.797540097501031*^9, 
  3.797540105906042*^9}},ExpressionUUID->"bb7e70a7-e933-4d60-8e26-\
5874b6adbd4d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "cJ", " ", 
    SubsuperscriptBox["p", "1", "2"]}], ",", 
   RowBox[{"8", " ", "cJ", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"2", " ", "\[Gamma]1", " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.6968594504953814`*^9, 3.696859458774941*^9}, 
   3.696860928267994*^9, 3.696861475168703*^9, 3.696861506742793*^9, 
   3.6968615729683943`*^9, 3.6969325895238132`*^9, 3.744833042265123*^9, {
   3.796982109559013*^9, 3.796982162290544*^9}, 3.796982232816595*^9, {
   3.796982271599991*^9, 3.796982277752757*^9}, 3.796982600567075*^9, 
   3.797540024624928*^9, {3.7975400980310316`*^9, 3.7975401062210426`*^9}, 
   3.7984198054810553`*^9, 3.798686375052395*^9, 
   3.799037915808856*^9},ExpressionUUID->"e0071225-c4a3-4ebb-a15d-\
82f693a99b98"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"ecc1482a-5d5c-420e-9d20-\
a94c1a3017e3"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"8c829642-3d8b-4992-ae35-\
eb6d7a90dc43"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "4"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "i"}], "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "i"}], "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "i"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "i", ",", "j"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "j", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQzabqtWT1s9eOLm5ZYPp2fNcuEB1j8Q5Mi2yyeQqi
lxzyANNKujY5a4C0XfW6AhBtuOTNNBA9R2D7LLD44tnLQfRk5pLVIHqVcc8r
EG2R9+01iC75IvUHRP849ZNxLZBWCckrB9EZf/PqQTTv/mttIPpM+00w7XLs
zhEQncj39xSIXudv5bUOSLe9dwDTnLJ8KSA6Y8+sbBAdFZIrswFI+xleUQTR
bFd3G4Fo/dPvjEG0UvpKaxC94c8aMO21zcwFRHOcqvIE0f6Xl2SDaKZp6uUg
2vziHwdtrzeONf5BjiAaAOmfsTE=
  
  "],ExpressionUUID->"4f364dbc-7426-4304-bb98-b69e8bd3da30"],

Cell[BoxData[
 RowBox[{"-", "2"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448258234009595`*^9, 3.7448259321781816`*^9, 
   3.7448262014605837`*^9, 3.744826297784093*^9, 3.744833050466592*^9, 
   3.796982283044245*^9, 3.798419805503151*^9, 3.798686376574482*^9, 
   3.799037915831316*^9},ExpressionUUID->"41b19d9f-ae0c-4d68-a008-\
6311b5197078"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "1"}], "]"}], 
      SubsuperscriptBox["p", "1", "2"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2"}], "]"}], 
      SubsuperscriptBox["p", "2", "2"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "3"}], "]"}], 
      SubsuperscriptBox["p", "3", "2"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "0"}], "]"}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448258234009595`*^9, 3.7448259321781816`*^9, 
   3.7448262014605837`*^9, 3.744826297784093*^9, 3.744833050466592*^9, 
   3.796982283044245*^9, 3.798419805503151*^9, 3.798686376574482*^9, 
   3.799037915837221*^9},ExpressionUUID->"d114441d-30cc-4415-b2d1-\
0da5e7e6aa72"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"d9bd874d-0037-46fd-ac7c-\
1d13cd029477"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis1", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TJJ", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.744825621683422*^9, 3.744825667576047*^9}, {
   3.7448257092444305`*^9, 3.7448257097734604`*^9}, {3.744825937418481*^9, 
   3.744825937696497*^9}, 3.744826062704647*^9, 3.744826356535453*^9, 
   3.744826406038285*^9, {3.796982288227113*^9, 
   3.7969822894184093`*^9}},ExpressionUUID->"147aced9-fa61-4885-8305-\
a479bb0103fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "1"}], "]"}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "2"}], "]"}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "3"}], "]"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}]}]}], 
         SubsuperscriptBox["p", "3", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"3", ",", "1"}], "]"}]}]}], ")"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "3"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "0"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1"}], "]"}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "3"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"3", ",", "1"}], "]"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"c", "[", 
              RowBox[{"4", ",", "1", ",", "1"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"3", ",", "3"}], "]"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"c", "[", 
              RowBox[{"4", ",", "1", ",", "2"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"3", ",", "2"}], "]"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"c", "[", 
              RowBox[{"4", ",", "1", ",", "3"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "2"}], "]"}]}], 
        SubsuperscriptBox["p", "2", "2"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "2"}], "]"}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2"}], "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "[", 
            RowBox[{"1", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2", ",", "2"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3", ",", "3"}], "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "2"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "3"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubscriptBox["p", "2"], 
           SubscriptBox["p", "3"]], "]"}]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "1"}], "]"}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"1", ",", "2"}], "]"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "2"}], "]"}]}]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        FractionBox[
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "3"}], "]"}], 
         SubsuperscriptBox["p", "3", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "1"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "0"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1"}], "]"}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "2"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"3", ",", "3"}], "]"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"c", "[", 
              RowBox[{"4", ",", "1", ",", "3"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "4"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "4"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"c", "[", 
               RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"c", "[", 
               RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.7448257679317875`*^9, 3.7448259390115724`*^9, 
   3.7448260629036584`*^9, 3.7448263084147005`*^9, 3.744826406553314*^9, 
   3.7448330524937077`*^9, 3.796982302412747*^9, 3.798419815914054*^9, 
   3.798686396743622*^9, 
   3.799037933417767*^9},ExpressionUUID->"69c08f77-5675-45b5-938d-\
1946dad55f67"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448264236552925`*^9, 
  3.7448264546710663`*^9}},ExpressionUUID->"e137af1f-daf4-4c02-8096-\
177709390c32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826429491626*^9, 3.744826454993085*^9}, 
   3.7448330530437393`*^9, 3.79698230250526*^9, 3.798419815980392*^9, 
   3.798686396800625*^9, 
   3.79903793347852*^9},ExpressionUUID->"08a08832-47e6-42a1-8813-\
5b74603556e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], 
      SubsuperscriptBox["p", "3", "2"]], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "0"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1"}], "]"}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "3"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"3", ",", "3"}], "]"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"c", "[", 
              RowBox[{"4", ",", "1", ",", "2"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "2"}], "]"}]}], 
        SubsuperscriptBox["p", "2", "2"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], 
      SubsuperscriptBox["p", "3", "2"]], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2", ",", "2"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3", ",", "3"}], "]"}], "-", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubscriptBox["p", "2"], 
           SubscriptBox["p", "3"]], "]"}]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]]}], ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "0"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1"}], "]"}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "2"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"3", ",", "3"}], "]"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"c", "[", 
              RowBox[{"4", ",", "1", ",", "3"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "4"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "4"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"c", "[", 
               RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"c", "[", 
               RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826429491626*^9, 3.744826454993085*^9}, 
   3.7448330530437393`*^9, 3.79698230250526*^9, 3.798419815980392*^9, 
   3.798686396800625*^9, 
   3.79903793367553*^9},ExpressionUUID->"dfc35b7f-b722-4093-a3a9-\
f9987b979e94"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution2", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{"cwis2", "/.", "LocalPrimarySolution2"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.744826460959426*^9, 
  3.744826494751359*^9}},ExpressionUUID->"12e9927a-62c3-40ee-9d80-\
c4727c681c9e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.744826494932369*^9, 3.7448330537987823`*^9, 
  3.7969823027988358`*^9, 3.7984198161902323`*^9, 3.7986863970346384`*^9, 
  3.7990379336990213`*^9},ExpressionUUID->"115d70f3-7a1f-4db6-a91f-\
078b3207c6f1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "0"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1"}], "]"}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "3"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2", ",", "2"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3", ",", "3"}], "]"}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "4"]}], 
           SubsuperscriptBox["p", "2", "2"]]}], 
         SubsuperscriptBox["p", "3", "2"]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "0"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1"}], "]"}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "2"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}]}]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "1"}], "]"}]}], 
           SubsuperscriptBox["p", "1", "2"]]}], "+", 
         FractionBox[
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], 
          SubsuperscriptBox["p", "2", "2"]]}], ")"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744826494932369*^9, 3.7448330537987823`*^9, 
  3.7969823027988358`*^9, 3.7984198161902323`*^9, 3.7986863970346384`*^9, 
  3.7990379338403883`*^9},ExpressionUUID->"be8cd907-d333-4d33-9cd8-\
81a3f8d19e88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution3", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis4", "=", 
  RowBox[{
   RowBox[{"cwis3", "/.", "LocalPrimarySolution3"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.744826511335307*^9, 
  3.7448265551668143`*^9}},ExpressionUUID->"5ecb1190-87cb-4288-94b7-\
2204c111fe34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7448265555318356`*^9, 3.74483305498085*^9, {3.796982303016934*^9, 
   3.7969823083422937`*^9}, 3.798419816329281*^9, 3.7986863972126484`*^9, 
   3.799037933858852*^9},ExpressionUUID->"7e7494d4-2391-4aaa-bf5f-\
ea0f3b93698d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "0"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "3"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2", ",", "2"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3", ",", "3"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "0"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "2"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448265555318356`*^9, 3.74483305498085*^9, {3.796982303016934*^9, 
   3.7969823083422937`*^9}, 3.798419816329281*^9, 3.7986863972126484`*^9, 
   3.799037933863193*^9},ExpressionUUID->"df9d33c4-ff2c-407a-9e79-\
1fc26341f19e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LocalPrimarySolution4", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cwis4", "\[LeftDoubleBracket]", 
         RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], "\[Equal]", "0"}], 
       ",", 
       RowBox[{
        RowBox[{"cwis4", "\[LeftDoubleBracket]", 
         RowBox[{"-", "2"}], "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], ",", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}]}], "}"}]}], "]"}], 
   "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], "Input",
 CellChangeTimes->{{3.74482657099572*^9, 
  3.7448265971972184`*^9}},ExpressionUUID->"456877ab-9539-4d46-873d-\
4a4e76fefa51"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "0"}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "0"}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448265973422265`*^9, 3.7448330561399164`*^9, 
  3.7969823096139*^9, 3.79841981640339*^9, 3.7986863972676516`*^9, 
  3.799037933906705*^9},ExpressionUUID->"28a6192c-31d0-4561-803c-\
4b62b490be96"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{
   "LocalPrimarySolution1", ",", "LocalPrimarySolution2", ",", 
    "LocalPrimarySolution3", ",", "LocalPrimarySolution4"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cwis1", "/.", "LocalPrimarySolution"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.744826611003008*^9, 
  3.7448266584187202`*^9}},ExpressionUUID->"1e829b3b-1123-4566-a9aa-\
ee18a05015d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "0"}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "0"}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448330569109607`*^9, 3.7969823116053333`*^9, 3.798419816420714*^9, 
   3.798686397320655*^9, 
   3.799037933954092*^9},ExpressionUUID->"7cc8f4ca-66a4-4ac4-984c-\
aeb77fd89329"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448330569109607`*^9, 3.7969823116053333`*^9, 3.798419816420714*^9, 
   3.798686397320655*^9, 
   3.799037933958074*^9},ExpressionUUID->"dd519b49-ae4c-4a1c-967e-\
5cf4094d5e1d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "0"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "0"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "0"}], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "0"}], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448330569109607`*^9, 3.7969823116053333`*^9, 3.798419816420714*^9, 
   3.798686397320655*^9, 
   3.7990379339634457`*^9},ExpressionUUID->"cfa331ba-9a54-4d4d-b796-\
4b88559d4d4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TJJ", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TJJ", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.796982315050866*^9, 
  3.796982325770357*^9}},ExpressionUUID->"1abce8dd-3ce8-43c8-893b-\
61429c9cb511"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "-", 
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "0"}], "]"}]}], ")"}]}], ",", 
   RowBox[{"4", " ", 
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "0"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      SubsuperscriptBox["p", "3", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "1"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{"8", " ", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "2"}], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "-", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "0"}], "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      SubscriptBox["p", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{"8", " ", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "-", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "0"}], "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      SubscriptBox["p", "3"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.744826169179737*^9, {3.7448266424458065`*^9, 3.744826682356089*^9}, 
   3.744833077371131*^9, 3.796982326444159*^9, 3.798419816537486*^9, 
   3.7986863974216604`*^9, 
   3.799037934047173*^9},ExpressionUUID->"12d5771a-aaaa-485a-9270-\
8cf9bc52eb61"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cJ", "[", "0", "]"}], "+", 
       RowBox[{"cJ", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["p", "2", "2"], 
          SuperscriptBox["\[Mu]", "2"]], "]"}]}]}], ")"}], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "-", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cJ", "[", "0", "]"}], "+", 
       RowBox[{"cJ", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["p", "3", "2"], 
          SuperscriptBox["\[Mu]", "2"]], "]"}]}]}], ")"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}]}], ",", 
   RowBox[{"16", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c3", " ", "cJ", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["p", "2", "2"], 
         SuperscriptBox["\[Mu]", "2"]], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "c3"}], ")"}], " ", "cJ", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["p", "3", "2"], 
         SuperscriptBox["\[Mu]", "2"]], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{
       RowBox[{"cJ", "[", "0", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"c3", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.744826169179737*^9, {3.7448266424458065`*^9, 3.744826682356089*^9}, 
   3.744833077371131*^9, 3.796982326444159*^9, 3.798419816537486*^9, 
   3.7986863974216604`*^9, 
   3.799037934097526*^9},ExpressionUUID->"7487e2b7-0d92-4061-9f3e-\
42c0ef811c77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution4", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis5", "=", 
  RowBox[{
   RowBox[{"LocalSecs", "/.", "LocalPrimarySolution4"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448266891794796`*^9, 
  3.7448267345480747`*^9}},ExpressionUUID->"a36098e5-b634-407b-a92d-\
0be2bc7c6eba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826729627793*^9, 3.7448267348770933`*^9}, 
   3.796982328936522*^9, 3.7984198166031237`*^9, 3.798686397515666*^9, 
   3.799037934115245*^9},ExpressionUUID->"7f058251-196d-46d7-9532-\
e5614ec9228d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826729627793*^9, 3.7448267348770933`*^9}, 
   3.796982328936522*^9, 3.7984198166031237`*^9, 3.798686397515666*^9, 
   3.799037934140748*^9},ExpressionUUID->"0ba9a16a-2438-4987-a085-\
23a2670ccb77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution5", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis6", "=", 
  RowBox[{
   RowBox[{"cwis5", "/.", "LocalPrimarySolution5"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.744826743539589*^9, 
  3.744826767827978*^9}},ExpressionUUID->"48dce4a7-2a4d-4622-8608-\
2a34fe89520a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744826768180998*^9, 3.796982330479536*^9, 
  3.79841981666853*^9, 3.7986863975706687`*^9, 
  3.799037934163086*^9},ExpressionUUID->"91129cb7-aa62-41d0-b1d7-\
c393b90fe42c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.744826768180998*^9, 3.796982330479536*^9, 
  3.79841981666853*^9, 3.7986863975706687`*^9, 
  3.799037934167416*^9},ExpressionUUID->"010140ce-7104-4d5c-ba55-\
826b330c237b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FinalLocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution4", ",", "LocalPrimarySolution5", ",", 
    RowBox[{"LocalPrimarySolution", "/.", 
     RowBox[{"Union", "[", 
      RowBox[{"LocalPrimarySolution4", ",", "LocalPrimarySolution5"}], 
      "]"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "/.", "FinalLocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.744826772249231*^9, 3.7448268460924544`*^9}, {
  3.7448268870907993`*^9, 
  3.744826887545825*^9}},ExpressionUUID->"8fb5a744-7fcb-469c-a809-\
a1e5932e7bae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744826815491704*^9, 3.7448268464384737`*^9}, 
   3.7448268879008455`*^9, 3.7969823317757196`*^9, 3.79841981673796*^9, 
   3.798686397627672*^9, 
   3.799037934212041*^9},ExpressionUUID->"367ab4fa-991d-47d4-a24e-\
c793ad3af598"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826815491704*^9, 3.7448268464384737`*^9}, 
   3.7448268879008455`*^9, 3.7969823317757196`*^9, 3.79841981673796*^9, 
   3.798686397627672*^9, 
   3.7990379342155743`*^9},ExpressionUUID->"1de16f8f-94bc-47ce-b6ed-\
f741c69b52f9"]
}, Open  ]],

Cell["No solution.", "Text",
 CellChangeTimes->{{3.744825691873437*^9, 
  3.744825694136566*^9}},ExpressionUUID->"b84ddd68-79e4-4c14-aa3c-\
59ae86f1ba41"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["<TTT>", "Section",
 CellChangeTimes->{{3.696662757712263*^9, 3.696662759359742*^9}, {
  3.696682859217309*^9, 3.696682859569441*^9}, {3.696686788827385*^9, 
  3.696686789194077*^9}, {3.696690487457403*^9, 3.696690487825531*^9}, {
  3.696693989613895*^9, 
  3.6966939902328978`*^9}},ExpressionUUID->"2ef28e9a-f480-4c1a-bda2-\
f6339bb0c2fd"],

Cell[CellGroupData[{

Cell["d=3", "Subsection",
 CellChangeTimes->{{3.696663690437581*^9, 3.6966636937738028`*^9}, 
   3.6966888362755013`*^9},ExpressionUUID->"f75bb685-9bce-49a9-b8ab-\
0f907f56d99e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"8", " ", 
       RowBox[{"a", "/", 
        RowBox[{"a123", "^", "6"}]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a123", "^", "3"}], "+", 
         RowBox[{"3", "a123", " ", "b123"}], "+", 
         RowBox[{"15", " ", "c123"}]}], ")"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"8", 
        RowBox[{"a", "/", 
         RowBox[{"a123", "^", "5"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], "+", 
          RowBox[{"20", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "3"}], " ", "a12"}], "+", 
          RowBox[{"4", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", 
              RowBox[{"a12", "^", "2"}]}], "+", 
             RowBox[{"6", "b12"}]}], ")"}]}], "+", 
          RowBox[{"15", 
           RowBox[{"p", "[", "3", "]"}], "a12", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a12", "^", "2"}], "+", "b12"}], ")"}]}], "+", 
          RowBox[{"3", 
           RowBox[{"a12", "^", "2"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a12", "^", "2"}], "+", "b12"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"b", "/", 
         RowBox[{"a123", "^", "4"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a123", "^", "3"}], "+", 
          RowBox[{"a123", " ", "b123"}], "+", 
          RowBox[{"3", "c123"}]}], ")"}]}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"2", "a", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
         RowBox[{"a123", "^", "4"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], "+", 
          RowBox[{"28", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], "a12"}], "+", 
          RowBox[{"3", 
           RowBox[{"p", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"11", 
              RowBox[{"a12", "^", "2"}]}], "+", 
             RowBox[{"6", "b12"}]}], ")"}]}], "+", 
          RowBox[{"12", "a12", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a12", "^", "2"}], "+", "b12"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"b", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
         RowBox[{"a123", "^", "3"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "+", 
          RowBox[{"3", 
           RowBox[{"p", "[", "3", "]"}], "a12"}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a12", "^", "2"}], "+", "b12"}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"2", 
        RowBox[{"cT", "/", 
         RowBox[{"a123", "^", "2"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a123", "^", "3"}], "-", 
          RowBox[{"a123", " ", "b123"}], "-", "c123"}], ")"}]}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"4", 
        RowBox[{"a", "/", 
         RowBox[{"a123", "^", "4"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "5"}]}], "-", 
          RowBox[{"12", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "4"}], "a12"}], "-", 
          RowBox[{"9", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "3"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a12", "^", "2"}], "+", 
             RowBox[{"2", "b12"}]}], ")"}]}], "+", 
          RowBox[{"9", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], "a12", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a12", "^", "2"}], "-", 
             RowBox[{"3", "b12"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", 
              RowBox[{"p", "[", "3", "]"}]}], "+", "a12"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", 
              RowBox[{"a12", "^", "4"}]}], "-", 
             RowBox[{"3", 
              RowBox[{"a12", "^", "2"}], "b12"}], "+", 
             RowBox[{"4", 
              RowBox[{"b12", "^", "2"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"b", "/", 
         RowBox[{"a123", "^", "3"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], "-", 
          RowBox[{"3", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "3"}], "a12"}], "-", 
          RowBox[{"6", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}], "b12"}], "+", 
          RowBox[{"a12", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a12", "^", "2"}], "-", "b12"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", 
              RowBox[{"p", "[", "3", "]"}]}], "+", "a12"}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{"4", 
        RowBox[{"cT", "/", 
         RowBox[{"a123", "^", "2"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a123", "^", "3"}], "-", 
          RowBox[{"a123", " ", "b123"}], "-", "c123"}], ")"}]}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"2", 
        RowBox[{"a", "/", 
         RowBox[{"a123", "^", "3"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], 
           RowBox[{"a123", "^", "6"}]}], "+", 
          RowBox[{"9", 
           RowBox[{"a123", "^", "4"}], " ", "b123"}], "+", 
          RowBox[{"12", 
           RowBox[{"a123", "^", "2"}], " ", 
           RowBox[{"b123", "^", "2"}]}], "-", 
          RowBox[{"33", " ", 
           RowBox[{"a123", "^", "3"}], " ", "c123"}], "+", 
          RowBox[{"12", " ", "a123", " ", "b123", " ", "c123"}], " ", "+", 
          RowBox[{"8", " ", 
           RowBox[{"c123", "^", "2"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"b", "/", 
         RowBox[{"(", 
          RowBox[{"2", 
           RowBox[{"a123", "^", "2"}]}], ")"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"a123", "^", "5"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"a123", "^", "3"}], " ", "b123"}], "+", 
          RowBox[{"4", " ", "a123", " ", 
           RowBox[{"b123", "^", "2"}]}], "-", 
          RowBox[{"11", " ", 
           RowBox[{"a123", "^", "2"}], " ", "c123"}], "+", 
          RowBox[{"4", " ", "b123", " ", "c123"}]}], ")"}]}], "+", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"4", "\[Gamma]"}]}], ")"}], "cT", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "3"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "3"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], ")"}]}]}]}]}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
   3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
   3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
   3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
   3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
   3.696684013724811*^9, 3.696684064967544*^9}, {3.696688839660561*^9, 
   3.696688862140767*^9}, {3.696688902834281*^9, 3.696688922139936*^9}, {
   3.6966893311366453`*^9, 3.69668933408633*^9}, {3.696690238543086*^9, 
   3.696690238880156*^9}, {3.696690288573051*^9, 3.696690288741581*^9}, {
   3.6966924967498302`*^9, 3.6966925965674343`*^9}, 3.696692744549728*^9, {
   3.696692801152857*^9, 3.696692818171936*^9}, {3.696692875211596*^9, 
   3.696692875556382*^9}, {3.696694347655616*^9, 3.696694357595643*^9}, {
   3.69669444117598*^9, 3.696694757447371*^9}, 3.696694824747635*^9, {
   3.696694875035569*^9, 3.696694875532051*^9}, {3.744832054940651*^9, 
   3.7448320610089984`*^9}},ExpressionUUID->"753d4803-223c-4534-b553-\
a896f7e265f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677607964088*^9, 
  3.6966776258540688`*^9}},ExpressionUUID->"7c6685bf-b55e-43be-bdf7-\
b2f96c85def6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.696677627230453*^9, 3.6966776623071833`*^9, 3.696678324117044*^9, 
   3.696679200338336*^9, {3.696684066743404*^9, 3.6966840824275312`*^9}, 
   3.69668892366024*^9, 3.696689334936253*^9, 3.696689963534178*^9, 
   3.696690289670549*^9, 3.696692600831484*^9, 3.696692746038089*^9, {
   3.696692802888487*^9, 3.696692819140151*^9}, 3.696692877323474*^9, 
   3.6966947394609118`*^9, 3.6967015062314215`*^9, 3.696703822338073*^9, 
   3.6969190748375673`*^9, 3.7448269076449747`*^9, 3.7448316545397496`*^9, 
   3.7448319034589868`*^9, 3.796982342319202*^9, 3.796982614963581*^9, 
   3.798419816830872*^9, 3.798420333008739*^9, 3.798686408767302*^9, 
   3.799037934291889*^9},ExpressionUUID->"e5d4b631-22ea-465d-968d-\
28b3eda1894a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TTT", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.79698234460644*^9, 
  3.796982345627297*^9}},ExpressionUUID->"3c3b405a-6dfa-4827-8d81-\
d35865754ebe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, {3.696684068482006*^9, 
   3.696684082890736*^9}, 3.696688925859529*^9, 3.696689335378479*^9, 
   3.696689964009571*^9, 3.69669029008694*^9, 3.696692604822192*^9, {
   3.6966927468247137`*^9, 3.696692838124413*^9}, {3.696692877837805*^9, 
   3.69669288591216*^9}, {3.696694742127984*^9, 3.6966947610567493`*^9}, 
   3.696694827826784*^9, 3.696694879294722*^9, {3.6967015064414215`*^9, 
   3.6967015089844265`*^9}, 3.696703823039113*^9, 3.696919076148986*^9, 
   3.744826909009053*^9, 3.744831905251089*^9, {3.744832051524456*^9, 
   3.744832057518799*^9}, {3.796982347233575*^9, 3.79698236281812*^9}, 
   3.796982616066019*^9, 3.798419817404964*^9, 3.798420334196607*^9, 
   3.798686409924367*^9, 
   3.799037934863791*^9},ExpressionUUID->"f6905a37-4a5b-4167-8e7b-\
4f5cb0923bc7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TTT", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTT", ",", "Dims", ",", 
    RowBox[{"dTdgDerivative", "\[Rule]", "\[Gamma]"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", "%%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
   3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
   3.6966772912178926`*^9}, {3.696684086068306*^9, 3.6966840888764772`*^9}, {
   3.6966902221590433`*^9, 3.696690304039969*^9}, {3.6966928953364277`*^9, 
   3.696692914743807*^9}, {3.696692999505937*^9, 3.696693008918251*^9}, {
   3.6969190955387077`*^9, 3.696919103122005*^9}, 3.7448321049595118`*^9, {
   3.7969823703872147`*^9, 3.796982403731395*^9}, {3.79698262190245*^9, 
   3.796982628443602*^9}},ExpressionUUID->"2ed611d9-f6a8-461e-81c2-\
b33b395eb0cd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"24", " ", "cT", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "\[Gamma]"}]}], ")"}], " ", 
       SubsuperscriptBox["p", "2", "3"]}], "+", 
      RowBox[{"2", " ", "\[Gamma]", " ", 
       SubsuperscriptBox["p", "3", "3"]}]}], ")"}]}], ",", 
   RowBox[{"6", " ", "cT", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "2", "3"], "-", 
      SubsuperscriptBox["p", "3", "3"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.696694885907452*^9, 3.696701509879428*^9, 
   3.6967038241491766`*^9, {3.6969190772425823`*^9, 3.696919103339509*^9}, {
   3.744831808602562*^9, 3.7448318238154316`*^9}, 3.7448319063471518`*^9, 
   3.744832063345132*^9, 3.7448321062855883`*^9, 3.79698240432228*^9, 
   3.796982629075903*^9, 3.79841981777577*^9, 3.798420335528427*^9, 
   3.7986864110334277`*^9, 
   3.799037935225296*^9},ExpressionUUID->"aef6f859-e73b-4bed-935f-\
31d503682688"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"24", " ", "cT", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "\[Gamma]"}]}], ")"}], " ", 
    SubsuperscriptBox["p", "2", "3"]}], ",", 
   RowBox[{"6", " ", "cT", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "2", "3"], "-", 
      SubsuperscriptBox["p", "3", "3"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.696694885907452*^9, 3.696701509879428*^9, 
   3.6967038241491766`*^9, {3.6969190772425823`*^9, 3.696919103339509*^9}, {
   3.744831808602562*^9, 3.7448318238154316`*^9}, 3.7448319063471518`*^9, 
   3.744832063345132*^9, 3.7448321062855883`*^9, 3.79698240432228*^9, 
   3.796982629075903*^9, 3.79841981777577*^9, 3.798420335528427*^9, 
   3.7986864110334277`*^9, 
   3.7990379353224487`*^9},ExpressionUUID->"5e67881f-6040-4111-91af-\
78b5bce5944a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "48"}], " ", "cT", " ", "\[Gamma]", " ", 
    SubsuperscriptBox["p", "3", "3"]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.696694885907452*^9, 3.696701509879428*^9, 
   3.6967038241491766`*^9, {3.6969190772425823`*^9, 3.696919103339509*^9}, {
   3.744831808602562*^9, 3.7448318238154316`*^9}, 3.7448319063471518`*^9, 
   3.744832063345132*^9, 3.7448321062855883`*^9, 3.79698240432228*^9, 
   3.796982629075903*^9, 3.79841981777577*^9, 3.798420335528427*^9, 
   3.7986864110334277`*^9, 
   3.799037935326579*^9},ExpressionUUID->"0596968e-f868-4c23-873a-\
0e4361fb9d36"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"f3a3a50d-f8fb-4012-8257-\
114bd4a9ce0d"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"a322f93a-c43d-477f-8e24-\
c54d55ed1043"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "6"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"-", "3"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"+", "1"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"+", "1"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "i"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"+", "3"}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQzabqtWT1s9eOLm5ZYPp2fNcuEB1j8Q5Mi2yyeQqi
lxzyANNKujY5a4C0XfW6AhBtuOTNNBA9R2D7LLD44tnLQfRk5pLVIHqVcc8r
EG2R9+01iC75IvUHRP849ZNxLZBWCckrB9EZf/PqQTTv/mttIPpM+00w7XLs
zhEQncj39xSIXudv5bUOSLe9dwDTnLJ8KSA6Y8+sbBAdFZIrswFI+xleUQTR
bFd3G4Fo/dPvjEG0UvpKaxC94c8aMO21zcwFRHOcqvIE0f6Xl2SDaKZp6uVg
cyzuHwHR11mLz4NosUNTCrW93jiq7VwLpgF7J7s1
  
  "],ExpressionUUID->"de58da20-72c6-481d-a686-0c0fad1edb05"],

Cell[BoxData[
 RowBox[{"-", "3"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448258234009595`*^9, 3.7448259321781816`*^9, 
   3.7448262014605837`*^9, 3.744826297784093*^9, 3.744826919532655*^9, 
   3.7448270079787135`*^9, 3.74483167710004*^9, {3.796982664160212*^9, 
   3.796982670084072*^9}, 3.798419817896315*^9, 3.798686412761527*^9, 
   3.799037935348797*^9},ExpressionUUID->"2c0734cd-a1a9-4c7e-921f-\
072deea64a6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "1"}], "]"}], 
      SubsuperscriptBox["p", "1", "3"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2"}], "]"}], 
      SubsuperscriptBox["p", "2", "3"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "3"}], "]"}], 
      SubsuperscriptBox["p", "3", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "1"}], "]"}], 
      SubscriptBox["p", "1"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "2"}], "]"}], 
      SubscriptBox["p", "2"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "3"}], "]"}], 
      SubscriptBox["p", "3"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      SubscriptBox["p", "1"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      SubscriptBox["p", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      SubscriptBox["p", "3"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      SubscriptBox["p", "1"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      SubscriptBox["p", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      SubscriptBox["p", "3"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "3"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "3"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "3"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448258234009595`*^9, 3.7448259321781816`*^9, 
   3.7448262014605837`*^9, 3.744826297784093*^9, 3.744826919532655*^9, 
   3.7448270079787135`*^9, 3.74483167710004*^9, {3.796982664160212*^9, 
   3.796982670084072*^9}, 3.798419817896315*^9, 3.798686412761527*^9, 
   3.799037935352847*^9},ExpressionUUID->"d1851fdb-ec46-41aa-9b45-\
093314c96a82"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"0c27fdc8-d1ae-476a-87fa-\
558269998c50"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis1", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TTT", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.744825621683422*^9, 3.744825667576047*^9}, {
   3.7448257092444305`*^9, 3.7448257097734604`*^9}, {3.744825937418481*^9, 
   3.744825937696497*^9}, 3.744826062704647*^9, 3.744826356535453*^9, 
   3.744826406038285*^9, {3.79698267647138*^9, 
   3.7969826781789217`*^9}},ExpressionUUID->"0028fc13-f3ca-47a7-87f9-\
8eee41661932"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "1"}], "]"}]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}]}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"1", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "3"}], "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "1"}], "]"}]}], ")"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], 
       SubscriptBox["p", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "3"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}]}], 
       SubscriptBox["p", "1"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "2"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "1"], "-", 
        SubscriptBox["p", "3"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]], "-", 
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "5"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "3"]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "2"}], "]"}]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "2"}], "]"}]}]}], 
       SubsuperscriptBox["p", "2", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"1", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "3"}], "]"}]}], ")"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "2"}], "]"}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "1"]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "2"}], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}]}]}], 
       SubscriptBox["p", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "2"], "-", 
        SubscriptBox["p", "3"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "5"]], "-", 
      FractionBox[
       RowBox[{"18", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "5"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "3"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}]}], 
       SubscriptBox["p", "2"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"c", "[", 
             RowBox[{"2", ",", "1"}], "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"2", ",", "3"}], "]"}]}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1"}], "]"}]}], ")"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "2"}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "2"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["p", "1"], "-", 
           SubscriptBox["p", "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["p", "2"], "-", 
           SubscriptBox["p", "3"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["p", "1"]}], "+", 
           SubscriptBox["p", "3"]}], ")"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.7448257679317875`*^9, 3.7448259390115724`*^9, 
   3.7448260629036584`*^9, 3.7448263084147005`*^9, 3.744826406553314*^9, 
   3.744827011983943*^9, 3.744831682360341*^9, {3.7969826717078867`*^9, 
   3.796982681382923*^9}, 3.79841982039259*^9, 3.798686417295786*^9, 
   3.799037938423843*^9},ExpressionUUID->"97e5eff7-990c-4360-8c12-\
2beaa6f9b1d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448264236552925`*^9, 3.7448264546710663`*^9}, {
  3.7448270456038656`*^9, 
  3.7448270529792876`*^9}},ExpressionUUID->"e785b43a-84ee-455c-812d-\
5c76509b19f9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826429491626*^9, 3.744826454993085*^9}, 
   3.7448270545043745`*^9, 3.744831686928602*^9, 3.7969826832345467`*^9, 
   3.7984198204785967`*^9, 3.7986864173387885`*^9, 
   3.799037938494906*^9},ExpressionUUID->"56e5fad3-936e-430b-a5c1-\
8d369c3bdc25"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "3"}], "]"}], "-", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "1"], "-", 
        SubscriptBox["p", "3"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2"}], "]"}]}], 
        SubscriptBox["p", "2"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "1"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}]}], 
       SubscriptBox["p", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "2"], "-", 
        SubscriptBox["p", "3"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}]}], 
       SubscriptBox["p", "2"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"2", ",", "3"}], "]"}]}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1"}], "]"}]}], ")"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}]}], "+", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2"}], "]"}]}], ")"}]}], 
       SubscriptBox["p", "2"]]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["p", "1"], "-", 
           SubscriptBox["p", "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["p", "2"], "-", 
           SubscriptBox["p", "3"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["p", "1"]}], "+", 
           SubscriptBox["p", "3"]}], ")"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744826429491626*^9, 3.744826454993085*^9}, 
   3.7448270545043745`*^9, 3.744831686928602*^9, 3.7969826832345467`*^9, 
   3.7984198204785967`*^9, 3.7986864173387885`*^9, 
   3.79903793855267*^9},ExpressionUUID->"41517269-61ad-40e5-b4cd-\
d47f40ff7330"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution2", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{"cwis2", "/.", "LocalPrimarySolution2"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.744826460959426*^9, 3.744826494751359*^9}, {
  3.744827061043749*^9, 
  3.7448270750265484`*^9}},ExpressionUUID->"072e9167-b307-4ade-b739-\
a298aa6dd705"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.744826494932369*^9, 3.7448270759976044`*^9, 
  3.74483168881071*^9, 3.796982684571734*^9, 3.798419820559313*^9, 
  3.7986864174427943`*^9, 
  3.799037938574615*^9},ExpressionUUID->"2335aa6b-0b2f-459c-af02-\
694eca90fb49"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "1"], "-", 
        SubscriptBox["p", "3"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}]}], 
        SubscriptBox["p", "2"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], 
       SubscriptBox["p", "3"]]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "2"], "-", 
        SubscriptBox["p", "3"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}], 
        SubscriptBox["p", "1"]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}]}], 
       SubscriptBox["p", "2"]]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["p", "1"], "-", 
           SubscriptBox["p", "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["p", "2"], "-", 
           SubscriptBox["p", "3"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["p", "1"]}], "+", 
           SubscriptBox["p", "3"]}], ")"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.744826494932369*^9, 3.7448270759976044`*^9, 
  3.74483168881071*^9, 3.796982684571734*^9, 3.798419820559313*^9, 
  3.7986864174427943`*^9, 
  3.799037938600568*^9},ExpressionUUID->"aded598e-f679-4d55-8826-\
3d96ba1a1ea4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution3", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis4", "=", 
  RowBox[{
   RowBox[{"cwis3", "/.", "LocalPrimarySolution3"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.744826511335307*^9, 3.7448265551668143`*^9}, {
  3.7448270796898155`*^9, 
  3.744827088594325*^9}},ExpressionUUID->"0211ca23-f59e-40da-b9c5-\
b2af112a4b2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7448265555318356`*^9, 3.7448270906384416`*^9, 
  3.744831690325796*^9, 3.79698268561439*^9, 3.7984198207138166`*^9, 
  3.798686417499798*^9, 
  3.7990379386195707`*^9},ExpressionUUID->"8a0e44e9-b497-4097-8633-\
dc23e7916fd5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7448265555318356`*^9, 3.7448270906384416`*^9, 
  3.744831690325796*^9, 3.79698268561439*^9, 3.7984198207138166`*^9, 
  3.798686417499798*^9, 
  3.799037938623455*^9},ExpressionUUID->"bed7df99-558b-42d0-9c9b-\
44b02bfd45e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{
   "LocalPrimarySolution1", ",", "LocalPrimarySolution2", ",", 
    "LocalPrimarySolution3"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cwis1", "/.", "LocalPrimarySolution"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.744826611003008*^9, 3.7448266584187202`*^9}, {
  3.744827105906315*^9, 
  3.744827106129328*^9}},ExpressionUUID->"02a032bb-216f-42a2-a75e-\
828ca128baf9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448271073373966`*^9, 3.7448316921929035`*^9, 3.7969826869483356`*^9, 
   3.7984198207938843`*^9, 3.7986864176278048`*^9, 
   3.799037938665152*^9},ExpressionUUID->"2c521b7f-5ab4-4253-a2e1-\
aaccd1d97dc4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448271073373966`*^9, 3.7448316921929035`*^9, 3.7969826869483356`*^9, 
   3.7984198207938843`*^9, 3.7986864176278048`*^9, 
   3.7990379386687107`*^9},ExpressionUUID->"1eab934c-ea9d-4c28-b338-\
020a117d8e18"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "3"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "3"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "3"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448271073373966`*^9, 3.7448316921929035`*^9, 3.7969826869483356`*^9, 
   3.7984198207938843`*^9, 3.7986864176278048`*^9, 
   3.799037938672965*^9},ExpressionUUID->"c75feb1d-53ec-4663-9c4e-\
a59dbbae7af0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecs", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTT", "]"}], ",", 
     RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTT", ",", "Dims", ",", 
    RowBox[{"dTdgDerivative", "\[Rule]", "\[Gamma]"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{
  3.7448317502412233`*^9, {3.796982690627736*^9, 
   3.7969827063543663`*^9}},ExpressionUUID->"ae89cfca-acd1-4050-a3df-\
4e14990349fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "3"]}], "+", 
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "3"]}]}], ")"}]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.744826169179737*^9, {3.7448266424458065`*^9, 3.744826682356089*^9}, 
   3.7448271152728505`*^9, 3.74483169475805*^9, {3.7448317519823227`*^9, 
   3.7448317722004795`*^9}, 3.796982709173258*^9, 3.798419820869783*^9, 
   3.7986864186148615`*^9, 
   3.799037938713347*^9},ExpressionUUID->"b3e8d43c-b444-4cad-913e-\
8c2e7d6b2596"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"24", " ", "cT", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "\[Gamma]"}]}], ")"}], " ", 
    SubsuperscriptBox["p", "2", "3"]}], ",", 
   RowBox[{"6", " ", "cT", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "2", "3"], "-", 
      SubsuperscriptBox["p", "3", "3"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.744826169179737*^9, {3.7448266424458065`*^9, 3.744826682356089*^9}, 
   3.7448271152728505`*^9, 3.74483169475805*^9, {3.7448317519823227`*^9, 
   3.7448317722004795`*^9}, 3.796982709173258*^9, 3.798419820869783*^9, 
   3.7986864186148615`*^9, 
   3.799037938807589*^9},ExpressionUUID->"147d7747-ad16-4c41-b646-\
e608c2f16a17"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution4", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "3"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"FinalLocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution4", ",", "LocalPrimarySolution"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "/.", "FinalLocalPrimarySolution"}]}], "Input",
 CellChangeTimes->{{3.7448266891794796`*^9, 3.7448267345480747`*^9}, {
  3.744827198240596*^9, 
  3.7448272289693537`*^9}},ExpressionUUID->"cf765e0b-400d-47f5-9061-\
f50bbc3db957"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826729627793*^9, 3.7448267348770933`*^9}, {
   3.744827220652878*^9, 3.7448272293673763`*^9}, 3.7969827110607443`*^9, 
   3.798419820987219*^9, 3.798686419649919*^9, 
   3.799037938834044*^9},ExpressionUUID->"f0230747-b42c-4880-9023-\
a475e7c766ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826729627793*^9, 3.7448267348770933`*^9}, {
   3.744827220652878*^9, 3.7448272293673763`*^9}, 3.7969827110607443`*^9, 
   3.798419820987219*^9, 3.798686419649919*^9, 
   3.7990379388382072`*^9},ExpressionUUID->"56f90566-0da6-4c2c-9a3d-\
6a7f4b6aa38a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "1"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "3"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826729627793*^9, 3.7448267348770933`*^9}, {
   3.744827220652878*^9, 3.7448272293673763`*^9}, 3.7969827110607443`*^9, 
   3.798419820987219*^9, 3.798686419649919*^9, 
   3.7990379388414516`*^9},ExpressionUUID->"e16ddf75-7753-4638-8750-\
628d15584772"]
}, Open  ]],

Cell["\<\
No symmetric solution. Let\[CloseCurlyQuote]s check the asymmetric one: A[j] \
= 0 for j=1,2,3,4 and A[5] = c[5,1] p[1]^3.\
\>", "Text",
 CellChangeTimes->{{3.744825691873437*^9, 3.744825694136566*^9}, {
   3.744827261797231*^9, 3.7448272927890043`*^9}, 
   3.79698274381269*^9},ExpressionUUID->"407731f0-79be-4729-a050-\
9e86c3a22756"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"A", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"A", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"A", "[", "4", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1"}], "]"}], 
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], "^", "3"}]}], "+", 
       RowBox[{"cc", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "3"}], "+", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "3"}]}], ")"}]}]}]}]}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{"d", "\[Rule]", "3"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696663706557436*^9, 3.696663726810328*^9}, {
   3.696663830924735*^9, 3.696663832106821*^9}, {3.696663897134307*^9, 
   3.696663912713964*^9}, {3.696663990704321*^9, 3.6966639947644863`*^9}, {
   3.69667626115385*^9, 3.696676261625379*^9}, {3.696676336850709*^9, 
   3.69667633799463*^9}, {3.696676373547495*^9, 3.696676380531411*^9}, {
   3.696684013724811*^9, 3.696684064967544*^9}, {3.696688839660561*^9, 
   3.696688862140767*^9}, {3.696688902834281*^9, 3.696688922139936*^9}, {
   3.6966893311366453`*^9, 3.69668933408633*^9}, {3.696690238543086*^9, 
   3.696690238880156*^9}, {3.696690288573051*^9, 3.696690288741581*^9}, {
   3.6966924967498302`*^9, 3.6966925965674343`*^9}, 3.696692744549728*^9, {
   3.696692801152857*^9, 3.696692818171936*^9}, {3.696692875211596*^9, 
   3.696692875556382*^9}, {3.696694347655616*^9, 3.696694357595643*^9}, {
   3.69669444117598*^9, 3.696694757447371*^9}, 3.696694824747635*^9, {
   3.696694875035569*^9, 3.696694875532051*^9}, {3.744827298627338*^9, 
   3.74482733031115*^9}, {3.7969827612078533`*^9, 
   3.79698276581214*^9}},ExpressionUUID->"753d4803-223c-4534-b553-\
a896f7e265f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677607964088*^9, 
  3.6966776258540688`*^9}},ExpressionUUID->"7c6685bf-b55e-43be-bdf7-\
b2f96c85def6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.696677627230453*^9, 3.6966776623071833`*^9, 3.696678324117044*^9, 
   3.696679200338336*^9, {3.696684066743404*^9, 3.6966840824275312`*^9}, 
   3.69668892366024*^9, 3.696689334936253*^9, 3.696689963534178*^9, 
   3.696690289670549*^9, 3.696692600831484*^9, 3.696692746038089*^9, {
   3.696692802888487*^9, 3.696692819140151*^9}, 3.696692877323474*^9, 
   3.6966947394609118`*^9, 3.6967015062314215`*^9, 3.696703822338073*^9, 
   3.6969190748375673`*^9, 3.7448269076449747`*^9, 3.7448273333093214`*^9, 
   3.79698271450849*^9, 3.7969827670855083`*^9, 3.7984198210800323`*^9, 
   3.798686422034054*^9, 
   3.799037938902689*^9},ExpressionUUID->"3b1342ce-6e6b-4fb7-8a61-\
76bc40e46f78"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TTT", "]"}], ",", "As", ",", "Dims"}], "]"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796982716955476*^9, 
  3.7969827178354273`*^9}},ExpressionUUID->"3c3b405a-6dfa-4827-8d81-\
d35865754ebe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, {3.696684068482006*^9, 
   3.696684082890736*^9}, 3.696688925859529*^9, 3.696689335378479*^9, 
   3.696689964009571*^9, 3.69669029008694*^9, 3.696692604822192*^9, {
   3.6966927468247137`*^9, 3.696692838124413*^9}, {3.696692877837805*^9, 
   3.69669288591216*^9}, {3.696694742127984*^9, 3.6966947610567493`*^9}, 
   3.696694827826784*^9, 3.696694879294722*^9, {3.6967015064414215`*^9, 
   3.6967015089844265`*^9}, 3.696703823039113*^9, 3.696919076148986*^9, 
   3.744826909009053*^9, 3.744827334417385*^9, 3.7969827181807537`*^9, 
   3.796982767730123*^9, 3.79841982113684*^9, 3.7986864227480946`*^9, 
   3.799037938943377*^9},ExpressionUUID->"3e647bc4-2738-443d-87ad-\
e7ac98ce1f0c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TTT", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTT", ",", "Dims", ",", 
    RowBox[{"dTdgDerivative", "\[Rule]", "\[Gamma]"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696684086068306*^9, 3.6966840888764772`*^9}, {
  3.6966902221590433`*^9, 3.696690304039969*^9}, {3.6966928953364277`*^9, 
  3.696692914743807*^9}, {3.696692999505937*^9, 3.696693008918251*^9}, {
  3.6969190955387077`*^9, 3.696919103122005*^9}, {3.744827343805922*^9, 
  3.744827344030935*^9}, {3.79698272116356*^9, 
  3.796982731679303*^9}},ExpressionUUID->"2ed611d9-f6a8-461e-81c2-\
b33b395eb0cd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"6", " ", "cc", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "2", "3"], "+", 
      SubsuperscriptBox["p", "3", "3"]}], ")"}]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.696694885907452*^9, 3.696701509879428*^9, 
   3.6967038241491766`*^9, {3.6969190772425823`*^9, 3.696919103339509*^9}, {
   3.744827336112482*^9, 3.744827344542964*^9}, 3.796982732779911*^9, 
   3.7969827685750723`*^9, 3.798419821185217*^9, 3.7986864232801247`*^9, 
   3.799037938964767*^9},ExpressionUUID->"4520c067-b005-448e-ad04-\
769147c59795"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"24", " ", "cT", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "\[Gamma]"}]}], ")"}], " ", 
    SubsuperscriptBox["p", "2", "3"]}], ",", 
   RowBox[{"6", " ", "cT", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "2", "3"], "-", 
      SubsuperscriptBox["p", "3", "3"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.696694885907452*^9, 3.696701509879428*^9, 
   3.6967038241491766`*^9, {3.6969190772425823`*^9, 3.696919103339509*^9}, {
   3.744827336112482*^9, 3.744827344542964*^9}, 3.796982732779911*^9, 
   3.7969827685750723`*^9, 3.798419821185217*^9, 3.7986864232801247`*^9, 
   3.7990379390633707`*^9},ExpressionUUID->"e7c4ed6a-d4c3-461e-af96-\
5ea09e1c9bcc"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["d=4", "Subsection",
 CellChangeTimes->{{3.696677702174165*^9, 3.69667770458226*^9}, 
   3.696690321058776*^9},ExpressionUUID->"658f867a-63d8-4057-9eb9-\
92cc7a4c57a6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i7222", "=", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"MRed", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "[", 
     RowBox[{
      RowBox[{"MRed", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "[", 
      RowBox[{
       RowBox[{"MRed", "[", 
        RowBox[{"3", ",", "1"}], "]"}], "[", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], 
        RowBox[{"p", "[", "2", "]"}], 
        RowBox[{"p", "[", "3", "]"}], " ", 
        RowBox[{"D", "[", 
         RowBox[{"i1000", ",", 
          RowBox[{"p", "[", "1", "]"}], ",", 
          RowBox[{"p", "[", "2", "]"}], ",", 
          RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "]"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i5222fin", "=", 
   RowBox[{
    RowBox[{"MRed", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "[", 
    RowBox[{
     RowBox[{"MRed", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", 
     RowBox[{
      RowBox[{"MRed", "[", 
       RowBox[{"3", ",", "1"}], "]"}], "[", "i2111fin", "]"}], "]"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i3222fin", "=", 
   RowBox[{
    RowBox[{"MRed", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "[", 
    RowBox[{
     RowBox[{"MRed", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", 
     RowBox[{
      RowBox[{"MRed", "[", 
       RowBox[{"3", ",", "1"}], "]"}], "[", 
      RowBox[{
       RowBox[{"1", "/", "4"}], " ", "J2", " ", "i1000"}], "]"}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i1222fin", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
      RowBox[{
       RowBox[{"J2", "/", "4"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}]}], ")"}], 
    "i1000"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696694912757983*^9, 3.696694990500902*^9}, {
  3.6966953354556513`*^9, 
  3.6966953541512747`*^9}},ExpressionUUID->"2e66c63a-7faa-44ec-9725-\
4130ee784fdf"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"i7222", "-", 
       RowBox[{"i", "[", 
        RowBox[{"7", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], "]"}]}], "//", 
      RowBox[{
       RowBox[{"KEvaluate", "[", 
        RowBox[{"#", ",", 
         RowBox[{"ExpansionLevel", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}],
      ",", 
     RowBox[{"NL", "[", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], ",", 
       RowBox[{"p", "[", "2", "]"}], ",", 
       RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "]"}], "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"i5222fin", "-", 
       RowBox[{"i", "[", 
        RowBox[{"5", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], "]"}]}], "//", 
      RowBox[{
       RowBox[{"KEvaluate", "[", 
        RowBox[{"#", ",", 
         RowBox[{"ExpansionLevel", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}],
      ",", 
     RowBox[{"NL", "[", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], ",", 
       RowBox[{"p", "[", "2", "]"}], ",", 
       RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "]"}], "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"i3222fin", "-", 
       RowBox[{"i", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], "]"}]}], "//", 
      RowBox[{
       RowBox[{"KEvaluate", "[", 
        RowBox[{"#", ",", 
         RowBox[{"ExpansionLevel", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}],
      ",", 
     RowBox[{"NL", "[", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], ",", 
       RowBox[{"p", "[", "2", "]"}], ",", 
       RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "]"}], "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"i1222fin", "-", 
       RowBox[{"i", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], "]"}]}], "//", 
      RowBox[{
       RowBox[{"KEvaluate", "[", 
        RowBox[{"#", ",", 
         RowBox[{"ExpansionLevel", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}],
      ",", 
     RowBox[{"NL", "[", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], ",", 
       RowBox[{"p", "[", "2", "]"}], ",", 
       RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "]"}], "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.796982858685143*^9, 3.7969828876636353`*^9}, {
  3.798418996193089*^9, 3.798419012997541*^9}, {3.7984203721191893`*^9, 
  3.798420389655164*^9}},ExpressionUUID->"9f7d42f2-4667-4773-868f-\
3a14e97f3c08"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.796982853416946*^9, 3.796982892738077*^9, 
  3.798419823970879*^9, 3.798420346899928*^9, 3.798420391388777*^9, 
  3.798423781345498*^9, 3.7986864301965156`*^9, 
  3.799037941191196*^9},ExpressionUUID->"27dea62b-bfb0-4a55-b3dd-\
0f35ccefe8a2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.796982853416946*^9, 3.796982892738077*^9, 
  3.798419823970879*^9, 3.798420346899928*^9, 3.798420391388777*^9, 
  3.798423781345498*^9, 3.7986864301965156`*^9, 
  3.7990379417235413`*^9},ExpressionUUID->"a0f03f91-f3fb-4ab0-b145-\
ea3ebbcc7328"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.796982853416946*^9, 3.796982892738077*^9, 
  3.798419823970879*^9, 3.798420346899928*^9, 3.798420391388777*^9, 
  3.798423781345498*^9, 3.7986864301965156`*^9, 
  3.799037942308344*^9},ExpressionUUID->"5a57a247-3b67-4e28-8953-\
2e930e1f0392"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.796982853416946*^9, 3.796982892738077*^9, 
  3.798419823970879*^9, 3.798420346899928*^9, 3.798420391388777*^9, 
  3.798423781345498*^9, 3.7986864301965156`*^9, 
  3.7990379425009604`*^9},ExpressionUUID->"11a8e9ef-1e80-442b-a11e-\
7bfb3b1203f0"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Q", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "4"}], "+", 
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "4"}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
      RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NonLocalTerm", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"b", " ", "i7222"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "i5222fin"}], "-", 
      RowBox[{"4", "b", " ", 
       RowBox[{"p", "[", "3", "]"}], 
       RowBox[{"D", "[", 
        RowBox[{"i5222fin", ",", 
         RowBox[{"p", "[", "3", "]"}]}], "]"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"4", "c", " ", "i3222fin"}], "-", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"a", "+", "c", "+", "b"}], ")"}], 
       RowBox[{"p", "[", "3", "]"}], 
       RowBox[{"D", "[", 
        RowBox[{"i3222fin", ",", 
         RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "+", 
      RowBox[{"2", "b", " ", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", 
       RowBox[{"D", "[", 
        RowBox[{"i3222fin", ",", 
         RowBox[{"p", "[", "3", "]"}], ",", 
         RowBox[{"p", "[", "3", "]"}]}], "]"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"4", 
       RowBox[{"(", 
        RowBox[{"c", "-", "a"}], ")"}], "i3222fin"}], "+", 
      RowBox[{"4", 
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], 
       RowBox[{"p", "[", "3", "]"}], 
       RowBox[{"D", "[", 
        RowBox[{"i3222fin", ",", 
         RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "+", 
      RowBox[{"8", "b", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", "i3222fin"}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], 
             RowBox[{"D", "[", 
              RowBox[{"i3222fin", ",", 
               RowBox[{"p", "[", "j", "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], 
          RowBox[{"p", "[", "2", "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"i3222fin", ",", 
            RowBox[{"p", "[", "1", "]"}], ",", 
            RowBox[{"p", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"32", "i1222fin"}], "-", 
         RowBox[{"8", " ", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "j", "]"}], " ", 
             RowBox[{"D", "[", 
              RowBox[{"i1222fin", ",", 
               RowBox[{"p", "[", "j", "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], 
             RowBox[{"p", "[", "2", "]"}], 
             RowBox[{"D", "[", 
              RowBox[{"i1222fin", ",", 
               RowBox[{"p", "[", "1", "]"}], ",", 
               RowBox[{"p", "[", "2", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], 
             RowBox[{"p", "[", "3", "]"}], 
             RowBox[{"D", "[", 
              RowBox[{"i1222fin", ",", 
               RowBox[{"p", "[", "1", "]"}], ",", 
               RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], 
             RowBox[{"p", "[", "3", "]"}], 
             RowBox[{"D", "[", 
              RowBox[{"i1222fin", ",", 
               RowBox[{"p", "[", "2", "]"}], ",", 
               RowBox[{"p", "[", "3", "]"}]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
      "-", 
      RowBox[{"8", "b", " ", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "3"}], 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "^", "3"}], 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "3"}], 
       RowBox[{"D", "[", 
        RowBox[{"i1000", ",", 
         RowBox[{"p", "[", "1", "]"}], ",", 
         RowBox[{"p", "[", "2", "]"}], ",", 
         RowBox[{"p", "[", "3", "]"}]}], "]"}]}]}]}], " ", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LogTerm", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], "/", "3"}], 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
          RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], " ", ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], "-", 
         RowBox[{"a", " ", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ")"}], 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
         RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", 
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "-", 
         RowBox[{"a", " ", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ")"}], 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
         RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], " ", "+", 
      RowBox[{"2", "c", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
         RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"c", "-", "a"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}], 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"3", "c"}]}], ")"}], 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}], "+", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
           RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], ")"}]}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], 
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"Q", "+", 
         RowBox[{"Swap", "[", 
          RowBox[{"Q", ",", 
           RowBox[{"p", "[", "1", "]"}], ",", 
           RowBox[{"p", "[", "3", "]"}]}], "]"}], "+", 
         RowBox[{"Swap", "[", 
          RowBox[{"Q", ",", 
           RowBox[{"p", "[", "2", "]"}], ",", 
           RowBox[{"p", "[", "3", "]"}]}], "]"}]}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", "a"}], "+", 
         RowBox[{"c", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"8", " ", "\[Gamma]0"}]}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "4"}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "4"}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "4"}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}]}], ")"}]}]}]}], " ", 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remainder", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"8", 
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "EulerGamma", "-", 
         RowBox[{"Log", "[", "2", "]"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"64", "/", "3"}], " ", "b"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"cT", "[", "0", "]"}]}], "-", 
      RowBox[{"8", " ", "scdep"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], 
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"3", "c"}], "+", 
         RowBox[{"2", "b"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}]}], "+", 
      RowBox[{"4", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"EulerGamma", "-", 
            RowBox[{"Log", "[", "2", "]"}]}], ")"}]}], "-", "c", "-", 
         RowBox[{"4", "b"}]}], ")"}]}], "-", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"cT", "[", "0", "]"}]}], "-", 
      RowBox[{"4", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], " ", "scdep"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], "c", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "+", 
      RowBox[{"4", 
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"EulerGamma", "-", 
         RowBox[{"Log", "[", "2", "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "+", 
      RowBox[{"4", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "b"}], "-", "a", "-", "c"}], ")"}]}], "-", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cT", "[", "0", "]"}], "+", 
         RowBox[{"2", "scdep"}]}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], 
          RowBox[{"cT", "[", "0", "]"}]}], "+", 
         RowBox[{"2", "scdep"}]}], ")"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], "J2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "/", "2"}], "-", "EulerGamma", "+", 
            RowBox[{"Log", "[", "2", "]"}]}], ")"}]}], "+", 
         RowBox[{"4", "b"}]}], ")"}]}], "+", 
      RowBox[{"4", 
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "4"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "4"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], ")"}]}], "+", 
      RowBox[{"J2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cT", "[", "0", "]"}], "-", 
         RowBox[{"2", "scdep"}]}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"4", "\[Gamma]0"}]}], ")"}], 
       RowBox[{"cT", "[", "0", "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], "^", "4"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "4"}], "+", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "4"}]}], ")"}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.696693466836891*^9, 3.696693770634088*^9}, 
   3.6966938305172043`*^9, {3.696695004481614*^9, 3.696695203512908*^9}, {
   3.696695434268731*^9, 3.6966959959254513`*^9}, {3.6966961171299458`*^9, 
   3.6966961172801867`*^9}, {3.6967040461748753`*^9, 
   3.6967040463538857`*^9}, {3.696704867663862*^9, 3.6967048746852636`*^9}, {
   3.796989970856453*^9, 3.796989976246067*^9}, 
   3.79699000667773*^9},ExpressionUUID->"dc9db744-30ad-4248-a8e0-\
8fa31764dab1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cTocT", "=", 
   RowBox[{"{", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "cT"}], "/", "2"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.79699091654637*^9, 
  3.796990924596382*^9}},ExpressionUUID->"a361654b-7ff3-4a74-ab59-\
3488c0146a18"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SemiLocTerm", "=", 
  RowBox[{"{", 
   RowBox[{"0", ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"L", "[", "2", "]"}], 
      RowBox[{"Log", "[", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], "]"}]}], "+", 
     RowBox[{"M", "[", "2", "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"L", "[", "3", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
      RowBox[{"Log", "[", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"M", "[", "3", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"L", "[", "4", "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{
          RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], "-", 
        RowBox[{
         RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], ")"}], 
      RowBox[{"Log", "[", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "2"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"M", "[", "4", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}]}], ",", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7119849671213837`*^9, 3.7119849781520147`*^9}, {
  3.711985034831257*^9, 3.7119851097365413`*^9}, {3.711985183431756*^9, 
  3.7119852029768744`*^9}, {3.7119852782721806`*^9, 3.7119853023785596`*^9}, {
  3.711985353945509*^9, 3.7119853929217386`*^9}, {3.7119854258976245`*^9, 
  3.7119854472108436`*^9}, {3.711985592978181*^9, 
  3.71198560414382*^9}},ExpressionUUID->"27a386e6-9e02-4185-ab2e-\
b9f230668ecc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"L", "[", "2", "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}]}], "+", 
    RowBox[{"M", "[", "2", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"L", "[", "3", "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{
     RowBox[{"M", "[", "3", "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", "4", "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{
     RowBox[{"L", "[", "4", "]"}], " ", 
     RowBox[{"Log", "[", 
      SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["p", "1", "2"]}], "-", 
       SubsuperscriptBox["p", "2", "2"], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7119856046488485`*^9, 3.7448273614429307`*^9, 3.796982911356019*^9, {
   3.796990037774406*^9, 3.796990053432094*^9}, 3.798419866354169*^9, 
   3.7984203977321577`*^9, 3.7984237862991962`*^9, 3.7986864333686957`*^9, 
   3.7990379427057333`*^9},ExpressionUUID->"955609a8-fed3-4f6a-94b9-\
41740d3a4fb2"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "n", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
       "NonLocalTerm", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
        "+", 
       RowBox[{
       "LogTerm", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], "+", 
       RowBox[{
       "Remainder", "\[LeftDoubleBracket]", "n", 
        "\[RightDoubleBracket]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"Length", "[", "NonLocalTerm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dims", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{"d", "\[Rule]", "4"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.696677730447885*^9, 3.696677765480186*^9}, {
   3.696684161089705*^9, 3.696684198078211*^9}, {3.696684252001034*^9, 
   3.696684254088887*^9}, {3.696690336520917*^9, 3.69669042548135*^9}, 
   3.6966934033084173`*^9, {3.6966934363449297`*^9, 3.696693437524848*^9}, {
   3.696693775102064*^9, 3.6966938040822763`*^9}, {3.6966960033340816`*^9, 
   3.696696005156571*^9}, {3.711977959237556*^9, 3.711977962597748*^9}, {
   3.744827386378357*^9, 3.744827386698375*^9}, {3.7969900217487497`*^9, 
   3.796990028042737*^9}, 
   3.796990070837645*^9},ExpressionUUID->"2f2fc0d9-8fba-4594-92cd-\
a071509054b0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PrimaryAnomalies", "=", " ", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"32", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "-", 
          RowBox[{
           RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], ")"}]}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"16", 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"-", "32"}], 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}], ",", 
       RowBox[{"32", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "^", "2"}], "-", 
          RowBox[{
           RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}]}], "}"}]}], 
    " ", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SecondaryAnomalies", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", 
     RowBox[{
      RowBox[{"-", "32"}], 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], ",", 
     RowBox[{
      RowBox[{"-", "16"}], 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], ",", 
     RowBox[{"16", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "+", 
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "+", 
        RowBox[{"c", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
           RowBox[{"3", 
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], "+", 
           RowBox[{
            RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}]}], ")"}]}], 
     ",", " ", 
     RowBox[{
      RowBox[{"8", 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "^", "4"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cT", " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", "scdep"}], ")"}]}], 
      "-", 
      RowBox[{"8", 
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "^", "4"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cT", " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], "/", 
            RowBox[{"\[Mu]", "^", "2"}]}], "]"}]}], "+", "scdep"}], ")"}]}], 
      "+", 
      RowBox[{"8", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "-", 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}], "+", 
         RowBox[{"c", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}]}]}], 
        ")"}]}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7969912028140306`*^9, 3.796991211834144*^9}, {
  3.796991265168171*^9, 3.796991359936845*^9}, {3.796991390696817*^9, 
  3.796991452753063*^9}},ExpressionUUID->"faa61121-710c-4959-acd9-\
ad558cd484a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dmu", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"ApplyDmu", "[", "As", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696677448107196*^9, 3.696677477196095*^9}, {
  3.696677676423441*^9, 3.6966776876239157`*^9}, {3.69669381153874*^9, 
  3.696693814491118*^9}, {3.6969206880665817`*^9, 3.696920708554274*^9}, {
  3.79698291834754*^9, 
  3.79698291867546*^9}},ExpressionUUID->"fa24ded1-c548-4a38-b0ab-\
8a50c1ae55f9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"16", " ", 
    RowBox[{"(", 
     RowBox[{"a", "+", "c"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "2"], "+", 
       SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
    RowBox[{"8", " ", "a", " ", 
     SubsuperscriptBox["p", "3", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"8", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "2"], "+", 
       SubsuperscriptBox["p", "2", "2"], "-", 
       SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
    RowBox[{"8", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "2"], "+", 
       SubsuperscriptBox["p", "2", "2"], "+", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "4"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], "-", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"8", " ", "\[Gamma]0"}]}], ")"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"8", " ", "\[Gamma]0"}]}], ")"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"8", " ", "\[Gamma]0"}]}], ")"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.696677455429895*^9, 3.696677477465596*^9}, {
   3.696677670908154*^9, 3.6966776883154173`*^9}, 3.696678060553405*^9, 
   3.6966792152018747`*^9, 3.696684203185841*^9, 3.6966904272283993`*^9, {
   3.6966938085734673`*^9, 3.696693832208404*^9}, 3.696696012652359*^9, 
   3.6966961243701878`*^9, 3.69669617174231*^9, 3.696701529746464*^9, 
   3.696703838588002*^9, 3.6967041021450768`*^9, 3.696706455044655*^9, 
   3.6967069714211903`*^9, 3.696707774856144*^9, 3.696919119520952*^9, {
   3.69692069754247*^9, 3.696920713293746*^9}, 3.69692496035399*^9, 
   3.696936271501216*^9, 3.697367879348714*^9, 3.71197797259832*^9, 
   3.7448273922416925`*^9, 3.796982921258223*^9, {3.796990029839321*^9, 
   3.796990039267603*^9}, 3.796990075648692*^9, 3.7984198678222837`*^9, 
   3.79842040121726*^9, 3.7984237906724987`*^9, 3.7986864386849966`*^9, 
   3.799037944166028*^9},ExpressionUUID->"05a19a46-9818-4ecf-9e56-\
ecd5e3cf7107"]
}, Open  ]],

Cell["This takes a few minutes.", "Text",
 CellChangeTimes->{{3.796983480047464*^9, 
  3.7969834842665586`*^9}},ExpressionUUID->"e11c0549-226f-4c11-85b9-\
3c216bc0ae36"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{"time", ",", "K12"}], "}"}], "=", 
  RowBox[{
   RowBox[{"NumEval", "[", 
    RowBox[{"ApplyCWIs", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PrimaryCWIs", "[", "TTT", "]"}], "\[LeftDoubleBracket]", "3", 
       "\[RightDoubleBracket]"}], ",", "As", ",", "Dims"}], "]"}], "]"}], "//",
    "AbsoluteTiming"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"time", ",", "K13"}], "}"}], "=", 
  RowBox[{
   RowBox[{"NumEval", "[", 
    RowBox[{"ApplyCWIs", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PrimaryCWIs", "[", "TTT", "]"}], "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}], ",", "As", ",", "Dims"}], "]"}], "]"}], "//",
    "AbsoluteTiming"}]}]}], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
   3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
   3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
   3.696678063348724*^9, 3.696678095765924*^9}, {3.696678228183914*^9, 
   3.696678231271586*^9}, {3.696685624589093*^9, 3.696685625004813*^9}, {
   3.6966856618613453`*^9, 3.696685675845212*^9}, {3.6966857426828213`*^9, 
   3.696685747175213*^9}, {3.7969798422733393`*^9, 3.796979843264803*^9}, 
   3.796983016516687*^9, {3.796990543068219*^9, 3.796990554577742*^9}, {
   3.7969912356449203`*^9, 3.7969912421004*^9}, {3.798419432171689*^9, 
   3.798419443461359*^9}},ExpressionUUID->"b45b7389-899d-477f-b5c6-\
8146a9df1612"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"193.782064`", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "7.972121238708496`*^-7"}], " ", "b"}], ",", 
     RowBox[{"1.1920928955078125`*^-7", " ", "b"}], ",", 
     RowBox[{
      RowBox[{"-", "0.000010028481483459473`"}], " ", "b"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "788.4799999952666`"}], " ", "a"}], "+", 
      RowBox[{"1.7648562788963318`*^-7", " ", "b"}], "+", 
      RowBox[{"3153.92`", " ", "c", " ", "\[Gamma]0"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, 3.696684208811737*^9, {3.696684242701248*^9, 
   3.6966842567745113`*^9}, 3.696685619683587*^9, {3.696685668189961*^9, 
   3.696685681594283*^9}, 3.696685752950491*^9, 3.6967669650995607`*^9, 
   3.697366471758523*^9, 3.697366524914908*^9, 3.729943540404763*^9, 
   3.7448207185719805`*^9, 3.796979854752492*^9, 3.79698006677277*^9, 
   3.796983464315505*^9, 3.796990002870226*^9, 3.7969902923260593`*^9, 
   3.7969907031283617`*^9, 3.796991250021287*^9, 3.796991422142817*^9, 
   3.7984202221422157`*^9, 3.7984206679327793`*^9, 3.79842400314644*^9, 
   3.798686632754987*^9, 
   3.7990381380519333`*^9},ExpressionUUID->"f53c2108-e90b-46bd-9cd1-\
894576f29477"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"182.446262`", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"16.000000027939677`", " ", "a"}], "+", 
      RowBox[{"4.246830940246582`*^-7", " ", "b"}], "+", 
      RowBox[{"16.00000000745058`", " ", "c"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "32.000000049127266`"}], " ", "a"}], "+", 
      RowBox[{"1.996755599975586`*^-6", " ", "b"}], "-", 
      RowBox[{"32.00000000069849`", " ", "c"}]}], ",", 
     RowBox[{
      RowBox[{"299.52000001381384`", " ", "a"}], "-", 
      RowBox[{"1198.0800000000002`", " ", "c", " ", "\[Gamma]0"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, 3.696677404912499*^9, 3.696677689997962*^9, {
   3.696678065020378*^9, 3.696678098766781*^9}, 3.6966782338040047`*^9, 
   3.696679217297453*^9, 3.696684208811737*^9, {3.696684242701248*^9, 
   3.6966842567745113`*^9}, 3.696685619683587*^9, {3.696685668189961*^9, 
   3.696685681594283*^9}, 3.696685752950491*^9, 3.6967669650995607`*^9, 
   3.697366471758523*^9, 3.697366524914908*^9, 3.729943540404763*^9, 
   3.7448207185719805`*^9, 3.796979854752492*^9, 3.79698006677277*^9, 
   3.796983464315505*^9, 3.796990002870226*^9, 3.7969902923260593`*^9, 
   3.7969907031283617`*^9, 3.796991250021287*^9, 3.796991422142817*^9, 
   3.7984202221422157`*^9, 3.7984206679327793`*^9, 3.79842400314644*^9, 
   3.798686632754987*^9, 
   3.799038320505232*^9},ExpressionUUID->"63547037-0b33-455c-bac1-\
b030433f2198"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"NumEval", "[", 
   RowBox[{"PrimaryAnomalies", "/.", "cTocT"}], "]"}], "//", 
  "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{{3.7969914713198957`*^9, 3.796991480856106*^9}, {
  3.796991513296401*^9, 3.7969915157686653`*^9}, {3.798419447770547*^9, 
  3.7984194503170443`*^9}},ExpressionUUID->"c71d8c5b-805f-4c4e-84f5-\
c0ba6354b571"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.002979`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "788.48`"}], " ", "a"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"16", " ", "a"}], "-", 
        RowBox[{"8", " ", "cT"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "32"}], " ", "a"}], "+", 
        RowBox[{"16", " ", "cT"}]}], ",", 
       RowBox[{"299.52000000000004`", " ", "a"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7969915704562674`*^9, 3.7984241951469307`*^9, 
  3.7986868051637435`*^9, 
  3.799038320582345*^9},ExpressionUUID->"193035b4-0a42-4a39-b342-\
5f151cdf7226"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{"time", ",", "lhs"}], "}"}], "=", 
  RowBox[{
   RowBox[{"NumEval", "[", 
    RowBox[{
     RowBox[{"ApplyCWIs", "[", 
      RowBox[{
       RowBox[{"SecondaryCWIsLhs", "[", "TTT", "]"}], ",", "As", ",", 
       "Dims"}], "]"}], "/.", "cTocT"}], "]"}], "//", 
   "AbsoluteTiming"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"time", ",", "rhs"}], "}"}], "=", 
  RowBox[{
   RowBox[{"NumEval", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ApplyTWIs", "[", 
       RowBox[{"TTT", ",", "Dims"}], "]"}], "+", "SecondaryAnomalies"}], "/.",
      "cTocT"}], "]"}], "//", "AbsoluteTiming"}]}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
   3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
   3.6966772912178926`*^9}, {3.696678106749449*^9, 3.6966781141980352`*^9}, {
   3.696678238255801*^9, 3.696678242655888*^9}, {3.6973665818718567`*^9, 
   3.697366582661743*^9}, {3.729943639989152*^9, 3.729943671698748*^9}, {
   3.729943744101709*^9, 3.729943746403071*^9}, 3.729943777700529*^9, {
   3.7969798675853167`*^9, 3.796979881985394*^9}, {3.796983489405979*^9, 
   3.796983512724435*^9}, {3.796989778126795*^9, 3.7969898016090593`*^9}, {
   3.79699100275802*^9, 3.796991004373871*^9}, {3.7969910452415447`*^9, 
   3.796991064090131*^9}, {3.796991500938332*^9, 3.7969915086881227`*^9}, {
   3.796991602786298*^9, 3.796991610746393*^9}, {3.798419454082985*^9, 
   3.7984194636750307`*^9}},ExpressionUUID->"3c26cd92-f705-441c-9aa9-\
b4187f354495"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"169.869095`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3.986060619354248`*^-7", " ", "b"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "648.0000001173466`"}], " ", "a"}], "-", 
      RowBox[{"0.000010907649993896484`", " ", "b"}], "+", 
      RowBox[{"324.0000001024455`", " ", "cT"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "324.0000000037253`"}], " ", "a"}], "-", 
      RowBox[{"1.4901161193847656`*^-6", " ", "b"}], "+", 
      RowBox[{"161.99999999441206`", " ", "cT"}]}], ",", 
     RowBox[{
      RowBox[{"11511.720003508031`", " ", "a"}], "-", 
      RowBox[{"0.0002512931823730469`", " ", "b"}], "+", 
      RowBox[{"cT", " ", 
       RowBox[{"(", 
        RowBox[{"218448.21308309585`", "\[VeryThinSpace]", "+", 
         RowBox[{"495620.35708375473`", " ", "\[Gamma]0"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"64483.5872`", "\[VeryThinSpace]", "+", 
         RowBox[{"136557.0688`", " ", "\[Gamma]0"}]}], ")"}], " ", 
       RowBox[{"cT", "[", "0", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8788.500000391155`"}], " ", "a"}], "-", 
      RowBox[{"0.00003522634506225586`", " ", "b"}], "+", 
      RowBox[{"54543.74190671928`", " ", "cT"}], "+", 
      RowBox[{"15172.16`", " ", 
       RowBox[{"cT", "[", "0", "]"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696684262444735*^9, 3.696685768314904*^9, 3.696766967601866*^9, 
   3.697366475995571*^9, 3.6973665282558317`*^9, 3.697366585237156*^9, 
   3.729943551721242*^9, {3.7299436419014883`*^9, 3.729943666524374*^9}, {
   3.729943719225932*^9, 3.729943748169105*^9}, 3.729943780134572*^9, 
   3.7448207210271206`*^9, 3.796979882921516*^9, 3.7969800998745403`*^9, 
   3.79698358175524*^9, 3.79698990743814*^9, 3.796991045187825*^9, 
   3.796991090034321*^9, 3.796991627776156*^9, 3.798424375153472*^9, 
   3.7986869643077664`*^9, 
   3.799038490527128*^9},ExpressionUUID->"435efd23-e3e0-4d2e-a210-\
fc9c0fdf8636"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.196911`", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "648.`"}], " ", "a"}], "+", 
      RowBox[{"324.`", " ", "cT"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "324.`"}], " ", "a"}], "+", 
      RowBox[{"162.`", " ", "cT"}]}], ",", 
     RowBox[{
      RowBox[{"11511.720000000001`", " ", "a"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"218448.21308438425`", "\[VeryThinSpace]", "+", 
         RowBox[{"490618.8661687685`", " ", "cg"}]}], ")"}], " ", "cT"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"64483.5872`", "\[VeryThinSpace]", "+", 
         RowBox[{"128967.1744`", " ", "cg"}]}], ")"}], " ", 
       RowBox[{"cT", "[", "0", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8788.5`"}], " ", "a"}], "+", 
      RowBox[{"113605.66381344557`", " ", "cT"}], "+", 
      RowBox[{"15172.16`", " ", "scdep"}], "+", 
      RowBox[{"15172.16`", " ", 
       RowBox[{"cT", "[", "0", "]"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, 3.696677408585855*^9, 3.696677691590582*^9, 
   3.696678121375881*^9, 3.6966782440915728`*^9, 3.696679218437241*^9, 
   3.696684262444735*^9, 3.696685768314904*^9, 3.696766967601866*^9, 
   3.697366475995571*^9, 3.6973665282558317`*^9, 3.697366585237156*^9, 
   3.729943551721242*^9, {3.7299436419014883`*^9, 3.729943666524374*^9}, {
   3.729943719225932*^9, 3.729943748169105*^9}, 3.729943780134572*^9, 
   3.7448207210271206`*^9, 3.796979882921516*^9, 3.7969800998745403`*^9, 
   3.79698358175524*^9, 3.79698990743814*^9, 3.796991045187825*^9, 
   3.796991090034321*^9, 3.796991627776156*^9, 3.798424375153472*^9, 
   3.7986869643077664`*^9, 
   3.7990384907247543`*^9},ExpressionUUID->"acd2cf65-e96b-4f6a-8b72-\
6f344eca9105"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semilocal terms", "Subsubsection",
 CellChangeTimes->{{3.7448164090104876`*^9, 
  3.744816412273674*^9}},ExpressionUUID->"5e740a43-c13c-405f-9ae3-\
5bd1a7b85798"],

Cell["\<\
The most general form of semilocal terms of correct dimensionality:\
\>", "Text",
 CellChangeTimes->{{3.744816425297419*^9, 3.744816431817792*^9}, {
  3.7448169463422213`*^9, 
  3.744816947431283*^9}},ExpressionUUID->"b1b7c916-5c94-4da6-84db-\
9eb9b072cd31"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dimA1", "=", 
  RowBox[{"Scaling", "[", 
   RowBox[{"Dims", ",", "6"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SemiLocals", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "i"}], "]"}], "/", 
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "^", "2"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "i"}], "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "i"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "i", ",", "j"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "j", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "i"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "i", ",", "j"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "j", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "i", ",", "j"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
         RowBox[{
          RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "+", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "i", ",", "j", ",", "k"}], "]"}], 
         RowBox[{
          RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
         RowBox[{
          RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"p", "[", "k", "]"}], "^", "2"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "i"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQzabqtWT1s9eOLm5ZYPp2fNcuEB1j8Q5Mi2yyeQqi
lxzyANNKujY5a4C0XfW6AhBtuOTNNBA9R2D7LLD44tnLQfRk5pLVIHqVcc8r
EG2R9+01iC75IvUHRP849ZNxLZBWCckrB9EZf/PqQTTv/mttIPpM+00w7XLs
zhEQncj39xSIXudv5bUOSLe9dwDTnLJ8KSA6Y8+sbBAdFZIrswFI+xleUQTR
bFd3G4Fo/dPvjEG0UvpKaxC94c8aMO21zcwFRHOcqvIE0f6Xl2SDaKZp6uVg
cyzuHwHR11mLz4PofZtrWTcCabnYSEEQvS225J2e1xvHkkV9YBoAmXPExw==

  "],ExpressionUUID->"94ae8dac-d805-4b8d-b2d1-459a801ec130"],

Cell[BoxData[
 RowBox[{"-", "2"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448258234009595`*^9, 3.7448259321781816`*^9, 
   3.7448262014605837`*^9, 3.744826297784093*^9, 3.744826919532655*^9, 
   3.7448270079787135`*^9, 3.7448274305678844`*^9, {3.744827524230242*^9, 
   3.7448275312916455`*^9}, 3.796991636166848*^9, 3.798424375399795*^9, 
   3.798686964521779*^9, 
   3.7990384907842283`*^9},ExpressionUUID->"355dfedf-eb68-48a4-b75e-\
09c9476a1465"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "1"}], "]"}], 
      SubsuperscriptBox["p", "1", "2"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2"}], "]"}], 
      SubsuperscriptBox["p", "2", "2"]], "+", 
     FractionBox[
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "3"}], "]"}], 
      SubsuperscriptBox["p", "3", "2"]]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "1", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], " ", 
      RowBox[{"Log", "[", 
       SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
      SubsuperscriptBox["p", "3", "4"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448165089622045`*^9, 3.7448165997563972`*^9, {3.7448169494814005`*^9, 
   3.7448169636482105`*^9}, 3.7448172070541325`*^9, {3.7448180243238783`*^9, 
   3.744818053747561*^9}, {3.7448183535977116`*^9, 3.744818390039796*^9}, {
   3.744818514801932*^9, 3.7448185242044697`*^9}, 3.7448187281541348`*^9, 
   3.7448187752998314`*^9, 3.744818842204658*^9, {3.744819014640521*^9, 
   3.744819040174981*^9}, 3.7448191598168244`*^9, 3.744819216161047*^9, 
   3.7448196510079193`*^9, {3.7448201507315016`*^9, 3.744820162390168*^9}, 
   3.7448202198054523`*^9, 3.744820278983837*^9, 3.744820464404443*^9, 
   3.7448207695248947`*^9, 3.744820812052327*^9, 3.7448218444643774`*^9, 
   3.744822037282406*^9, 3.7448221094355335`*^9, 3.744823159652602*^9, 
   3.7448255723225985`*^9, 3.744825615854089*^9, {3.7448257420253053`*^9, 
   3.744825759984332*^9}, 3.7448258234009595`*^9, 3.7448259321781816`*^9, 
   3.7448262014605837`*^9, 3.744826297784093*^9, 3.744826919532655*^9, 
   3.7448270079787135`*^9, 3.7448274305678844`*^9, {3.744827524230242*^9, 
   3.7448275312916455`*^9}, 3.796991636166848*^9, 3.798424375399795*^9, 
   3.798686964521779*^9, 
   3.799038490790307*^9},ExpressionUUID->"c2596883-1800-4502-95fa-\
a1a387f31af9"]
}, Open  ]],

Cell["\<\
Substitute to primary CWIs and find the most general solution:\
\>", "Text",
 CellChangeTimes->{{3.744816484897828*^9, 
  3.744816494969404*^9}},ExpressionUUID->"c595d744-7018-4dcb-b511-\
9c9b6a241168"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cwis1", "=", 
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TTT", "]"}], ",", "SemiLocals", ",", 
     "Dims"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7448152608118143`*^9, 3.7448153025812035`*^9}, {
   3.7448158722897887`*^9, 3.7448158821213512`*^9}, {3.7448162492863517`*^9, 
   3.7448163293039284`*^9}, {3.7448163651689796`*^9, 3.744816368272157*^9}, {
   3.744816497501549*^9, 3.7448164987326193`*^9}, {3.744818062856082*^9, 
   3.7448180630960956`*^9}, {3.7448181387444224`*^9, 3.744818139342457*^9}, {
   3.7448183923749294`*^9, 3.744818394222035*^9}, {3.744818586941058*^9, 
   3.7448185876761*^9}, 3.744819257184394*^9, {3.7448202234556613`*^9, 
   3.74482023182514*^9}, {3.744825621683422*^9, 3.744825667576047*^9}, {
   3.7448257092444305`*^9, 3.7448257097734604`*^9}, {3.744825937418481*^9, 
   3.744825937696497*^9}, 3.744826062704647*^9, 3.744826356535453*^9, 
   3.744826406038285*^9, {3.79699162322433*^9, 3.796991624354846*^9}, {
   3.796991813869214*^9, 
   3.796991814306711*^9}},ExpressionUUID->"81382327-1c07-4ed1-8e02-\
a8df6ff49643"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "1"}], "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "1", ",", "1"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3", ",", "1"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3", ",", "2"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "1"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "2"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "2"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], "-", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["p", "1", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["p", "1", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c", "[", 
          RowBox[{"1", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "3"}], "]"}]}], 
       SubsuperscriptBox["p", "3", "2"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "2"}], "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3", ",", "1"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2", ",", "2"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3", ",", "2"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "1"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "2"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "2"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "1"}], "]"}], "-", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "1"}], "]"}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"c", "[", 
              RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}]}]}], ")"}], 
          " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], 
       SubsuperscriptBox["p", "1", "4"]], "-", 
      FractionBox[
       RowBox[{"12", " ", 
        RowBox[{"c", "[", 
         RowBox[{"1", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}]}], 
        SubsuperscriptBox["p", "1", "2"]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}], 
       SubsuperscriptBox["p", "2", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}]}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "1", ",", "1"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "2", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "1", ",", "2"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "1"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "1"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "2"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"2", ",", "3"}], "]"}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "2"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"2", ",", "2"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1"}], "]"}]}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "4"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "4"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "4"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "4"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "+", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "+", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744820226349827*^9, 3.744820232096155*^9}, 
   3.7448202807799397`*^9, 3.744820470914815*^9, 3.7448208265901585`*^9, 
   3.7448218467175064`*^9, 3.7448221157548943`*^9, 3.7448231657969537`*^9, 
   3.7448256219324365`*^9, {3.744825653943267*^9, 3.7448256678290615`*^9}, 
   3.744825710378495*^9, 3.7448257679317875`*^9, 3.7448259390115724`*^9, 
   3.7448260629036584`*^9, 3.7448263084147005`*^9, 3.744826406553314*^9, 
   3.744827011983943*^9, 3.744827547822591*^9, {3.796991810876046*^9, 
   3.7969918218147373`*^9}, 3.7969926776453247`*^9, 3.796992918116602*^9, 
   3.798424378687318*^9, 3.7986869693570538`*^9, 
   3.799038495798778*^9},ExpressionUUID->"ed02d2b9-cc3a-4aef-8dd0-\
55f6042ab9c8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution1", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis2", "=", 
  RowBox[{
   RowBox[{"cwis1", "/.", "LocalPrimarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448264236552925`*^9, 3.7448264546710663`*^9}, {
  3.7448270456038656`*^9, 3.7448270529792876`*^9}, {3.744827565031575*^9, 
  3.7448275672237005`*^9}},ExpressionUUID->"bf4d2082-603f-49a1-af58-\
075b2a31d962"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826429491626*^9, 3.744826454993085*^9}, 
   3.7448270545043745`*^9, 3.744827567936742*^9, 3.796991828569968*^9, 
   3.796992685962654*^9, 3.796992919567151*^9, 3.798424378765033*^9, 
   3.7986869694230576`*^9, 
   3.799038495888735*^9},ExpressionUUID->"0079582d-d769-4453-b9b7-\
db80326acfd2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "1"}], "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1", ",", "1"}], "]"}], "-", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "3", ",", "1"}], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1", ",", "2"}], "]"}], "-", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "3", ",", "2"}], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "1"}], "]"}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "1"}], "]"}]}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "2"}], "]"}]}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], "-", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["p", "1", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["p", "1", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "2"}], "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2", ",", "1"}], "]"}], "-", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "3", ",", "1"}], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2", ",", "2"}], "]"}], "-", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "3", ",", "2"}], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "1"}], "]"}]}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "2"}], "]"}]}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "3", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "3", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "1"}], "]"}], "-", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "1"}], "]"}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"c", "[", 
              RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}]}]}], ")"}], 
          " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1"}], "]"}]}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"3", ",", "2"}], "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "1", ",", "1"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "2", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "1", ",", "2"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"3", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}]}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "2"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "1"}], "]"}]}], "+", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "1"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "1", ",", "2"}], "]"}], "-", 
           RowBox[{"c", "[", 
            RowBox[{"4", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "1"}], "]"}]}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "1", "2"]}], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "4"]}], 
         SubsuperscriptBox["p", "2", "2"]], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "4"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"c", "[", 
          RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"], " ", 
          SubsuperscriptBox["p", "3", "2"]}], 
         SubsuperscriptBox["p", "1", "2"]], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "4"]}], 
         SubsuperscriptBox["p", "1", "2"]], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "3", "4"]}], 
         SubsuperscriptBox["p", "2", "2"]], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "1"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "+", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "1", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "+", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "3", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "2", "2"]}], "-", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "1", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", 
           RowBox[{
            RowBox[{"c", "[", 
             RowBox[{"4", ",", "2", ",", "3"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], " ", 
            SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826429491626*^9, 3.744826454993085*^9}, 
   3.7448270545043745`*^9, 3.744827567936742*^9, 3.796991828569968*^9, 
   3.796992685962654*^9, 3.796992919567151*^9, 3.798424378765033*^9, 
   3.7986869694230576`*^9, 
   3.7990384979682198`*^9},ExpressionUUID->"077c8185-14ec-4a25-a714-\
86f1da1abab0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution2", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"p", "[", "i", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"p", "[", "i", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "4"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"p", "[", "i", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"cwis2", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "4"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"p", "[", "i", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
             RowBox[{
              RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
             RowBox[{"cwis2", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "/.", 
            RowBox[{
             RowBox[{"Log", "[", "x_", "]"}], "\[RuleDelayed]", "0"}]}], ",", 
           
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "i"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
             RowBox[{
              RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
             RowBox[{"cwis2", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "4"}], "\[RightDoubleBracket]"}]}], "/.", 
            RowBox[{
             RowBox[{"Log", "[", "x_", "]"}], "\[RuleDelayed]", "0"}]}], ",", 
           
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "i"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
             RowBox[{
              RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
             RowBox[{"cwis2", "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}], "/.", 
            RowBox[{
             RowBox[{"Log", "[", "x_", "]"}], "\[RuleDelayed]", "0"}]}], ",", 
           
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "i"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
             RowBox[{
              RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
             RowBox[{"cwis2", "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "4"}], "\[RightDoubleBracket]"}]}], "/.", 
            RowBox[{
             RowBox[{"Log", "[", "x_", "]"}], "\[RuleDelayed]", "0"}]}], ",", 
           
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "i"}], "}"}]}], "]"}]}], "]"}]}], " ", "}"}], 
       "]"}]}], ",", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"3", ",", "i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"4", ",", "i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3", ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], " ", "}"}], "//", 
      "Flatten"}]}], "]"}], "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis3", "=", 
  RowBox[{
   RowBox[{"cwis2", "/.", "LocalPrimarySolution2"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448276530286083`*^9, 3.7448278309217834`*^9}, {
  3.796991935769587*^9, 3.796991972737975*^9}, {3.796992044313154*^9, 
  3.7969921062047243`*^9}, {3.7969921365401983`*^9, 3.796992195557849*^9}, {
  3.796992227566388*^9, 3.796992244566687*^9}, {3.79699237761622*^9, 
  3.796992387626297*^9}},ExpressionUUID->"78f0fb9b-91f9-4f8d-9393-\
5cc794cb9ac3"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   580,6,29347142503502531606,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.744827811070648*^9, 3.744827831337807*^9}, {
   3.796991945706499*^9, 3.796991973200109*^9}, 3.79699206794398*^9, 
   3.796992245561466*^9, 3.7969923896743593`*^9, 3.7969926891784353`*^9, 
   3.796992928234988*^9, 3.798424379712291*^9, 3.7986869715051765`*^9, 
   3.799038498079376*^9},ExpressionUUID->"3de1b9a1-61be-40f1-abce-\
7cdd3f440922"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744827672097699*^9, 3.744827749197109*^9}, {
   3.7448277888803787`*^9, 3.7448278313418074`*^9}, {3.796991945891741*^9, 
   3.7969919732366858`*^9}, 3.7969920679829693`*^9, 3.7969922455799828`*^9, 
   3.7969923896890993`*^9, 3.796992689192286*^9, 3.796992928247158*^9, 
   3.798424380134336*^9, 3.7986869715281773`*^9, 
   3.7990384980951843`*^9},ExpressionUUID->"0815354a-ab2d-4acb-9eef-\
8db2cac8f7db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c", "[", 
              RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}]}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c", "[", 
              RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}]}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "3", "2"]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["p", "2", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["p", "2", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"c", "[", 
        RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "2", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], 
       SubsuperscriptBox["p", "1", "2"]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "1", "2"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}], 
       SubsuperscriptBox["p", "2", "2"]], "+", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c", "[", 
              RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}]}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c", "[", 
              RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}]}], "+", 
            RowBox[{"c", "[", 
             RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744827672097699*^9, 3.744827749197109*^9}, {
   3.7448277888803787`*^9, 3.7448278313418074`*^9}, {3.796991945891741*^9, 
   3.7969919732366858`*^9}, 3.7969920679829693`*^9, 3.7969922455799828`*^9, 
   3.7969923896890993`*^9, 3.796992689192286*^9, 3.796992928247158*^9, 
   3.798424380134336*^9, 3.7986869715281773`*^9, 
   3.7990384991593227`*^9},ExpressionUUID->"9da06f68-05de-4c3d-b551-\
e3b4577a7030"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution3", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"cwis3", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "5"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
              RowBox[{"Log", "[", 
               RowBox[{"p", "[", "i", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"cwis3", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "5"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
              RowBox[{"Log", "[", 
               RowBox[{"p", "[", "i", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
              RowBox[{"cwis3", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "5"}], "\[RightDoubleBracket]"}]}], "/.", 
             RowBox[{
              RowBox[{"Log", "[", "x_", "]"}], "\[RuleDelayed]", "0"}]}], "//",
             "Expand"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "k", "]"}], "^", "2"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
              RowBox[{"cwis3", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "5"}], "\[RightDoubleBracket]"}]}], "/.", 
             RowBox[{
              RowBox[{"Log", "[", "x_", "]"}], "\[RuleDelayed]", "0"}]}], "//",
             "Expand"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "i", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "2"}], 
              RowBox[{
               RowBox[{"p", "[", "k", "]"}], "^", "2"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}], "]"}]}], " ", "}"}], 
       "]"}]}], ",", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"5", ",", "i", ",", "j", ",", "k"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}], " ", "}"}], "//", 
      "Flatten"}]}], "]"}], "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"cwis4", "=", 
  RowBox[{
   RowBox[{"cwis3", "/.", "LocalPrimarySolution3"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.796992403324243*^9, 3.796992584018396*^9}, {
  3.7969927381778727`*^9, 3.7969927725331087`*^9}, {3.796992810215626*^9, 
  3.796992817121413*^9}},ExpressionUUID->"3bb23691-307d-4ffb-b9d0-\
d206de4809d8"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   582,7,29347142503502531606,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.79699258540689*^9, 3.7969927054072227`*^9, 
  3.79699274021614*^9, 3.796992774020062*^9, 3.796992817773636*^9, 
  3.796992937692308*^9, 3.798424380547474*^9, 3.7986869725452337`*^9, 
  3.7990384992805367`*^9},ExpressionUUID->"adbbc4d3-ca70-4db7-b9ee-\
e518fd5a0716"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.796992585497267*^9, 3.7969927054243193`*^9, 
  3.796992740240492*^9, 3.7969927740439787`*^9, 3.7969928177914457`*^9, 
  3.796992937710986*^9, 3.79842438056328*^9, 3.798686972567235*^9, 
  3.799038499295568*^9},ExpressionUUID->"dd7743c8-0d74-4077-949a-\
1fb276ebee99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.796992585497267*^9, 3.7969927054243193`*^9, 
  3.796992740240492*^9, 3.7969927740439787`*^9, 3.7969928177914457`*^9, 
  3.796992937710986*^9, 3.79842438056328*^9, 3.798686972567235*^9, 
  3.799038499301002*^9},ExpressionUUID->"5207bdf5-2b22-463e-8306-\
d8b630c7d6c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalPrimarySolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{
   "LocalPrimarySolution1", ",", "LocalPrimarySolution2", ",", 
    "LocalPrimarySolution3"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cwis1", "/.", "LocalPrimarySolution"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SemiLocals", "/.", "LocalPrimarySolution"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.744826611003008*^9, 3.7448266584187202`*^9}, {
   3.744827105906315*^9, 3.744827106129328*^9}, {3.7448284490721397`*^9, 
   3.744828474758609*^9}, 
   3.7969926103307734`*^9},ExpressionUUID->"a3e22c5e-5f88-4469-9a2c-\
3c00df85a9f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448271073373966`*^9, {3.744828461421846*^9, 3.744828475081627*^9}, 
   3.796992612221097*^9, 3.796992707853902*^9, 3.796992822005838*^9, 
   3.796992855511403*^9, 3.796992956523991*^9, 3.798424380644721*^9, 
   3.7986869726252384`*^9, 
   3.799038499328649*^9},ExpressionUUID->"d7c6a821-c38d-44bb-ab8f-\
d53b791b8092"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448271073373966`*^9, {3.744828461421846*^9, 3.744828475081627*^9}, 
   3.796992612221097*^9, 3.796992707853902*^9, 3.796992822005838*^9, 
   3.796992855511403*^9, 3.796992956523991*^9, 3.798424380644721*^9, 
   3.7986869726252384`*^9, 
   3.79903849933482*^9},ExpressionUUID->"946ce3ce-10e2-492b-99fe-\
8e8b712ca0f1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "0"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"c", "[", 
          RowBox[{"3", ",", "3"}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], "+", 
        SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"4", ",", "3"}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], "+", 
        SubsuperscriptBox["p", "2", "2"]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "1", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"2", ",", "0"}], "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}], " ", 
        SubsuperscriptBox["p", "1", "4"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"5", ",", "2", ",", "2"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"2", ",", "0"}], "]"}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"c", "[", 
               RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}]}]}], ")"}], " ", 
        SubsuperscriptBox["p", "2", "4"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "+", 
          SubsuperscriptBox["p", "2", "2"]}], ")"}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"c", "[", 
            RowBox[{"5", ",", "3", ",", "3"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"2", ",", "0"}], "]"}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"c", "[", 
               RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}]}]}], ")"}], " ", 
        SubsuperscriptBox["p", "3", "4"]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744826617540382*^9, 3.7448266587377386`*^9}, 
   3.7448271073373966`*^9, {3.744828461421846*^9, 3.744828475081627*^9}, 
   3.796992612221097*^9, 3.796992707853902*^9, 3.796992822005838*^9, 
   3.796992855511403*^9, 3.796992956523991*^9, 3.798424380644721*^9, 
   3.7986869726252384`*^9, 
   3.7990385001790533`*^9},ExpressionUUID->"d1a4b90d-0725-4af0-b802-\
c491369e50c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"PrimaryCWIs", "[", "TTT", "]"}], ",", 
    RowBox[{"SemiLocals", "//.", "LocalPrimarySolution"}], ",", "Dims"}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.796993247716827*^9, 
  3.796993250500102*^9}},ExpressionUUID->"25423bd6-33d9-4c33-a5de-\
92b407a3f2b8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7969932515634527`*^9, 3.798424381533392*^9, 
  3.7986869734212837`*^9, 
  3.7990385002928123`*^9},ExpressionUUID->"a66a9ce0-eea4-47e6-b302-\
f7ee18298144"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LocalSecs", "=", 
  RowBox[{"SimplifyCWIs", "[", 
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"SecondaryCWIsLhs", "[", "TTT", "]"}], ",", 
     RowBox[{"SemiLocals", "//.", "LocalPrimarySolution"}], ",", "Dims"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.7448285084005327`*^9, {3.744828663095381*^9, 3.744828665294507*^9}, {
   3.79699261920257*^9, 3.796992632108921*^9}, 3.796992887157817*^9, {
   3.7969929664233847`*^9, 3.7969929725389233`*^9}, {3.796993237591732*^9, 
   3.796993293147708*^9}},ExpressionUUID->"1ddf7d7b-2388-4a1c-a85b-\
f570530c053b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"4", ",", "3"}], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], ",", "0", 
   ",", 
   RowBox[{
    RowBox[{"5", " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "4"]}], "-", 
    RowBox[{"8", " ", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "4"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "4"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "4"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "-", 
    RowBox[{"8", " ", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "2", "4"]}], "+", 
    RowBox[{"8", " ", 
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "2", ",", "2"}], "]"}], " ", 
     SubsuperscriptBox["p", "2", "4"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      SubscriptBox["p", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", "4"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "-", 
    RowBox[{"8", " ", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
     SubsuperscriptBox["p", "1", "2"], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{"8", " ", 
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "2", ",", "1"}], "]"}], " ", 
     SubsuperscriptBox["p", "2", "2"], " ", 
     SubsuperscriptBox["p", "3", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "3", "4"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "3", "4"]}], "+", 
    RowBox[{"8", " ", 
     RowBox[{"c", "[", 
      RowBox[{"5", ",", "3", ",", "3"}], "]"}], " ", 
     SubsuperscriptBox["p", "3", "4"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "[", 
        RowBox[{"2", ",", "0"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"c", "[", 
         RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      SubscriptBox["p", "3"], "]"}], " ", 
     SubsuperscriptBox["p", "3", "4"]}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", 
        RowBox[{"3", ",", "3"}], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "2", "4"], "-", 
      SubsuperscriptBox["p", "3", "4"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7448285096676054`*^9, 3.744828666135555*^9, 3.7969926336960907`*^9, 
   3.796992710341119*^9, 3.796992825776807*^9, {3.796992865203136*^9, 
   3.796992887815219*^9}, 3.796992972809807*^9, {3.7969932415669107`*^9, 
   3.796993293585627*^9}, 3.798424381660459*^9, 3.7986869735272884`*^9, 
   3.799038500383759*^9},ExpressionUUID->"d86f94a3-b829-4146-a42d-\
b60e47361b4c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LocalSecondarySolution1", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[Equal]", "0"}], "&"}], "/@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "LocalSecs", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"LocalSecs", "\[LeftDoubleBracket]", 
          RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"LocalSecs", "\[LeftDoubleBracket]", 
            RowBox[{"-", "2"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", "j", "]"}], "^", "4"}], " ", 
              RowBox[{"Log", "[", 
               RowBox[{"p", "[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"LocalSecs", "\[LeftDoubleBracket]", 
             RowBox[{"-", "2"}], "\[RightDoubleBracket]"}], "/.", 
            RowBox[{
             RowBox[{"Log", "[", "x_", "]"}], "\[RuleDelayed]", "0"}]}], ",", 
           
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"p", "[", "i", "]"}], "^", "2"}], " ", 
               RowBox[{
                RowBox[{"p", "[", "j", "]"}], "^", "2"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "3"}], "}"}]}], "]"}], " ", "//", " ", 
            "Flatten"}]}], "]"}]}], "}"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"i", ",", "j", ",", "k"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "3"}], "}"}]}], "]"}], ",", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], " ", "}"}], "//", 
      "Flatten"}]}], "]"}], "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"secs1", "=", 
  RowBox[{
   RowBox[{"LocalSecs", "/.", "LocalSecondarySolution1"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.796993301791799*^9, 3.79699333569084*^9}, {
  3.7969933760726624`*^9, 3.796993489308765*^9}, {3.796993530893784*^9, 
  3.7969935901127653`*^9}},ExpressionUUID->"09334d50-f8a7-45cf-afab-\
aa2ef270b9f5"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   589,8,29347142503502531606,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.796993579615296*^9, 3.796993592116291*^9}, 
   3.7984243817532253`*^9, 3.798686973577291*^9, 
   3.799038500455001*^9},ExpressionUUID->"343631bb-1157-4d99-ab97-\
6afd5479a956"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7969934897327433`*^9, 3.796993532270742*^9, {3.796993579636985*^9, 
   3.796993592134428*^9}, 3.798424381765836*^9, 3.798686973597292*^9, 
   3.7990385004681273`*^9},ExpressionUUID->"0fe2bd49-cc63-4d43-8979-\
4dcd9d7f12c3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7969934897327433`*^9, 3.796993532270742*^9, {3.796993579636985*^9, 
   3.796993592134428*^9}, 3.798424381765836*^9, 3.798686973597292*^9, 
   3.7990385004731197`*^9},ExpressionUUID->"c0e25a09-3d14-410a-ab23-\
8db231d6f4eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSolution", "=", 
  RowBox[{"Union", "[", 
   RowBox[{"LocalPrimarySolution", ",", "LocalSecondarySolution1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"As", "=", 
  RowBox[{
   RowBox[{"SemiLocals", "//.", "FullSolution"}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7448288397884874`*^9, 3.7448289196050525`*^9}, {
   3.796993629164082*^9, 3.796993631524539*^9}, 3.796993673487831*^9, {
   3.796993709712022*^9, 
   3.796993713700008*^9}},ExpressionUUID->"188ad73b-c038-4e88-9fa0-\
e6ad9b4b7310"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], "+", 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "3"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"4", ",", "3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "1", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "2", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "1", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "2", ",", "3"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "1"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "2"}], "]"}], "\[Rule]", "0"}], 
   ",", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"5", ",", "3", ",", "3", ",", "3"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "2", ",", "1"}], "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.744828870068219*^9, 3.7448289206391115`*^9}, 
   3.796993632978381*^9, 3.796993673792692*^9, 3.7969937147331133`*^9, 
   3.798424381852479*^9, 3.7986869736552954`*^9, 
   3.799038500497821*^9},ExpressionUUID->"d02cc3fa-c9c9-446c-b5b6-\
c5bd99ded246"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"A", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "0"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "3", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], " ", 
     SubsuperscriptBox["p", "3", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "0"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "2"], "+", 
       SubsuperscriptBox["p", "2", "2"], "-", 
       SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"A", "[", "5", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"5", ",", "1", ",", "1"}], "]"}], " ", 
      SubsuperscriptBox["p", "1", "4"]}], "-", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["p", "2", "2"], "-", 
           SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["p", "2", "2"], "+", 
           SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.744828870068219*^9, 3.7448289206391115`*^9}, 
   3.796993632978381*^9, 3.796993673792692*^9, 3.7969937147331133`*^9, 
   3.798424381852479*^9, 3.7986869736552954`*^9, 
   3.79903850053413*^9},ExpressionUUID->"03d40278-5f15-4fd6-9566-\
b0f8450d90d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApplyDmu", "[", "As", "]"}]], "Input",
 CellChangeTimes->{{3.696677607964088*^9, 
  3.6966776258540688`*^9}},ExpressionUUID->"7c6685bf-b55e-43be-bdf7-\
b2f96c85def6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.696677627230453*^9, 3.6966776623071833`*^9, 3.696678324117044*^9, 
   3.696679200338336*^9, {3.696684066743404*^9, 3.6966840824275312`*^9}, 
   3.69668892366024*^9, 3.696689334936253*^9, 3.696689963534178*^9, 
   3.696690289670549*^9, 3.696692600831484*^9, 3.696692746038089*^9, {
   3.696692802888487*^9, 3.696692819140151*^9}, 3.696692877323474*^9, 
   3.6966947394609118`*^9, 3.6967015062314215`*^9, 3.696703822338073*^9, 
   3.6969190748375673`*^9, 3.7448269076449747`*^9, 3.7448273333093214`*^9, 
   3.7448289244703307`*^9, 3.7969936363378973`*^9, 3.796993676274723*^9, 
   3.796993718323028*^9, 3.798424382001216*^9, 3.7986869737403*^9, 
   3.799038500598837*^9},ExpressionUUID->"b6b89216-10c3-424d-ac66-\
479ba5945a36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ApplyCWIs", "[", 
    RowBox[{
     RowBox[{"PrimaryCWIs", "[", "TTT", "]"}], ",", "As", ",", "Dims"}], 
    "]"}], "/.", "FullSolution"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.696663815739999*^9, 3.6966638232402067`*^9}, {
  3.696664136878702*^9, 3.696664149902071*^9}, {3.6966764316282177`*^9, 
  3.696676445171884*^9}, {3.696676584654389*^9, 3.696676603430434*^9}, {
  3.796993638763308*^9, 3.796993639787434*^9}, {3.7969936818302927`*^9, 
  3.796993682232759*^9}},ExpressionUUID->"3c3b405a-6dfa-4827-8d81-\
d35865754ebe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6966638234139338`*^9, 3.696664150172068*^9, 3.696676338962*^9, {
   3.696676440940804*^9, 3.696676445608027*^9}, {3.6966765850277843`*^9, 
   3.6966766037539797`*^9}, {3.696677651109548*^9, 3.696677663845582*^9}, 
   3.696678324960087*^9, 3.6966792013708477`*^9, {3.696684068482006*^9, 
   3.696684082890736*^9}, 3.696688925859529*^9, 3.696689335378479*^9, 
   3.696689964009571*^9, 3.69669029008694*^9, 3.696692604822192*^9, {
   3.6966927468247137`*^9, 3.696692838124413*^9}, {3.696692877837805*^9, 
   3.69669288591216*^9}, {3.696694742127984*^9, 3.6966947610567493`*^9}, 
   3.696694827826784*^9, 3.696694879294722*^9, {3.6967015064414215`*^9, 
   3.6967015089844265`*^9}, 3.696703823039113*^9, 3.696919076148986*^9, 
   3.744826909009053*^9, 3.744827334417385*^9, 3.7448289259194136`*^9, 
   3.796993640124404*^9, {3.796993676865592*^9, 3.796993682659018*^9}, 
   3.796993720084177*^9, 3.7984243820806227`*^9, 3.7986869738083043`*^9, 
   3.799038500656207*^9},ExpressionUUID->"dca511d7-c50d-424b-9eb0-\
9a25d42c3752"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SimplifyCWIs", "[", 
  RowBox[{"ApplyCWIs", "[", 
   RowBox[{
    RowBox[{"SecondaryCWIsLhs", "[", "TTT", "]"}], ",", "As", ",", "Dims"}], 
   "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyTWIs", "[", 
   RowBox[{"TTT", ",", "Dims"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.696676605902673*^9, 3.6966766107671432`*^9}, {
  3.6966770356294003`*^9, 3.696677043453857*^9}, {3.696677254737146*^9, 
  3.6966772912178926`*^9}, {3.696684086068306*^9, 3.6966840888764772`*^9}, {
  3.6966902221590433`*^9, 3.696690304039969*^9}, {3.6966928953364277`*^9, 
  3.696692914743807*^9}, {3.696692999505937*^9, 3.696693008918251*^9}, {
  3.6969190955387077`*^9, 3.696919103122005*^9}, {3.744827343805922*^9, 
  3.744827344030935*^9}, {3.796993723244172*^9, 
  3.7969937337240267`*^9}},ExpressionUUID->"2ed611d9-f6a8-461e-81c2-\
b33b395eb0cd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.696694885907452*^9, 3.696701509879428*^9, 
   3.6967038241491766`*^9, {3.6969190772425823`*^9, 3.696919103339509*^9}, {
   3.744827336112482*^9, 3.744827344542964*^9}, 3.7448289285785656`*^9, 
   3.796993734236*^9, 3.79842438218718*^9, 3.798686973856307*^9, 
   3.79903850070474*^9},ExpressionUUID->"6bddba67-b936-468d-b5ff-\
f98d1c671e6a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", 
   RowBox[{"32", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "cg"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cT", "[", "0", "]"}], "+", 
      RowBox[{"cT", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["p", "2", "2"], 
         SuperscriptBox["\[Mu]", "2"]], "]"}]}]}], ")"}], " ", 
    SubsuperscriptBox["p", "2", "4"]}], ",", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cT", "[", "0", "]"}], "+", 
       RowBox[{"cT", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["p", "2", "2"], 
          SuperscriptBox["\[Mu]", "2"]], "]"}]}]}], ")"}], " ", 
     SubsuperscriptBox["p", "2", "4"]}], "-", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cT", "[", "0", "]"}], "+", 
       RowBox[{"cT", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["p", "3", "2"], 
          SuperscriptBox["\[Mu]", "2"]], "]"}]}]}], ")"}], " ", 
     SubsuperscriptBox["p", "3", "4"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.696676604821599*^9, 3.696676611218294*^9}, {
   3.696677032759117*^9, 3.6966770436993723`*^9}, 3.6966772557302303`*^9, 
   3.696677291491214*^9, {3.696677653096038*^9, 3.696677664479432*^9}, 
   3.696678326019452*^9, 3.6966792037886257`*^9, {3.696684071047801*^9, 
   3.696684089116178*^9}, 3.696689343579805*^9, 3.696689964560713*^9, 
   3.696690184387495*^9, {3.69669022288431*^9, 3.696690304316018*^9}, {
   3.6966929055813007`*^9, 3.696692915632391*^9}, {3.696693002457663*^9, 
   3.696693009226214*^9}, 3.696694885907452*^9, 3.696701509879428*^9, 
   3.6967038241491766`*^9, {3.6969190772425823`*^9, 3.696919103339509*^9}, {
   3.744827336112482*^9, 3.744827344542964*^9}, 3.7448289285785656`*^9, 
   3.796993734236*^9, 3.79842438218718*^9, 3.798686973856307*^9, 
   3.799038500888289*^9},ExpressionUUID->"0610e273-88a5-41f9-a390-\
d3334bed2e6e"]
}, Open  ]],

Cell["\<\
The c[2,0] part of the solution is the redundant solution. c[5,1,1] is an \
asymmetric local solution, A[j] = 0, j=1,2,3,4, A[5] = c[5,1,1] p[1]^4.\
\>", "Text",
 CellChangeTimes->{{3.7448289628735275`*^9, 3.744829004424904*^9}, 
   3.796993744019664*^9},ExpressionUUID->"94dd3166-4be6-43ad-9181-\
5e78715993b9"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{920, 872},
WindowMargins->{{Automatic, -11}, {Automatic, 146}},
Magnification:>1.25 Inherited,
FrontEndVersion->"11.2 for Linux x86 (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 273, 6, 39, "Input",ExpressionUUID->"14421c1c-57e8-4218-bb57-d9d540f4628a"],
Cell[834, 28, 205, 4, 39, "Input",ExpressionUUID->"c2e79324-f909-450e-95ba-52618b29cd11"],
Cell[1042, 34, 182, 4, 39, "Input",ExpressionUUID->"ab2417f3-5435-41ee-8f05-92faa1c3bcfa"],
Cell[CellGroupData[{
Cell[1249, 42, 156, 3, 84, "Section",ExpressionUUID->"1f3612d0-22e2-42e8-a7f0-0c2d8e802e7a"],
Cell[1408, 47, 505, 15, 69, "Input",ExpressionUUID->"5bdee2b6-13eb-4650-a506-536006e7f2f7"],
Cell[1916, 64, 186, 3, 44, "Text",ExpressionUUID->"6dca54c3-3032-454a-810d-d42f45540f24"],
Cell[2105, 69, 1753, 52, 98, "Input",ExpressionUUID->"6006c93b-3e30-4949-9d0b-da04d735224d"],
Cell[3861, 123, 1000, 29, 69, "Input",ExpressionUUID->"d17054ad-5e10-45f6-89ca-f13acf7f4529"],
Cell[4864, 154, 200, 3, 44, "Text",ExpressionUUID->"40eab396-6e6e-458c-a67f-fbf069198059"],
Cell[5067, 159, 500, 13, 39, "Input",ExpressionUUID->"ba584ccf-c8a4-4895-9cee-20f5588dddc7"],
Cell[5570, 174, 487, 15, 39, "Input",ExpressionUUID->"1f593d72-d52e-4e44-aa99-9a72a1a34e8b"],
Cell[6060, 191, 1236, 34, 156, "Input",ExpressionUUID->"9089bb95-f89b-4d16-8f65-0446df494a62"],
Cell[7299, 227, 1358, 32, 98, "Input",ExpressionUUID->"49e7340b-1e0b-4fff-882b-debf6a116e38"],
Cell[8660, 261, 811, 20, 98, "Input",ExpressionUUID->"31c6f2d4-bfd3-454a-9886-fee78dec48ab"],
Cell[9474, 283, 2400, 62, 214, "Input",ExpressionUUID->"911f0882-1d84-4160-a8bd-a609ff159545"],
Cell[11877, 347, 411, 12, 44, "Text",ExpressionUUID->"da75c4c0-d852-45cc-a530-322cf0e6ebb8"],
Cell[12291, 361, 502, 15, 39, "Input",ExpressionUUID->"9b1c9588-da9e-47d1-974c-d98069d8c061"],
Cell[12796, 378, 4118, 127, 243, "Input",ExpressionUUID->"a7bd4255-d2cb-4964-8ee6-ded60df42a88"],
Cell[16917, 507, 151, 3, 44, "Text",ExpressionUUID->"80d99238-d9ab-4c7a-a4b7-8f609f87487e"],
Cell[17071, 512, 1578, 49, 127, "Input",ExpressionUUID->"a2370107-3466-4ff3-92f6-ca119716a189"],
Cell[18652, 563, 1115, 25, 98, "Input",ExpressionUUID->"fe395b7a-9395-4566-bf7c-3f7570fec166"]
}, Closed]],
Cell[CellGroupData[{
Cell[19804, 593, 203, 4, 65, "Section",ExpressionUUID->"42c7f3cc-eb5c-4c6f-b45d-7230e8f23871"],
Cell[CellGroupData[{
Cell[20032, 601, 223, 4, 68, "Subsection",ExpressionUUID->"606c999d-b12b-4657-94e8-277503ba5552"],
Cell[20258, 607, 1138, 29, 69, "Input",ExpressionUUID->"792d4662-4ff2-4a2e-8677-27a2f5f18fe0"],
Cell[CellGroupData[{
Cell[21421, 640, 190, 4, 39, "Input",ExpressionUUID->"4d67d8de-a3b1-454a-808c-2364bac5891a"],
Cell[21614, 646, 902, 15, 44, "Output",ExpressionUUID->"8ede1066-d241-4900-9379-e3a8509831eb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22553, 666, 643, 13, 69, "Input",ExpressionUUID->"826861a2-89e6-48d3-a464-8f337301f850"],
Cell[23199, 681, 6479, 171, 336, "Output",ExpressionUUID->"c86664e2-9c0b-4f32-904d-9770a56be4fc"],
Cell[29681, 854, 1322, 23, 44, "Output",ExpressionUUID->"8474b5d3-fd5a-431c-9f4b-d29fa2db4360"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31040, 882, 771, 19, 98, "Input",ExpressionUUID->"5d294889-21ee-40df-bd27-3d1561e2e5aa"],
Cell[31814, 903, 743, 17, 67, "Output",ExpressionUUID->"af15fc94-3edb-4aa3-a3c8-8156a3dba386"],
Cell[32560, 922, 792, 19, 67, "Output",ExpressionUUID->"bdff51da-0287-4e6a-b621-80b3b244eb1f"],
Cell[33355, 943, 516, 9, 44, "Output",ExpressionUUID->"dcf606d7-8fb5-4f10-b449-844570d942f0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33908, 957, 168, 3, 57, "Subsubsection",ExpressionUUID->"c11b6fdb-6d36-4485-bdd1-63c4b84f6ab4"],
Cell[34079, 962, 270, 6, 44, "Text",ExpressionUUID->"e28f5806-8724-49ca-912b-654b11955428"],
Cell[CellGroupData[{
Cell[34374, 972, 879, 24, 69, "Input",ExpressionUUID->"3c5a1c74-9fc0-4bd8-8855-42311963ec0c"],
Cell[35256, 998, 560, 10, 44, "Output",ExpressionUUID->"a5fdf699-6f85-4d47-8020-9a8ef77bf015"],
Cell[35819, 1010, 922, 22, 71, "Output",ExpressionUUID->"feee296c-476e-4426-9c06-09f3c0945729"]
}, Open  ]],
Cell[36756, 1035, 265, 6, 44, "Text",ExpressionUUID->"128286c2-b4d3-4bfa-8baa-49512600a6ca"],
Cell[CellGroupData[{
Cell[37046, 1045, 698, 13, 39, "Input",ExpressionUUID->"496c7953-4cee-4ee9-b33e-2d1f72220e8c"],
Cell[37747, 1060, 1366, 39, 71, "Output",ExpressionUUID->"f2d1d6bb-0759-417c-9ec4-86db735a9fbf"]
}, Open  ]],
Cell[39128, 1102, 159, 3, 44, "Text",ExpressionUUID->"5e11ae5f-aee0-473b-b16d-97a802bf6a33"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[39336, 1111, 170, 3, 47, "Subsection",ExpressionUUID->"7d206a98-72d1-4f7e-bc8c-446d46414c05"],
Cell[39509, 1116, 2041, 53, 214, "Input",ExpressionUUID->"d2e29670-b7d7-49d0-b76e-0175d7039cdd"],
Cell[CellGroupData[{
Cell[41575, 1173, 239, 5, 39, "Input",ExpressionUUID->"675662d1-dbd7-47e8-b47f-26cb3818991d"],
Cell[41817, 1180, 793, 13, 44, "Output",ExpressionUUID->"b98d6677-9833-47a2-91c9-a51772698ecd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42647, 1198, 501, 11, 39, "Input",ExpressionUUID->"6c06e8e5-d756-4704-80cb-4dcdee7ed653"],
Cell[43151, 1211, 905, 17, 44, "Output",ExpressionUUID->"34cf5070-af51-448f-af66-4c3a790fccb3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44093, 1233, 1041, 22, 98, "Input",ExpressionUUID->"e413af9d-2c47-488d-bd22-e3728cbe2f81"],
Cell[45137, 1257, 1142, 21, 48, "Output",ExpressionUUID->"dea9c500-3d2c-412a-8cfb-41517d188df5"],
Cell[46282, 1280, 1166, 22, 48, "Output",ExpressionUUID->"b0698444-a347-428f-9abc-b84a38303099"],
Cell[47451, 1304, 1013, 17, 48, "Output",ExpressionUUID->"61c0527f-a71d-44e7-bde1-03dc81373e3d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48501, 1326, 168, 3, 57, "Subsubsection",ExpressionUUID->"3684403e-4eea-433b-a861-c7caf2376d8d"],
Cell[48672, 1331, 268, 6, 44, "Text",ExpressionUUID->"3a39f067-7637-4b92-9973-e7b1009fd3a8"],
Cell[CellGroupData[{
Cell[48965, 1341, 797, 21, 69, "Input",ExpressionUUID->"46500e9d-70a2-4cca-919d-68d5c147ddaa"],
Cell[49765, 1364, 495, 8, 44, "Output",ExpressionUUID->"6598bb5c-b829-433a-bd61-016757115ad2"],
Cell[50263, 1374, 854, 21, 44, "Output",ExpressionUUID->"5af49365-9fe6-4dd4-b348-12b4a241ccf9"]
}, Open  ]],
Cell[51132, 1398, 212, 5, 44, "Text",ExpressionUUID->"cc2b340e-92e4-4e38-b5dd-0722cdcf39c0"],
Cell[CellGroupData[{
Cell[51369, 1407, 981, 23, 69, "Input",ExpressionUUID->"705d8fed-ec97-491c-8e78-db43f6a32f4e"],
Cell[52353, 1432, 1067, 30, 67, "Output",ExpressionUUID->"6bc2b96b-6c34-4269-aa03-43b4c0240bc1"],
Cell[53423, 1464, 640, 12, 28, "Message",ExpressionUUID->"15ab2c3d-75d2-4be5-9d66-f716e3767c4d"],
Cell[54066, 1478, 652, 15, 44, "Output",ExpressionUUID->"b441fb96-346d-4375-82fe-8f69d4730cbc"]
}, Open  ]],
Cell[54733, 1496, 235, 6, 44, "Text",ExpressionUUID->"7fdb4544-e2dc-4e90-a4b4-a523326a0a49"],
Cell[CellGroupData[{
Cell[54993, 1506, 1045, 25, 156, "Input",ExpressionUUID->"61f22a6f-c9c5-45d4-b7dd-fd130bbefcf1"],
Cell[56041, 1533, 512, 8, 44, "Output",ExpressionUUID->"4a93f370-1a28-4d28-9782-46dcafdf5815"],
Cell[56556, 1543, 689, 14, 48, "Output",ExpressionUUID->"d82a4132-e0ac-4899-b881-4ba4139e7f35"]
}, Open  ]],
Cell[57260, 1560, 322, 7, 73, "Text",ExpressionUUID->"600bac7f-f175-4e36-bec5-ed2000eff64f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[57631, 1573, 169, 3, 47, "Subsection",ExpressionUUID->"ca2d690f-ea1a-4918-8fe2-f13b48f3ac7d"],
Cell[57803, 1578, 1278, 36, 69, "Input",ExpressionUUID->"e50c20c7-8eec-40c8-9c92-2f080a2aeaac"],
Cell[CellGroupData[{
Cell[59106, 1618, 239, 5, 39, "Input",ExpressionUUID->"0d075e8f-b8d1-4a2d-9d6c-4d09524ba62b"],
Cell[59348, 1625, 692, 11, 44, "Output",ExpressionUUID->"fff682ab-5715-4507-b466-4616260b66f6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60077, 1641, 773, 15, 39, "Input",ExpressionUUID->"1febc738-e0ed-43ba-bf3f-60023e02df4f"],
Cell[60853, 1658, 1124, 20, 44, "Output",ExpressionUUID->"f90dfeeb-5109-433e-aa8f-e7446db00b45"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62014, 1683, 561, 11, 39, "Input",ExpressionUUID->"c7168f94-e8a8-4784-9898-1ae65d75e5c1"],
Cell[62578, 1696, 648, 13, 44, "Output",ExpressionUUID->"5d50fb03-ee4e-499a-adaf-56c37d7a8d8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63263, 1714, 437, 10, 39, "Input",ExpressionUUID->"ebd4afc8-5345-43a7-9397-2a4a17758d19"],
Cell[63703, 1726, 1199, 33, 48, "Output",ExpressionUUID->"b24e2998-9d35-4525-a20d-b511c6516039"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64939, 1764, 909, 23, 98, "Input",ExpressionUUID->"386d6399-5b1c-4668-b7a6-c2e307421274"],
Cell[65851, 1789, 1020, 26, 64, "Output",ExpressionUUID->"7a635bf3-df7c-4b32-b982-5ac69183d467"],
Cell[66874, 1817, 648, 14, 76, "Output",ExpressionUUID->"b322c25e-9297-4fc6-aa7f-ee6463d475fc"],
Cell[67525, 1833, 626, 14, 48, "Output",ExpressionUUID->"8b922651-9975-4a30-b0d8-b3f3a5f96328"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68188, 1852, 168, 3, 57, "Subsubsection",ExpressionUUID->"9adfb789-f4e9-40be-a0d0-e002e1d0cb0a"],
Cell[68359, 1857, 270, 6, 44, "Text",ExpressionUUID->"8c28a688-fa76-4ab8-8301-6c6025b3225a"],
Cell[CellGroupData[{
Cell[68654, 1867, 899, 24, 69, "Input",ExpressionUUID->"a9de90da-21b1-4876-8109-50c2ef2362f9"],
Cell[69556, 1893, 485, 9, 44, "Output",ExpressionUUID->"e2e193d8-fc23-4599-ac06-6f93fc0dbc0c"],
Cell[70044, 1904, 851, 21, 71, "Output",ExpressionUUID->"913cd982-3aee-4857-946c-a9903171daf5"]
}, Open  ]],
Cell[70910, 1928, 212, 5, 44, "Text",ExpressionUUID->"b76f5bec-ed73-406c-a21a-ff3eda84a0a4"],
Cell[CellGroupData[{
Cell[71147, 1937, 673, 13, 39, "Input",ExpressionUUID->"c1bcdd13-530d-4414-940e-4a2927c6b71d"],
Cell[71823, 1952, 1337, 39, 71, "Output",ExpressionUUID->"14bcef6d-d4aa-4da7-99b8-13a5030c1398"]
}, Open  ]],
Cell[73175, 1994, 251, 4, 44, "Text",ExpressionUUID->"5dc1269a-33a8-4e67-aa33-06efd9024ead"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[73475, 2004, 220, 4, 47, "Subsection",ExpressionUUID->"c22f1d71-6014-4622-957e-936d7c5bbb95"],
Cell[73698, 2010, 4287, 126, 301, "Input",ExpressionUUID->"6c480c7c-c233-4274-84b2-128755fca3f0"],
Cell[77988, 2138, 947, 24, 69, "Input",ExpressionUUID->"d7765540-5e1a-482c-94f0-57e643ce3152"],
Cell[CellGroupData[{
Cell[78960, 2166, 514, 13, 39, "Input",ExpressionUUID->"32f6bde3-6b80-46ee-b16f-56d2bae99a60"],
Cell[79477, 2181, 1472, 31, 87, "Output",ExpressionUUID->"85c9bcd9-ea0e-4f0e-ac49-af630b957f33"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80986, 2217, 1029, 24, 69, "Input",ExpressionUUID->"786d0829-29a0-44fb-851c-c823e389b233"],
Cell[82018, 2243, 1266, 23, 44, "Output",ExpressionUUID->"1ce99ebc-fbc8-4628-beb4-068866eeb5e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83321, 2271, 1909, 47, 185, "Input",ExpressionUUID->"b40e61bf-240f-495b-b87c-58092c86f010"],
Cell[85233, 2320, 2412, 53, 145, "Output",ExpressionUUID->"b1f8b30e-77e4-4724-8160-67e7003c0d5c"],
Cell[87648, 2375, 1652, 38, 75, "Output",ExpressionUUID->"e89c52b6-6d3c-40ac-bb16-0b6c539f8ffe"],
Cell[89303, 2415, 2453, 53, 133, "Output",ExpressionUUID->"bd28d4f5-b743-4998-a10a-1ca1912319ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91793, 2473, 168, 3, 57, "Subsubsection",ExpressionUUID->"04a3925b-1f40-4015-aa45-607eca545a67"],
Cell[91964, 2478, 268, 6, 44, "Text",ExpressionUUID->"9ddfaecd-b66b-4773-9a6b-965daa323c69"],
Cell[CellGroupData[{
Cell[92257, 2488, 1435, 39, 127, "Input",ExpressionUUID->"60cf211e-960f-40ea-a55b-eb50c0b5f47d"],
Cell[93695, 2529, 503, 8, 44, "Output",ExpressionUUID->"d3ee7e87-f091-4efc-8ad5-236f2ec06f8d"],
Cell[94201, 2539, 2754, 75, 134, "Output",ExpressionUUID->"07414189-1fc1-4c4a-8a04-a30fc1f3bb44"]
}, Open  ]],
Cell[96970, 2617, 212, 5, 44, "Text",ExpressionUUID->"ba7bf28c-344b-4cfd-bcd5-a4525f599453"],
Cell[CellGroupData[{
Cell[97207, 2626, 624, 12, 39, "Input",ExpressionUUID->"78bac6fc-5dbc-4f61-b58f-451db3754875"],
Cell[97834, 2640, 5790, 162, 468, "Output",ExpressionUUID->"ebf39a0e-8632-49b6-9bcf-be4e4521e3da"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103661, 2807, 774, 22, 98, "Input",ExpressionUUID->"d1fa7ade-4dc6-4edf-838d-8d8a1d279ca1"],
Cell[104438, 2831, 1404, 39, 74, "Output",ExpressionUUID->"04ae3770-6327-4a1d-9989-ce92a18512e0"],
Cell[105845, 2872, 500, 11, 44, "Output",ExpressionUUID->"09683a58-f1d7-48b7-bcb8-c076c5216f50"]
}, Open  ]],
Cell[106360, 2886, 235, 6, 44, "Text",ExpressionUUID->"27bf8fd6-2d90-48c1-be11-6d087cbe3669"],
Cell[CellGroupData[{
Cell[106620, 2896, 832, 18, 98, "Input",ExpressionUUID->"e740856c-60a3-40b8-bee4-4fdcda898da9"],
Cell[107455, 2916, 635, 13, 48, "Output",ExpressionUUID->"7c6cf647-63c7-42f9-85b9-99e0e1fdf32d"],
Cell[108093, 2931, 489, 8, 44, "Output",ExpressionUUID->"bfb130c9-21c0-4fee-b045-31e10a19d1ee"],
Cell[108585, 2941, 1299, 35, 75, "Output",ExpressionUUID->"59108bb3-d889-488d-90f7-8be94d15e39f"]
}, Open  ]],
Cell[109899, 2979, 372, 7, 73, "Text",ExpressionUUID->"1e23dac5-9335-439a-a0f3-b954f3e9bc80"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[110332, 2993, 150, 3, 84, "Section",ExpressionUUID->"f9914962-1785-4a25-a80e-25ca5e7dca8c"],
Cell[CellGroupData[{
Cell[110507, 3000, 172, 3, 68, "Subsection",ExpressionUUID->"875469da-9d5e-46f7-a508-a1a1ebebcdb4"],
Cell[110682, 3005, 1307, 33, 69, "Input",ExpressionUUID->"c7e0bb36-912d-4d78-a9eb-489c2fb1e84d"],
Cell[CellGroupData[{
Cell[112014, 3042, 190, 4, 39, "Input",ExpressionUUID->"74a6f5d0-85f2-4967-9903-994d452b37ff"],
Cell[112207, 3048, 632, 11, 44, "Output",ExpressionUUID->"e94fae19-5e90-4198-8317-4d6360212a5e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112876, 3064, 499, 11, 39, "Input",ExpressionUUID->"0c867bd8-904a-4138-9ed9-e0d6f89f0ff3"],
Cell[113378, 3077, 909, 17, 44, "Output",ExpressionUUID->"e16d68cf-bdf6-429c-a7e0-05ec1ea1db05"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114324, 3099, 988, 23, 98, "Input",ExpressionUUID->"d0e64291-2600-4092-94fd-c93e66a3fbdb"],
Cell[115315, 3124, 1073, 21, 67, "Output",ExpressionUUID->"40754541-f2da-4fe5-afc1-8ccd66151765"],
Cell[116391, 3147, 1073, 21, 67, "Output",ExpressionUUID->"4abf486c-e056-446b-9d27-4001d59aa036"],
Cell[117467, 3170, 890, 14, 44, "Output",ExpressionUUID->"685859ee-e175-4ede-8cfc-5988840c11b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118394, 3189, 168, 3, 57, "Subsubsection",ExpressionUUID->"4aeedcb1-e4ca-4392-9551-e7323c292148"],
Cell[118565, 3194, 268, 6, 44, "Text",ExpressionUUID->"ae74c350-f102-4bb3-b71c-6eb4d1f9c761"],
Cell[CellGroupData[{
Cell[118858, 3204, 993, 25, 69, "Input",ExpressionUUID->"e30706ac-b13f-4402-ab79-d577e726b536"],
Cell[119854, 3231, 547, 10, 44, "Output",ExpressionUUID->"91e03bb2-5038-4c6c-b5df-e19542e4e959"],
Cell[120404, 3243, 911, 22, 71, "Output",ExpressionUUID->"4b3407b3-c509-4a5d-a110-811a92923ef6"]
}, Open  ]],
Cell[121330, 3268, 212, 5, 44, "Text",ExpressionUUID->"314cac44-5eeb-4c4b-9d87-f27a1caa0b0e"],
Cell[CellGroupData[{
Cell[121567, 3277, 618, 12, 39, "Input",ExpressionUUID->"734f4c0e-18c8-4d3b-ba1d-b0d0f95a9053"],
Cell[122188, 3291, 1366, 39, 71, "Output",ExpressionUUID->"342ce93a-9e69-4d9a-b694-cd4f83039047"]
}, Open  ]],
Cell[123569, 3333, 259, 4, 44, "Text",ExpressionUUID->"3c329dfb-753a-4c7f-b1c6-427b828ac738"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[123877, 3343, 170, 3, 47, "Subsection",ExpressionUUID->"6868da7f-edc0-4a98-881b-3086c3b354ac"],
Cell[124050, 3348, 1363, 34, 69, "Input",ExpressionUUID->"dd03bc85-6b26-46f8-8d24-43c30e76c77d"],
Cell[CellGroupData[{
Cell[125438, 3386, 239, 5, 39, "Input",ExpressionUUID->"c1a4ac8b-2dc6-4802-bda9-7ff617e8e799"],
Cell[125680, 3393, 593, 10, 44, "Output",ExpressionUUID->"5a550cc4-d76d-494c-9d23-56a4f5870934"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126310, 3408, 499, 11, 39, "Input",ExpressionUUID->"5fb44c01-1d51-4205-b520-84d4ccb7704f"],
Cell[126812, 3421, 809, 16, 44, "Output",ExpressionUUID->"2a0a76de-86cb-4e08-8fd0-429246ceb5af"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127658, 3442, 895, 21, 98, "Input",ExpressionUUID->"b43260e6-ee48-4c13-b274-96edcb53c49b"],
Cell[128556, 3465, 897, 17, 48, "Output",ExpressionUUID->"58977d64-3b08-48e8-bd88-51cfdc8ca1fa"],
Cell[129456, 3484, 895, 17, 48, "Output",ExpressionUUID->"0f1cfb5a-0513-40f0-9a7b-a0beb6145610"],
Cell[130354, 3503, 742, 12, 44, "Output",ExpressionUUID->"56afde4d-7033-46a1-ad83-ffd16417a873"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131133, 3520, 168, 3, 57, "Subsubsection",ExpressionUUID->"6622eb63-21b3-4a77-b36a-5977f5252d2f"],
Cell[131304, 3525, 268, 6, 44, "Text",ExpressionUUID->"aa5cf9d5-2931-4ee6-b539-63282ba8a3ae"],
Cell[CellGroupData[{
Cell[131597, 3535, 898, 22, 69, "Input",ExpressionUUID->"f82bcfd6-e5c5-43f1-96c0-cda8bad436a9"],
Cell[132498, 3559, 525, 9, 44, "Output",ExpressionUUID->"eae0482b-e568-4dcf-9523-579c20c21e0b"],
Cell[133026, 3570, 885, 22, 44, "Output",ExpressionUUID->"18af0a82-4d9c-4b71-87fb-69fdfabc6ba7"]
}, Open  ]],
Cell[133926, 3595, 212, 5, 44, "Text",ExpressionUUID->"76b6b086-4ae0-4c1f-90d6-8d3f324890d1"],
Cell[CellGroupData[{
Cell[134163, 3604, 618, 12, 39, "Input",ExpressionUUID->"f2d3948f-712e-4c4b-8661-a28791f2f0f6"],
Cell[134784, 3618, 1390, 42, 67, "Output",ExpressionUUID->"63a71e92-b7ff-4177-99fe-580f105afa22"]
}, Open  ]],
Cell[136189, 3663, 256, 4, 44, "Text",ExpressionUUID->"ff29c2b2-02a1-44e0-8b40-8bd94c1fe820"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[136494, 3673, 169, 3, 47, "Subsection",ExpressionUUID->"0d683512-f14a-4128-8b8d-08d05fc1a5c9"],
Cell[136666, 3678, 1210, 35, 69, "Input",ExpressionUUID->"df1882dd-f2df-4f33-98cf-0767cf1e9a46"],
Cell[CellGroupData[{
Cell[137901, 3717, 239, 5, 39, "Input",ExpressionUUID->"4ad46ba8-9b21-4c45-acb9-e2ce891a55c9"],
Cell[138143, 3724, 534, 9, 44, "Output",ExpressionUUID->"cba9c727-a6b2-48b4-8da1-c8e28c141b12"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138714, 3738, 604, 12, 39, "Input",ExpressionUUID->"a9e481b2-0a61-4f61-9e89-c7a27ba89173"],
Cell[139321, 3752, 810, 16, 44, "Output",ExpressionUUID->"18261ead-1248-4682-9e47-683d81739cfe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140168, 3773, 1029, 24, 98, "Input",ExpressionUUID->"037d7f27-407e-4775-9f79-c14d43feaef4"],
Cell[141200, 3799, 822, 16, 64, "Output",ExpressionUUID->"103df170-194d-41b0-8a39-a936d1796454"],
Cell[142025, 3817, 841, 16, 76, "Output",ExpressionUUID->"3f37e6c0-0bcb-477f-bbcd-9f799aedb794"],
Cell[142869, 3835, 682, 11, 44, "Output",ExpressionUUID->"b297c6d5-9791-41c5-845e-3d0005690ea3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143588, 3851, 168, 3, 57, "Subsubsection",ExpressionUUID->"61e19532-ad30-4744-b022-ddbdbe0bedce"],
Cell[143759, 3856, 268, 6, 44, "Text",ExpressionUUID->"cbc0da49-0176-48d0-9085-1b25eff772f8"],
Cell[CellGroupData[{
Cell[144052, 3866, 943, 25, 69, "Input",ExpressionUUID->"3c6848df-e579-44f9-b26b-2f0b40a33a63"],
Cell[144998, 3893, 453, 8, 44, "Output",ExpressionUUID->"bb8fe89b-8161-4741-85c2-a263001f57b4"],
Cell[145454, 3903, 817, 20, 71, "Output",ExpressionUUID->"fc339e2c-c652-4cb3-8ae1-3db04dc988d1"]
}, Open  ]],
Cell[146286, 3926, 212, 5, 44, "Text",ExpressionUUID->"bc7724b5-6894-45b0-bc1f-c1658b8d02e5"],
Cell[CellGroupData[{
Cell[146523, 3935, 618, 12, 39, "Input",ExpressionUUID->"353a4222-d282-497a-b319-a146fa93c25e"],
Cell[147144, 3949, 1320, 38, 71, "Output",ExpressionUUID->"bf9f72fb-182a-47c7-80b8-18bc82f8882d"]
}, Open  ]],
Cell[148479, 3990, 255, 4, 44, "Text",ExpressionUUID->"9673afec-14da-4cb6-a9f9-7599cd8791a7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[148783, 4000, 220, 4, 47, "Subsection",ExpressionUUID->"3f17a921-3727-4e64-9d93-0726bce13c38"],
Cell[149006, 4006, 2545, 79, 185, "Input",ExpressionUUID->"e405dd56-0424-44d0-adc8-e1893e1fed23"],
Cell[151554, 4087, 994, 24, 69, "Input",ExpressionUUID->"4b1ce7f9-6a50-4aa5-a292-2a4b6602d7b3"],
Cell[CellGroupData[{
Cell[152573, 4115, 514, 13, 39, "Input",ExpressionUUID->"5f30dd93-1e3b-4d48-9a57-40a6be01f95d"],
Cell[153090, 4130, 879, 17, 48, "Output",ExpressionUUID->"7e35761b-aed2-49cb-acea-6b9aa217288a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154006, 4152, 1029, 24, 69, "Input",ExpressionUUID->"b1657f2e-4fac-406f-a8ec-182cc0cfd2f3"],
Cell[155038, 4178, 981, 18, 44, "Output",ExpressionUUID->"df18c0ab-c928-4f8d-b8da-64c1b4e3e04c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[156056, 4201, 682, 19, 69, "Input",ExpressionUUID->"6057404f-7323-4ca4-8170-e1f0696d6a4b"],
Cell[156741, 4222, 1408, 37, 81, "Output",ExpressionUUID->"68835e3e-3a95-429c-9ab6-6f874843c776"],
Cell[158152, 4261, 1056, 29, 75, "Output",ExpressionUUID->"b7796e91-ba66-40ca-9218-6e052bc6e60f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159245, 4295, 294, 7, 39, "Input",ExpressionUUID->"63eaedf7-5439-4298-93fb-41365efbcd20"],
Cell[159542, 4304, 562, 14, 48, "Output",ExpressionUUID->"46b150bd-276a-44b1-8a7d-fabb3a4635ab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160141, 4323, 168, 3, 57, "Subsubsection",ExpressionUUID->"fc63dda8-8f57-43dd-9ee0-33d48827b7e7"],
Cell[160312, 4328, 268, 6, 44, "Text",ExpressionUUID->"443d70d2-1059-47f5-a443-bd1d80a9e549"],
Cell[CellGroupData[{
Cell[160605, 4338, 1386, 39, 127, "Input",ExpressionUUID->"6142b1cf-f134-4e68-8484-3212b35c0cb8"],
Cell[161994, 4379, 430, 7, 70, "Output",ExpressionUUID->"8adf52c0-f15f-46ef-91a2-6f8cef26142b"],
Cell[162427, 4388, 2680, 74, 70, "Output",ExpressionUUID->"4d43aede-0741-4731-bc2e-b3059bbc1e8f"]
}, Open  ]],
Cell[165122, 4465, 212, 5, 53, "Text",ExpressionUUID->"394a3604-d39e-4ef9-be52-a6d01b5944a7"],
Cell[CellGroupData[{
Cell[165359, 4474, 701, 14, 39, "Input",ExpressionUUID->"8322fc61-be5a-4c10-af1f-b32d248dec3e"],
Cell[166063, 4490, 6561, 186, 485, "Output",ExpressionUUID->"4a524816-c477-414b-a1df-190800ca2b03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172661, 4681, 1396, 42, 160, "Input",ExpressionUUID->"99e1d7ea-5e86-4d5a-ae1c-2e8a4d8b4a7e"],
Cell[174060, 4725, 903, 25, 44, "Output",ExpressionUUID->"30b78035-dc86-41eb-b5bb-99f75b14d132"],
Cell[174966, 4752, 1999, 59, 103, "Output",ExpressionUUID->"d3444d30-0f49-4a06-ae8f-1f9a1e2e8341"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177002, 4816, 810, 23, 98, "Input",ExpressionUUID->"f0c2b35b-a661-4d1f-a6fe-4990604f4c08"],
Cell[177815, 4841, 1367, 40, 74, "Output",ExpressionUUID->"9d11c9c1-5a71-4741-af3e-af29b2053c20"]
}, Open  ]],
Cell[179197, 4884, 235, 6, 44, "Text",ExpressionUUID->"6b04955d-de0e-4878-aa98-bcc5516051cb"],
Cell[CellGroupData[{
Cell[179457, 4894, 758, 16, 127, "Input",ExpressionUUID->"d7b7379b-41b6-4da5-aa87-753a0feebb8c"],
Cell[180218, 4912, 624, 14, 48, "Output",ExpressionUUID->"a6cf0e5d-0228-46fa-aa96-925670dfd2fc"],
Cell[180845, 4928, 1246, 33, 75, "Output",ExpressionUUID->"53c1f94d-635f-4752-8f0c-213720dcb890"]
}, Open  ]],
Cell[182106, 4964, 501, 9, 102, "Text",ExpressionUUID->"ba1d5fbf-b705-4456-bf6d-8abb3abcc7e0"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[182668, 4980, 199, 4, 84, "Section",ExpressionUUID->"6744bcd3-37b3-47c7-8f7c-f5c3122efc2f"],
Cell[CellGroupData[{
Cell[182892, 4988, 172, 3, 68, "Subsection",ExpressionUUID->"c643a012-8ffb-444d-a8b6-e3f7b6f24319"],
Cell[183067, 4993, 1799, 47, 69, "Input",ExpressionUUID->"744db7f6-1452-42f7-92f4-3713fbcbcaaf"],
Cell[CellGroupData[{
Cell[184891, 5044, 190, 4, 39, "Input",ExpressionUUID->"363c7206-e291-44d0-abd5-031354ea89e6"],
Cell[185084, 5050, 539, 10, 44, "Output",ExpressionUUID->"b6744c62-7a5b-48b1-a45f-82ca3709770a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185660, 5065, 499, 11, 39, "Input",ExpressionUUID->"35a7ab3c-579b-4973-8afd-e0fed968ab71"],
Cell[186162, 5078, 889, 19, 44, "Output",ExpressionUUID->"ed9129e3-661a-4411-9442-525922e8ac0e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187088, 5102, 819, 18, 98, "Input",ExpressionUUID->"0d5b349f-a13d-4096-8f79-38c7b1b66587"],
Cell[187910, 5122, 816, 15, 67, "Output",ExpressionUUID->"b474b869-6d11-44b4-ae85-536a67d54b84"],
Cell[188729, 5139, 709, 11, 44, "Output",ExpressionUUID->"90818340-7142-4d48-b7c4-5ed4ff7954a2"],
Cell[189441, 5152, 797, 14, 67, "Output",ExpressionUUID->"de0fdff1-0d5e-41e4-8a9f-deb45efecaf8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190275, 5171, 168, 3, 57, "Subsubsection",ExpressionUUID->"08d27be6-1e95-458c-b97d-494a76ba096d"],
Cell[190446, 5176, 268, 6, 44, "Text",ExpressionUUID->"16c27a4a-e5a9-45a6-8b8d-c06a8070f312"],
Cell[CellGroupData[{
Cell[190739, 5186, 1318, 35, 98, "Input",ExpressionUUID->"34dd996e-0acc-4b40-90e3-65ef4f710ede"],
Cell[192060, 5223, 551, 10, 44, "Output",ExpressionUUID->"7b4508a4-1b2c-44c6-92e0-e68e114a1e0b"],
Cell[192614, 5235, 1297, 35, 71, "Output",ExpressionUUID->"f39414f5-b276-44d8-96ac-1eecd6babee5"]
}, Open  ]],
Cell[193926, 5273, 212, 5, 44, "Text",ExpressionUUID->"00b536af-a67b-4fd3-a689-93b316c71b15"],
Cell[CellGroupData[{
Cell[194163, 5282, 794, 15, 39, "Input",ExpressionUUID->"9aaf704e-52de-4402-b4cb-c9fe91a9f9bd"],
Cell[194960, 5299, 2925, 87, 189, "Output",ExpressionUUID->"bf0c8601-7f38-44fd-bd28-f0681125db2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197922, 5391, 677, 18, 98, "Input",ExpressionUUID->"492827f5-815b-4c11-9ab1-eefce9a58a6e"],
Cell[198602, 5411, 658, 17, 44, "Output",ExpressionUUID->"3ecea387-f6ba-4915-9669-b71f73a66b6f"],
Cell[199263, 5430, 478, 13, 44, "Output",ExpressionUUID->"7dff2000-db15-42e7-818d-6470754bdfb8"]
}, Open  ]],
Cell[199756, 5446, 235, 6, 44, "Text",ExpressionUUID->"7c05c533-11c8-45b3-a602-7b27dc160ea9"],
Cell[CellGroupData[{
Cell[200016, 5456, 751, 16, 127, "Input",ExpressionUUID->"7203198c-a5b9-441f-b2d8-30866a283f6d"],
Cell[200770, 5474, 542, 12, 67, "Output",ExpressionUUID->"82056588-9cd4-47eb-8dcb-d97137c7d36d"],
Cell[201315, 5488, 419, 7, 44, "Output",ExpressionUUID->"86710cde-d0f8-410a-ae83-650b7bfa7931"]
}, Open  ]],
Cell[201749, 5498, 634, 11, 131, "Text",ExpressionUUID->"3e3dd3fa-9410-4308-a708-310fd36e9070"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[202432, 5515, 170, 3, 47, "Subsection",ExpressionUUID->"a8e2ba60-e678-4130-8271-2e62d29b1f4b"],
Cell[202605, 5520, 1839, 49, 98, "Input",ExpressionUUID->"d15a3e0a-eaaf-4191-ab15-8f92e395f908"],
Cell[CellGroupData[{
Cell[204469, 5573, 239, 5, 39, "Input",ExpressionUUID->"d316aa4f-393a-408f-b147-6cc235b2af99"],
Cell[204711, 5580, 540, 10, 44, "Output",ExpressionUUID->"3ccbcae1-b942-48c5-916c-ae3431477633"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205288, 5595, 501, 11, 39, "Input",ExpressionUUID->"268602f1-e9c1-4ddf-8e7a-26e29f048951"],
Cell[205792, 5608, 821, 18, 44, "Output",ExpressionUUID->"bf04aadf-75dc-4eac-9b0c-42d29250fc77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[206650, 5631, 680, 14, 69, "Input",ExpressionUUID->"6243f0a3-3eef-485d-8f26-820a126bc0e5"],
Cell[207333, 5647, 631, 10, 44, "Output",ExpressionUUID->"2bf66dd5-3819-4eef-a455-492d6ab1c198"],
Cell[207967, 5659, 633, 10, 44, "Output",ExpressionUUID->"98af7799-7883-47d3-818c-bc6a5a4f4af7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208637, 5674, 168, 3, 57, "Subsubsection",ExpressionUUID->"eb5b7b56-6e28-4079-9def-325cddcbb60e"],
Cell[208808, 5679, 268, 6, 44, "Text",ExpressionUUID->"aeb1d4ba-6d0b-440c-9205-e791824c83fb"],
Cell[CellGroupData[{
Cell[209101, 5689, 1322, 35, 98, "Input",ExpressionUUID->"df523ff1-615c-4d80-b7c2-6d19a6dc0f27"],
Cell[210426, 5726, 598, 10, 44, "Output",ExpressionUUID->"40d5401e-1c81-44e1-8ce9-db85d67c842b"],
Cell[211027, 5738, 1322, 35, 67, "Output",ExpressionUUID->"0f576dc6-71b8-4160-8bf9-0afb6b9b3bd9"]
}, Open  ]],
Cell[212364, 5776, 212, 5, 44, "Text",ExpressionUUID->"0917fc43-dff4-483c-8ae7-4b50ae29895c"],
Cell[CellGroupData[{
Cell[212601, 5785, 796, 15, 39, "Input",ExpressionUUID->"834d29e2-c190-4dd4-a76f-c0ed1e72673f"],
Cell[213400, 5802, 2557, 78, 189, "Output",ExpressionUUID->"e2c9d85c-269b-4ba8-a1e8-a4088827f6e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215994, 5885, 657, 17, 69, "Input",ExpressionUUID->"8cc697ac-4971-4e51-b167-723f538ddf76"],
Cell[216654, 5904, 629, 15, 44, "Output",ExpressionUUID->"af17d518-352c-41ea-ba16-05ce36676535"],
Cell[217286, 5921, 524, 13, 44, "Output",ExpressionUUID->"783856c2-8e15-41c9-9e2b-3e31b07d1c4f"]
}, Open  ]],
Cell[217825, 5937, 235, 6, 44, "Text",ExpressionUUID->"08ce6bb4-bada-4218-975a-bb0a96fc74f1"],
Cell[CellGroupData[{
Cell[218085, 5947, 756, 16, 127, "Input",ExpressionUUID->"25f38d64-0bd1-4d8f-bbee-3a9e97268189"],
Cell[218844, 5965, 574, 12, 44, "Output",ExpressionUUID->"c8bcce63-12a3-422b-a9e0-50511ca2c2b3"],
Cell[219421, 5979, 469, 8, 44, "Output",ExpressionUUID->"5089e78d-b192-46cb-aa14-f01b08ff0edd"]
}, Open  ]],
Cell[219905, 5990, 435, 9, 44, "Text",ExpressionUUID->"d7988999-b95a-43f5-b077-9b1d92d84e63"],
Cell[220343, 6001, 2001, 52, 98, "Input",ExpressionUUID->"d15a3e0a-eaaf-4191-ab15-8f92e395f908"],
Cell[CellGroupData[{
Cell[222369, 6057, 239, 5, 39, "Input",ExpressionUUID->"d316aa4f-393a-408f-b147-6cc235b2af99"],
Cell[222611, 6064, 561, 10, 44, "Output",ExpressionUUID->"b2aa1e7a-a850-43ab-a296-4ee79a16d0b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[223209, 6079, 501, 11, 39, "Input",ExpressionUUID->"268602f1-e9c1-4ddf-8e7a-26e29f048951"],
Cell[223713, 6092, 841, 18, 44, "Output",ExpressionUUID->"4af0e45d-ac1a-401f-bdce-e7fd9c164fac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[224591, 6115, 682, 14, 69, "Input",ExpressionUUID->"6243f0a3-3eef-485d-8f26-820a126bc0e5"],
Cell[225276, 6131, 661, 11, 44, "Output",ExpressionUUID->"7727a7e8-65d0-4cab-a8c2-7354465ea88b"],
Cell[225940, 6144, 663, 11, 44, "Output",ExpressionUUID->"013c02ce-bd48-4e28-b1ae-ced3df18f4cc"]
}, Open  ]],
Cell[226618, 6158, 147, 3, 44, "Text",ExpressionUUID->"0325f17b-a1c3-4f58-8150-e851b1635ad8"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[226814, 6167, 169, 3, 47, "Subsection",ExpressionUUID->"1eea18bc-2e64-4c1c-9879-57d352a4c4d4"],
Cell[226986, 6172, 2129, 58, 127, "Input",ExpressionUUID->"b0d5ec4c-18ea-4e8a-89de-63e42c05154e"],
Cell[CellGroupData[{
Cell[229140, 6234, 239, 5, 39, "Input",ExpressionUUID->"97cde6f5-4cea-4bfc-91f6-cb3609dbab46"],
Cell[229382, 6241, 609, 12, 44, "Output",ExpressionUUID->"6ab775d8-20b0-47bd-aceb-3c4e0371cc7c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230028, 6258, 701, 13, 39, "Input",ExpressionUUID->"8fc5f08f-de5f-404e-abdb-4f2434140771"],
Cell[230732, 6273, 990, 20, 44, "Output",ExpressionUUID->"1be72725-ed48-416b-8fc4-2bdbec8e6d82"]
}, Open  ]],
Cell[CellGroupData[{
Cell[231759, 6298, 688, 14, 69, "Input",ExpressionUUID->"d2f86c00-89f3-41d3-9986-7a24d68d147e"],
Cell[232450, 6314, 935, 20, 44, "Output",ExpressionUUID->"8e811283-f610-46b0-8d1f-ddf4f27f7fec"],
Cell[233388, 6336, 660, 11, 44, "Output",ExpressionUUID->"e86b47d8-2ef3-410e-9358-28296829fbc8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[234085, 6352, 168, 3, 57, "Subsubsection",ExpressionUUID->"b903009a-22ab-4bf6-9f88-8d91b9b97eed"],
Cell[234256, 6357, 268, 6, 44, "Text",ExpressionUUID->"63dea736-4bb6-4535-8ce2-a36fef88fa49"],
Cell[CellGroupData[{
Cell[234549, 6367, 1380, 36, 98, "Input",ExpressionUUID->"13c0ddd6-1d7b-40e6-b9f8-f0febd3b1ff1"],
Cell[235932, 6405, 646, 11, 44, "Output",ExpressionUUID->"7258615b-33f4-4609-b6dd-76286a06aaaf"],
Cell[236581, 6418, 1545, 39, 113, "Output",ExpressionUUID->"3379321b-8a0d-44d6-b114-c7b25ac7e046"]
}, Open  ]],
Cell[238141, 6460, 212, 5, 44, "Text",ExpressionUUID->"0a4a4b6b-94fb-45de-a427-437f13cdfab1"],
Cell[CellGroupData[{
Cell[238378, 6469, 794, 15, 39, "Input",ExpressionUUID->"c6a51a1e-56bf-40ae-bae4-123929a9dd0c"],
Cell[239175, 6486, 3013, 89, 189, "Output",ExpressionUUID->"c0199a6a-2bd2-4442-96c0-179ea69cce92"]
}, Open  ]],
Cell[CellGroupData[{
Cell[242225, 6580, 776, 19, 98, "Input",ExpressionUUID->"3c0521dc-9ce3-4f44-87c7-04a2846790b7"],
Cell[243004, 6601, 729, 18, 44, "Output",ExpressionUUID->"14d164e4-7d65-4ce9-a805-6de161f2f8d6"],
Cell[243736, 6621, 548, 13, 44, "Output",ExpressionUUID->"bcd35cee-253f-424e-bf9e-513544c109fe"]
}, Open  ]],
Cell[244299, 6637, 235, 6, 44, "Text",ExpressionUUID->"d1bf059a-6d86-4155-b6d7-8f4749732328"],
Cell[CellGroupData[{
Cell[244559, 6647, 753, 16, 127, "Input",ExpressionUUID->"d25b184e-dbb6-4588-b43f-dae6546001d7"],
Cell[245315, 6665, 714, 16, 44, "Output",ExpressionUUID->"37e03318-f35b-4750-99bb-10ee53a19d67"],
Cell[246032, 6683, 493, 8, 44, "Output",ExpressionUUID->"c10ba27a-6acb-43c4-ac72-dabb6d5bb32a"]
}, Open  ]],
Cell[246540, 6694, 406, 6, 44, "Text",ExpressionUUID->"e25bb784-b685-4114-af4b-939b18ce46f3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[246995, 6706, 220, 4, 47, "Subsection",ExpressionUUID->"c8720ac8-845f-477d-861a-e49219549136"],
Cell[247218, 6712, 4038, 113, 272, "Input",ExpressionUUID->"9cc5556e-d5e7-4b39-aa7f-e39a276d1d2a"],
Cell[CellGroupData[{
Cell[251281, 6829, 365, 7, 39, "Input",ExpressionUUID->"e3313f07-ff52-401a-9c9f-5fb01158cd15"],
Cell[251649, 6838, 829, 18, 48, "Output",ExpressionUUID->"6432e5f1-c34d-4977-aac3-a84997773e4d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[252515, 6861, 697, 13, 39, "Input",ExpressionUUID->"f8ee9291-44e9-4ec2-a1a5-2cef1b1b84c3"],
Cell[253215, 6876, 1082, 23, 44, "Output",ExpressionUUID->"3c6565d7-e5dd-47e5-a70a-400863934d44"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254334, 6904, 764, 15, 69, "Input",ExpressionUUID->"5d35bb63-d5c6-4768-9d64-64e3e25608a2"],
Cell[255101, 6921, 631, 10, 44, "Output",ExpressionUUID->"92993499-f331-401e-9185-1277b3976cd5"],
Cell[255735, 6933, 631, 10, 44, "Output",ExpressionUUID->"aeb2e227-55c9-482a-8719-81b65144a7cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256403, 6948, 168, 3, 57, "Subsubsection",ExpressionUUID->"9a1f3a53-97a5-4112-ace8-e153ab23bf5c"],
Cell[256574, 6953, 268, 6, 44, "Text",ExpressionUUID->"b33b8c8e-1f65-4e27-9780-1ee8a8284514"],
Cell[CellGroupData[{
Cell[256867, 6963, 1906, 50, 127, "Input",ExpressionUUID->"079287f4-5c92-43b3-a405-ca5378991d5a"],
Cell[258776, 7015, 754, 12, 44, "Output",ExpressionUUID->"1237ed3c-95c4-498c-a7de-9d2ad6c8139e"],
Cell[259533, 7029, 3601, 95, 212, "Output",ExpressionUUID->"84e087ce-52cc-4ba3-8e94-b145f5368a28"]
}, Open  ]],
Cell[263149, 7127, 212, 5, 44, "Text",ExpressionUUID->"1d96bcb4-899c-4420-9d65-9d4c21a21574"],
Cell[CellGroupData[{
Cell[263386, 7136, 824, 15, 39, "Input",ExpressionUUID->"eb36f0c8-6121-45d5-b672-f6b4cb34912e"],
Cell[264213, 7153, 6931, 199, 552, "Output",ExpressionUUID->"060ba0df-4f1b-455c-a3eb-6b8f30960614"]
}, Open  ]],
Cell[CellGroupData[{
Cell[271181, 7357, 745, 19, 69, "Input",ExpressionUUID->"91633264-ea76-48af-8544-174f98d38a92"],
Cell[271929, 7378, 693, 16, 44, "Output",ExpressionUUID->"1cc0d4a6-e790-4378-b933-99aab5357696"],
Cell[272625, 7396, 5011, 143, 388, "Output",ExpressionUUID->"86d9925c-a33a-46bc-9794-7262fb8b8643"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277673, 7544, 1078, 32, 127, "Input",ExpressionUUID->"d5bc76e7-cdc0-4b83-af86-1f92de73a900"],
Cell[278754, 7578, 1027, 28, 74, "Output",ExpressionUUID->"1a8795c1-2665-48fa-9922-43d2ce50fb9b"],
Cell[279784, 7608, 1265, 39, 74, "Output",ExpressionUUID->"710fe454-5f19-454e-9029-1348b0c72585"]
}, Open  ]],
Cell[CellGroupData[{
Cell[281086, 7652, 912, 25, 156, "Input",ExpressionUUID->"a81da4d7-8c86-4dea-9b34-dff855fc4b62"],
Cell[282001, 7679, 747, 20, 44, "Output",ExpressionUUID->"3fec4c98-1d1b-4c62-9187-00e9cff0231c"],
Cell[282751, 7701, 1639, 47, 103, "Output",ExpressionUUID->"5928a0f3-1aa6-465d-b63e-c6f9b91c0cc2"],
Cell[284393, 7750, 556, 14, 44, "Output",ExpressionUUID->"9b4497d4-45ec-4f6d-8bfc-b7fee13a4d3e"]
}, Open  ]],
Cell[284964, 7767, 235, 6, 44, "Text",ExpressionUUID->"447ea9f3-b035-455b-9aae-36e787638e74"],
Cell[CellGroupData[{
Cell[285224, 7777, 751, 16, 127, "Input",ExpressionUUID->"6c466464-a524-4d02-b5c8-6c9fd4202d2c"],
Cell[285978, 7795, 2646, 72, 145, "Output",ExpressionUUID->"4bb73de9-435a-4ca3-ae18-6f42a5985cd2"],
Cell[288627, 7869, 568, 9, 44, "Output",ExpressionUUID->"b57e3df2-a9d1-479e-ae46-e87ba9ec533c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289232, 7883, 1047, 30, 127, "Input",ExpressionUUID->"dad1e519-158d-4918-b1e6-3c45bc00136a"],
Cell[290282, 7915, 1680, 49, 103, "Output",ExpressionUUID->"f531a147-080f-47ad-8dfe-f5ea175c9dd5"],
Cell[291965, 7966, 447, 10, 48, "Output",ExpressionUUID->"6b8c824f-4d06-4c6a-9397-bd2731ea4f69"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292449, 7981, 211, 4, 39, "Input",ExpressionUUID->"8d11acec-2691-46a1-b159-9498fa5b5974"],
Cell[292663, 7987, 863, 24, 48, "Output",ExpressionUUID->"818a11ca-c999-4780-9da8-411377381c2c"]
}, Open  ]],
Cell[293541, 8014, 727, 12, 73, "Text",ExpressionUUID->"bfdc3488-68d3-4e1c-bf6a-39e9c7fca7f7"],
Cell[294271, 8028, 1135, 24, 69, "Input",ExpressionUUID->"9cc5556e-d5e7-4b39-aa7f-e39a276d1d2a"],
Cell[CellGroupData[{
Cell[295431, 8056, 365, 7, 39, "Input",ExpressionUUID->"e3313f07-ff52-401a-9c9f-5fb01158cd15"],
Cell[295799, 8065, 698, 12, 44, "Output",ExpressionUUID->"61e072da-6060-4912-be2a-8f6b85b6e3a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[296534, 8082, 697, 13, 39, "Input",ExpressionUUID->"f8ee9291-44e9-4ec2-a1a5-2cef1b1b84c3"],
Cell[297234, 8097, 1084, 22, 44, "Output",ExpressionUUID->"f804caf7-fa4d-4b88-b89f-4d3aa5e64b20"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298355, 8124, 764, 15, 69, "Input",ExpressionUUID->"5d35bb63-d5c6-4768-9d64-64e3e25608a2"],
Cell[299122, 8141, 685, 11, 44, "Output",ExpressionUUID->"74ac94ea-93b4-49c3-bdfe-1cf574796fef"],
Cell[299810, 8154, 685, 11, 44, "Output",ExpressionUUID->"e241bc30-73b7-48e3-8245-af9e18c459df"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[300568, 8173, 246, 4, 84, "Section",ExpressionUUID->"a977d338-a959-4424-918f-2e887bba4fe0"],
Cell[CellGroupData[{
Cell[300839, 8181, 172, 3, 68, "Subsection",ExpressionUUID->"6174f6c4-6463-412c-8104-38e2a7b41c3b"],
Cell[301014, 8186, 3576, 98, 185, "Input",ExpressionUUID->"f063aedf-d3ae-43a6-a8e6-8262773db74f"],
Cell[CellGroupData[{
Cell[304615, 8288, 351, 9, 39, "Input",ExpressionUUID->"b0170095-b8f9-401b-9c95-9a746cd9736a"],
Cell[304969, 8299, 652, 15, 44, "Output",ExpressionUUID->"82aac1a5-661f-442d-8801-dbf288c1770f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305658, 8319, 727, 17, 98, "Input",ExpressionUUID->"df2cd2f8-4afc-4ce1-9777-cda464f21bd9"],
Cell[306388, 8338, 763, 13, 44, "Output",ExpressionUUID->"54aabff7-a449-43c0-b635-e3a76c497bdc"],
Cell[307154, 8353, 765, 13, 44, "Output",ExpressionUUID->"dfdc7af2-911e-4b2c-8191-3e90600f64b3"],
Cell[307922, 8368, 765, 13, 44, "Output",ExpressionUUID->"9ddd3e2f-eb92-4ecc-8611-d1abc1b825cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[308724, 8386, 168, 3, 57, "Subsubsection",ExpressionUUID->"1e18cf65-5fd7-4120-a56b-705f81e7dbca"],
Cell[308895, 8391, 268, 6, 44, "Text",ExpressionUUID->"4ca147fd-455e-47d0-a64a-e8a8605f2660"],
Cell[CellGroupData[{
Cell[309188, 8401, 1903, 50, 127, "Input",ExpressionUUID->"b5ac24a1-5beb-462b-8a4f-253418b396c0"],
Cell[311094, 8453, 890, 14, 44, "Output",ExpressionUUID->"e4274623-db4a-4896-8f47-66a469bf90cf"],
Cell[311987, 8469, 1996, 51, 125, "Output",ExpressionUUID->"a05764a2-5224-4d76-9778-faee4e471608"]
}, Open  ]],
Cell[313998, 8523, 212, 5, 44, "Text",ExpressionUUID->"f753994a-18e3-46ce-a3ef-a194c23c9213"],
Cell[CellGroupData[{
Cell[314235, 8532, 875, 16, 39, "Input",ExpressionUUID->"96f8c343-b9ee-4509-832c-2860be69ef68"],
Cell[315113, 8550, 4552, 142, 295, "Output",ExpressionUUID->"0e918b22-1748-4d93-b878-d8a969f41100"]
}, Open  ]],
Cell[CellGroupData[{
Cell[319702, 8697, 1086, 28, 127, "Input",ExpressionUUID->"f50e1cf4-294e-4fe4-bce8-e45bb9b1eedd"],
Cell[320791, 8727, 1076, 25, 44, "Output",ExpressionUUID->"fcdf939a-939b-4adf-a4c5-4267c3d035d9"],
Cell[321870, 8754, 1256, 33, 67, "Output",ExpressionUUID->"5d124133-6a4d-4213-a516-30c80dd25cc2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323163, 8792, 612, 17, 69, "Input",ExpressionUUID->"39131c66-2839-4a20-adc9-56f28b3adf8e"],
Cell[323778, 8811, 961, 25, 74, "Output",ExpressionUUID->"aa225c9b-61b6-4cb2-bdf7-8c18c59a7897"],
Cell[324742, 8838, 546, 13, 44, "Output",ExpressionUUID->"8ba3e42f-d9cc-42db-bdc9-392b938f8099"]
}, Open  ]],
Cell[325303, 8854, 235, 6, 44, "Text",ExpressionUUID->"c0680935-94ae-4025-a029-aecef9375f28"],
Cell[CellGroupData[{
Cell[325563, 8864, 133, 1, 39, "Input",ExpressionUUID->"d6d0f10c-6529-4139-b126-3d0ce6bd6e6a"],
Cell[325699, 8867, 709, 20, 67, "Output",ExpressionUUID->"046f0555-6201-4235-8dae-4d0ced64451d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326445, 8892, 751, 16, 127, "Input",ExpressionUUID->"2054a5fe-17b3-4e37-be88-f59ffe254d35"],
Cell[327199, 8910, 1185, 30, 74, "Output",ExpressionUUID->"9bcc8288-871f-47fa-8445-012290a929c2"],
Cell[328387, 8942, 635, 11, 44, "Output",ExpressionUUID->"b7d6ad58-2cd1-4f55-976f-024f882648f1"]
}, Open  ]],
Cell[329037, 8956, 233, 6, 44, "Text",ExpressionUUID->"ff92fe21-1723-4704-a5df-cce339a4645a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[329319, 8968, 170, 3, 47, "Subsection",ExpressionUUID->"28952264-c3d3-4418-8407-ea6486283726"],
Cell[329492, 8973, 3619, 96, 243, "Input",ExpressionUUID->"a505a2a4-b5b3-49a5-aa7e-f50f1e0507c8"],
Cell[CellGroupData[{
Cell[333136, 9073, 239, 5, 39, "Input",ExpressionUUID->"659a1993-fe92-4afb-a8b1-bac38641a458"],
Cell[333378, 9080, 570, 10, 44, "Output",ExpressionUUID->"5eee65f3-17c8-435f-be01-ba819bac00a9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[333985, 9095, 499, 11, 39, "Input",ExpressionUUID->"9b52ee7c-7549-4740-ba22-ffac3ae9b929"],
Cell[334487, 9108, 867, 18, 44, "Output",ExpressionUUID->"c69cd856-a068-4ba7-a65b-becc7ce3b896"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335391, 9131, 585, 13, 69, "Input",ExpressionUUID->"9be87307-5c02-4540-95c3-ecf2581863fa"],
Cell[335979, 9146, 740, 13, 48, "Output",ExpressionUUID->"9b560262-9e91-4cbc-ba9c-ececfdf5512d"],
Cell[336722, 9161, 655, 11, 44, "Output",ExpressionUUID->"e478b8d1-c2a1-406b-acdb-57aeb9d7584a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337414, 9177, 263, 6, 39, "Input",ExpressionUUID->"43817390-5de5-4063-88f2-d9e17105d7ae"],
Cell[337680, 9185, 2401, 67, 227, "Output",ExpressionUUID->"eabe4ebd-dd51-4696-9e98-114330a81f89"]
}, Open  ]],
Cell[340096, 9255, 1939, 63, 214, "Input",ExpressionUUID->"ee86a0ba-8ac4-4c71-965e-80a353aa3180"],
Cell[CellGroupData[{
Cell[342060, 9322, 672, 22, 69, "Input",ExpressionUUID->"6e518317-918f-48c2-8de9-a52d3121fdb3"],
Cell[342735, 9346, 319, 5, 44, "Output",ExpressionUUID->"cf514c1b-0795-4baa-8287-79121a17ec60"],
Cell[343057, 9353, 321, 5, 44, "Output",ExpressionUUID->"152161fe-1b15-4ef9-b913-d2a75c295dc2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343415, 9363, 168, 3, 57, "Subsubsection",ExpressionUUID->"f2604ca9-be2e-4d46-8c90-4dec0a84bba7"],
Cell[343586, 9368, 268, 6, 44, "Text",ExpressionUUID->"208d28c5-054c-46a6-8388-63bb35ee07aa"],
Cell[CellGroupData[{
Cell[343879, 9378, 1901, 50, 127, "Input",ExpressionUUID->"281df248-7e6b-44c4-8275-c66427b855ce"],
Cell[345783, 9430, 888, 14, 44, "Output",ExpressionUUID->"1853b96d-9d21-4b0d-b4c6-abb9ee0eb58c"],
Cell[346674, 9446, 2000, 51, 107, "Output",ExpressionUUID->"45b078b1-880a-45dc-81d2-ba867fce2020"]
}, Open  ]],
Cell[348689, 9500, 212, 5, 44, "Text",ExpressionUUID->"15750ecf-c96d-416b-b651-f53b9d156b95"],
Cell[CellGroupData[{
Cell[348926, 9509, 875, 16, 39, "Input",ExpressionUUID->"b09db85d-8494-4a2a-a6fe-893dcbb329a5"],
Cell[349804, 9527, 3823, 121, 70, "Output",ExpressionUUID->"c83a874f-decd-454d-bdce-2f033309113d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353664, 9653, 988, 24, 190, "Input",ExpressionUUID->"e9887645-686e-46e4-b465-43b4acc74e27"],
Cell[354655, 9679, 938, 21, 70, "Output",ExpressionUUID->"1890ec5b-8abb-4679-ab6c-9ffeea1a7076"],
Cell[355596, 9702, 1246, 33, 70, "Output",ExpressionUUID->"cccc1d2f-d5c1-4f30-a3f8-49ae370e982a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[356879, 9740, 604, 15, 133, "Input",ExpressionUUID->"d7c15d7d-783b-43f4-838f-1f7b004e3f09"],
Cell[357486, 9757, 770, 19, 70, "Output",ExpressionUUID->"60b42e48-2e3f-4a49-aea6-67e32646823c"],
Cell[358259, 9778, 549, 13, 70, "Output",ExpressionUUID->"569b5a67-0b04-4fa1-939b-ab5a2bb6a1eb"]
}, Open  ]],
Cell[358823, 9794, 235, 6, 44, "Text",ExpressionUUID->"e15d9433-5c83-4283-8699-3fa42109bb47"],
Cell[CellGroupData[{
Cell[359083, 9804, 750, 16, 127, "Input",ExpressionUUID->"f749e283-303b-4c78-a22e-0be9d2a538fc"],
Cell[359836, 9822, 955, 21, 48, "Output",ExpressionUUID->"20c40747-5087-4a61-a441-febecff73370"],
Cell[360794, 9845, 661, 11, 44, "Output",ExpressionUUID->"0919fdd1-70ef-49b5-bd4f-45d6d5503dbc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361492, 9861, 768, 21, 127, "Input",ExpressionUUID->"2bb2e9a6-8467-4e54-a79b-fbb4cc94b539"],
Cell[362263, 9884, 911, 23, 74, "Output",ExpressionUUID->"d376bf0a-ef3f-4e2c-af47-003f0f7dbfcc"],
Cell[363177, 9909, 645, 16, 48, "Output",ExpressionUUID->"ae4d8cba-7cf3-49c4-890a-66e1d61f71de"]
}, Open  ]],
Cell[363837, 9928, 298, 7, 44, "Text",ExpressionUUID->"82ca8632-23e3-4924-8d01-4d13f69943e9"],
Cell[364138, 9937, 1298, 27, 69, "Input",ExpressionUUID->"a505a2a4-b5b3-49a5-aa7e-f50f1e0507c8"],
Cell[CellGroupData[{
Cell[365461, 9968, 239, 5, 39, "Input",ExpressionUUID->"659a1993-fe92-4afb-a8b1-bac38641a458"],
Cell[365703, 9975, 620, 11, 44, "Output",ExpressionUUID->"02b0e89f-7c65-4d85-ba90-ff2482742395"]
}, Open  ]],
Cell[CellGroupData[{
Cell[366360, 9991, 499, 11, 39, "Input",ExpressionUUID->"9b52ee7c-7549-4740-ba22-ffac3ae9b929"],
Cell[366862, 10004, 915, 19, 44, "Output",ExpressionUUID->"a8b6d475-3652-49b1-846a-472242aa9d2e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367814, 10028, 587, 13, 69, "Input",ExpressionUUID->"9be87307-5c02-4540-95c3-ecf2581863fa"],
Cell[368404, 10043, 708, 12, 44, "Output",ExpressionUUID->"998453a0-4f6f-4601-9a81-480c27978d95"],
Cell[369115, 10057, 708, 12, 44, "Output",ExpressionUUID->"a2c982b5-f088-4e9d-b9d7-845825a320be"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[369884, 10076, 169, 3, 47, "Subsection",ExpressionUUID->"edf8f951-96cf-45d2-b861-4f6bf920cf5e"],
Cell[370056, 10081, 1714, 49, 98, "Input",ExpressionUUID->"33faba58-1476-4957-b526-41ebf8477915"],
Cell[371773, 10132, 4934, 139, 330, "Input",ExpressionUUID->"719f5baa-1bd9-4c44-92b2-99c6d7fd5e39"],
Cell[CellGroupData[{
Cell[376732, 10275, 239, 5, 39, "Input",ExpressionUUID->"508c3e96-90df-4256-af05-581bb9679cda"],
Cell[376974, 10282, 689, 12, 44, "Output",ExpressionUUID->"5715a33e-e8f8-4e42-853d-b53620db7f5b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377700, 10299, 747, 14, 39, "Input",ExpressionUUID->"6018e081-a1eb-4374-bde6-94344d04e490"],
Cell[378450, 10315, 1136, 22, 44, "Output",ExpressionUUID->"700c992e-88bf-4611-82ba-3f57b63182bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[379623, 10342, 876, 18, 69, "Input",ExpressionUUID->"1effed3f-c0a0-4afc-b6c4-63517f67ddb4"],
Cell[380502, 10362, 901, 15, 44, "Output",ExpressionUUID->"d8385fbb-4320-4939-bc70-c55f6e48c1c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381440, 10382, 420, 13, 39, "Input",ExpressionUUID->"f387cc7e-274e-44c4-b5a3-7ecf98e6e49b"],
Cell[381863, 10397, 497, 15, 48, "Output",ExpressionUUID->"bf1d17b8-5ee4-4087-92fd-9d239a9cbf65"]
}, Open  ]],
Cell[CellGroupData[{
Cell[382397, 10417, 168, 3, 57, "Subsubsection",ExpressionUUID->"2ac2a2a9-e350-410f-845f-3632190e0d6e"],
Cell[382568, 10422, 268, 6, 44, "Text",ExpressionUUID->"9de44be7-9c6b-4bd2-97bd-539c5763b9a3"],
Cell[CellGroupData[{
Cell[382861, 10432, 2527, 66, 156, "Input",ExpressionUUID->"a0cb4336-e7c1-40d6-9902-b07bb99f5b1e"],
Cell[385391, 10500, 965, 15, 44, "Output",ExpressionUUID->"9b9b37e2-8a4e-4acf-bbf0-9a8a0bc7b6d8"],
Cell[386359, 10517, 4210, 110, 230, "Output",ExpressionUUID->"765ec9cc-c988-4366-b3d4-ed56af41e471"]
}, Open  ]],
Cell[390584, 10630, 212, 5, 44, "Text",ExpressionUUID->"09a78886-b366-465f-a416-f64a37fa065e"],
Cell[CellGroupData[{
Cell[390821, 10639, 898, 16, 39, "Input",ExpressionUUID->"60f0bfb0-a4e9-4c69-b9ad-6ecc7ac4589e"],
Cell[391722, 10657, 9302, 273, 684, "Output",ExpressionUUID->"b5527223-cda3-401b-8fa6-392639dd10b6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[401061, 10935, 988, 24, 98, "Input",ExpressionUUID->"5afe4fe7-fb53-4552-9a7c-1d67d5a37872"],
Cell[402052, 10961, 1008, 22, 44, "Output",ExpressionUUID->"07283327-08cb-496a-9714-a1c6072c74d2"],
Cell[403063, 10985, 1318, 34, 67, "Output",ExpressionUUID->"3b5ccbfe-646e-4fa2-b863-317ccb4ad71d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[404418, 11024, 1937, 51, 214, "Input",ExpressionUUID->"c02f5433-831a-4551-b443-172593a6e663"],
Cell[406358, 11077, 492, 9, 44, "Output",ExpressionUUID->"a01330e3-6340-427a-afc6-5ed36cf6735b"],
Cell[406853, 11088, 1533, 40, 134, "Output",ExpressionUUID->"a5f13a68-2d98-4fe5-87a7-720a313ab292"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408423, 11133, 2654, 72, 272, "Input",ExpressionUUID->"56a5df82-f768-4455-8b2d-cd2e9d6ad545"],
Cell[411080, 11207, 579, 12, 28, "Message",ExpressionUUID->"b9dbb976-59df-4031-bf5a-cc6864dd1a40"],
Cell[411662, 11221, 482, 10, 44, "Output",ExpressionUUID->"2c99dd9e-92df-4281-9a5a-8b8bfd8cde69"],
Cell[412147, 11233, 1461, 39, 134, "Output",ExpressionUUID->"143a1a07-be38-4bd8-a3b5-0bdb115a573d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[413645, 11277, 413, 10, 98, "Input",ExpressionUUID->"8fd02cba-a71c-49a8-a95f-d4b45f35ff48"],
Cell[414061, 11289, 769, 19, 44, "Output",ExpressionUUID->"31630bb2-38fb-4c7b-a85a-bd663f7ee9b7"]
}, Open  ]],
Cell[414845, 11311, 235, 6, 44, "Text",ExpressionUUID->"7cdbb024-47e9-4fa5-8dbb-b354029cf3c0"],
Cell[CellGroupData[{
Cell[415105, 11321, 750, 16, 127, "Input",ExpressionUUID->"1bba32e2-f4e0-4d20-8fc4-c63ff2790cd0"],
Cell[415858, 11339, 3871, 102, 208, "Output",ExpressionUUID->"e19d4bb7-4a12-43bc-a209-ec667e7952f2"],
Cell[419732, 11443, 687, 12, 44, "Output",ExpressionUUID->"7c2ca168-c8e2-4307-9ce6-8b5e6437e97e"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[420480, 11462, 220, 4, 47, "Subsection",ExpressionUUID->"822bd6b9-ba7a-48d4-9435-59adb022172b"],
Cell[420703, 11468, 7358, 217, 400, "Input",ExpressionUUID->"fc4e3916-2c91-4435-8f25-f557d2b05b67"],
Cell[428064, 11687, 1590, 39, 98, "Input",ExpressionUUID->"1a802061-9805-4ce1-ad3f-ef7d30566b32"],
Cell[CellGroupData[{
Cell[429679, 11730, 442, 9, 39, "Input",ExpressionUUID->"f904990e-81bb-4c5e-9fd5-8ed8f2441592"],
Cell[430124, 11741, 1474, 34, 48, "Output",ExpressionUUID->"498cb64d-6dbe-4bda-af9b-c777c1cede91"]
}, Open  ]],
Cell[CellGroupData[{
Cell[431635, 11780, 545, 14, 69, "Input",ExpressionUUID->"1d0a3201-2413-43b7-95ab-000d2df75db0"],
Cell[432183, 11796, 283, 5, 44, "Output",ExpressionUUID->"3730aa24-f59f-4a86-847c-4624175d842a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[432503, 11806, 454, 8, 39, "Input",ExpressionUUID->"82c7bcb1-bfb8-43c9-abac-d4d3b6ffef40"],
Cell[432960, 11816, 1699, 46, 121, "Output",ExpressionUUID->"4ea374f6-b2f5-4e6d-9c22-d2975ea5ca83"]
}, Open  ]],
Cell[CellGroupData[{
Cell[434696, 11867, 443, 10, 39, "Input",ExpressionUUID->"b3032765-6ac2-469a-ae2a-9a56a1087308"],
Cell[435142, 11879, 803, 21, 72, "Output",ExpressionUUID->"b9bd2ef4-7200-4704-be90-9e10f34d11d9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[435982, 11905, 559, 16, 69, "Input",ExpressionUUID->"1743c08d-5100-4aee-b4cb-8b51cffeccf9"],
Cell[436544, 11923, 421, 11, 64, "Output",ExpressionUUID->"0dea6558-aa0d-4557-b829-3b572ecbec8a"],
Cell[436968, 11936, 1179, 32, 48, "Output",ExpressionUUID->"74283e6e-0240-4a38-a60a-62824b543717"]
}, Open  ]],
Cell[CellGroupData[{
Cell[438184, 11973, 358, 9, 69, "Input",ExpressionUUID->"0b9e4f78-7736-43c0-80d9-1e5908588ddf"],
Cell[438545, 11984, 956, 27, 48, "Output",ExpressionUUID->"e5301b5c-592c-4b5a-be32-1c2579a5b02e"],
Cell[439504, 12013, 420, 9, 48, "Output",ExpressionUUID->"30bab3f6-686a-4686-8bb6-e9e33278f915"]
}, Open  ]],
Cell[CellGroupData[{
Cell[439961, 12027, 168, 3, 57, "Subsubsection",ExpressionUUID->"0de42ee0-5d1e-4746-bacf-78b90c4c6b78"],
Cell[440132, 12032, 268, 6, 44, "Text",ExpressionUUID->"9f5cb12f-93a7-412d-ba04-48417e7e0b82"],
Cell[CellGroupData[{
Cell[440425, 12042, 3317, 89, 185, "Input",ExpressionUUID->"9c48edee-8b6e-49f2-a960-ea4850eb30b5"],
Cell[443745, 12133, 948, 14, 44, "Output",ExpressionUUID->"c7b9f239-2e50-4cde-b97d-3e39e1031484"],
Cell[444696, 12149, 9285, 245, 524, "Output",ExpressionUUID->"52a0c260-184d-4249-902b-2821919ff503"]
}, Open  ]],
Cell[453996, 12397, 212, 5, 44, "Text",ExpressionUUID->"2d202777-9e50-4935-b75c-d6750adadba3"],
Cell[CellGroupData[{
Cell[454233, 12406, 877, 16, 39, "Input",ExpressionUUID->"b4c4c86b-2e00-481c-8889-113414158fb5"],
Cell[455113, 12424, 27157, 731, 2151, "Output",ExpressionUUID->"521e123a-7de4-4d2b-9928-725fad772c6a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[482307, 13160, 945, 22, 69, "Input",ExpressionUUID->"169a9726-9180-42a9-ad13-6a0395c1f8f3"],
Cell[483255, 13184, 868, 18, 44, "Output",ExpressionUUID->"0736e891-a87e-42f8-ac0e-794661f31086"],
Cell[484126, 13204, 25850, 689, 2072, "Output",ExpressionUUID->"fb0df2b4-4a38-4b08-823e-00b70f39800b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510013, 13898, 8954, 251, 591, "Input",ExpressionUUID->"2f2d4353-8745-4395-a6cb-d7f45ffc0b80"],
Cell[518970, 14151, 9474, 285, 712, "Output",ExpressionUUID->"48158703-77f2-4612-99ef-02c9362fca2e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[528481, 14441, 2061, 53, 165, "Input",ExpressionUUID->"fdbd3323-0756-471e-98b2-e6a08ceabfbc"],
Cell[530545, 14496, 496, 10, 70, "Message",ExpressionUUID->"2718438d-2cfb-4333-90db-427b416a5bdc"],
Cell[531044, 14508, 3999, 116, 70, "Output",ExpressionUUID->"503d739f-d8ba-4da1-9df3-e29b5b6ffd92"],
Cell[535046, 14626, 4535, 122, 70, "Output",ExpressionUUID->"2105620c-69b8-44c1-a83b-3dba5b3f2925"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539618, 14753, 347, 8, 43, "Input",ExpressionUUID->"37245f5b-de3f-40a9-ab42-e3699a9ec001"],
Cell[539968, 14763, 4058, 119, 70, "Output",ExpressionUUID->"6dfc46fb-503f-4b8f-ba71-255042694856"]
}, Open  ]],
Cell[544041, 14885, 312, 7, 53, "Text",ExpressionUUID->"445ec3d9-749d-4ba4-938e-c94ae18c568f"],
Cell[CellGroupData[{
Cell[544378, 14896, 755, 16, 135, "Input",ExpressionUUID->"a470febf-6429-4e54-8924-8f2e6bfefac5"],
Cell[545136, 14914, 4545, 118, 70, "Output",ExpressionUUID->"74dc7dec-7716-4ad5-bdb9-d104abc1ed09"],
Cell[549684, 15034, 738, 12, 70, "Output",ExpressionUUID->"567ec422-2162-47ae-b286-725c7ee71121"]
}, Open  ]],
Cell[CellGroupData[{
Cell[550459, 15051, 668, 15, 75, "Input",ExpressionUUID->"fe3d45ee-0ace-4318-85ee-f5bc0472d124"],
Cell[551130, 15068, 528, 11, 70, "Output",ExpressionUUID->"0e73c359-e7cf-460c-b8b1-8610a1b8c3d5"],
Cell[551661, 15081, 3330, 88, 70, "Output",ExpressionUUID->"fd64be53-c59a-437f-9188-e7834468e6b8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555028, 15174, 2011, 57, 225, "Input",ExpressionUUID->"2b46e3ee-0d11-4883-9ed4-5f1e36b709a0"],
Cell[557042, 15233, 2508, 78, 70, "Output",ExpressionUUID->"db5a7bd9-ed16-46cd-adfe-273c647faf7f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[559587, 15316, 1763, 49, 165, "Input",ExpressionUUID->"70a196ce-c40c-432e-b5c8-fe19fe2c2aa9"],
Cell[561353, 15367, 547, 11, 70, "Message",ExpressionUUID->"6df21fd6-976f-4412-b7b6-1bd9c985f188"],
Cell[561903, 15380, 1297, 37, 70, "Output",ExpressionUUID->"4d037507-a8fa-4320-a5b4-d57451f7b5d9"],
Cell[563203, 15419, 416, 8, 70, "Output",ExpressionUUID->"9b0d305d-e3e6-49c4-ae1e-65bbe2c4d29d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[563656, 15432, 856, 18, 214, "Input",ExpressionUUID->"1ed6af5c-161d-4539-99e4-4a629a643cb4"],
Cell[564515, 15452, 4420, 129, 336, "Output",ExpressionUUID->"d27ec821-ecbc-43ac-bea0-087b8385b62f"],
Cell[568938, 15583, 2013, 55, 141, "Output",ExpressionUUID->"e3a48fd9-1a17-4a2e-bac2-53c6ef94badc"]
}, Open  ]],
Cell[570966, 15641, 551, 10, 73, "Text",ExpressionUUID->"6ec10eb1-7269-4267-9262-e9a6969dd920"],
Cell[CellGroupData[{
Cell[571542, 15655, 2035, 55, 98, "Input",ExpressionUUID->"1a802061-9805-4ce1-ad3f-ef7d30566b32"],
Cell[573580, 15712, 1298, 36, 81, "Output",ExpressionUUID->"eb283612-69e6-47e0-9ca7-4f5d46726269"]
}, Open  ]],
Cell[CellGroupData[{
Cell[574915, 15753, 442, 10, 39, "Input",ExpressionUUID->"82c7bcb1-bfb8-43c9-abac-d4d3b6ffef40"],
Cell[575360, 15765, 618, 14, 44, "Output",ExpressionUUID->"2ff832e2-6365-4833-a7e9-4467049e03cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[576015, 15784, 482, 11, 39, "Input",ExpressionUUID->"b3032765-6ac2-469a-ae2a-9a56a1087308"],
Cell[576500, 15797, 464, 9, 44, "Output",ExpressionUUID->"c1cc5b3b-2eba-48cb-a64d-d50b668ac2ec"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[577037, 15814, 245, 4, 84, "Section",ExpressionUUID->"8c789367-e10e-4c71-9577-593a70ec7fb7"],
Cell[CellGroupData[{
Cell[577307, 15822, 178, 3, 68, "Subsection",ExpressionUUID->"911318c2-21fb-4fdf-b357-72d0cccaeeb4"],
Cell[577488, 15827, 1778, 42, 69, "Input",ExpressionUUID->"d220060c-ef4a-4465-b201-64048b2864fa"],
Cell[CellGroupData[{
Cell[579291, 15873, 190, 4, 39, "Input",ExpressionUUID->"200503d4-d856-47a5-979c-c2931968cb53"],
Cell[579484, 15879, 652, 12, 44, "Output",ExpressionUUID->"d1886d58-c726-4a9b-a399-97e848fba255"]
}, Open  ]],
Cell[CellGroupData[{
Cell[580173, 15896, 501, 11, 39, "Input",ExpressionUUID->"62465093-aa44-4790-82fe-a3eba5a1bdc1"],
Cell[580677, 15909, 988, 20, 44, "Output",ExpressionUUID->"8d81c6ab-24c1-4de2-a53b-cf4bde58a8ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[581702, 15934, 616, 12, 39, "Input",ExpressionUUID->"42a586a8-810e-454d-9f5a-798a28c974bc"],
Cell[582321, 15948, 1035, 19, 44, "Output",ExpressionUUID->"00d01486-a7e4-4532-81be-51172f7caec1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[583393, 15972, 342, 7, 39, "Input",ExpressionUUID->"2f438e05-e88c-46d3-8c5d-e956faa27eee"],
Cell[583738, 15981, 586, 13, 44, "Output",ExpressionUUID->"06c55d6b-deba-465d-9533-6094ba628bb2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[584361, 15999, 168, 3, 57, "Subsubsection",ExpressionUUID->"7c2f35bb-a878-47df-bf30-a09e0e1347bd"],
Cell[584532, 16004, 268, 6, 44, "Text",ExpressionUUID->"ef418171-faac-47aa-97ee-b19ceec7cf69"],
Cell[CellGroupData[{
Cell[584825, 16014, 1730, 40, 98, "Input",ExpressionUUID->"6cc5ec64-9c7e-4db1-8daf-051d71a909ed"],
Cell[586558, 16056, 1065, 17, 44, "Output",ExpressionUUID->"bb8ff287-8acc-4678-b4ab-dd4ff009756b"],
Cell[587626, 16075, 1811, 42, 71, "Output",ExpressionUUID->"701ef3d9-b54f-4814-8adb-3f9ce9c4fb69"]
}, Open  ]],
Cell[589452, 16120, 212, 5, 44, "Text",ExpressionUUID->"b690f5b3-5b1c-4201-b4ef-c5a3580aa578"],
Cell[CellGroupData[{
Cell[589689, 16129, 1562, 34, 127, "Input",ExpressionUUID->"ea3117d1-5d7d-46c0-9c18-002484de9177"],
Cell[591254, 16165, 3130, 93, 189, "Output",ExpressionUUID->"6f22f543-feb9-4337-ab1d-261741b204e1"],
Cell[594387, 16260, 902, 20, 44, "Output",ExpressionUUID->"56b16aeb-9706-49d2-a7e3-b21585b3c68d"],
Cell[595292, 16282, 1016, 26, 71, "Output",ExpressionUUID->"c80438e9-c274-49af-a7a2-6b15c2fa15a1"]
}, Open  ]],
Cell[596323, 16311, 154, 3, 44, "Text",ExpressionUUID->"c336da3e-580b-4edf-86ac-d68935d8a894"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[596526, 16320, 173, 3, 47, "Subsection",ExpressionUUID->"a1057c38-5267-444a-bc57-6375bf3c51a3"],
Cell[596702, 16325, 2510, 67, 156, "Input",ExpressionUUID->"b19efd89-be3c-4b52-9342-1ce0e5d0a880"],
Cell[CellGroupData[{
Cell[599237, 16396, 239, 5, 39, "Input",ExpressionUUID->"52e0aaf5-e0fc-4e07-8b50-cd890673d58c"],
Cell[599479, 16403, 539, 10, 44, "Output",ExpressionUUID->"94fc53d8-7aba-44eb-8595-ebd681698c8c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600055, 16418, 604, 12, 39, "Input",ExpressionUUID->"be9e60ab-5c10-4e03-aae5-ede835ee0f46"],
Cell[600662, 16432, 891, 19, 44, "Output",ExpressionUUID->"17a3815e-07cb-4562-a964-7c27f33b53d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[601590, 16456, 638, 13, 39, "Input",ExpressionUUID->"0028dbd9-b579-4bcb-a591-233cf6bed596"],
Cell[602231, 16471, 1257, 33, 81, "Output",ExpressionUUID->"8dd08307-c9e6-4603-b7f0-0287bcb2b379"]
}, Open  ]],
Cell[CellGroupData[{
Cell[603525, 16509, 586, 15, 39, "Input",ExpressionUUID->"1f0821ce-db03-49cb-9ae6-84279a9af7d2"],
Cell[604114, 16526, 1201, 30, 75, "Output",ExpressionUUID->"372de600-f72d-46a5-8060-82a6c6893095"]
}, Open  ]],
Cell[CellGroupData[{
Cell[605352, 16561, 382, 11, 39, "Input",ExpressionUUID->"bdc4c98d-beff-4a9c-a37e-b84a86985410"],
Cell[605737, 16574, 495, 10, 48, "Output",ExpressionUUID->"469f9954-d6af-451c-897c-dfcfa02cc1c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[606269, 16589, 168, 3, 57, "Subsubsection",ExpressionUUID->"c3b70d19-df57-4a15-ac78-7ba6d556e32e"],
Cell[606440, 16594, 268, 6, 44, "Text",ExpressionUUID->"c8d56013-270d-441c-b40b-cc4ed2df4bad"],
Cell[CellGroupData[{
Cell[606733, 16604, 1828, 43, 98, "Input",ExpressionUUID->"11bf8711-d93b-4ecc-b705-c9b5a846eeef"],
Cell[608564, 16649, 1091, 17, 44, "Output",ExpressionUUID->"19b7ee3f-cd94-43f2-8ffc-2224f105a3e8"],
Cell[609658, 16668, 2020, 46, 113, "Output",ExpressionUUID->"62f2d67c-5275-4741-98e7-c753705faaeb"]
}, Open  ]],
Cell[611693, 16717, 212, 5, 44, "Text",ExpressionUUID->"e66a1656-85ca-4358-882f-538f7c9d964d"],
Cell[CellGroupData[{
Cell[611930, 16726, 1561, 34, 127, "Input",ExpressionUUID->"d2d30573-555b-4c2a-b2be-d1bebc6914d5"],
Cell[613494, 16762, 3276, 97, 189, "Output",ExpressionUUID->"f2210c2a-cabe-41e7-bc0a-3d8997d35ee7"],
Cell[616773, 16861, 926, 20, 44, "Output",ExpressionUUID->"b9988adb-90a6-4a2e-af36-d9a50229f682"],
Cell[617702, 16883, 992, 24, 71, "Output",ExpressionUUID->"22206749-f698-49c6-8126-b906d480c2fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[618731, 16912, 653, 17, 98, "Input",ExpressionUUID->"60ff9ee6-67b0-499d-ab28-f6e1e9ab7cbd"],
Cell[619387, 16931, 705, 19, 44, "Output",ExpressionUUID->"1af67588-1b92-4505-b553-027e4e676b58"],
Cell[620095, 16952, 510, 14, 48, "Output",ExpressionUUID->"3cd23989-ccb7-4673-9a6f-ce3e0424fded"]
}, Open  ]],
Cell[620620, 16969, 154, 3, 44, "Text",ExpressionUUID->"fba39d64-7589-4501-8c96-45113d407fa5"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[620835, 16979, 294, 5, 84, "Section",ExpressionUUID->"8b59e486-e928-4a5e-85ab-8abcca2c3d7b"],
Cell[CellGroupData[{
Cell[621154, 16988, 178, 3, 68, "Subsection",ExpressionUUID->"67895a5c-c9ed-4309-9dfa-b451d75c76c9"],
Cell[621335, 16993, 4097, 110, 243, "Input",ExpressionUUID->"858ed6e6-d5c5-4e6e-81c0-fa3ce8a787a8"],
Cell[CellGroupData[{
Cell[625457, 17107, 190, 4, 39, "Input",ExpressionUUID->"987e351d-36cd-4b0c-97ef-52cec0c42815"],
Cell[625650, 17113, 720, 13, 44, "Output",ExpressionUUID->"1d73740f-8089-4283-9a6d-15cc3f09681d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[626407, 17131, 499, 11, 39, "Input",ExpressionUUID->"0050ee0b-be3b-4026-b0d3-20392296fdff"],
Cell[626909, 17144, 1096, 21, 44, "Output",ExpressionUUID->"0de50107-7c74-42fe-a36d-256133696a5f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[628042, 17170, 1057, 22, 98, "Input",ExpressionUUID->"f275c6d5-d600-44c0-9f72-7382163a1b5f"],
Cell[629102, 17194, 1354, 30, 44, "Output",ExpressionUUID->"5fa22d36-b3c3-4a48-8316-cc32f3712d3e"],
Cell[630459, 17226, 1352, 30, 44, "Output",ExpressionUUID->"5df17830-e36d-4c63-a9b4-75d9b8681a2f"],
Cell[631814, 17258, 929, 15, 44, "Output",ExpressionUUID->"d94c9584-955e-42fb-957c-eef7f525a8ed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[632780, 17278, 168, 3, 57, "Subsubsection",ExpressionUUID->"12def57d-03cc-44bc-b901-a4d255bb10c1"],
Cell[632951, 17283, 268, 6, 44, "Text",ExpressionUUID->"08a54d79-eab4-48e3-99fe-b2d094353510"],
Cell[CellGroupData[{
Cell[633244, 17293, 2684, 69, 127, "Input",ExpressionUUID->"f3359186-b56c-4477-9357-509bcf8fb6cc"],
Cell[635931, 17364, 1163, 18, 44, "Output",ExpressionUUID->"39efe00b-c821-49c5-8658-92d25a321aa1"],
Cell[637097, 17384, 2945, 79, 165, "Output",ExpressionUUID->"263f6ccf-39a0-4a8d-a1c3-d589a6a23b19"]
}, Open  ]],
Cell[640057, 17466, 212, 5, 44, "Text",ExpressionUUID->"b6a37aed-19a5-431f-ad88-e238758ddd4b"],
Cell[CellGroupData[{
Cell[640294, 17475, 1051, 18, 39, "Input",ExpressionUUID->"ccedcb83-30f9-49b5-8ef0-bfbecbb6b2f5"],
Cell[641348, 17495, 7407, 227, 545, "Output",ExpressionUUID->"0d87cb4b-7414-493a-9484-5d9f26979bf7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[648792, 17727, 921, 27, 75, "Input",ExpressionUUID->"f4e38d51-48f8-4590-bab2-64feeaf0a10a"],
Cell[649716, 17756, 773, 22, 44, "Output",ExpressionUUID->"b5870223-af2f-4e2f-85d0-2069d280cc55"],
Cell[650492, 17780, 2853, 92, 189, "Output",ExpressionUUID->"757bd004-00df-42b3-a9b3-afb677650683"]
}, Open  ]],
Cell[CellGroupData[{
Cell[653382, 17877, 865, 26, 98, "Input",ExpressionUUID->"2a910d6c-8752-4910-b0b6-9be1174a6301"],
Cell[654250, 17905, 778, 22, 44, "Output",ExpressionUUID->"301b0a07-34b8-4e3b-818c-cca3d9a8d11d"],
Cell[655031, 17929, 537, 13, 44, "Output",ExpressionUUID->"e0e22b0d-f425-46b4-bc71-fb0a022b272e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[655605, 17947, 377, 8, 98, "Input",ExpressionUUID->"04b2cdca-7328-4925-8662-b4478867883b"],
Cell[655985, 17957, 1285, 37, 74, "Output",ExpressionUUID->"467b2803-a056-4921-b2a7-9f36f97cec50"],
Cell[657273, 17996, 854, 24, 44, "Output",ExpressionUUID->"7e7e0cf9-6e55-43a2-90ea-323bcf7ea0f7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[658164, 18025, 742, 21, 127, "Input",ExpressionUUID->"8225ef7e-9dba-48b0-9390-f672d1dd7ae1"],
Cell[658909, 18048, 618, 17, 44, "Output",ExpressionUUID->"061a015d-c953-49c0-8f5e-8022b597692a"],
Cell[659530, 18067, 509, 14, 44, "Output",ExpressionUUID->"d628ef0b-57ce-48f0-b5d8-7b1a75182e36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[660076, 18086, 815, 25, 39, "Input",ExpressionUUID->"cb0c83ed-7338-446c-a9e6-2fcfa7ff8282"],
Cell[660894, 18113, 687, 19, 44, "Output",ExpressionUUID->"1fc87efa-94b9-4235-a374-44129affaca0"]
}, Open  ]],
Cell[661596, 18135, 154, 3, 44, "Text",ExpressionUUID->"9538f964-4632-40d4-a12f-aef1306bd22a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[661799, 18144, 173, 3, 47, "Subsection",ExpressionUUID->"d242f314-dc20-4c9c-b7a6-fb42dc122b6c"],
Cell[661975, 18149, 7565, 223, 562, "Input",ExpressionUUID->"a87b6f5c-a7a0-4528-9de5-c3024f655422"],
Cell[669543, 18374, 1643, 40, 98, "Input",ExpressionUUID->"250205a7-b0b6-4f32-9663-879dd96a968a"],
Cell[CellGroupData[{
Cell[671211, 18418, 370, 7, 39, "Input",ExpressionUUID->"2f8e3ed5-7529-4bc1-a81b-b542276647fc"],
Cell[671584, 18427, 1499, 33, 48, "Output",ExpressionUUID->"f992edd1-1651-45bd-afa8-ca288760cbdb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[673120, 18465, 532, 13, 69, "Input",ExpressionUUID->"2ff46d12-d677-4c15-9346-7d248ae98a6c"],
Cell[673655, 18480, 1288, 31, 44, "Output",ExpressionUUID->"dda4bceb-2e50-4f63-85ee-ed4c0f80bb14"]
}, Open  ]],
Cell[CellGroupData[{
Cell[674980, 18516, 695, 14, 39, "Input",ExpressionUUID->"883c6ac5-c4fe-4408-a6e1-c926c7367f76"],
Cell[675678, 18532, 3464, 80, 147, "Output",ExpressionUUID->"5700acde-c1d1-4624-a021-fb34a5c9e68c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[679179, 18617, 680, 16, 69, "Input",ExpressionUUID->"ab4d1d3d-22fc-45cd-8be8-5d439f735322"],
Cell[679862, 18635, 2810, 75, 145, "Output",ExpressionUUID->"43b8c604-b46c-4b2f-bf2e-224b95c4a034"]
}, Open  ]],
Cell[CellGroupData[{
Cell[682709, 18715, 453, 11, 39, "Input",ExpressionUUID->"bb7e70a7-e933-4d60-8e26-5874b6adbd4d"],
Cell[683165, 18728, 1075, 25, 48, "Output",ExpressionUUID->"e0071225-c4a3-4ebb-a15d-82f693a99b98"]
}, Open  ]],
Cell[CellGroupData[{
Cell[684277, 18758, 168, 3, 57, "Subsubsection",ExpressionUUID->"ecc1482a-5d5c-420e-9d20-a94c1a3017e3"],
Cell[684448, 18763, 268, 6, 44, "Text",ExpressionUUID->"8c829642-3d8b-4992-ae35-eb6d7a90dc43"],
Cell[CellGroupData[{
Cell[684741, 18773, 2832, 84, 185, "Input",ExpressionUUID->"4f364dbc-7426-4304-bb98-b69e8bd3da30"],
Cell[687576, 18859, 1185, 18, 70, "Output",ExpressionUUID->"41b19d9f-ae0c-4d68-a008-6311b5197078"],
Cell[688764, 18879, 5424, 143, 70, "Output",ExpressionUUID->"d114441d-30cc-4415-b2d1-0da5e7e6aa72"]
}, Open  ]],
Cell[694203, 19025, 212, 5, 53, "Text",ExpressionUUID->"d9bd874d-0037-46fd-ac7c-1d13cd029477"],
Cell[CellGroupData[{
Cell[694440, 19034, 1101, 19, 43, "Input",ExpressionUUID->"147aced9-fa61-4885-8305-a479bb0103fa"],
Cell[695544, 19055, 12208, 354, 70, "Output",ExpressionUUID->"69c08f77-5675-45b5-938d-1946dad55f67"]
}, Open  ]],
Cell[CellGroupData[{
Cell[707789, 19414, 870, 26, 75, "Input",ExpressionUUID->"e137af1f-daf4-4c02-8096-177709390c32"],
Cell[708662, 19442, 778, 22, 70, "Output",ExpressionUUID->"08a08832-47e6-42a1-8813-5b74603556e8"],
Cell[709443, 19466, 7540, 216, 70, "Output",ExpressionUUID->"dfc35b7f-b722-4093-a3a9-f9987b979e94"]
}, Open  ]],
Cell[CellGroupData[{
Cell[717020, 19687, 985, 29, 105, "Input",ExpressionUUID->"12e9927a-62c3-40ee-9d80-c4727c681c9e"],
Cell[718008, 19718, 877, 25, 70, "Output",ExpressionUUID->"115d70f3-7a1f-4db6-a91f-078b3207c6f1"],
Cell[718888, 19745, 4281, 119, 70, "Output",ExpressionUUID->"be8cd907-d333-4d33-9cd8-81a3f8d19e88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[723206, 19869, 923, 26, 105, "Input",ExpressionUUID->"5ecb1190-87cb-4288-94b7-2204c111fe34"],
Cell[724132, 19897, 835, 23, 70, "Output",ExpressionUUID->"7e7494d4-2391-4aaa-bf5f-ea0f3b93698d"],
Cell[724970, 19922, 1592, 48, 70, "Output",ExpressionUUID->"df9d33c4-ff2c-407a-9e79-1fc26341f19e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[726599, 19975, 869, 24, 75, "Input",ExpressionUUID->"456877ab-9539-4d46-873d-4a4e76fefa51"],
Cell[727471, 20001, 1045, 32, 70, "Output",ExpressionUUID->"28a6192c-31d0-4561-803c-4b62b490be96"]
}, Open  ]],
Cell[CellGroupData[{
Cell[728553, 20038, 554, 13, 135, "Input",ExpressionUUID->"1e829b3b-1123-4566-a9aa-ee18a05015d3"],
Cell[729110, 20053, 2684, 81, 70, "Output",ExpressionUUID->"7cc8f4ca-66a4-4ac4-984c-aeb77fd89329"],
Cell[731797, 20136, 541, 13, 70, "Output",ExpressionUUID->"dd519b49-ae4c-4a1c-967e-5cf4094d5e1d"],
Cell[732341, 20151, 1955, 58, 70, "Output",ExpressionUUID->"cfa331ba-9a54-4d4d-b796-4b88559d4d4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[734333, 20214, 522, 13, 135, "Input",ExpressionUUID->"1abce8dd-3ce8-43c8-893b-61429c9cb511"],
Cell[734858, 20229, 2342, 70, 142, "Output",ExpressionUUID->"12d5771a-aaaa-485a-9270-8cf9bc52eb61"],
Cell[737203, 20301, 2022, 59, 140, "Output",ExpressionUUID->"7487e2b7-0d92-4061-9f3e-42c0ef811c77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[739262, 20365, 582, 17, 69, "Input",ExpressionUUID->"a36098e5-b634-407b-a92d-0be2bc7c6eba"],
Cell[739847, 20384, 468, 12, 44, "Output",ExpressionUUID->"7f058251-196d-46d7-9532-e5614ec9228d"],
Cell[740318, 20398, 1237, 33, 81, "Output",ExpressionUUID->"0ba9a16a-2438-4987-a085-23a2670ccb77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[741592, 20436, 673, 20, 69, "Input",ExpressionUUID->"48dce4a7-2a4d-4622-8608-2a34fe89520a"],
Cell[742268, 20458, 535, 15, 44, "Output",ExpressionUUID->"91129cb7-aa62-41d0-b1d7-c393b90fe42c"],
Cell[742806, 20475, 287, 6, 44, "Output",ExpressionUUID->"010140ce-7104-4d5c-ba55-826b330c237b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[743130, 20486, 598, 12, 156, "Input",ExpressionUUID->"8fb5a744-7fcb-469c-a809-a1e5932e7bae"],
Cell[743731, 20500, 2604, 77, 161, "Output",ExpressionUUID->"367ab4fa-991d-47d4-a24e-c793ad3af598"],
Cell[746338, 20579, 585, 15, 44, "Output",ExpressionUUID->"1de16f8f-94bc-47ce-b6ed-f741c69b52f9"]
}, Open  ]],
Cell[746938, 20597, 154, 3, 44, "Text",ExpressionUUID->"b84ddd68-79e4-4c14-aa3c-59ae86f1ba41"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[747153, 20607, 345, 6, 84, "Section",ExpressionUUID->"2ef28e9a-f480-4c1a-bda2-f6339bb0c2fd"],
Cell[CellGroupData[{
Cell[747523, 20617, 178, 3, 68, "Subsection",ExpressionUUID->"f75bb685-9bce-49a9-b8ab-0f907f56d99e"],
Cell[747704, 20622, 9242, 254, 736, "Input",ExpressionUUID->"753d4803-223c-4534-b553-a896f7e265f9"],
Cell[CellGroupData[{
Cell[756971, 20880, 190, 4, 39, "Input",ExpressionUUID->"7c6685bf-b55e-43be-bdf7-b2f96c85def6"],
Cell[757164, 20886, 854, 14, 44, "Output",ExpressionUUID->"e5d4b631-22ea-465d-968d-28b3eda1894a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[758055, 20905, 498, 11, 39, "Input",ExpressionUUID->"3c3b405a-6dfa-4827-8d81-d35865754ebe"],
Cell[758556, 20918, 1391, 26, 44, "Output",ExpressionUUID->"f6905a37-4a5b-4167-8e7b-4f5cb0923bc7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[759984, 20949, 1069, 21, 98, "Input",ExpressionUUID->"2ed611d9-f6a8-461e-81c2-b33b395eb0cd"],
Cell[761056, 20972, 1565, 32, 48, "Output",ExpressionUUID->"aef6f859-e73b-4bed-935f-31d503682688"],
Cell[762624, 21006, 1406, 27, 48, "Output",ExpressionUUID->"5e67881f-6040-4111-91af-78b5bce5944a"],
Cell[764033, 21035, 1188, 20, 48, "Output",ExpressionUUID->"0596968e-f868-4c23-873a-0e4361fb9d36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[765258, 21060, 168, 3, 57, "Subsubsection",ExpressionUUID->"f3a3a50d-f8fb-4012-8257-114bd4a9ce0d"],
Cell[765429, 21065, 268, 6, 44, "Text",ExpressionUUID->"a322f93a-c43d-477f-8e24-c54d55ed1043"],
Cell[CellGroupData[{
Cell[765722, 21075, 2634, 80, 185, "Input",ExpressionUUID->"de58da20-72c6-481d-a686-0c0fad1edb05"],
Cell[768359, 21157, 1258, 19, 44, "Output",ExpressionUUID->"2c0734cd-a1a9-4c7e-921f-072deea64a6f"],
Cell[769620, 21178, 3519, 95, 170, "Output",ExpressionUUID->"d1851fdb-ec46-41aa-9b45-093314c96a82"]
}, Open  ]],
Cell[773154, 21276, 212, 5, 44, "Text",ExpressionUUID->"0c27fdc8-d1ae-476a-87fa-558269998c50"],
Cell[CellGroupData[{
Cell[773391, 21285, 1100, 19, 39, "Input",ExpressionUUID->"0028fc13-f3ca-47a7-87f9-8eee41661932"],
Cell[774494, 21306, 10131, 318, 708, "Output",ExpressionUUID->"97e5eff7-990c-4360-8c12-2beaa6f9b1d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[784662, 21629, 928, 27, 98, "Input",ExpressionUUID->"e785b43a-84ee-455c-812d-5c76509b19f9"],
Cell[785593, 21658, 808, 22, 44, "Output",ExpressionUUID->"56e5fad3-936e-430b-a5c1-8d369c3bdc25"],
Cell[786404, 21682, 5374, 175, 331, "Output",ExpressionUUID->"41517269-61ad-40e5-b4cd-d47f40ff7330"]
}, Open  ]],
Cell[CellGroupData[{
Cell[791815, 21862, 823, 24, 98, "Input",ExpressionUUID->"072e9167-b307-4ade-b739-a298aa6dd705"],
Cell[792641, 21888, 680, 19, 44, "Output",ExpressionUUID->"2335aa6b-0b2f-459c-af02-694eca90fb49"],
Cell[793324, 21909, 3066, 99, 215, "Output",ExpressionUUID->"aded598e-f679-4d55-8826-3d96ba1a1ea4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[796427, 22013, 721, 21, 75, "Input",ExpressionUUID->"0211ca23-f59e-40da-b9c5-b2af112a4b2f"],
Cell[797151, 22036, 588, 16, 70, "Output",ExpressionUUID->"8a0e44e9-b497-4097-8633-dc23e7916fd5"],
Cell[797742, 22054, 568, 14, 70, "Output",ExpressionUUID->"bed7df99-558b-42d0-9c9b-44b02bfd45e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[798347, 22073, 569, 13, 135, "Input",ExpressionUUID->"02a032bb-216f-42a2-a75e-828ca128baf9"],
Cell[798919, 22088, 1484, 43, 70, "Output",ExpressionUUID->"2c521b7f-5ab4-4253-a2e1-aaccd1d97dc4"],
Cell[800406, 22133, 604, 14, 70, "Output",ExpressionUUID->"1eab934c-ea9d-4c28-b338-020a117d8e18"],
Cell[801013, 22149, 1083, 30, 70, "Output",ExpressionUUID->"c75feb1d-53ec-4663-9c4e-a59dbbae7af0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[802133, 22184, 616, 16, 135, "Input",ExpressionUUID->"ae89cfca-acd1-4050-a3df-4e14990349fa"],
Cell[802752, 22202, 784, 21, 48, "Output",ExpressionUUID->"b3e8d43c-b444-4cad-913e-8c2e7d6b2596"],
Cell[803539, 22225, 777, 19, 48, "Output",ExpressionUUID->"147d7747-ad16-4c41-b646-e608c2f16a17"]
}, Open  ]],
Cell[CellGroupData[{
Cell[804353, 22249, 748, 19, 127, "Input",ExpressionUUID->"cf765e0b-400d-47f5-9061-f50bbc3db957"],
Cell[805104, 22270, 520, 13, 44, "Output",ExpressionUUID->"f0230747-b42c-4880-9023-a475e7c766ab"],
Cell[805627, 22285, 1674, 49, 103, "Output",ExpressionUUID->"56f90566-0da6-4c2c-9a3d-6a7f4b6aa38a"],
Cell[807304, 22336, 798, 21, 48, "Output",ExpressionUUID->"e16ddf75-7753-4638-8750-628d15584772"]
}, Open  ]],
Cell[808117, 22360, 346, 7, 73, "Text",ExpressionUUID->"407731f0-79be-4729-a050-9e86c3a22756"],
Cell[808466, 22369, 2431, 56, 98, "Input",ExpressionUUID->"753d4803-223c-4534-b553-a896f7e265f9"],
Cell[CellGroupData[{
Cell[810922, 22429, 190, 4, 39, "Input",ExpressionUUID->"7c6685bf-b55e-43be-bdf7-b2f96c85def6"],
Cell[811115, 22435, 811, 14, 44, "Output",ExpressionUUID->"3b1342ce-6e6b-4fb7-8a61-76bc40e46f78"]
}, Open  ]],
Cell[CellGroupData[{
Cell[811963, 22454, 501, 11, 39, "Input",ExpressionUUID->"3c3b405a-6dfa-4827-8d81-d35865754ebe"],
Cell[812467, 22467, 1295, 24, 44, "Output",ExpressionUUID->"3e647bc4-2738-443d-87ad-e7ac98ce1f0c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[813799, 22496, 950, 19, 69, "Input",ExpressionUUID->"2ed611d9-f6a8-461e-81c2-b33b395eb0cd"],
Cell[814752, 22517, 1144, 21, 48, "Output",ExpressionUUID->"4520c067-b005-448e-ad04-769147c59795"],
Cell[815899, 22540, 1308, 25, 48, "Output",ExpressionUUID->"e7c4ed6a-d4c3-461e-af96-5ea09e1c9bcc"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[817268, 22572, 173, 3, 47, "Subsection",ExpressionUUID->"658f867a-63d8-4057-9eb9-92cc7a4c57a6"],
Cell[817444, 22577, 2356, 75, 214, "Input",ExpressionUUID->"2e66c63a-7faa-44ec-9725-4130ee784fdf"],
Cell[CellGroupData[{
Cell[819825, 22656, 3063, 88, 359, "Input",ExpressionUUID->"9f7d42f2-4667-4773-868f-3a14e97f3c08"],
Cell[822891, 22746, 292, 5, 44, "Output",ExpressionUUID->"27dea62b-bfb0-4a55-b3dd-0f35ccefe8a2"],
Cell[823186, 22753, 294, 5, 44, "Output",ExpressionUUID->"a0f03f91-f3fb-4ab0-b145-ea3ebbcc7328"],
Cell[823483, 22760, 292, 5, 44, "Output",ExpressionUUID->"5a57a247-3b67-4e28-8953-2e930e1f0392"],
Cell[823778, 22767, 294, 5, 44, "Output",ExpressionUUID->"11a8e9ef-1e80-442b-a11e-7bfb3b1203f0"]
}, Open  ]],
Cell[824087, 22775, 15829, 471, 1084, "Input",ExpressionUUID->"dc9db744-30ad-4248-a8e0-8fa31764dab1"],
Cell[839919, 23248, 300, 9, 39, "Input",ExpressionUUID->"a361654b-7ff3-4a74-ab59-3488c0146a18"],
Cell[CellGroupData[{
Cell[840244, 23261, 1777, 50, 127, "Input",ExpressionUUID->"27a386e6-9e02-4185-ab2e-b9f230668ecc"],
Cell[842024, 23313, 1373, 39, 95, "Output",ExpressionUUID->"955609a8-fed3-4f6a-94b9-41740d3a4fb2"]
}, Open  ]],
Cell[843412, 23355, 1644, 40, 98, "Input",ExpressionUUID->"2f2fc0d9-8fba-4594-92cd-a071509054b0"],
Cell[845059, 23397, 4026, 125, 243, "Input",ExpressionUUID->"faa61121-710c-4959-acd9-ad558cd484a4"],
Cell[CellGroupData[{
Cell[849110, 23526, 443, 9, 39, "Input",ExpressionUUID->"fa24ded1-c548-4a38-b0ab-8a50c1ae55f9"],
Cell[849556, 23537, 3376, 87, 114, "Output",ExpressionUUID->"05a19a46-9818-4ecf-9e56-ecd5e3cf7107"]
}, Open  ]],
Cell[852947, 23627, 169, 3, 44, "Text",ExpressionUUID->"e11c0549-226f-4c11-85b9-3c216bc0ae36"],
Cell[CellGroupData[{
Cell[853141, 23634, 1504, 33, 127, "Input",ExpressionUUID->"b45b7389-899d-477f-b5c6-8146a9df1612"],
Cell[854648, 23669, 1554, 31, 81, "Output",ExpressionUUID->"f53c2108-e90b-46bd-9cd1-894576f29477"],
Cell[856205, 23702, 1665, 33, 81, "Output",ExpressionUUID->"63547037-0b33-455c-bac1-b030433f2198"]
}, Open  ]],
Cell[CellGroupData[{
Cell[857907, 23740, 371, 8, 39, "Input",ExpressionUUID->"c71d8c5b-805f-4c4e-84f5-c0ba6354b571"],
Cell[858281, 23750, 792, 23, 74, "Output",ExpressionUUID->"193035b4-0a42-4a39-b342-5f151cdf7226"]
}, Open  ]],
Cell[CellGroupData[{
Cell[859110, 23778, 1571, 34, 185, "Input",ExpressionUUID->"3c26cd92-f705-441c-9aa9-b4187f354495"],
Cell[860684, 23814, 2291, 48, 140, "Output",ExpressionUUID->"435efd23-e3e0-4d2e-a210-fc9c0fdf8636"],
Cell[862978, 23864, 1979, 44, 103, "Output",ExpressionUUID->"acd2cf65-e96b-4f6a-8b72-6f344eca9105"]
}, Open  ]],
Cell[CellGroupData[{
Cell[864994, 23913, 168, 3, 57, "Subsubsection",ExpressionUUID->"5e740a43-c13c-405f-9ae3-5bd1a7b85798"],
Cell[865165, 23918, 268, 6, 44, "Text",ExpressionUUID->"b1b7c916-5c94-4da6-84db-9eb9b072cd31"],
Cell[CellGroupData[{
Cell[865458, 23928, 4314, 127, 272, "Input",ExpressionUUID->"94ae8dac-d805-4b8d-b2d1-459a801ec130"],
Cell[869775, 24057, 1291, 20, 44, "Output",ExpressionUUID->"355dfedf-eb68-48a4-b75e-09c9476a1465"],
Cell[871069, 24079, 13035, 341, 776, "Output",ExpressionUUID->"c2596883-1800-4502-95fa-a1a387f31af9"]
}, Open  ]],
Cell[884119, 24423, 212, 5, 44, "Text",ExpressionUUID->"c595d744-7018-4dcb-b511-9c9b6a241168"],
Cell[CellGroupData[{
Cell[884356, 24432, 1144, 20, 39, "Input",ExpressionUUID->"81382327-1c07-4ed1-8e02-a8df6ff49643"],
Cell[885503, 24454, 46417, 1225, 3324, "Output",ExpressionUUID->"ed02d2b9-cc3a-4aef-8dd0-55f6042ab9c8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[931957, 25684, 1075, 30, 127, "Input",ExpressionUUID->"bf4d2082-603f-49a1-af58-075b2a31d962"],
Cell[933035, 25716, 948, 26, 44, "Output",ExpressionUUID->"0079582d-d769-4453-b9b7-db80326acfd2"],
Cell[933986, 25744, 40817, 1064, 3088, "Output",ExpressionUUID->"077c8185-14ec-4a25-a714-86f1da1abab0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[974840, 26813, 7225, 186, 533, "Input",ExpressionUUID->"78f0fb9b-91f9-4f8d-9393-5cc794cb9ac3"],
Cell[982068, 27001, 572, 11, 28, "Message",ExpressionUUID->"3de1b9a1-61be-40f1-abce-7cdd3f440922"],
Cell[982643, 27014, 3488, 101, 258, "Output",ExpressionUUID->"0815354a-ab2d-4acb-9eef-8db2cac8f7db"],
Cell[986134, 27117, 16611, 432, 1203, "Output",ExpressionUUID->"9da06f68-05de-4c3d-b551-e3b4577a7030"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1002782, 27554, 5001, 131, 417, "Input",ExpressionUUID->"3bb23691-307d-4ffb-b9d0-d206de4809d8"],
Cell[1007786, 27687, 494, 10, 28, "Message",ExpressionUUID->"adbbc4d3-ca70-4db7-b9ee-e518fd5a0716"],
Cell[1008283, 27699, 3605, 113, 287, "Output",ExpressionUUID->"dd7743c8-0d74-4077-949a-1fb276ebee99"],
Cell[1011891, 27814, 612, 14, 44, "Output",ExpressionUUID->"5207bdf5-2b22-463e-8306-d8b630c7d6c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1012540, 27833, 685, 16, 156, "Input",ExpressionUUID->"a3e22c5e-5f88-4469-9a2c-3c00df85a9f4"],
Cell[1013228, 27851, 7293, 225, 510, "Output",ExpressionUUID->"d7c6a821-c38d-44bb-ab8f-d53b791b8092"],
Cell[1020524, 28078, 715, 16, 44, "Output",ExpressionUUID->"946ce3ce-10e2-492b-99fe-8e8b712ca0f1"],
Cell[1021242, 28096, 4279, 122, 254, "Output",ExpressionUUID->"d1a4b90d-0725-4af0-b802-c491369e50c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1025558, 28223, 365, 9, 69, "Input",ExpressionUUID->"25423bd6-33d9-4c33-a5de-92b407a3f2b8"],
Cell[1025926, 28234, 500, 13, 44, "Output",ExpressionUUID->"a66a9ce0-eea4-47e6-b302-f7ee18298144"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1026463, 28252, 605, 13, 98, "Input",ExpressionUUID->"1ddf7d7b-2388-4a1c-a85b-f570530c053b"],
Cell[1027071, 28267, 5337, 151, 232, "Output",ExpressionUUID->"d86f94a3-b829-4146-a42d-b60e47361b4c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1032445, 28423, 3044, 80, 272, "Input",ExpressionUUID->"09334d50-f8a7-45cf-afab-aa2ef270b9f5"],
Cell[1035492, 28505, 405, 9, 28, "Message",ExpressionUUID->"343631bb-1157-4d99-ab97-6afd5479a956"],
Cell[1035900, 28516, 1412, 45, 112, "Output",ExpressionUUID->"0fe2bd49-cc63-4d43-8979-4dcd9d7f12c3"],
Cell[1037315, 28563, 351, 7, 44, "Output",ExpressionUUID->"c0e25a09-3d14-410a-ab23-8db231d6f4eb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1037703, 28575, 548, 13, 69, "Input",ExpressionUUID->"188ad73b-c038-4e88-9fa0-e6ad9b4b7310"],
Cell[1038254, 28590, 8284, 261, 648, "Output",ExpressionUUID->"d02cc3fa-c9c9-446c-b5b6-c5bd99ded246"],
Cell[1046541, 28853, 1904, 56, 151, "Output",ExpressionUUID->"03d40278-5f15-4fd6-9566-b0f8450d90d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1048482, 28914, 190, 4, 39, "Input",ExpressionUUID->"7c6685bf-b55e-43be-bdf7-b2f96c85def6"],
Cell[1048675, 28920, 854, 14, 44, "Output",ExpressionUUID->"b6b89216-10c3-424d-ac66-479ba5945a36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1049566, 28939, 587, 12, 39, "Input",ExpressionUUID->"3c3b405a-6dfa-4827-8d81-d35865754ebe"],
Cell[1050156, 28953, 1370, 25, 44, "Output",ExpressionUUID->"dca511d7-c50d-424b-9eb0-9a25d42c3752"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1051563, 28983, 889, 17, 69, "Input",ExpressionUUID->"2ed611d9-f6a8-461e-81c2-b33b395eb0cd"],
Cell[1052455, 29002, 976, 15, 44, "Output",ExpressionUUID->"6bddba67-b936-468d-b5ff-f98d1c671e6a"],
Cell[1053434, 29019, 2059, 49, 140, "Output",ExpressionUUID->"0610e273-88a5-41f9-a390-d3334bed2e6e"]
}, Open  ]],
Cell[1055508, 29071, 322, 6, 73, "Text",ExpressionUUID->"94dd3166-4be6-43ad-9181-5e78715993b9"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

